/* Generated from core.scm by the CHICKEN compiler
   http://www.call-cc.org
   Version 5.4.0rc1 (prerelease) (rev bc191a47)
   linux-unix-gnu-x86-64 [ 64bit dload ptables ]
   command line: core.scm -optimize-level 2 -include-path . -include-path ./ -inline -ignore-repository -feature chicken-bootstrap -no-warnings -specialize -consult-types-file ./types.db -no-lambda-info -no-trace -emit-import-library chicken.compiler.core -output-file core.c
   unit: compiler
   uses: expand data-structures pathname internal extras file eval support scrutinizer library
*/
#include "chicken.h"

static C_word code_817() { C_clear_trace_buffer();
; return C_SCHEME_UNDEFINED; }


static C_PTABLE_ENTRY *create_ptable(void);
C_noret_decl(C_expand_toplevel)
C_externimport void C_ccall C_expand_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_data_2dstructures_toplevel)
C_externimport void C_ccall C_data_2dstructures_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_pathname_toplevel)
C_externimport void C_ccall C_pathname_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_internal_toplevel)
C_externimport void C_ccall C_internal_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_extras_toplevel)
C_externimport void C_ccall C_extras_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_file_toplevel)
C_externimport void C_ccall C_file_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_eval_toplevel)
C_externimport void C_ccall C_eval_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_support_toplevel)
C_externimport void C_ccall C_support_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_scrutinizer_toplevel)
C_externimport void C_ccall C_scrutinizer_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(C_library_toplevel)
C_externimport void C_ccall C_library_toplevel(C_word c,C_word *av) C_noret;

static C_TLS C_word lf[716];
static double C_possibly_force_alignment;


C_noret_decl(f24688)
static void C_ccall f24688(C_word c,C_word *av) C_noret;
C_noret_decl(f25357)
static void C_ccall f25357(C_word c,C_word *av) C_noret;
C_noret_decl(f_10002)
static void C_ccall f_10002(C_word c,C_word *av) C_noret;
C_noret_decl(f_10006)
static C_word C_fcall f_10006(C_word t0,C_word t1);
C_noret_decl(f_10025)
static void C_ccall f_10025(C_word c,C_word *av) C_noret;
C_noret_decl(f_10029)
static void C_ccall f_10029(C_word c,C_word *av) C_noret;
C_noret_decl(f_10033)
static void C_ccall f_10033(C_word c,C_word *av) C_noret;
C_noret_decl(f_10036)
static void C_ccall f_10036(C_word c,C_word *av) C_noret;
C_noret_decl(f_10042)
static void C_ccall f_10042(C_word c,C_word *av) C_noret;
C_noret_decl(f_10050)
static void C_ccall f_10050(C_word c,C_word *av) C_noret;
C_noret_decl(f_10056)
static void C_ccall f_10056(C_word c,C_word *av) C_noret;
C_noret_decl(f_10060)
static void C_ccall f_10060(C_word c,C_word *av) C_noret;
C_noret_decl(f_10063)
static void C_ccall f_10063(C_word c,C_word *av) C_noret;
C_noret_decl(f_10066)
static C_word C_fcall f_10066(C_word t0,C_word t1);
C_noret_decl(f_10091)
static void C_ccall f_10091(C_word c,C_word *av) C_noret;
C_noret_decl(f_10093)
static void C_fcall f_10093(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10134)
static void C_ccall f_10134(C_word c,C_word *av) C_noret;
C_noret_decl(f_10137)
static void C_ccall f_10137(C_word c,C_word *av) C_noret;
C_noret_decl(f_10140)
static void C_fcall f_10140(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10143)
static void C_ccall f_10143(C_word c,C_word *av) C_noret;
C_noret_decl(f_10146)
static void C_ccall f_10146(C_word c,C_word *av) C_noret;
C_noret_decl(f_10149)
static void C_ccall f_10149(C_word c,C_word *av) C_noret;
C_noret_decl(f_10152)
static void C_ccall f_10152(C_word c,C_word *av) C_noret;
C_noret_decl(f_10174)
static void C_ccall f_10174(C_word c,C_word *av) C_noret;
C_noret_decl(f_10178)
static void C_ccall f_10178(C_word c,C_word *av) C_noret;
C_noret_decl(f_10182)
static void C_ccall f_10182(C_word c,C_word *av) C_noret;
C_noret_decl(f_10196)
static void C_ccall f_10196(C_word c,C_word *av) C_noret;
C_noret_decl(f_10227)
static void C_ccall f_10227(C_word c,C_word *av) C_noret;
C_noret_decl(f_10249)
static void C_ccall f_10249(C_word c,C_word *av) C_noret;
C_noret_decl(f_10252)
static void C_fcall f_10252(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10255)
static void C_ccall f_10255(C_word c,C_word *av) C_noret;
C_noret_decl(f_10303)
static void C_ccall f_10303(C_word c,C_word *av) C_noret;
C_noret_decl(f_10307)
static void C_ccall f_10307(C_word c,C_word *av) C_noret;
C_noret_decl(f_10311)
static void C_ccall f_10311(C_word c,C_word *av) C_noret;
C_noret_decl(f_10319)
static void C_ccall f_10319(C_word c,C_word *av) C_noret;
C_noret_decl(f_10329)
static void C_fcall f_10329(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10333)
static void C_ccall f_10333(C_word c,C_word *av) C_noret;
C_noret_decl(f_10336)
static void C_ccall f_10336(C_word c,C_word *av) C_noret;
C_noret_decl(f_10343)
static void C_fcall f_10343(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10347)
static void C_ccall f_10347(C_word c,C_word *av) C_noret;
C_noret_decl(f_10357)
static void C_ccall f_10357(C_word c,C_word *av) C_noret;
C_noret_decl(f_10361)
static void C_ccall f_10361(C_word c,C_word *av) C_noret;
C_noret_decl(f_10365)
static void C_ccall f_10365(C_word c,C_word *av) C_noret;
C_noret_decl(f_10386)
static void C_ccall f_10386(C_word c,C_word *av) C_noret;
C_noret_decl(f_10389)
static void C_ccall f_10389(C_word c,C_word *av) C_noret;
C_noret_decl(f_10397)
static void C_ccall f_10397(C_word c,C_word *av) C_noret;
C_noret_decl(f_10419)
static void C_fcall f_10419(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10429)
static void C_ccall f_10429(C_word c,C_word *av) C_noret;
C_noret_decl(f_10442)
static void C_ccall f_10442(C_word c,C_word *av) C_noret;
C_noret_decl(f_10450)
static void C_ccall f_10450(C_word c,C_word *av) C_noret;
C_noret_decl(f_10456)
static void C_ccall f_10456(C_word c,C_word *av) C_noret;
C_noret_decl(f_10478)
static void C_fcall f_10478(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10488)
static void C_ccall f_10488(C_word c,C_word *av) C_noret;
C_noret_decl(f_10501)
static void C_fcall f_10501(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10526)
static void C_ccall f_10526(C_word c,C_word *av) C_noret;
C_noret_decl(f_10552)
static void C_ccall f_10552(C_word c,C_word *av) C_noret;
C_noret_decl(f_10556)
static void C_ccall f_10556(C_word c,C_word *av) C_noret;
C_noret_decl(f_10561)
static void C_ccall f_10561(C_word c,C_word *av) C_noret;
C_noret_decl(f_10566)
static void C_ccall f_10566(C_word c,C_word *av) C_noret;
C_noret_decl(f_10572)
static void C_ccall f_10572(C_word c,C_word *av) C_noret;
C_noret_decl(f_10585)
static void C_ccall f_10585(C_word c,C_word *av) C_noret;
C_noret_decl(f_10614)
static void C_ccall f_10614(C_word c,C_word *av) C_noret;
C_noret_decl(f_10626)
static void C_ccall f_10626(C_word c,C_word *av) C_noret;
C_noret_decl(f_10628)
static void C_ccall f_10628(C_word c,C_word *av) C_noret;
C_noret_decl(f_10642)
static void C_fcall f_10642(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10667)
static void C_ccall f_10667(C_word c,C_word *av) C_noret;
C_noret_decl(f_10683)
static void C_ccall f_10683(C_word c,C_word *av) C_noret;
C_noret_decl(f_10692)
static void C_fcall f_10692(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10695)
static void C_ccall f_10695(C_word c,C_word *av) C_noret;
C_noret_decl(f_10698)
static void C_ccall f_10698(C_word c,C_word *av) C_noret;
C_noret_decl(f_10701)
static void C_ccall f_10701(C_word c,C_word *av) C_noret;
C_noret_decl(f_10704)
static void C_ccall f_10704(C_word c,C_word *av) C_noret;
C_noret_decl(f_10707)
static void C_ccall f_10707(C_word c,C_word *av) C_noret;
C_noret_decl(f_10710)
static void C_fcall f_10710(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10717)
static void C_ccall f_10717(C_word c,C_word *av) C_noret;
C_noret_decl(f_10725)
static void C_ccall f_10725(C_word c,C_word *av) C_noret;
C_noret_decl(f_10731)
static void C_fcall f_10731(C_word t0,C_word t1) C_noret;
C_noret_decl(f_10734)
static void C_ccall f_10734(C_word c,C_word *av) C_noret;
C_noret_decl(f_10737)
static void C_ccall f_10737(C_word c,C_word *av) C_noret;
C_noret_decl(f_10742)
static void C_ccall f_10742(C_word c,C_word *av) C_noret;
C_noret_decl(f_10746)
static void C_ccall f_10746(C_word c,C_word *av) C_noret;
C_noret_decl(f_10749)
static void C_ccall f_10749(C_word c,C_word *av) C_noret;
C_noret_decl(f_10753)
static void C_ccall f_10753(C_word c,C_word *av) C_noret;
C_noret_decl(f_10757)
static void C_ccall f_10757(C_word c,C_word *av) C_noret;
C_noret_decl(f_10760)
static void C_ccall f_10760(C_word c,C_word *av) C_noret;
C_noret_decl(f_10763)
static void C_ccall f_10763(C_word c,C_word *av) C_noret;
C_noret_decl(f_10772)
static void C_ccall f_10772(C_word c,C_word *av) C_noret;
C_noret_decl(f_10777)
static void C_fcall f_10777(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10784)
static void C_ccall f_10784(C_word c,C_word *av) C_noret;
C_noret_decl(f_10792)
static void C_fcall f_10792(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10817)
static void C_ccall f_10817(C_word c,C_word *av) C_noret;
C_noret_decl(f_10830)
static void C_ccall f_10830(C_word c,C_word *av) C_noret;
C_noret_decl(f_10834)
static void C_ccall f_10834(C_word c,C_word *av) C_noret;
C_noret_decl(f_10837)
static void C_ccall f_10837(C_word c,C_word *av) C_noret;
C_noret_decl(f_10840)
static void C_ccall f_10840(C_word c,C_word *av) C_noret;
C_noret_decl(f_10843)
static void C_ccall f_10843(C_word c,C_word *av) C_noret;
C_noret_decl(f_10862)
static void C_ccall f_10862(C_word c,C_word *av) C_noret;
C_noret_decl(f_10865)
static void C_ccall f_10865(C_word c,C_word *av) C_noret;
C_noret_decl(f_10875)
static void C_ccall f_10875(C_word c,C_word *av) C_noret;
C_noret_decl(f_10877)
static void C_fcall f_10877(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_10888)
static void C_ccall f_10888(C_word c,C_word *av) C_noret;
C_noret_decl(f_10902)
static void C_ccall f_10902(C_word c,C_word *av) C_noret;
C_noret_decl(f_10906)
static void C_ccall f_10906(C_word c,C_word *av) C_noret;
C_noret_decl(f_10909)
static void C_ccall f_10909(C_word c,C_word *av) C_noret;
C_noret_decl(f_10912)
static void C_ccall f_10912(C_word c,C_word *av) C_noret;
C_noret_decl(f_10915)
static void C_ccall f_10915(C_word c,C_word *av) C_noret;
C_noret_decl(f_10919)
static void C_ccall f_10919(C_word c,C_word *av) C_noret;
C_noret_decl(f_10923)
static void C_ccall f_10923(C_word c,C_word *av) C_noret;
C_noret_decl(f_10927)
static void C_ccall f_10927(C_word c,C_word *av) C_noret;
C_noret_decl(f_10931)
static void C_ccall f_10931(C_word c,C_word *av) C_noret;
C_noret_decl(f_10934)
static void C_ccall f_10934(C_word c,C_word *av) C_noret;
C_noret_decl(f_10937)
static void C_ccall f_10937(C_word c,C_word *av) C_noret;
C_noret_decl(f_10940)
static void C_ccall f_10940(C_word c,C_word *av) C_noret;
C_noret_decl(f_10943)
static void C_ccall f_10943(C_word c,C_word *av) C_noret;
C_noret_decl(f_10958)
static void C_ccall f_10958(C_word c,C_word *av) C_noret;
C_noret_decl(f_10964)
static void C_ccall f_10964(C_word c,C_word *av) C_noret;
C_noret_decl(f_10974)
static void C_fcall f_10974(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_10984)
static void C_ccall f_10984(C_word c,C_word *av) C_noret;
C_noret_decl(f_10989)
static void C_ccall f_10989(C_word c,C_word *av) C_noret;
C_noret_decl(f_10995)
static void C_ccall f_10995(C_word c,C_word *av) C_noret;
C_noret_decl(f_11001)
static void C_ccall f_11001(C_word c,C_word *av) C_noret;
C_noret_decl(f_11005)
static void C_ccall f_11005(C_word c,C_word *av) C_noret;
C_noret_decl(f_11010)
static void C_ccall f_11010(C_word c,C_word *av) C_noret;
C_noret_decl(f_11012)
static void C_fcall f_11012(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11016)
static void C_ccall f_11016(C_word c,C_word *av) C_noret;
C_noret_decl(f_11021)
static void C_ccall f_11021(C_word c,C_word *av) C_noret;
C_noret_decl(f_11034)
static void C_ccall f_11034(C_word c,C_word *av) C_noret;
C_noret_decl(f_11040)
static void C_ccall f_11040(C_word c,C_word *av) C_noret;
C_noret_decl(f_11046)
static void C_ccall f_11046(C_word c,C_word *av) C_noret;
C_noret_decl(f_11047)
static void C_fcall f_11047(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11053)
static void C_ccall f_11053(C_word c,C_word *av) C_noret;
C_noret_decl(f_11064)
static void C_ccall f_11064(C_word c,C_word *av) C_noret;
C_noret_decl(f_11079)
static void C_ccall f_11079(C_word c,C_word *av) C_noret;
C_noret_decl(f_11083)
static void C_ccall f_11083(C_word c,C_word *av) C_noret;
C_noret_decl(f_11087)
static void C_ccall f_11087(C_word c,C_word *av) C_noret;
C_noret_decl(f_11090)
static void C_ccall f_11090(C_word c,C_word *av) C_noret;
C_noret_decl(f_11093)
static void C_ccall f_11093(C_word c,C_word *av) C_noret;
C_noret_decl(f_11096)
static void C_ccall f_11096(C_word c,C_word *av) C_noret;
C_noret_decl(f_11099)
static void C_ccall f_11099(C_word c,C_word *av) C_noret;
C_noret_decl(f_11102)
static void C_ccall f_11102(C_word c,C_word *av) C_noret;
C_noret_decl(f_11105)
static void C_ccall f_11105(C_word c,C_word *av) C_noret;
C_noret_decl(f_11108)
static void C_ccall f_11108(C_word c,C_word *av) C_noret;
C_noret_decl(f_11115)
static void C_ccall f_11115(C_word c,C_word *av) C_noret;
C_noret_decl(f_11125)
static void C_ccall f_11125(C_word c,C_word *av) C_noret;
C_noret_decl(f_11129)
static void C_fcall f_11129(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11142)
static void C_fcall f_11142(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11153)
static C_word C_fcall f_11153(C_word t0);
C_noret_decl(f_11178)
static void C_ccall f_11178(C_word c,C_word *av) C_noret;
C_noret_decl(f_11186)
static void C_fcall f_11186(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11211)
static void C_ccall f_11211(C_word c,C_word *av) C_noret;
C_noret_decl(f_11259)
static void C_ccall f_11259(C_word c,C_word *av) C_noret;
C_noret_decl(f_11262)
static void C_ccall f_11262(C_word c,C_word *av) C_noret;
C_noret_decl(f_11265)
static void C_ccall f_11265(C_word c,C_word *av) C_noret;
C_noret_decl(f_11271)
static void C_ccall f_11271(C_word c,C_word *av) C_noret;
C_noret_decl(f_11274)
static void C_ccall f_11274(C_word c,C_word *av) C_noret;
C_noret_decl(f_11279)
static void C_ccall f_11279(C_word c,C_word *av) C_noret;
C_noret_decl(f_11283)
static void C_ccall f_11283(C_word c,C_word *av) C_noret;
C_noret_decl(f_11287)
static void C_ccall f_11287(C_word c,C_word *av) C_noret;
C_noret_decl(f_11290)
static void C_ccall f_11290(C_word c,C_word *av) C_noret;
C_noret_decl(f_11296)
static void C_ccall f_11296(C_word c,C_word *av) C_noret;
C_noret_decl(f_11304)
static void C_ccall f_11304(C_word c,C_word *av) C_noret;
C_noret_decl(f_11308)
static void C_ccall f_11308(C_word c,C_word *av) C_noret;
C_noret_decl(f_11310)
static void C_ccall f_11310(C_word c,C_word *av) C_noret;
C_noret_decl(f_11314)
static void C_ccall f_11314(C_word c,C_word *av) C_noret;
C_noret_decl(f_11317)
static void C_ccall f_11317(C_word c,C_word *av) C_noret;
C_noret_decl(f_11322)
static void C_ccall f_11322(C_word c,C_word *av) C_noret;
C_noret_decl(f_11324)
static void C_fcall f_11324(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11349)
static void C_ccall f_11349(C_word c,C_word *av) C_noret;
C_noret_decl(f_11368)
static void C_ccall f_11368(C_word c,C_word *av) C_noret;
C_noret_decl(f_11371)
static void C_ccall f_11371(C_word c,C_word *av) C_noret;
C_noret_decl(f_11374)
static void C_ccall f_11374(C_word c,C_word *av) C_noret;
C_noret_decl(f_11377)
static void C_ccall f_11377(C_word c,C_word *av) C_noret;
C_noret_decl(f_11384)
static void C_ccall f_11384(C_word c,C_word *av) C_noret;
C_noret_decl(f_11387)
static void C_ccall f_11387(C_word c,C_word *av) C_noret;
C_noret_decl(f_11393)
static void C_ccall f_11393(C_word c,C_word *av) C_noret;
C_noret_decl(f_11396)
static void C_ccall f_11396(C_word c,C_word *av) C_noret;
C_noret_decl(f_11399)
static void C_ccall f_11399(C_word c,C_word *av) C_noret;
C_noret_decl(f_11414)
static void C_ccall f_11414(C_word c,C_word *av) C_noret;
C_noret_decl(f_11417)
static void C_ccall f_11417(C_word c,C_word *av) C_noret;
C_noret_decl(f_11423)
static void C_ccall f_11423(C_word c,C_word *av) C_noret;
C_noret_decl(f_11430)
static void C_fcall f_11430(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11437)
static void C_ccall f_11437(C_word c,C_word *av) C_noret;
C_noret_decl(f_11460)
static void C_ccall f_11460(C_word c,C_word *av) C_noret;
C_noret_decl(f_11472)
static void C_ccall f_11472(C_word c,C_word *av) C_noret;
C_noret_decl(f_11482)
static void C_fcall f_11482(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11489)
static void C_ccall f_11489(C_word c,C_word *av) C_noret;
C_noret_decl(f_11516)
static void C_ccall f_11516(C_word c,C_word *av) C_noret;
C_noret_decl(f_11524)
static void C_ccall f_11524(C_word c,C_word *av) C_noret;
C_noret_decl(f_11530)
static void C_ccall f_11530(C_word c,C_word *av) C_noret;
C_noret_decl(f_11537)
static void C_ccall f_11537(C_word c,C_word *av) C_noret;
C_noret_decl(f_11548)
static void C_ccall f_11548(C_word c,C_word *av) C_noret;
C_noret_decl(f_11551)
static void C_ccall f_11551(C_word c,C_word *av) C_noret;
C_noret_decl(f_11554)
static void C_fcall f_11554(C_word t0,C_word t1) C_noret;
C_noret_decl(f_11560)
static void C_ccall f_11560(C_word c,C_word *av) C_noret;
C_noret_decl(f_11563)
static void C_ccall f_11563(C_word c,C_word *av) C_noret;
C_noret_decl(f_11569)
static void C_ccall f_11569(C_word c,C_word *av) C_noret;
C_noret_decl(f_11576)
static void C_ccall f_11576(C_word c,C_word *av) C_noret;
C_noret_decl(f_11580)
static void C_ccall f_11580(C_word c,C_word *av) C_noret;
C_noret_decl(f_11586)
static void C_ccall f_11586(C_word c,C_word *av) C_noret;
C_noret_decl(f_11589)
static void C_ccall f_11589(C_word c,C_word *av) C_noret;
C_noret_decl(f_11592)
static void C_ccall f_11592(C_word c,C_word *av) C_noret;
C_noret_decl(f_11595)
static void C_ccall f_11595(C_word c,C_word *av) C_noret;
C_noret_decl(f_11598)
static void C_ccall f_11598(C_word c,C_word *av) C_noret;
C_noret_decl(f_11602)
static void C_ccall f_11602(C_word c,C_word *av) C_noret;
C_noret_decl(f_11605)
static void C_ccall f_11605(C_word c,C_word *av) C_noret;
C_noret_decl(f_11611)
static void C_ccall f_11611(C_word c,C_word *av) C_noret;
C_noret_decl(f_11614)
static void C_ccall f_11614(C_word c,C_word *av) C_noret;
C_noret_decl(f_11617)
static void C_ccall f_11617(C_word c,C_word *av) C_noret;
C_noret_decl(f_11633)
static void C_ccall f_11633(C_word c,C_word *av) C_noret;
C_noret_decl(f_11639)
static void C_ccall f_11639(C_word c,C_word *av) C_noret;
C_noret_decl(f_11642)
static void C_ccall f_11642(C_word c,C_word *av) C_noret;
C_noret_decl(f_11645)
static void C_ccall f_11645(C_word c,C_word *av) C_noret;
C_noret_decl(f_11648)
static void C_ccall f_11648(C_word c,C_word *av) C_noret;
C_noret_decl(f_11651)
static void C_ccall f_11651(C_word c,C_word *av) C_noret;
C_noret_decl(f_11655)
static void C_ccall f_11655(C_word c,C_word *av) C_noret;
C_noret_decl(f_11658)
static void C_ccall f_11658(C_word c,C_word *av) C_noret;
C_noret_decl(f_11664)
static void C_ccall f_11664(C_word c,C_word *av) C_noret;
C_noret_decl(f_11667)
static void C_ccall f_11667(C_word c,C_word *av) C_noret;
C_noret_decl(f_11670)
static void C_ccall f_11670(C_word c,C_word *av) C_noret;
C_noret_decl(f_11677)
static void C_ccall f_11677(C_word c,C_word *av) C_noret;
C_noret_decl(f_11681)
static void C_ccall f_11681(C_word c,C_word *av) C_noret;
C_noret_decl(f_11704)
static void C_ccall f_11704(C_word c,C_word *av) C_noret;
C_noret_decl(f_11717)
static void C_ccall f_11717(C_word c,C_word *av) C_noret;
C_noret_decl(f_11723)
static void C_ccall f_11723(C_word c,C_word *av) C_noret;
C_noret_decl(f_11726)
static void C_ccall f_11726(C_word c,C_word *av) C_noret;
C_noret_decl(f_11729)
static void C_ccall f_11729(C_word c,C_word *av) C_noret;
C_noret_decl(f_11732)
static void C_ccall f_11732(C_word c,C_word *av) C_noret;
C_noret_decl(f_11735)
static void C_ccall f_11735(C_word c,C_word *av) C_noret;
C_noret_decl(f_11739)
static void C_ccall f_11739(C_word c,C_word *av) C_noret;
C_noret_decl(f_11742)
static void C_ccall f_11742(C_word c,C_word *av) C_noret;
C_noret_decl(f_11748)
static void C_ccall f_11748(C_word c,C_word *av) C_noret;
C_noret_decl(f_11751)
static void C_ccall f_11751(C_word c,C_word *av) C_noret;
C_noret_decl(f_11754)
static void C_ccall f_11754(C_word c,C_word *av) C_noret;
C_noret_decl(f_11783)
static void C_fcall f_11783(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11791)
static void C_ccall f_11791(C_word c,C_word *av) C_noret;
C_noret_decl(f_11799)
static void C_ccall f_11799(C_word c,C_word *av) C_noret;
C_noret_decl(f_11801)
static void C_fcall f_11801(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11826)
static void C_ccall f_11826(C_word c,C_word *av) C_noret;
C_noret_decl(f_11850)
static void C_ccall f_11850(C_word c,C_word *av) C_noret;
C_noret_decl(f_11854)
static void C_ccall f_11854(C_word c,C_word *av) C_noret;
C_noret_decl(f_11888)
static void C_ccall f_11888(C_word c,C_word *av) C_noret;
C_noret_decl(f_11892)
static void C_ccall f_11892(C_word c,C_word *av) C_noret;
C_noret_decl(f_11898)
static void C_fcall f_11898(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_11923)
static void C_ccall f_11923(C_word c,C_word *av) C_noret;
C_noret_decl(f_11947)
static void C_ccall f_11947(C_word c,C_word *av) C_noret;
C_noret_decl(f_11968)
static void C_ccall f_11968(C_word c,C_word *av) C_noret;
C_noret_decl(f_11972)
static void C_ccall f_11972(C_word c,C_word *av) C_noret;
C_noret_decl(f_11995)
static void C_ccall f_11995(C_word c,C_word *av) C_noret;
C_noret_decl(f_12010)
static void C_ccall f_12010(C_word c,C_word *av) C_noret;
C_noret_decl(f_12033)
static void C_ccall f_12033(C_word c,C_word *av) C_noret;
C_noret_decl(f_12037)
static void C_fcall f_12037(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12055)
static void C_ccall f_12055(C_word c,C_word *av) C_noret;
C_noret_decl(f_12062)
static void C_ccall f_12062(C_word c,C_word *av) C_noret;
C_noret_decl(f_12066)
static void C_ccall f_12066(C_word c,C_word *av) C_noret;
C_noret_decl(f_12081)
static void C_ccall f_12081(C_word c,C_word *av) C_noret;
C_noret_decl(f_12094)
static void C_ccall f_12094(C_word c,C_word *av) C_noret;
C_noret_decl(f_12107)
static void C_ccall f_12107(C_word c,C_word *av) C_noret;
C_noret_decl(f_12120)
static void C_ccall f_12120(C_word c,C_word *av) C_noret;
C_noret_decl(f_12133)
static void C_ccall f_12133(C_word c,C_word *av) C_noret;
C_noret_decl(f_12142)
static void C_ccall f_12142(C_word c,C_word *av) C_noret;
C_noret_decl(f_12145)
static void C_ccall f_12145(C_word c,C_word *av) C_noret;
C_noret_decl(f_12148)
static void C_ccall f_12148(C_word c,C_word *av) C_noret;
C_noret_decl(f_12189)
static void C_ccall f_12189(C_word c,C_word *av) C_noret;
C_noret_decl(f_12195)
static void C_ccall f_12195(C_word c,C_word *av) C_noret;
C_noret_decl(f_12204)
static void C_ccall f_12204(C_word c,C_word *av) C_noret;
C_noret_decl(f_12207)
static void C_ccall f_12207(C_word c,C_word *av) C_noret;
C_noret_decl(f_12210)
static void C_ccall f_12210(C_word c,C_word *av) C_noret;
C_noret_decl(f_12213)
static void C_ccall f_12213(C_word c,C_word *av) C_noret;
C_noret_decl(f_12216)
static void C_ccall f_12216(C_word c,C_word *av) C_noret;
C_noret_decl(f_12219)
static void C_ccall f_12219(C_word c,C_word *av) C_noret;
C_noret_decl(f_12222)
static void C_ccall f_12222(C_word c,C_word *av) C_noret;
C_noret_decl(f_12225)
static void C_ccall f_12225(C_word c,C_word *av) C_noret;
C_noret_decl(f_12228)
static void C_ccall f_12228(C_word c,C_word *av) C_noret;
C_noret_decl(f_12243)
static void C_fcall f_12243(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12263)
static void C_ccall f_12263(C_word c,C_word *av) C_noret;
C_noret_decl(f_12267)
static void C_ccall f_12267(C_word c,C_word *av) C_noret;
C_noret_decl(f_12270)
static void C_ccall f_12270(C_word c,C_word *av) C_noret;
C_noret_decl(f_12277)
static void C_ccall f_12277(C_word c,C_word *av) C_noret;
C_noret_decl(f_12280)
static void C_ccall f_12280(C_word c,C_word *av) C_noret;
C_noret_decl(f_12286)
static void C_ccall f_12286(C_word c,C_word *av) C_noret;
C_noret_decl(f_12289)
static void C_ccall f_12289(C_word c,C_word *av) C_noret;
C_noret_decl(f_12292)
static void C_ccall f_12292(C_word c,C_word *av) C_noret;
C_noret_decl(f_12311)
static void C_ccall f_12311(C_word c,C_word *av) C_noret;
C_noret_decl(f_12314)
static void C_ccall f_12314(C_word c,C_word *av) C_noret;
C_noret_decl(f_12323)
static void C_ccall f_12323(C_word c,C_word *av) C_noret;
C_noret_decl(f_12326)
static void C_ccall f_12326(C_word c,C_word *av) C_noret;
C_noret_decl(f_12329)
static void C_fcall f_12329(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12349)
static void C_ccall f_12349(C_word c,C_word *av) C_noret;
C_noret_decl(f_12357)
static void C_ccall f_12357(C_word c,C_word *av) C_noret;
C_noret_decl(f_12368)
static void C_ccall f_12368(C_word c,C_word *av) C_noret;
C_noret_decl(f_12371)
static void C_ccall f_12371(C_word c,C_word *av) C_noret;
C_noret_decl(f_12377)
static void C_ccall f_12377(C_word c,C_word *av) C_noret;
C_noret_decl(f_12380)
static void C_ccall f_12380(C_word c,C_word *av) C_noret;
C_noret_decl(f_12383)
static void C_ccall f_12383(C_word c,C_word *av) C_noret;
C_noret_decl(f_12398)
static void C_ccall f_12398(C_word c,C_word *av) C_noret;
C_noret_decl(f_12401)
static void C_ccall f_12401(C_word c,C_word *av) C_noret;
C_noret_decl(f_12404)
static void C_ccall f_12404(C_word c,C_word *av) C_noret;
C_noret_decl(f_12410)
static void C_ccall f_12410(C_word c,C_word *av) C_noret;
C_noret_decl(f_12422)
static void C_ccall f_12422(C_word c,C_word *av) C_noret;
C_noret_decl(f_12426)
static void C_ccall f_12426(C_word c,C_word *av) C_noret;
C_noret_decl(f_12430)
static void C_ccall f_12430(C_word c,C_word *av) C_noret;
C_noret_decl(f_12433)
static void C_ccall f_12433(C_word c,C_word *av) C_noret;
C_noret_decl(f_12439)
static void C_ccall f_12439(C_word c,C_word *av) C_noret;
C_noret_decl(f_12459)
static void C_ccall f_12459(C_word c,C_word *av) C_noret;
C_noret_decl(f_12463)
static void C_fcall f_12463(C_word t0,C_word t1) C_noret;
C_noret_decl(f_12488)
static void C_ccall f_12488(C_word c,C_word *av) C_noret;
C_noret_decl(f_12511)
static void C_ccall f_12511(C_word c,C_word *av) C_noret;
C_noret_decl(f_12513)
static void C_ccall f_12513(C_word c,C_word *av) C_noret;
C_noret_decl(f_12517)
static void C_ccall f_12517(C_word c,C_word *av) C_noret;
C_noret_decl(f_12520)
static void C_ccall f_12520(C_word c,C_word *av) C_noret;
C_noret_decl(f_12525)
static void C_ccall f_12525(C_word c,C_word *av) C_noret;
C_noret_decl(f_12558)
static void C_ccall f_12558(C_word c,C_word *av) C_noret;
C_noret_decl(f_12561)
static void C_ccall f_12561(C_word c,C_word *av) C_noret;
C_noret_decl(f_12564)
static void C_ccall f_12564(C_word c,C_word *av) C_noret;
C_noret_decl(f_12571)
static void C_ccall f_12571(C_word c,C_word *av) C_noret;
C_noret_decl(f_12574)
static void C_ccall f_12574(C_word c,C_word *av) C_noret;
C_noret_decl(f_12580)
static void C_ccall f_12580(C_word c,C_word *av) C_noret;
C_noret_decl(f_12583)
static void C_ccall f_12583(C_word c,C_word *av) C_noret;
C_noret_decl(f_12586)
static void C_ccall f_12586(C_word c,C_word *av) C_noret;
C_noret_decl(f_12593)
static void C_ccall f_12593(C_word c,C_word *av) C_noret;
C_noret_decl(f_12605)
static void C_ccall f_12605(C_word c,C_word *av) C_noret;
C_noret_decl(f_12611)
static void C_ccall f_12611(C_word c,C_word *av) C_noret;
C_noret_decl(f_12614)
static void C_ccall f_12614(C_word c,C_word *av) C_noret;
C_noret_decl(f_12617)
static void C_ccall f_12617(C_word c,C_word *av) C_noret;
C_noret_decl(f_12627)
static void C_ccall f_12627(C_word c,C_word *av) C_noret;
C_noret_decl(f_12630)
static void C_ccall f_12630(C_word c,C_word *av) C_noret;
C_noret_decl(f_12640)
static void C_ccall f_12640(C_word c,C_word *av) C_noret;
C_noret_decl(f_12643)
static void C_ccall f_12643(C_word c,C_word *av) C_noret;
C_noret_decl(f_12646)
static void C_ccall f_12646(C_word c,C_word *av) C_noret;
C_noret_decl(f_12649)
static void C_ccall f_12649(C_word c,C_word *av) C_noret;
C_noret_decl(f_12652)
static void C_ccall f_12652(C_word c,C_word *av) C_noret;
C_noret_decl(f_12655)
static void C_ccall f_12655(C_word c,C_word *av) C_noret;
C_noret_decl(f_12673)
static void C_ccall f_12673(C_word c,C_word *av) C_noret;
C_noret_decl(f_12676)
static void C_ccall f_12676(C_word c,C_word *av) C_noret;
C_noret_decl(f_12682)
static void C_ccall f_12682(C_word c,C_word *av) C_noret;
C_noret_decl(f_12685)
static void C_ccall f_12685(C_word c,C_word *av) C_noret;
C_noret_decl(f_12688)
static void C_ccall f_12688(C_word c,C_word *av) C_noret;
C_noret_decl(f_12706)
static void C_ccall f_12706(C_word c,C_word *av) C_noret;
C_noret_decl(f_12709)
static void C_ccall f_12709(C_word c,C_word *av) C_noret;
C_noret_decl(f_12715)
static void C_ccall f_12715(C_word c,C_word *av) C_noret;
C_noret_decl(f_12718)
static void C_ccall f_12718(C_word c,C_word *av) C_noret;
C_noret_decl(f_12721)
static void C_ccall f_12721(C_word c,C_word *av) C_noret;
C_noret_decl(f_12726)
static void C_ccall f_12726(C_word c,C_word *av) C_noret;
C_noret_decl(f_12732)
static void C_ccall f_12732(C_word c,C_word *av) C_noret;
C_noret_decl(f_12738)
static void C_ccall f_12738(C_word c,C_word *av) C_noret;
C_noret_decl(f_12744)
static void C_ccall f_12744(C_word c,C_word *av) C_noret;
C_noret_decl(f_12750)
static void C_ccall f_12750(C_word c,C_word *av) C_noret;
C_noret_decl(f_12757)
static void C_ccall f_12757(C_word c,C_word *av) C_noret;
C_noret_decl(f_12776)
static void C_ccall f_12776(C_word c,C_word *av) C_noret;
C_noret_decl(f_12782)
static void C_ccall f_12782(C_word c,C_word *av) C_noret;
C_noret_decl(f_12804)
static void C_fcall f_12804(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12810)
static void C_fcall f_12810(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12818)
static void C_ccall f_12818(C_word c,C_word *av) C_noret;
C_noret_decl(f_12825)
static void C_ccall f_12825(C_word c,C_word *av) C_noret;
C_noret_decl(f_12827)
static void C_fcall f_12827(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_12852)
static void C_ccall f_12852(C_word c,C_word *av) C_noret;
C_noret_decl(f_12870)
static void C_ccall f_12870(C_word c,C_word *av) C_noret;
C_noret_decl(f_12880)
static void C_ccall f_12880(C_word c,C_word *av) C_noret;
C_noret_decl(f_12890)
static void C_ccall f_12890(C_word c,C_word *av) C_noret;
C_noret_decl(f_12902)
static void C_ccall f_12902(C_word c,C_word *av) C_noret;
C_noret_decl(f_12905)
static void C_ccall f_12905(C_word c,C_word *av) C_noret;
C_noret_decl(f_12912)
static void C_ccall f_12912(C_word c,C_word *av) C_noret;
C_noret_decl(f_12916)
static void C_ccall f_12916(C_word c,C_word *av) C_noret;
C_noret_decl(f_12924)
static void C_ccall f_12924(C_word c,C_word *av) C_noret;
C_noret_decl(f_12936)
static void C_ccall f_12936(C_word c,C_word *av) C_noret;
C_noret_decl(f_12940)
static void C_ccall f_12940(C_word c,C_word *av) C_noret;
C_noret_decl(f_12952)
static void C_ccall f_12952(C_word c,C_word *av) C_noret;
C_noret_decl(f_13012)
static void C_ccall f_13012(C_word c,C_word *av) C_noret;
C_noret_decl(f_13041)
static void C_fcall f_13041(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_13065)
static void C_ccall f_13065(C_word c,C_word *av) C_noret;
C_noret_decl(f_13073)
static void C_ccall f_13073(C_word c,C_word *av) C_noret;
C_noret_decl(f_13077)
static void C_ccall f_13077(C_word c,C_word *av) C_noret;
C_noret_decl(f_13081)
static void C_ccall f_13081(C_word c,C_word *av) C_noret;
C_noret_decl(f_13122)
static void C_ccall f_13122(C_word c,C_word *av) C_noret;
C_noret_decl(f_13133)
static void C_ccall f_13133(C_word c,C_word *av) C_noret;
C_noret_decl(f_13140)
static void C_ccall f_13140(C_word c,C_word *av) C_noret;
C_noret_decl(f_13143)
static void C_ccall f_13143(C_word c,C_word *av) C_noret;
C_noret_decl(f_13149)
static void C_ccall f_13149(C_word c,C_word *av) C_noret;
C_noret_decl(f_13152)
static void C_ccall f_13152(C_word c,C_word *av) C_noret;
C_noret_decl(f_13155)
static void C_ccall f_13155(C_word c,C_word *av) C_noret;
C_noret_decl(f_13192)
static void C_fcall f_13192(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_13218)
static void C_fcall f_13218(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_13246)
static void C_ccall f_13246(C_word c,C_word *av) C_noret;
C_noret_decl(f_13261)
static void C_ccall f_13261(C_word c,C_word *av) C_noret;
C_noret_decl(f_13278)
static void C_ccall f_13278(C_word c,C_word *av) C_noret;
C_noret_decl(f_13284)
static void C_ccall f_13284(C_word c,C_word *av) C_noret;
C_noret_decl(f_13287)
static void C_ccall f_13287(C_word c,C_word *av) C_noret;
C_noret_decl(f_13307)
static void C_ccall f_13307(C_word c,C_word *av) C_noret;
C_noret_decl(f_13312)
static void C_ccall f_13312(C_word c,C_word *av) C_noret;
C_noret_decl(f_13318)
static void C_ccall f_13318(C_word c,C_word *av) C_noret;
C_noret_decl(f_13457)
static void C_ccall f_13457(C_word c,C_word *av) C_noret;
C_noret_decl(f_13462)
static void C_ccall f_13462(C_word c,C_word *av) C_noret;
C_noret_decl(f_13470)
static void C_ccall f_13470(C_word c,C_word *av) C_noret;
C_noret_decl(f_13472)
static void C_ccall f_13472(C_word c,C_word *av) C_noret;
C_noret_decl(f_13490)
static void C_ccall f_13490(C_word c,C_word *av) C_noret;
C_noret_decl(f_13496)
static void C_ccall f_13496(C_word c,C_word *av) C_noret;
C_noret_decl(f_13499)
static void C_ccall f_13499(C_word c,C_word *av) C_noret;
C_noret_decl(f_13502)
static void C_ccall f_13502(C_word c,C_word *av) C_noret;
C_noret_decl(f_13505)
static void C_ccall f_13505(C_word c,C_word *av) C_noret;
C_noret_decl(f_13523)
static void C_ccall f_13523(C_word c,C_word *av) C_noret;
C_noret_decl(f_13526)
static void C_ccall f_13526(C_word c,C_word *av) C_noret;
C_noret_decl(f_13529)
static void C_ccall f_13529(C_word c,C_word *av) C_noret;
C_noret_decl(f_13535)
static void C_ccall f_13535(C_word c,C_word *av) C_noret;
C_noret_decl(f_13538)
static void C_ccall f_13538(C_word c,C_word *av) C_noret;
C_noret_decl(f_13577)
static void C_fcall f_13577(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_13582)
static void C_fcall f_13582(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_13594)
static void C_fcall f_13594(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_13619)
static void C_ccall f_13619(C_word c,C_word *av) C_noret;
C_noret_decl(f_13629)
static void C_ccall f_13629(C_word c,C_word *av) C_noret;
C_noret_decl(f_13640)
static void C_ccall f_13640(C_word c,C_word *av) C_noret;
C_noret_decl(f_13644)
static void C_ccall f_13644(C_word c,C_word *av) C_noret;
C_noret_decl(f_13654)
static void C_ccall f_13654(C_word c,C_word *av) C_noret;
C_noret_decl(f_13660)
static void C_ccall f_13660(C_word c,C_word *av) C_noret;
C_noret_decl(f_13668)
static void C_fcall f_13668(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_13703)
static void C_fcall f_13703(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_13710)
static void C_ccall f_13710(C_word c,C_word *av) C_noret;
C_noret_decl(f_13713)
static void C_ccall f_13713(C_word c,C_word *av) C_noret;
C_noret_decl(f_13720)
static void C_ccall f_13720(C_word c,C_word *av) C_noret;
C_noret_decl(f_13722)
static void C_fcall f_13722(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_13728)
static void C_fcall f_13728(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13736)
static void C_ccall f_13736(C_word c,C_word *av) C_noret;
C_noret_decl(f_13742)
static void C_ccall f_13742(C_word c,C_word *av) C_noret;
C_noret_decl(f_13745)
static void C_ccall f_13745(C_word c,C_word *av) C_noret;
C_noret_decl(f_13748)
static void C_ccall f_13748(C_word c,C_word *av) C_noret;
C_noret_decl(f_13751)
static void C_ccall f_13751(C_word c,C_word *av) C_noret;
C_noret_decl(f_13756)
static void C_fcall f_13756(C_word t0,C_word t1) C_noret;
C_noret_decl(f_13760)
static void C_ccall f_13760(C_word c,C_word *av) C_noret;
C_noret_decl(f_13763)
static void C_ccall f_13763(C_word c,C_word *av) C_noret;
C_noret_decl(f_13766)
static void C_ccall f_13766(C_word c,C_word *av) C_noret;
C_noret_decl(f_13772)
static void C_ccall f_13772(C_word c,C_word *av) C_noret;
C_noret_decl(f_13776)
static void C_ccall f_13776(C_word c,C_word *av) C_noret;
C_noret_decl(f_13780)
static void C_ccall f_13780(C_word c,C_word *av) C_noret;
C_noret_decl(f_13791)
static void C_ccall f_13791(C_word c,C_word *av) C_noret;
C_noret_decl(f_13794)
static void C_ccall f_13794(C_word c,C_word *av) C_noret;
C_noret_decl(f_13797)
static void C_ccall f_13797(C_word c,C_word *av) C_noret;
C_noret_decl(f_13833)
static void C_ccall f_13833(C_word c,C_word *av) C_noret;
C_noret_decl(f_13837)
static void C_ccall f_13837(C_word c,C_word *av) C_noret;
C_noret_decl(f_13858)
static void C_ccall f_13858(C_word c,C_word *av) C_noret;
C_noret_decl(f_13862)
static void C_ccall f_13862(C_word c,C_word *av) C_noret;
C_noret_decl(f_13883)
static void C_ccall f_13883(C_word c,C_word *av) C_noret;
C_noret_decl(f_13887)
static void C_ccall f_13887(C_word c,C_word *av) C_noret;
C_noret_decl(f_13891)
static void C_ccall f_13891(C_word c,C_word *av) C_noret;
C_noret_decl(f_13904)
static void C_ccall f_13904(C_word c,C_word *av) C_noret;
C_noret_decl(f_13908)
static void C_ccall f_13908(C_word c,C_word *av) C_noret;
C_noret_decl(f_13991)
static void C_fcall f_13991(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14001)
static void C_ccall f_14001(C_word c,C_word *av) C_noret;
C_noret_decl(f_14033)
static void C_ccall f_14033(C_word c,C_word *av) C_noret;
C_noret_decl(f_14039)
static void C_ccall f_14039(C_word c,C_word *av) C_noret;
C_noret_decl(f_14047)
static void C_ccall f_14047(C_word c,C_word *av) C_noret;
C_noret_decl(f_14055)
static void C_fcall f_14055(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14065)
static void C_ccall f_14065(C_word c,C_word *av) C_noret;
C_noret_decl(f_14078)
static void C_fcall f_14078(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14088)
static void C_ccall f_14088(C_word c,C_word *av) C_noret;
C_noret_decl(f_14115)
static void C_ccall f_14115(C_word c,C_word *av) C_noret;
C_noret_decl(f_14126)
static void C_ccall f_14126(C_word c,C_word *av) C_noret;
C_noret_decl(f_14136)
static void C_fcall f_14136(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14146)
static void C_ccall f_14146(C_word c,C_word *av) C_noret;
C_noret_decl(f_14159)
static void C_fcall f_14159(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14169)
static void C_ccall f_14169(C_word c,C_word *av) C_noret;
C_noret_decl(f_14195)
static void C_ccall f_14195(C_word c,C_word *av) C_noret;
C_noret_decl(f_14199)
static void C_ccall f_14199(C_word c,C_word *av) C_noret;
C_noret_decl(f_14237)
static void C_ccall f_14237(C_word c,C_word *av) C_noret;
C_noret_decl(f_14245)
static void C_fcall f_14245(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14255)
static void C_ccall f_14255(C_word c,C_word *av) C_noret;
C_noret_decl(f_14282)
static void C_ccall f_14282(C_word c,C_word *av) C_noret;
C_noret_decl(f_14290)
static void C_fcall f_14290(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14300)
static void C_ccall f_14300(C_word c,C_word *av) C_noret;
C_noret_decl(f_14322)
static void C_ccall f_14322(C_word c,C_word *av) C_noret;
C_noret_decl(f_14325)
static void C_ccall f_14325(C_word c,C_word *av) C_noret;
C_noret_decl(f_14342)
static void C_ccall f_14342(C_word c,C_word *av) C_noret;
C_noret_decl(f_14346)
static void C_ccall f_14346(C_word c,C_word *av) C_noret;
C_noret_decl(f_14370)
static void C_ccall f_14370(C_word c,C_word *av) C_noret;
C_noret_decl(f_14374)
static void C_ccall f_14374(C_word c,C_word *av) C_noret;
C_noret_decl(f_14402)
static void C_ccall f_14402(C_word c,C_word *av) C_noret;
C_noret_decl(f_14410)
static void C_fcall f_14410(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14420)
static void C_ccall f_14420(C_word c,C_word *av) C_noret;
C_noret_decl(f_14455)
static void C_ccall f_14455(C_word c,C_word *av) C_noret;
C_noret_decl(f_14459)
static void C_ccall f_14459(C_word c,C_word *av) C_noret;
C_noret_decl(f_14463)
static void C_ccall f_14463(C_word c,C_word *av) C_noret;
C_noret_decl(f_14491)
static void C_ccall f_14491(C_word c,C_word *av) C_noret;
C_noret_decl(f_14499)
static void C_fcall f_14499(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14509)
static void C_ccall f_14509(C_word c,C_word *av) C_noret;
C_noret_decl(f_14530)
static void C_ccall f_14530(C_word c,C_word *av) C_noret;
C_noret_decl(f_14533)
static void C_ccall f_14533(C_word c,C_word *av) C_noret;
C_noret_decl(f_14582)
static void C_ccall f_14582(C_word c,C_word *av) C_noret;
C_noret_decl(f_14597)
static void C_fcall f_14597(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14607)
static void C_ccall f_14607(C_word c,C_word *av) C_noret;
C_noret_decl(f_14630)
static void C_ccall f_14630(C_word c,C_word *av) C_noret;
C_noret_decl(f_14638)
static void C_fcall f_14638(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14648)
static void C_ccall f_14648(C_word c,C_word *av) C_noret;
C_noret_decl(f_14689)
static void C_ccall f_14689(C_word c,C_word *av) C_noret;
C_noret_decl(f_14697)
static void C_fcall f_14697(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14707)
static void C_ccall f_14707(C_word c,C_word *av) C_noret;
C_noret_decl(f_14731)
static void C_ccall f_14731(C_word c,C_word *av) C_noret;
C_noret_decl(f_14753)
static void C_ccall f_14753(C_word c,C_word *av) C_noret;
C_noret_decl(f_14775)
static void C_ccall f_14775(C_word c,C_word *av) C_noret;
C_noret_decl(f_14781)
static void C_ccall f_14781(C_word c,C_word *av) C_noret;
C_noret_decl(f_14789)
static void C_ccall f_14789(C_word c,C_word *av) C_noret;
C_noret_decl(f_14797)
static void C_fcall f_14797(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14807)
static void C_ccall f_14807(C_word c,C_word *av) C_noret;
C_noret_decl(f_14833)
static void C_ccall f_14833(C_word c,C_word *av) C_noret;
C_noret_decl(f_14852)
static void C_ccall f_14852(C_word c,C_word *av) C_noret;
C_noret_decl(f_14856)
static void C_ccall f_14856(C_word c,C_word *av) C_noret;
C_noret_decl(f_14863)
static void C_fcall f_14863(C_word t0,C_word t1) C_noret;
C_noret_decl(f_14909)
static void C_ccall f_14909(C_word c,C_word *av) C_noret;
C_noret_decl(f_14915)
static void C_ccall f_14915(C_word c,C_word *av) C_noret;
C_noret_decl(f_14917)
static void C_fcall f_14917(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_14942)
static void C_ccall f_14942(C_word c,C_word *av) C_noret;
C_noret_decl(f_14967)
static void C_ccall f_14967(C_word c,C_word *av) C_noret;
C_noret_decl(f_14970)
static void C_fcall f_14970(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15019)
static void C_ccall f_15019(C_word c,C_word *av) C_noret;
C_noret_decl(f_15027)
static void C_fcall f_15027(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15037)
static void C_ccall f_15037(C_word c,C_word *av) C_noret;
C_noret_decl(f_15073)
static void C_ccall f_15073(C_word c,C_word *av) C_noret;
C_noret_decl(f_15081)
static void C_fcall f_15081(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15091)
static void C_ccall f_15091(C_word c,C_word *av) C_noret;
C_noret_decl(f_15128)
static void C_ccall f_15128(C_word c,C_word *av) C_noret;
C_noret_decl(f_15136)
static void C_fcall f_15136(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15146)
static void C_ccall f_15146(C_word c,C_word *av) C_noret;
C_noret_decl(f_15168)
static void C_fcall f_15168(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15175)
static void C_fcall f_15175(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15182)
static void C_ccall f_15182(C_word c,C_word *av) C_noret;
C_noret_decl(f_15185)
static void C_ccall f_15185(C_word c,C_word *av) C_noret;
C_noret_decl(f_15188)
static void C_ccall f_15188(C_word c,C_word *av) C_noret;
C_noret_decl(f_15194)
static void C_ccall f_15194(C_word c,C_word *av) C_noret;
C_noret_decl(f_15204)
static void C_ccall f_15204(C_word c,C_word *av) C_noret;
C_noret_decl(f_15210)
static void C_ccall f_15210(C_word c,C_word *av) C_noret;
C_noret_decl(f_15220)
static void C_ccall f_15220(C_word c,C_word *av) C_noret;
C_noret_decl(f_15223)
static void C_ccall f_15223(C_word c,C_word *av) C_noret;
C_noret_decl(f_15226)
static void C_ccall f_15226(C_word c,C_word *av) C_noret;
C_noret_decl(f_15229)
static void C_ccall f_15229(C_word c,C_word *av) C_noret;
C_noret_decl(f_15242)
static void C_ccall f_15242(C_word c,C_word *av) C_noret;
C_noret_decl(f_15258)
static void C_fcall f_15258(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15290)
static void C_ccall f_15290(C_word c,C_word *av) C_noret;
C_noret_decl(f_15332)
static void C_fcall f_15332(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15342)
static void C_ccall f_15342(C_word c,C_word *av) C_noret;
C_noret_decl(f_15360)
static void C_fcall f_15360(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15367)
static void C_fcall f_15367(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15370)
static void C_ccall f_15370(C_word c,C_word *av) C_noret;
C_noret_decl(f_15373)
static void C_ccall f_15373(C_word c,C_word *av) C_noret;
C_noret_decl(f_15379)
static void C_ccall f_15379(C_word c,C_word *av) C_noret;
C_noret_decl(f_15389)
static void C_ccall f_15389(C_word c,C_word *av) C_noret;
C_noret_decl(f_15395)
static void C_ccall f_15395(C_word c,C_word *av) C_noret;
C_noret_decl(f_15454)
static void C_fcall f_15454(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15464)
static void C_ccall f_15464(C_word c,C_word *av) C_noret;
C_noret_decl(f_15598)
static void C_ccall f_15598(C_word c,C_word *av) C_noret;
C_noret_decl(f_15621)
static void C_ccall f_15621(C_word c,C_word *av) C_noret;
C_noret_decl(f_15630)
static void C_ccall f_15630(C_word c,C_word *av) C_noret;
C_noret_decl(f_15639)
static void C_ccall f_15639(C_word c,C_word *av) C_noret;
C_noret_decl(f_15648)
static void C_ccall f_15648(C_word c,C_word *av) C_noret;
C_noret_decl(f_15657)
static void C_ccall f_15657(C_word c,C_word *av) C_noret;
C_noret_decl(f_15666)
static void C_ccall f_15666(C_word c,C_word *av) C_noret;
C_noret_decl(f_15675)
static void C_ccall f_15675(C_word c,C_word *av) C_noret;
C_noret_decl(f_15684)
static void C_ccall f_15684(C_word c,C_word *av) C_noret;
C_noret_decl(f_15693)
static void C_fcall f_15693(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7) C_noret;
C_noret_decl(f_15702)
static void C_fcall f_15702(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_15731)
static void C_ccall f_15731(C_word c,C_word *av) C_noret;
C_noret_decl(f_15735)
static void C_ccall f_15735(C_word c,C_word *av) C_noret;
C_noret_decl(f_15780)
static void C_ccall f_15780(C_word c,C_word *av) C_noret;
C_noret_decl(f_15783)
static void C_ccall f_15783(C_word c,C_word *av) C_noret;
C_noret_decl(f_15786)
static void C_ccall f_15786(C_word c,C_word *av) C_noret;
C_noret_decl(f_15789)
static void C_ccall f_15789(C_word c,C_word *av) C_noret;
C_noret_decl(f_15792)
static void C_ccall f_15792(C_word c,C_word *av) C_noret;
C_noret_decl(f_15795)
static void C_ccall f_15795(C_word c,C_word *av) C_noret;
C_noret_decl(f_15798)
static void C_ccall f_15798(C_word c,C_word *av) C_noret;
C_noret_decl(f_15808)
static void C_fcall f_15808(C_word t0,C_word t1) C_noret;
C_noret_decl(f_15820)
static void C_ccall f_15820(C_word c,C_word *av) C_noret;
C_noret_decl(f_15829)
static void C_ccall f_15829(C_word c,C_word *av) C_noret;
C_noret_decl(f_15840)
static void C_ccall f_15840(C_word c,C_word *av) C_noret;
C_noret_decl(f_15852)
static void C_ccall f_15852(C_word c,C_word *av) C_noret;
C_noret_decl(f_15860)
static void C_ccall f_15860(C_word c,C_word *av) C_noret;
C_noret_decl(f_15867)
static void C_ccall f_15867(C_word c,C_word *av) C_noret;
C_noret_decl(f_15870)
static void C_ccall f_15870(C_word c,C_word *av) C_noret;
C_noret_decl(f_15881)
static void C_ccall f_15881(C_word c,C_word *av) C_noret;
C_noret_decl(f_15885)
static void C_ccall f_15885(C_word c,C_word *av) C_noret;
C_noret_decl(f_15889)
static void C_ccall f_15889(C_word c,C_word *av) C_noret;
C_noret_decl(f_15915)
static void C_fcall f_15915(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_15944)
static void C_ccall f_15944(C_word c,C_word *av) C_noret;
C_noret_decl(f_15985)
static void C_ccall f_15985(C_word c,C_word *av) C_noret;
C_noret_decl(f_15996)
static void C_fcall f_15996(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16021)
static void C_ccall f_16021(C_word c,C_word *av) C_noret;
C_noret_decl(f_16040)
static void C_ccall f_16040(C_word c,C_word *av) C_noret;
C_noret_decl(f_16048)
static void C_fcall f_16048(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16073)
static void C_ccall f_16073(C_word c,C_word *av) C_noret;
C_noret_decl(f_16082)
static void C_fcall f_16082(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16089)
static void C_ccall f_16089(C_word c,C_word *av) C_noret;
C_noret_decl(f_16108)
static void C_ccall f_16108(C_word c,C_word *av) C_noret;
C_noret_decl(f_16119)
static void C_fcall f_16119(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16129)
static void C_ccall f_16129(C_word c,C_word *av) C_noret;
C_noret_decl(f_16143)
static void C_ccall f_16143(C_word c,C_word *av) C_noret;
C_noret_decl(f_16149)
static void C_ccall f_16149(C_word c,C_word *av) C_noret;
C_noret_decl(f_16155)
static void C_ccall f_16155(C_word c,C_word *av) C_noret;
C_noret_decl(f_16160)
static void C_fcall f_16160(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16194)
static void C_fcall f_16194(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16236)
static void C_fcall f_16236(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16242)
static void C_ccall f_16242(C_word c,C_word *av) C_noret;
C_noret_decl(f_16245)
static void C_ccall f_16245(C_word c,C_word *av) C_noret;
C_noret_decl(f_16259)
static void C_ccall f_16259(C_word c,C_word *av) C_noret;
C_noret_decl(f_16265)
static void C_ccall f_16265(C_word c,C_word *av) C_noret;
C_noret_decl(f_16271)
static void C_ccall f_16271(C_word c,C_word *av) C_noret;
C_noret_decl(f_16276)
static void C_fcall f_16276(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16310)
static void C_fcall f_16310(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16385)
static void C_ccall f_16385(C_word c,C_word *av) C_noret;
C_noret_decl(f_16388)
static void C_fcall f_16388(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_16392)
static void C_ccall f_16392(C_word c,C_word *av) C_noret;
C_noret_decl(f_16399)
static void C_ccall f_16399(C_word c,C_word *av) C_noret;
C_noret_decl(f_16411)
static void C_ccall f_16411(C_word c,C_word *av) C_noret;
C_noret_decl(f_16417)
static void C_ccall f_16417(C_word c,C_word *av) C_noret;
C_noret_decl(f_16433)
static void C_ccall f_16433(C_word c,C_word *av) C_noret;
C_noret_decl(f_16439)
static void C_fcall f_16439(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_16457)
static void C_ccall f_16457(C_word c,C_word *av) C_noret;
C_noret_decl(f_16461)
static void C_ccall f_16461(C_word c,C_word *av) C_noret;
C_noret_decl(f_16463)
static void C_fcall f_16463(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_16467)
static void C_ccall f_16467(C_word c,C_word *av) C_noret;
C_noret_decl(f_16470)
static void C_ccall f_16470(C_word c,C_word *av) C_noret;
C_noret_decl(f_16473)
static void C_ccall f_16473(C_word c,C_word *av) C_noret;
C_noret_decl(f_16476)
static void C_ccall f_16476(C_word c,C_word *av) C_noret;
C_noret_decl(f_16485)
static void C_fcall f_16485(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16497)
static void C_ccall f_16497(C_word c,C_word *av) C_noret;
C_noret_decl(f_16500)
static void C_ccall f_16500(C_word c,C_word *av) C_noret;
C_noret_decl(f_16501)
static void C_ccall f_16501(C_word c,C_word *av) C_noret;
C_noret_decl(f_16517)
static void C_ccall f_16517(C_word c,C_word *av) C_noret;
C_noret_decl(f_16532)
static void C_ccall f_16532(C_word c,C_word *av) C_noret;
C_noret_decl(f_16536)
static void C_ccall f_16536(C_word c,C_word *av) C_noret;
C_noret_decl(f_16542)
static void C_ccall f_16542(C_word c,C_word *av) C_noret;
C_noret_decl(f_16554)
static void C_ccall f_16554(C_word c,C_word *av) C_noret;
C_noret_decl(f_16558)
static void C_ccall f_16558(C_word c,C_word *av) C_noret;
C_noret_decl(f_16578)
static void C_ccall f_16578(C_word c,C_word *av) C_noret;
C_noret_decl(f_16582)
static void C_ccall f_16582(C_word c,C_word *av) C_noret;
C_noret_decl(f_16591)
static void C_ccall f_16591(C_word c,C_word *av) C_noret;
C_noret_decl(f_16606)
static void C_fcall f_16606(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_16629)
static void C_ccall f_16629(C_word c,C_word *av) C_noret;
C_noret_decl(f_16636)
static void C_ccall f_16636(C_word c,C_word *av) C_noret;
C_noret_decl(f_16660)
static void C_ccall f_16660(C_word c,C_word *av) C_noret;
C_noret_decl(f_16693)
static void C_ccall f_16693(C_word c,C_word *av) C_noret;
C_noret_decl(f_16706)
static void C_ccall f_16706(C_word c,C_word *av) C_noret;
C_noret_decl(f_16721)
static void C_ccall f_16721(C_word c,C_word *av) C_noret;
C_noret_decl(f_16737)
static void C_ccall f_16737(C_word c,C_word *av) C_noret;
C_noret_decl(f_16741)
static void C_ccall f_16741(C_word c,C_word *av) C_noret;
C_noret_decl(f_16745)
static void C_ccall f_16745(C_word c,C_word *av) C_noret;
C_noret_decl(f_16777)
static void C_ccall f_16777(C_word c,C_word *av) C_noret;
C_noret_decl(f_16783)
static void C_ccall f_16783(C_word c,C_word *av) C_noret;
C_noret_decl(f_16794)
static void C_ccall f_16794(C_word c,C_word *av) C_noret;
C_noret_decl(f_16798)
static void C_ccall f_16798(C_word c,C_word *av) C_noret;
C_noret_decl(f_16807)
static void C_fcall f_16807(C_word t0,C_word t1) C_noret;
C_noret_decl(f_16847)
static void C_ccall f_16847(C_word c,C_word *av) C_noret;
C_noret_decl(f_16855)
static void C_ccall f_16855(C_word c,C_word *av) C_noret;
C_noret_decl(f_16860)
static void C_ccall f_16860(C_word c,C_word *av) C_noret;
C_noret_decl(f_16866)
static void C_ccall f_16866(C_word c,C_word *av) C_noret;
C_noret_decl(f_17009)
static void C_fcall f_17009(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_17013)
static void C_ccall f_17013(C_word c,C_word *av) C_noret;
C_noret_decl(f_17016)
static void C_ccall f_17016(C_word c,C_word *av) C_noret;
C_noret_decl(f_17031)
static void C_ccall f_17031(C_word c,C_word *av) C_noret;
C_noret_decl(f_17035)
static void C_ccall f_17035(C_word c,C_word *av) C_noret;
C_noret_decl(f_17037)
static void C_ccall f_17037(C_word c,C_word *av) C_noret;
C_noret_decl(f_17043)
static void C_ccall f_17043(C_word c,C_word *av) C_noret;
C_noret_decl(f_17051)
static void C_ccall f_17051(C_word c,C_word *av) C_noret;
C_noret_decl(f_17055)
static void C_ccall f_17055(C_word c,C_word *av) C_noret;
C_noret_decl(f_17067)
static void C_ccall f_17067(C_word c,C_word *av) C_noret;
C_noret_decl(f_17071)
static void C_ccall f_17071(C_word c,C_word *av) C_noret;
C_noret_decl(f_17080)
static void C_ccall f_17080(C_word c,C_word *av) C_noret;
C_noret_decl(f_17090)
static void C_ccall f_17090(C_word c,C_word *av) C_noret;
C_noret_decl(f_17093)
static void C_ccall f_17093(C_word c,C_word *av) C_noret;
C_noret_decl(f_17108)
static void C_ccall f_17108(C_word c,C_word *av) C_noret;
C_noret_decl(f_17112)
static void C_ccall f_17112(C_word c,C_word *av) C_noret;
C_noret_decl(f_17124)
static void C_ccall f_17124(C_word c,C_word *av) C_noret;
C_noret_decl(f_17136)
static void C_ccall f_17136(C_word c,C_word *av) C_noret;
C_noret_decl(f_17140)
static void C_ccall f_17140(C_word c,C_word *av) C_noret;
C_noret_decl(f_17149)
static void C_ccall f_17149(C_word c,C_word *av) C_noret;
C_noret_decl(f_17155)
static void C_fcall f_17155(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_17161)
static void C_ccall f_17161(C_word c,C_word *av) C_noret;
C_noret_decl(f_17169)
static void C_ccall f_17169(C_word c,C_word *av) C_noret;
C_noret_decl(f_17171)
static void C_fcall f_17171(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_17177)
static void C_fcall f_17177(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_17191)
static void C_ccall f_17191(C_word c,C_word *av) C_noret;
C_noret_decl(f_17197)
static void C_ccall f_17197(C_word c,C_word *av) C_noret;
C_noret_decl(f_17211)
static void C_ccall f_17211(C_word c,C_word *av) C_noret;
C_noret_decl(f_17218)
static void C_ccall f_17218(C_word c,C_word *av) C_noret;
C_noret_decl(f_17225)
static void C_ccall f_17225(C_word c,C_word *av) C_noret;
C_noret_decl(f_17240)
static void C_ccall f_17240(C_word c,C_word *av) C_noret;
C_noret_decl(f_17255)
static void C_ccall f_17255(C_word c,C_word *av) C_noret;
C_noret_decl(f_17267)
static void C_ccall f_17267(C_word c,C_word *av) C_noret;
C_noret_decl(f_17273)
static void C_ccall f_17273(C_word c,C_word *av) C_noret;
C_noret_decl(f_17277)
static void C_ccall f_17277(C_word c,C_word *av) C_noret;
C_noret_decl(f_17294)
static void C_ccall f_17294(C_word c,C_word *av) C_noret;
C_noret_decl(f_17299)
static void C_ccall f_17299(C_word c,C_word *av) C_noret;
C_noret_decl(f_17306)
static void C_ccall f_17306(C_word c,C_word *av) C_noret;
C_noret_decl(f_17308)
static C_word C_fcall f_17308(C_word *a,C_word t0);
C_noret_decl(f_17315)
static void C_fcall f_17315(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_17319)
static void C_ccall f_17319(C_word c,C_word *av) C_noret;
C_noret_decl(f_17322)
static void C_ccall f_17322(C_word c,C_word *av) C_noret;
C_noret_decl(f_17325)
static void C_ccall f_17325(C_word c,C_word *av) C_noret;
C_noret_decl(f_17337)
static void C_fcall f_17337(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17352)
static void C_ccall f_17352(C_word c,C_word *av) C_noret;
C_noret_decl(f_17383)
static void C_ccall f_17383(C_word c,C_word *av) C_noret;
C_noret_decl(f_17413)
static void C_ccall f_17413(C_word c,C_word *av) C_noret;
C_noret_decl(f_17416)
static void C_ccall f_17416(C_word c,C_word *av) C_noret;
C_noret_decl(f_17434)
static void C_ccall f_17434(C_word c,C_word *av) C_noret;
C_noret_decl(f_17437)
static void C_ccall f_17437(C_word c,C_word *av) C_noret;
C_noret_decl(f_17447)
static void C_fcall f_17447(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17454)
static void C_ccall f_17454(C_word c,C_word *av) C_noret;
C_noret_decl(f_17482)
static void C_ccall f_17482(C_word c,C_word *av) C_noret;
C_noret_decl(f_17492)
static void C_ccall f_17492(C_word c,C_word *av) C_noret;
C_noret_decl(f_17496)
static void C_ccall f_17496(C_word c,C_word *av) C_noret;
C_noret_decl(f_17500)
static void C_ccall f_17500(C_word c,C_word *av) C_noret;
C_noret_decl(f_17504)
static void C_ccall f_17504(C_word c,C_word *av) C_noret;
C_noret_decl(f_17508)
static void C_ccall f_17508(C_word c,C_word *av) C_noret;
C_noret_decl(f_17512)
static void C_ccall f_17512(C_word c,C_word *av) C_noret;
C_noret_decl(f_17524)
static void C_ccall f_17524(C_word c,C_word *av) C_noret;
C_noret_decl(f_17529)
static void C_fcall f_17529(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_17547)
static void C_ccall f_17547(C_word c,C_word *av) C_noret;
C_noret_decl(f_17556)
static void C_ccall f_17556(C_word c,C_word *av) C_noret;
C_noret_decl(f_17559)
static void C_ccall f_17559(C_word c,C_word *av) C_noret;
C_noret_decl(f_17562)
static void C_ccall f_17562(C_word c,C_word *av) C_noret;
C_noret_decl(f_17587)
static void C_ccall f_17587(C_word c,C_word *av) C_noret;
C_noret_decl(f_17589)
static void C_fcall f_17589(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17599)
static void C_ccall f_17599(C_word c,C_word *av) C_noret;
C_noret_decl(f_17603)
static void C_ccall f_17603(C_word c,C_word *av) C_noret;
C_noret_decl(f_17612)
static void C_ccall f_17612(C_word c,C_word *av) C_noret;
C_noret_decl(f_17614)
static void C_fcall f_17614(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17624)
static void C_ccall f_17624(C_word c,C_word *av) C_noret;
C_noret_decl(f_17656)
static void C_ccall f_17656(C_word c,C_word *av) C_noret;
C_noret_decl(f_17663)
static void C_ccall f_17663(C_word c,C_word *av) C_noret;
C_noret_decl(f_17664)
static void C_fcall f_17664(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17668)
static void C_ccall f_17668(C_word c,C_word *av) C_noret;
C_noret_decl(f_17677)
static void C_ccall f_17677(C_word c,C_word *av) C_noret;
C_noret_decl(f_17680)
static void C_ccall f_17680(C_word c,C_word *av) C_noret;
C_noret_decl(f_17683)
static void C_ccall f_17683(C_word c,C_word *av) C_noret;
C_noret_decl(f_17686)
static void C_fcall f_17686(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17689)
static void C_fcall f_17689(C_word t0,C_word t1) C_noret;
C_noret_decl(f_17692)
static void C_ccall f_17692(C_word c,C_word *av) C_noret;
C_noret_decl(f_17708)
static void C_ccall f_17708(C_word c,C_word *av) C_noret;
C_noret_decl(f_17716)
static void C_ccall f_17716(C_word c,C_word *av) C_noret;
C_noret_decl(f_17734)
static void C_ccall f_17734(C_word c,C_word *av) C_noret;
C_noret_decl(f_17740)
static void C_ccall f_17740(C_word c,C_word *av) C_noret;
C_noret_decl(f_17749)
static void C_fcall f_17749(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_17759)
static void C_ccall f_17759(C_word c,C_word *av) C_noret;
C_noret_decl(f_17773)
static void C_ccall f_17773(C_word c,C_word *av) C_noret;
C_noret_decl(f_17794)
static void C_ccall f_17794(C_word c,C_word *av) C_noret;
C_noret_decl(f_17797)
static void C_ccall f_17797(C_word c,C_word *av) C_noret;
C_noret_decl(f_17800)
static void C_ccall f_17800(C_word c,C_word *av) C_noret;
C_noret_decl(f_17803)
static void C_ccall f_17803(C_word c,C_word *av) C_noret;
C_noret_decl(f_17806)
static void C_ccall f_17806(C_word c,C_word *av) C_noret;
C_noret_decl(f_17809)
static void C_ccall f_17809(C_word c,C_word *av) C_noret;
C_noret_decl(f_17845)
static void C_ccall f_17845(C_word c,C_word *av) C_noret;
C_noret_decl(f_17851)
static void C_ccall f_17851(C_word c,C_word *av) C_noret;
C_noret_decl(f_17891)
static void C_ccall f_17891(C_word c,C_word *av) C_noret;
C_noret_decl(f_17897)
static void C_ccall f_17897(C_word c,C_word *av) C_noret;
C_noret_decl(f_17986)
static void C_fcall f_17986(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_17988)
static void C_fcall f_17988(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18000)
static void C_fcall f_18000(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18010)
static void C_ccall f_18010(C_word c,C_word *av) C_noret;
C_noret_decl(f_18023)
static void C_fcall f_18023(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_18027)
static void C_ccall f_18027(C_word c,C_word *av) C_noret;
C_noret_decl(f_18036)
static void C_fcall f_18036(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_18040)
static void C_ccall f_18040(C_word c,C_word *av) C_noret;
C_noret_decl(f_18049)
static void C_fcall f_18049(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_18056)
static void C_ccall f_18056(C_word c,C_word *av) C_noret;
C_noret_decl(f_18062)
static void C_ccall f_18062(C_word c,C_word *av) C_noret;
C_noret_decl(f_18074)
static void C_fcall f_18074(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18098)
static void C_ccall f_18098(C_word c,C_word *av) C_noret;
C_noret_decl(f_18102)
static void C_ccall f_18102(C_word c,C_word *av) C_noret;
C_noret_decl(f_18121)
static void C_ccall f_18121(C_word c,C_word *av) C_noret;
C_noret_decl(f_18125)
static void C_ccall f_18125(C_word c,C_word *av) C_noret;
C_noret_decl(f_18128)
static void C_ccall f_18128(C_word c,C_word *av) C_noret;
C_noret_decl(f_18131)
static void C_fcall f_18131(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18135)
static void C_fcall f_18135(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18139)
static void C_ccall f_18139(C_word c,C_word *av) C_noret;
C_noret_decl(f_18142)
static void C_ccall f_18142(C_word c,C_word *av) C_noret;
C_noret_decl(f_18159)
static void C_fcall f_18159(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18162)
static void C_ccall f_18162(C_word c,C_word *av) C_noret;
C_noret_decl(f_18165)
static void C_ccall f_18165(C_word c,C_word *av) C_noret;
C_noret_decl(f_18204)
static void C_fcall f_18204(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18207)
static void C_ccall f_18207(C_word c,C_word *av) C_noret;
C_noret_decl(f_18213)
static void C_ccall f_18213(C_word c,C_word *av) C_noret;
C_noret_decl(f_18240)
static void C_ccall f_18240(C_word c,C_word *av) C_noret;
C_noret_decl(f_18247)
static void C_ccall f_18247(C_word c,C_word *av) C_noret;
C_noret_decl(f_18253)
static void C_ccall f_18253(C_word c,C_word *av) C_noret;
C_noret_decl(f_18263)
static void C_ccall f_18263(C_word c,C_word *av) C_noret;
C_noret_decl(f_18266)
static void C_ccall f_18266(C_word c,C_word *av) C_noret;
C_noret_decl(f_18273)
static void C_ccall f_18273(C_word c,C_word *av) C_noret;
C_noret_decl(f_18277)
static void C_ccall f_18277(C_word c,C_word *av) C_noret;
C_noret_decl(f_18281)
static void C_ccall f_18281(C_word c,C_word *av) C_noret;
C_noret_decl(f_18295)
static void C_ccall f_18295(C_word c,C_word *av) C_noret;
C_noret_decl(f_18299)
static void C_ccall f_18299(C_word c,C_word *av) C_noret;
C_noret_decl(f_18303)
static void C_ccall f_18303(C_word c,C_word *av) C_noret;
C_noret_decl(f_18306)
static void C_ccall f_18306(C_word c,C_word *av) C_noret;
C_noret_decl(f_18326)
static void C_ccall f_18326(C_word c,C_word *av) C_noret;
C_noret_decl(f_18330)
static void C_ccall f_18330(C_word c,C_word *av) C_noret;
C_noret_decl(f_18333)
static void C_ccall f_18333(C_word c,C_word *av) C_noret;
C_noret_decl(f_18353)
static void C_ccall f_18353(C_word c,C_word *av) C_noret;
C_noret_decl(f_18357)
static void C_ccall f_18357(C_word c,C_word *av) C_noret;
C_noret_decl(f_18359)
static void C_fcall f_18359(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_18380)
static void C_ccall f_18380(C_word c,C_word *av) C_noret;
C_noret_decl(f_18384)
static void C_ccall f_18384(C_word c,C_word *av) C_noret;
C_noret_decl(f_18387)
static void C_ccall f_18387(C_word c,C_word *av) C_noret;
C_noret_decl(f_18391)
static void C_ccall f_18391(C_word c,C_word *av) C_noret;
C_noret_decl(f_18397)
static void C_ccall f_18397(C_word c,C_word *av) C_noret;
C_noret_decl(f_18403)
static C_word C_fcall f_18403(C_word t0,C_word t1);
C_noret_decl(f_18546)
static void C_ccall f_18546(C_word c,C_word *av) C_noret;
C_noret_decl(f_18549)
static void C_ccall f_18549(C_word c,C_word *av) C_noret;
C_noret_decl(f_18552)
static void C_fcall f_18552(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18555)
static void C_ccall f_18555(C_word c,C_word *av) C_noret;
C_noret_decl(f_18558)
static void C_fcall f_18558(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18561)
static void C_ccall f_18561(C_word c,C_word *av) C_noret;
C_noret_decl(f_18564)
static void C_fcall f_18564(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18567)
static void C_ccall f_18567(C_word c,C_word *av) C_noret;
C_noret_decl(f_18573)
static void C_fcall f_18573(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18576)
static void C_ccall f_18576(C_word c,C_word *av) C_noret;
C_noret_decl(f_18594)
static void C_fcall f_18594(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18597)
static void C_ccall f_18597(C_word c,C_word *av) C_noret;
C_noret_decl(f_18615)
static void C_fcall f_18615(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18628)
static void C_ccall f_18628(C_word c,C_word *av) C_noret;
C_noret_decl(f_18652)
static void C_ccall f_18652(C_word c,C_word *av) C_noret;
C_noret_decl(f_18656)
static void C_ccall f_18656(C_word c,C_word *av) C_noret;
C_noret_decl(f_18660)
static void C_ccall f_18660(C_word c,C_word *av) C_noret;
C_noret_decl(f_18681)
static void C_ccall f_18681(C_word c,C_word *av) C_noret;
C_noret_decl(f_18687)
static void C_ccall f_18687(C_word c,C_word *av) C_noret;
C_noret_decl(f_18698)
static void C_ccall f_18698(C_word c,C_word *av) C_noret;
C_noret_decl(f_18716)
static void C_fcall f_18716(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18728)
static void C_ccall f_18728(C_word c,C_word *av) C_noret;
C_noret_decl(f_18750)
static void C_ccall f_18750(C_word c,C_word *av) C_noret;
C_noret_decl(f_18754)
static void C_ccall f_18754(C_word c,C_word *av) C_noret;
C_noret_decl(f_18758)
static void C_ccall f_18758(C_word c,C_word *av) C_noret;
C_noret_decl(f_18768)
static void C_ccall f_18768(C_word c,C_word *av) C_noret;
C_noret_decl(f_18772)
static void C_ccall f_18772(C_word c,C_word *av) C_noret;
C_noret_decl(f_18776)
static void C_ccall f_18776(C_word c,C_word *av) C_noret;
C_noret_decl(f_18797)
static void C_ccall f_18797(C_word c,C_word *av) C_noret;
C_noret_decl(f_18821)
static void C_ccall f_18821(C_word c,C_word *av) C_noret;
C_noret_decl(f_18831)
static void C_ccall f_18831(C_word c,C_word *av) C_noret;
C_noret_decl(f_18835)
static void C_ccall f_18835(C_word c,C_word *av) C_noret;
C_noret_decl(f_18842)
static void C_ccall f_18842(C_word c,C_word *av) C_noret;
C_noret_decl(f_18846)
static void C_ccall f_18846(C_word c,C_word *av) C_noret;
C_noret_decl(f_18855)
static void C_ccall f_18855(C_word c,C_word *av) C_noret;
C_noret_decl(f_18870)
static void C_ccall f_18870(C_word c,C_word *av) C_noret;
C_noret_decl(f_18874)
static void C_ccall f_18874(C_word c,C_word *av) C_noret;
C_noret_decl(f_18880)
static void C_fcall f_18880(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18893)
static void C_ccall f_18893(C_word c,C_word *av) C_noret;
C_noret_decl(f_18907)
static void C_ccall f_18907(C_word c,C_word *av) C_noret;
C_noret_decl(f_18908)
static void C_fcall f_18908(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18915)
static void C_fcall f_18915(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18918)
static void C_ccall f_18918(C_word c,C_word *av) C_noret;
C_noret_decl(f_18929)
static void C_ccall f_18929(C_word c,C_word *av) C_noret;
C_noret_decl(f_18933)
static void C_ccall f_18933(C_word c,C_word *av) C_noret;
C_noret_decl(f_18941)
static void C_fcall f_18941(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_18951)
static void C_ccall f_18951(C_word c,C_word *av) C_noret;
C_noret_decl(f_18972)
static void C_ccall f_18972(C_word c,C_word *av) C_noret;
C_noret_decl(f_18975)
static void C_fcall f_18975(C_word t0,C_word t1) C_noret;
C_noret_decl(f_18984)
static void C_ccall f_18984(C_word c,C_word *av) C_noret;
C_noret_decl(f_18997)
static void C_ccall f_18997(C_word c,C_word *av) C_noret;
C_noret_decl(f_19004)
static void C_ccall f_19004(C_word c,C_word *av) C_noret;
C_noret_decl(f_19007)
static void C_ccall f_19007(C_word c,C_word *av) C_noret;
C_noret_decl(f_19013)
static void C_ccall f_19013(C_word c,C_word *av) C_noret;
C_noret_decl(f_19045)
static void C_ccall f_19045(C_word c,C_word *av) C_noret;
C_noret_decl(f_19053)
static void C_ccall f_19053(C_word c,C_word *av) C_noret;
C_noret_decl(f_19055)
static void C_ccall f_19055(C_word c,C_word *av) C_noret;
C_noret_decl(f_19061)
static void C_ccall f_19061(C_word c,C_word *av) C_noret;
C_noret_decl(f_19073)
static void C_ccall f_19073(C_word c,C_word *av) C_noret;
C_noret_decl(f_19079)
static void C_ccall f_19079(C_word c,C_word *av) C_noret;
C_noret_decl(f_19090)
static void C_ccall f_19090(C_word c,C_word *av) C_noret;
C_noret_decl(f_19096)
static void C_ccall f_19096(C_word c,C_word *av) C_noret;
C_noret_decl(f_19100)
static void C_fcall f_19100(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19109)
static void C_ccall f_19109(C_word c,C_word *av) C_noret;
C_noret_decl(f_19117)
static void C_ccall f_19117(C_word c,C_word *av) C_noret;
C_noret_decl(f_19134)
static void C_ccall f_19134(C_word c,C_word *av) C_noret;
C_noret_decl(f_19141)
static void C_ccall f_19141(C_word c,C_word *av) C_noret;
C_noret_decl(f_19144)
static void C_ccall f_19144(C_word c,C_word *av) C_noret;
C_noret_decl(f_19148)
static void C_fcall f_19148(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19155)
static void C_ccall f_19155(C_word c,C_word *av) C_noret;
C_noret_decl(f_19161)
static void C_ccall f_19161(C_word c,C_word *av) C_noret;
C_noret_decl(f_19167)
static void C_ccall f_19167(C_word c,C_word *av) C_noret;
C_noret_decl(f_19185)
static void C_fcall f_19185(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19192)
static void C_ccall f_19192(C_word c,C_word *av) C_noret;
C_noret_decl(f_19198)
static void C_ccall f_19198(C_word c,C_word *av) C_noret;
C_noret_decl(f_19201)
static void C_ccall f_19201(C_word c,C_word *av) C_noret;
C_noret_decl(f_19204)
static void C_ccall f_19204(C_word c,C_word *av) C_noret;
C_noret_decl(f_19207)
static void C_ccall f_19207(C_word c,C_word *av) C_noret;
C_noret_decl(f_19241)
static void C_ccall f_19241(C_word c,C_word *av) C_noret;
C_noret_decl(f_19245)
static void C_ccall f_19245(C_word c,C_word *av) C_noret;
C_noret_decl(f_19249)
static void C_ccall f_19249(C_word c,C_word *av) C_noret;
C_noret_decl(f_19253)
static void C_ccall f_19253(C_word c,C_word *av) C_noret;
C_noret_decl(f_19259)
static void C_fcall f_19259(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19263)
static void C_fcall f_19263(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19281)
static void C_ccall f_19281(C_word c,C_word *av) C_noret;
C_noret_decl(f_19285)
static void C_ccall f_19285(C_word c,C_word *av) C_noret;
C_noret_decl(f_19293)
static void C_fcall f_19293(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19303)
static void C_ccall f_19303(C_word c,C_word *av) C_noret;
C_noret_decl(f_19328)
static C_word C_fcall f_19328(C_word t0,C_word t1);
C_noret_decl(f_19355)
static void C_ccall f_19355(C_word c,C_word *av) C_noret;
C_noret_decl(f_19358)
static void C_fcall f_19358(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_19364)
static void C_fcall f_19364(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_19369)
static void C_ccall f_19369(C_word c,C_word *av) C_noret;
C_noret_decl(f_19374)
static void C_fcall f_19374(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19381)
static void C_ccall f_19381(C_word c,C_word *av) C_noret;
C_noret_decl(f_19383)
static void C_fcall f_19383(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_19387)
static void C_ccall f_19387(C_word c,C_word *av) C_noret;
C_noret_decl(f_19390)
static void C_ccall f_19390(C_word c,C_word *av) C_noret;
C_noret_decl(f_19393)
static void C_ccall f_19393(C_word c,C_word *av) C_noret;
C_noret_decl(f_19423)
static void C_fcall f_19423(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19432)
static void C_ccall f_19432(C_word c,C_word *av) C_noret;
C_noret_decl(f_19435)
static void C_ccall f_19435(C_word c,C_word *av) C_noret;
C_noret_decl(f_19445)
static void C_ccall f_19445(C_word c,C_word *av) C_noret;
C_noret_decl(f_19449)
static void C_ccall f_19449(C_word c,C_word *av) C_noret;
C_noret_decl(f_19483)
static void C_ccall f_19483(C_word c,C_word *av) C_noret;
C_noret_decl(f_19517)
static void C_ccall f_19517(C_word c,C_word *av) C_noret;
C_noret_decl(f_19525)
static void C_fcall f_19525(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19535)
static void C_ccall f_19535(C_word c,C_word *av) C_noret;
C_noret_decl(f_19537)
static void C_fcall f_19537(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19562)
static void C_ccall f_19562(C_word c,C_word *av) C_noret;
C_noret_decl(f_19593)
static void C_ccall f_19593(C_word c,C_word *av) C_noret;
C_noret_decl(f_19599)
static void C_fcall f_19599(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19602)
static void C_ccall f_19602(C_word c,C_word *av) C_noret;
C_noret_decl(f_19611)
static void C_ccall f_19611(C_word c,C_word *av) C_noret;
C_noret_decl(f_19614)
static void C_ccall f_19614(C_word c,C_word *av) C_noret;
C_noret_decl(f_19617)
static void C_fcall f_19617(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19623)
static void C_fcall f_19623(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19626)
static void C_ccall f_19626(C_word c,C_word *av) C_noret;
C_noret_decl(f_19629)
static void C_ccall f_19629(C_word c,C_word *av) C_noret;
C_noret_decl(f_19642)
static void C_ccall f_19642(C_word c,C_word *av) C_noret;
C_noret_decl(f_19661)
static void C_ccall f_19661(C_word c,C_word *av) C_noret;
C_noret_decl(f_19679)
static void C_ccall f_19679(C_word c,C_word *av) C_noret;
C_noret_decl(f_19697)
static void C_ccall f_19697(C_word c,C_word *av) C_noret;
C_noret_decl(f_19707)
static void C_ccall f_19707(C_word c,C_word *av) C_noret;
C_noret_decl(f_19711)
static void C_ccall f_19711(C_word c,C_word *av) C_noret;
C_noret_decl(f_19719)
static void C_ccall f_19719(C_word c,C_word *av) C_noret;
C_noret_decl(f_19723)
static void C_ccall f_19723(C_word c,C_word *av) C_noret;
C_noret_decl(f_19727)
static void C_ccall f_19727(C_word c,C_word *av) C_noret;
C_noret_decl(f_19731)
static void C_ccall f_19731(C_word c,C_word *av) C_noret;
C_noret_decl(f_19759)
static void C_ccall f_19759(C_word c,C_word *av) C_noret;
C_noret_decl(f_19766)
static void C_ccall f_19766(C_word c,C_word *av) C_noret;
C_noret_decl(f_19771)
static void C_ccall f_19771(C_word c,C_word *av) C_noret;
C_noret_decl(f_19776)
static void C_ccall f_19776(C_word c,C_word *av) C_noret;
C_noret_decl(f_19780)
static void C_ccall f_19780(C_word c,C_word *av) C_noret;
C_noret_decl(f_19783)
static void C_ccall f_19783(C_word c,C_word *av) C_noret;
C_noret_decl(f_19786)
static void C_ccall f_19786(C_word c,C_word *av) C_noret;
C_noret_decl(f_19797)
static void C_ccall f_19797(C_word c,C_word *av) C_noret;
C_noret_decl(f_19803)
static void C_ccall f_19803(C_word c,C_word *av) C_noret;
C_noret_decl(f_19817)
static void C_fcall f_19817(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19827)
static void C_ccall f_19827(C_word c,C_word *av) C_noret;
C_noret_decl(f_19829)
static void C_fcall f_19829(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_19854)
static void C_ccall f_19854(C_word c,C_word *av) C_noret;
C_noret_decl(f_19914)
static void C_fcall f_19914(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_19918)
static void C_ccall f_19918(C_word c,C_word *av) C_noret;
C_noret_decl(f_19921)
static void C_ccall f_19921(C_word c,C_word *av) C_noret;
C_noret_decl(f_19924)
static void C_ccall f_19924(C_word c,C_word *av) C_noret;
C_noret_decl(f_19933)
static void C_fcall f_19933(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19945)
static void C_ccall f_19945(C_word c,C_word *av) C_noret;
C_noret_decl(f_19951)
static void C_ccall f_19951(C_word c,C_word *av) C_noret;
C_noret_decl(f_19967)
static void C_fcall f_19967(C_word t0,C_word t1) C_noret;
C_noret_decl(f_19970)
static void C_ccall f_19970(C_word c,C_word *av) C_noret;
C_noret_decl(f_19973)
static void C_ccall f_19973(C_word c,C_word *av) C_noret;
C_noret_decl(f_19976)
static void C_ccall f_19976(C_word c,C_word *av) C_noret;
C_noret_decl(f_19989)
static void C_ccall f_19989(C_word c,C_word *av) C_noret;
C_noret_decl(f_20002)
static void C_ccall f_20002(C_word c,C_word *av) C_noret;
C_noret_decl(f_20012)
static void C_ccall f_20012(C_word c,C_word *av) C_noret;
C_noret_decl(f_20053)
static void C_fcall f_20053(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20060)
static void C_ccall f_20060(C_word c,C_word *av) C_noret;
C_noret_decl(f_20064)
static void C_ccall f_20064(C_word c,C_word *av) C_noret;
C_noret_decl(f_20076)
static void C_ccall f_20076(C_word c,C_word *av) C_noret;
C_noret_decl(f_20079)
static void C_ccall f_20079(C_word c,C_word *av) C_noret;
C_noret_decl(f_20097)
static void C_ccall f_20097(C_word c,C_word *av) C_noret;
C_noret_decl(f_20101)
static void C_ccall f_20101(C_word c,C_word *av) C_noret;
C_noret_decl(f_20113)
static void C_ccall f_20113(C_word c,C_word *av) C_noret;
C_noret_decl(f_20117)
static void C_ccall f_20117(C_word c,C_word *av) C_noret;
C_noret_decl(f_20129)
static void C_ccall f_20129(C_word c,C_word *av) C_noret;
C_noret_decl(f_20140)
static void C_ccall f_20140(C_word c,C_word *av) C_noret;
C_noret_decl(f_20157)
static void C_ccall f_20157(C_word c,C_word *av) C_noret;
C_noret_decl(f_20161)
static void C_ccall f_20161(C_word c,C_word *av) C_noret;
C_noret_decl(f_20173)
static void C_ccall f_20173(C_word c,C_word *av) C_noret;
C_noret_decl(f_20182)
static void C_ccall f_20182(C_word c,C_word *av) C_noret;
C_noret_decl(f_20185)
static void C_ccall f_20185(C_word c,C_word *av) C_noret;
C_noret_decl(f_20191)
static void C_ccall f_20191(C_word c,C_word *av) C_noret;
C_noret_decl(f_20197)
static void C_ccall f_20197(C_word c,C_word *av) C_noret;
C_noret_decl(f_20203)
static void C_fcall f_20203(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20206)
static void C_ccall f_20206(C_word c,C_word *av) C_noret;
C_noret_decl(f_20221)
static void C_ccall f_20221(C_word c,C_word *av) C_noret;
C_noret_decl(f_20226)
static void C_fcall f_20226(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20234)
static void C_ccall f_20234(C_word c,C_word *av) C_noret;
C_noret_decl(f_20240)
static void C_ccall f_20240(C_word c,C_word *av) C_noret;
C_noret_decl(f_20243)
static void C_ccall f_20243(C_word c,C_word *av) C_noret;
C_noret_decl(f_20254)
static void C_ccall f_20254(C_word c,C_word *av) C_noret;
C_noret_decl(f_20258)
static void C_ccall f_20258(C_word c,C_word *av) C_noret;
C_noret_decl(f_20262)
static void C_ccall f_20262(C_word c,C_word *av) C_noret;
C_noret_decl(f_20270)
static void C_ccall f_20270(C_word c,C_word *av) C_noret;
C_noret_decl(f_20277)
static void C_ccall f_20277(C_word c,C_word *av) C_noret;
C_noret_decl(f_20283)
static void C_fcall f_20283(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20308)
static void C_ccall f_20308(C_word c,C_word *av) C_noret;
C_noret_decl(f_20327)
static void C_ccall f_20327(C_word c,C_word *av) C_noret;
C_noret_decl(f_20330)
static void C_ccall f_20330(C_word c,C_word *av) C_noret;
C_noret_decl(f_20340)
static void C_ccall f_20340(C_word c,C_word *av) C_noret;
C_noret_decl(f_20357)
static void C_ccall f_20357(C_word c,C_word *av) C_noret;
C_noret_decl(f_20367)
static void C_ccall f_20367(C_word c,C_word *av) C_noret;
C_noret_decl(f_20369)
static void C_fcall f_20369(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_20395)
static void C_ccall f_20395(C_word c,C_word *av) C_noret;
C_noret_decl(f_20405)
static void C_fcall f_20405(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20430)
static void C_ccall f_20430(C_word c,C_word *av) C_noret;
C_noret_decl(f_20457)
static void C_ccall f_20457(C_word c,C_word *av) C_noret;
C_noret_decl(f_20462)
static C_word C_fcall f_20462(C_word t0,C_word t1);
C_noret_decl(f_20478)
static void C_ccall f_20478(C_word c,C_word *av) C_noret;
C_noret_decl(f_20493)
static void C_fcall f_20493(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20536)
static void C_ccall f_20536(C_word c,C_word *av) C_noret;
C_noret_decl(f_20542)
static void C_ccall f_20542(C_word c,C_word *av) C_noret;
C_noret_decl(f_20570)
static void C_fcall f_20570(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_20618)
static void C_fcall f_20618(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20643)
static void C_ccall f_20643(C_word c,C_word *av) C_noret;
C_noret_decl(f_20652)
static void C_ccall f_20652(C_word c,C_word *av) C_noret;
C_noret_decl(f_20671)
static void C_ccall f_20671(C_word c,C_word *av) C_noret;
C_noret_decl(f_20674)
static void C_ccall f_20674(C_word c,C_word *av) C_noret;
C_noret_decl(f_20677)
static void C_fcall f_20677(C_word t0,C_word t1) C_noret;
C_noret_decl(f_20680)
static void C_ccall f_20680(C_word c,C_word *av) C_noret;
C_noret_decl(f_20684)
static void C_fcall f_20684(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_20691)
static void C_ccall f_20691(C_word c,C_word *av) C_noret;
C_noret_decl(f_20706)
static void C_ccall f_20706(C_word c,C_word *av) C_noret;
C_noret_decl(f_20710)
static void C_ccall f_20710(C_word c,C_word *av) C_noret;
C_noret_decl(f_20722)
static void C_ccall f_20722(C_word c,C_word *av) C_noret;
C_noret_decl(f_20743)
static void C_ccall f_20743(C_word c,C_word *av) C_noret;
C_noret_decl(f_20747)
static void C_ccall f_20747(C_word c,C_word *av) C_noret;
C_noret_decl(f_20758)
static void C_ccall f_20758(C_word c,C_word *av) C_noret;
C_noret_decl(f_20773)
static void C_ccall f_20773(C_word c,C_word *av) C_noret;
C_noret_decl(f_20777)
static void C_ccall f_20777(C_word c,C_word *av) C_noret;
C_noret_decl(f_20792)
static void C_ccall f_20792(C_word c,C_word *av) C_noret;
C_noret_decl(f_20825)
static void C_ccall f_20825(C_word c,C_word *av) C_noret;
C_noret_decl(f_20846)
static void C_ccall f_20846(C_word c,C_word *av) C_noret;
C_noret_decl(f_20857)
static void C_ccall f_20857(C_word c,C_word *av) C_noret;
C_noret_decl(f_20861)
static void C_ccall f_20861(C_word c,C_word *av) C_noret;
C_noret_decl(f_21100)
static void C_fcall f_21100(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_21105)
static void C_fcall f_21105(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21117)
static void C_fcall f_21117(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21142)
static void C_ccall f_21142(C_word c,C_word *av) C_noret;
C_noret_decl(f_21151)
static void C_fcall f_21151(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_21158)
static void C_ccall f_21158(C_word c,C_word *av) C_noret;
C_noret_decl(f_21162)
static void C_fcall f_21162(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21178)
static void C_ccall f_21178(C_word c,C_word *av) C_noret;
C_noret_decl(f_21189)
static void C_ccall f_21189(C_word c,C_word *av) C_noret;
C_noret_decl(f_21192)
static void C_ccall f_21192(C_word c,C_word *av) C_noret;
C_noret_decl(f_21195)
static void C_ccall f_21195(C_word c,C_word *av) C_noret;
C_noret_decl(f_21198)
static void C_ccall f_21198(C_word c,C_word *av) C_noret;
C_noret_decl(f_21201)
static void C_ccall f_21201(C_word c,C_word *av) C_noret;
C_noret_decl(f_21204)
static void C_ccall f_21204(C_word c,C_word *av) C_noret;
C_noret_decl(f_21207)
static void C_ccall f_21207(C_word c,C_word *av) C_noret;
C_noret_decl(f_21232)
static void C_ccall f_21232(C_word c,C_word *av) C_noret;
C_noret_decl(f_21241)
static void C_ccall f_21241(C_word c,C_word *av) C_noret;
C_noret_decl(f_21259)
static void C_ccall f_21259(C_word c,C_word *av) C_noret;
C_noret_decl(f_21268)
static void C_ccall f_21268(C_word c,C_word *av) C_noret;
C_noret_decl(f_21277)
static void C_ccall f_21277(C_word c,C_word *av) C_noret;
C_noret_decl(f_21286)
static void C_ccall f_21286(C_word c,C_word *av) C_noret;
C_noret_decl(f_21295)
static void C_ccall f_21295(C_word c,C_word *av) C_noret;
C_noret_decl(f_21304)
static void C_ccall f_21304(C_word c,C_word *av) C_noret;
C_noret_decl(f_21322)
static void C_ccall f_21322(C_word c,C_word *av) C_noret;
C_noret_decl(f_21331)
static void C_ccall f_21331(C_word c,C_word *av) C_noret;
C_noret_decl(f_21340)
static void C_ccall f_21340(C_word c,C_word *av) C_noret;
C_noret_decl(f_21349)
static void C_ccall f_21349(C_word c,C_word *av) C_noret;
C_noret_decl(f_21358)
static void C_ccall f_21358(C_word c,C_word *av) C_noret;
C_noret_decl(f_21367)
static void C_ccall f_21367(C_word c,C_word *av) C_noret;
C_noret_decl(f_21376)
static void C_ccall f_21376(C_word c,C_word *av) C_noret;
C_noret_decl(f_21380)
static void C_ccall f_21380(C_word c,C_word *av) C_noret;
C_noret_decl(f_21382)
static void C_fcall f_21382(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5) C_noret;
C_noret_decl(f_21386)
static void C_ccall f_21386(C_word c,C_word *av) C_noret;
C_noret_decl(f_21390)
static void C_fcall f_21390(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_21415)
static void C_ccall f_21415(C_word c,C_word *av) C_noret;
C_noret_decl(f_21426)
static void C_ccall f_21426(C_word c,C_word *av) C_noret;
C_noret_decl(f_21431)
static void C_fcall f_21431(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_21435)
static void C_ccall f_21435(C_word c,C_word *av) C_noret;
C_noret_decl(f_21438)
static void C_fcall f_21438(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21441)
static void C_fcall f_21441(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21452)
static void C_ccall f_21452(C_word c,C_word *av) C_noret;
C_noret_decl(f_21463)
static void C_ccall f_21463(C_word c,C_word *av) C_noret;
C_noret_decl(f_21470)
static void C_ccall f_21470(C_word c,C_word *av) C_noret;
C_noret_decl(f_21479)
static void C_ccall f_21479(C_word c,C_word *av) C_noret;
C_noret_decl(f_21487)
static void C_fcall f_21487(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_21491)
static void C_ccall f_21491(C_word c,C_word *av) C_noret;
C_noret_decl(f_21494)
static void C_ccall f_21494(C_word c,C_word *av) C_noret;
C_noret_decl(f_21497)
static void C_ccall f_21497(C_word c,C_word *av) C_noret;
C_noret_decl(f_21506)
static void C_fcall f_21506(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21534)
static void C_fcall f_21534(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21545)
static void C_ccall f_21545(C_word c,C_word *av) C_noret;
C_noret_decl(f_21565)
static void C_ccall f_21565(C_word c,C_word *av) C_noret;
C_noret_decl(f_21569)
static void C_ccall f_21569(C_word c,C_word *av) C_noret;
C_noret_decl(f_21590)
static void C_ccall f_21590(C_word c,C_word *av) C_noret;
C_noret_decl(f_21611)
static void C_ccall f_21611(C_word c,C_word *av) C_noret;
C_noret_decl(f_21628)
static void C_ccall f_21628(C_word c,C_word *av) C_noret;
C_noret_decl(f_21632)
static void C_ccall f_21632(C_word c,C_word *av) C_noret;
C_noret_decl(f_21653)
static void C_ccall f_21653(C_word c,C_word *av) C_noret;
C_noret_decl(f_21657)
static void C_ccall f_21657(C_word c,C_word *av) C_noret;
C_noret_decl(f_21661)
static void C_ccall f_21661(C_word c,C_word *av) C_noret;
C_noret_decl(f_21682)
static void C_ccall f_21682(C_word c,C_word *av) C_noret;
C_noret_decl(f_21707)
static void C_ccall f_21707(C_word c,C_word *av) C_noret;
C_noret_decl(f_21723)
static void C_ccall f_21723(C_word c,C_word *av) C_noret;
C_noret_decl(f_21733)
static void C_fcall f_21733(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21749)
static void C_ccall f_21749(C_word c,C_word *av) C_noret;
C_noret_decl(f_21753)
static void C_ccall f_21753(C_word c,C_word *av) C_noret;
C_noret_decl(f_21762)
static void C_ccall f_21762(C_word c,C_word *av) C_noret;
C_noret_decl(f_21803)
static void C_ccall f_21803(C_word c,C_word *av) C_noret;
C_noret_decl(f_21810)
static void C_ccall f_21810(C_word c,C_word *av) C_noret;
C_noret_decl(f_21813)
static void C_ccall f_21813(C_word c,C_word *av) C_noret;
C_noret_decl(f_21816)
static void C_ccall f_21816(C_word c,C_word *av) C_noret;
C_noret_decl(f_21819)
static void C_ccall f_21819(C_word c,C_word *av) C_noret;
C_noret_decl(f_21822)
static void C_ccall f_21822(C_word c,C_word *av) C_noret;
C_noret_decl(f_21830)
static void C_ccall f_21830(C_word c,C_word *av) C_noret;
C_noret_decl(f_21859)
static void C_ccall f_21859(C_word c,C_word *av) C_noret;
C_noret_decl(f_21866)
static void C_fcall f_21866(C_word t0,C_word t1) C_noret;
C_noret_decl(f_21870)
static void C_ccall f_21870(C_word c,C_word *av) C_noret;
C_noret_decl(f_21885)
static void C_ccall f_21885(C_word c,C_word *av) C_noret;
C_noret_decl(f_21908)
static void C_ccall f_21908(C_word c,C_word *av) C_noret;
C_noret_decl(f_21929)
static void C_ccall f_21929(C_word c,C_word *av) C_noret;
C_noret_decl(f_21938)
static void C_ccall f_21938(C_word c,C_word *av) C_noret;
C_noret_decl(f_21944)
static void C_ccall f_21944(C_word c,C_word *av) C_noret;
C_noret_decl(f_21969)
static void C_ccall f_21969(C_word c,C_word *av) C_noret;
C_noret_decl(f_22001)
static void C_ccall f_22001(C_word c,C_word *av) C_noret;
C_noret_decl(f_22005)
static void C_ccall f_22005(C_word c,C_word *av) C_noret;
C_noret_decl(f_22013)
static void C_ccall f_22013(C_word c,C_word *av) C_noret;
C_noret_decl(f_22021)
static void C_ccall f_22021(C_word c,C_word *av) C_noret;
C_noret_decl(f_22025)
static void C_ccall f_22025(C_word c,C_word *av) C_noret;
C_noret_decl(f_22035)
static void C_ccall f_22035(C_word c,C_word *av) C_noret;
C_noret_decl(f_22062)
static void C_ccall f_22062(C_word c,C_word *av) C_noret;
C_noret_decl(f_22066)
static void C_ccall f_22066(C_word c,C_word *av) C_noret;
C_noret_decl(f_22085)
static void C_ccall f_22085(C_word c,C_word *av) C_noret;
C_noret_decl(f_22089)
static void C_fcall f_22089(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22105)
static void C_ccall f_22105(C_word c,C_word *av) C_noret;
C_noret_decl(f_22119)
static void C_ccall f_22119(C_word c,C_word *av) C_noret;
C_noret_decl(f_22125)
static void C_ccall f_22125(C_word c,C_word *av) C_noret;
C_noret_decl(f_22128)
static void C_fcall f_22128(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22131)
static void C_fcall f_22131(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22150)
static void C_ccall f_22150(C_word c,C_word *av) C_noret;
C_noret_decl(f_22158)
static void C_ccall f_22158(C_word c,C_word *av) C_noret;
C_noret_decl(f_22199)
static void C_ccall f_22199(C_word c,C_word *av) C_noret;
C_noret_decl(f_22203)
static void C_ccall f_22203(C_word c,C_word *av) C_noret;
C_noret_decl(f_22218)
static void C_fcall f_22218(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22222)
static void C_ccall f_22222(C_word c,C_word *av) C_noret;
C_noret_decl(f_22225)
static void C_fcall f_22225(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22228)
static void C_fcall f_22228(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22235)
static void C_ccall f_22235(C_word c,C_word *av) C_noret;
C_noret_decl(f_22255)
static void C_ccall f_22255(C_word c,C_word *av) C_noret;
C_noret_decl(f_22259)
static void C_ccall f_22259(C_word c,C_word *av) C_noret;
C_noret_decl(f_22266)
static void C_fcall f_22266(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22303)
static void C_fcall f_22303(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22310)
static void C_ccall f_22310(C_word c,C_word *av) C_noret;
C_noret_decl(f_22330)
static void C_fcall f_22330(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22351)
static void C_fcall f_22351(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22354)
static void C_ccall f_22354(C_word c,C_word *av) C_noret;
C_noret_decl(f_22361)
static void C_ccall f_22361(C_word c,C_word *av) C_noret;
C_noret_decl(f_22365)
static void C_ccall f_22365(C_word c,C_word *av) C_noret;
C_noret_decl(f_22371)
static void C_ccall f_22371(C_word c,C_word *av) C_noret;
C_noret_decl(f_22374)
static void C_ccall f_22374(C_word c,C_word *av) C_noret;
C_noret_decl(f_22377)
static void C_ccall f_22377(C_word c,C_word *av) C_noret;
C_noret_decl(f_22380)
static void C_ccall f_22380(C_word c,C_word *av) C_noret;
C_noret_decl(f_22383)
static void C_ccall f_22383(C_word c,C_word *av) C_noret;
C_noret_decl(f_22387)
static void C_ccall f_22387(C_word c,C_word *av) C_noret;
C_noret_decl(f_22398)
static void C_ccall f_22398(C_word c,C_word *av) C_noret;
C_noret_decl(f_22409)
static void C_ccall f_22409(C_word c,C_word *av) C_noret;
C_noret_decl(f_22415)
static void C_ccall f_22415(C_word c,C_word *av) C_noret;
C_noret_decl(f_22429)
static void C_ccall f_22429(C_word c,C_word *av) C_noret;
C_noret_decl(f_22439)
static void C_ccall f_22439(C_word c,C_word *av) C_noret;
C_noret_decl(f_22451)
static void C_ccall f_22451(C_word c,C_word *av) C_noret;
C_noret_decl(f_22454)
static void C_ccall f_22454(C_word c,C_word *av) C_noret;
C_noret_decl(f_22457)
static void C_ccall f_22457(C_word c,C_word *av) C_noret;
C_noret_decl(f_22476)
static void C_ccall f_22476(C_word c,C_word *av) C_noret;
C_noret_decl(f_22488)
static void C_ccall f_22488(C_word c,C_word *av) C_noret;
C_noret_decl(f_22517)
static void C_ccall f_22517(C_word c,C_word *av) C_noret;
C_noret_decl(f_22528)
static void C_ccall f_22528(C_word c,C_word *av) C_noret;
C_noret_decl(f_22538)
static void C_fcall f_22538(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_22547)
static void C_ccall f_22547(C_word c,C_word *av) C_noret;
C_noret_decl(f_22558)
static void C_ccall f_22558(C_word c,C_word *av) C_noret;
C_noret_decl(f_22569)
static void C_ccall f_22569(C_word c,C_word *av) C_noret;
C_noret_decl(f_22572)
static void C_ccall f_22572(C_word c,C_word *av) C_noret;
C_noret_decl(f_22579)
static void C_ccall f_22579(C_word c,C_word *av) C_noret;
C_noret_decl(f_22589)
static void C_ccall f_22589(C_word c,C_word *av) C_noret;
C_noret_decl(f_22630)
static void C_ccall f_22630(C_word c,C_word *av) C_noret;
C_noret_decl(f_22697)
static void C_fcall f_22697(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6) C_noret;
C_noret_decl(f_22702)
static void C_fcall f_22702(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22714)
static void C_fcall f_22714(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22739)
static void C_ccall f_22739(C_word c,C_word *av) C_noret;
C_noret_decl(f_22748)
static void C_fcall f_22748(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22755)
static void C_ccall f_22755(C_word c,C_word *av) C_noret;
C_noret_decl(f_22780)
static C_word C_fcall f_22780(C_word t0,C_word t1);
C_noret_decl(f_22796)
static C_word C_fcall f_22796(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_22805)
static void C_fcall f_22805(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22809)
static void C_ccall f_22809(C_word c,C_word *av) C_noret;
C_noret_decl(f_22813)
static C_word C_fcall f_22813(C_word t0,C_word t1);
C_noret_decl(f_22831)
static void C_ccall f_22831(C_word c,C_word *av) C_noret;
C_noret_decl(f_22833)
static void C_fcall f_22833(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_22840)
static void C_ccall f_22840(C_word c,C_word *av) C_noret;
C_noret_decl(f_22847)
static void C_ccall f_22847(C_word c,C_word *av) C_noret;
C_noret_decl(f_22849)
static void C_fcall f_22849(C_word t0,C_word t1) C_noret;
C_noret_decl(f_22866)
static void C_ccall f_22866(C_word c,C_word *av) C_noret;
C_noret_decl(f_22915)
static void C_ccall f_22915(C_word c,C_word *av) C_noret;
C_noret_decl(f_22918)
static void C_ccall f_22918(C_word c,C_word *av) C_noret;
C_noret_decl(f_22921)
static void C_ccall f_22921(C_word c,C_word *av) C_noret;
C_noret_decl(f_22924)
static void C_ccall f_22924(C_word c,C_word *av) C_noret;
C_noret_decl(f_22927)
static void C_ccall f_22927(C_word c,C_word *av) C_noret;
C_noret_decl(f_22934)
static void C_ccall f_22934(C_word c,C_word *av) C_noret;
C_noret_decl(f_22938)
static void C_ccall f_22938(C_word c,C_word *av) C_noret;
C_noret_decl(f_22942)
static void C_ccall f_22942(C_word c,C_word *av) C_noret;
C_noret_decl(f_6227)
static void C_ccall f_6227(C_word c,C_word *av) C_noret;
C_noret_decl(f_6230)
static void C_ccall f_6230(C_word c,C_word *av) C_noret;
C_noret_decl(f_6233)
static void C_ccall f_6233(C_word c,C_word *av) C_noret;
C_noret_decl(f_6236)
static void C_ccall f_6236(C_word c,C_word *av) C_noret;
C_noret_decl(f_6239)
static void C_ccall f_6239(C_word c,C_word *av) C_noret;
C_noret_decl(f_6242)
static void C_ccall f_6242(C_word c,C_word *av) C_noret;
C_noret_decl(f_6245)
static void C_ccall f_6245(C_word c,C_word *av) C_noret;
C_noret_decl(f_6248)
static void C_ccall f_6248(C_word c,C_word *av) C_noret;
C_noret_decl(f_6251)
static void C_ccall f_6251(C_word c,C_word *av) C_noret;
C_noret_decl(f_6254)
static void C_ccall f_6254(C_word c,C_word *av) C_noret;
C_noret_decl(f_6440)
static void C_fcall f_6440(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_6454)
static void C_ccall f_6454(C_word c,C_word *av) C_noret;
C_noret_decl(f_6643)
static void C_fcall f_6643(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6649)
static void C_fcall f_6649(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6671)
static void C_ccall f_6671(C_word c,C_word *av) C_noret;
C_noret_decl(f_6683)
static C_word C_fcall f_6683(C_word t0,C_word t1);
C_noret_decl(f_6707)
static void C_fcall f_6707(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6713)
static void C_fcall f_6713(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_6727)
static void C_ccall f_6727(C_word c,C_word *av) C_noret;
C_noret_decl(f_6735)
static void C_fcall f_6735(C_word t0,C_word t1) C_noret;
C_noret_decl(f_6741)
static void C_fcall f_6741(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6759)
static void C_ccall f_6759(C_word c,C_word *av) C_noret;
C_noret_decl(f_6763)
static void C_fcall f_6763(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_6769)
static void C_fcall f_6769(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6782)
static void C_ccall f_6782(C_word c,C_word *av) C_noret;
C_noret_decl(f_6796)
static void C_ccall f_6796(C_word c,C_word *av) C_noret;
C_noret_decl(f_6844)
static void C_fcall f_6844(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6858)
static void C_ccall f_6858(C_word c,C_word *av) C_noret;
C_noret_decl(f_6871)
static void C_ccall f_6871(C_word c,C_word *av) C_noret;
C_noret_decl(f_6883)
static void C_fcall f_6883(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6892)
static void C_fcall f_6892(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6900)
static void C_fcall f_6900(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_6907)
static void C_ccall f_6907(C_word c,C_word *av) C_noret;
C_noret_decl(f_6921)
static void C_ccall f_6921(C_word c,C_word *av) C_noret;
C_noret_decl(f_6936)
static void C_fcall f_6936(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_6944)
static void C_fcall f_6944(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_6948)
static void C_ccall f_6948(C_word c,C_word *av) C_noret;
C_noret_decl(f_6952)
static C_word C_fcall f_6952(C_word *a,C_word t0,C_word t1);
C_noret_decl(f_6970)
static void C_ccall f_6970(C_word c,C_word *av) C_noret;
C_noret_decl(f_6992)
static void C_fcall f_6992(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7009)
static void C_fcall f_7009(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7049)
static C_word C_fcall f_7049(C_word t0);
C_noret_decl(f_7074)
static void C_fcall f_7074(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7087)
static void C_ccall f_7087(C_word c,C_word *av) C_noret;
C_noret_decl(f_7102)
static void C_fcall f_7102(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7108)
static void C_fcall f_7108(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7143)
static void C_fcall f_7143(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7149)
static void C_fcall f_7149(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7171)
static void C_ccall f_7171(C_word c,C_word *av) C_noret;
C_noret_decl(f_7182)
static void C_ccall f_7182(C_word c,C_word *av) C_noret;
C_noret_decl(f_7188)
static void C_fcall f_7188(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7194)
static void C_fcall f_7194(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7219)
static void C_fcall f_7219(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7247)
static C_word C_fcall f_7247(C_word t0,C_word t1);
C_noret_decl(f_7261)
static void C_ccall f_7261(C_word c,C_word *av) C_noret;
C_noret_decl(f_7267)
static void C_fcall f_7267(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7273)
static void C_ccall f_7273(C_word c,C_word *av) C_noret;
C_noret_decl(f_7279)
static void C_ccall f_7279(C_word c,C_word *av) C_noret;
C_noret_decl(f_7486)
static void C_fcall f_7486(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7492)
static C_word C_fcall f_7492(C_word t0,C_word t1,C_word t2);
C_noret_decl(f_7526)
static C_word C_fcall f_7526(C_word t0,C_word t1,C_word t2);
C_noret_decl(f_7622)
static void C_ccall f_7622(C_word c,C_word *av) C_noret;
C_noret_decl(f_7626)
static void C_ccall f_7626(C_word c,C_word *av) C_noret;
C_noret_decl(f_7629)
static void C_ccall f_7629(C_word c,C_word *av) C_noret;
C_noret_decl(f_7632)
static void C_ccall f_7632(C_word c,C_word *av) C_noret;
C_noret_decl(f_7635)
static void C_ccall f_7635(C_word c,C_word *av) C_noret;
C_noret_decl(f_7638)
static void C_ccall f_7638(C_word c,C_word *av) C_noret;
C_noret_decl(f_7648)
static void C_ccall f_7648(C_word c,C_word *av) C_noret;
C_noret_decl(f_7655)
static void C_ccall f_7655(C_word c,C_word *av) C_noret;
C_noret_decl(f_7662)
static void C_ccall f_7662(C_word c,C_word *av) C_noret;
C_noret_decl(f_7664)
static void C_ccall f_7664(C_word c,C_word *av) C_noret;
C_noret_decl(f_7668)
static void C_ccall f_7668(C_word c,C_word *av) C_noret;
C_noret_decl(f_7673)
static void C_ccall f_7673(C_word c,C_word *av) C_noret;
C_noret_decl(f_7675)
static void C_fcall f_7675(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7717)
static void C_ccall f_7717(C_word c,C_word *av) C_noret;
C_noret_decl(f_7749)
static void C_fcall f_7749(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7759)
static void C_ccall f_7759(C_word c,C_word *av) C_noret;
C_noret_decl(f_7772)
static void C_ccall f_7772(C_word c,C_word *av) C_noret;
C_noret_decl(f_7775)
static void C_fcall f_7775(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7788)
static void C_fcall f_7788(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7810)
static void C_fcall f_7810(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7814)
static void C_ccall f_7814(C_word c,C_word *av) C_noret;
C_noret_decl(f_7822)
static void C_ccall f_7822(C_word c,C_word *av) C_noret;
C_noret_decl(f_7828)
static void C_ccall f_7828(C_word c,C_word *av) C_noret;
C_noret_decl(f_7835)
static void C_ccall f_7835(C_word c,C_word *av) C_noret;
C_noret_decl(f_7842)
static void C_ccall f_7842(C_word c,C_word *av) C_noret;
C_noret_decl(f_7844)
static void C_fcall f_7844(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7848)
static void C_ccall f_7848(C_word c,C_word *av) C_noret;
C_noret_decl(f_7851)
static void C_ccall f_7851(C_word c,C_word *av) C_noret;
C_noret_decl(f_7855)
static void C_ccall f_7855(C_word c,C_word *av) C_noret;
C_noret_decl(f_7857)
static void C_fcall f_7857(C_word t0,C_word t1) C_noret;
C_noret_decl(f_7859)
static void C_ccall f_7859(C_word c,C_word *av) C_noret;
C_noret_decl(f_7866)
static void C_ccall f_7866(C_word c,C_word *av) C_noret;
C_noret_decl(f_7869)
static void C_ccall f_7869(C_word c,C_word *av) C_noret;
C_noret_decl(f_7884)
static void C_fcall f_7884(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4) C_noret;
C_noret_decl(f_7888)
static void C_ccall f_7888(C_word c,C_word *av) C_noret;
C_noret_decl(f_7893)
static void C_ccall f_7893(C_word c,C_word *av) C_noret;
C_noret_decl(f_7898)
static void C_ccall f_7898(C_word c,C_word *av) C_noret;
C_noret_decl(f_7906)
static void C_ccall f_7906(C_word c,C_word *av) C_noret;
C_noret_decl(f_7908)
static void C_ccall f_7908(C_word c,C_word *av) C_noret;
C_noret_decl(f_7913)
static void C_fcall f_7913(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_7930)
static void C_fcall f_7930(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_7940)
static void C_ccall f_7940(C_word c,C_word *av) C_noret;
C_noret_decl(f_7979)
static void C_fcall f_7979(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8011)
static void C_ccall f_8011(C_word c,C_word *av) C_noret;
C_noret_decl(f_8022)
static void C_fcall f_8022(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7) C_noret;
C_noret_decl(f_8026)
static void C_ccall f_8026(C_word c,C_word *av) C_noret;
C_noret_decl(f_8029)
static void C_ccall f_8029(C_word c,C_word *av) C_noret;
C_noret_decl(f_8041)
static void C_ccall f_8041(C_word c,C_word *av) C_noret;
C_noret_decl(f_8045)
static void C_fcall f_8045(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8055)
static void C_ccall f_8055(C_word c,C_word *av) C_noret;
C_noret_decl(f_8059)
static void C_fcall f_8059(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8073)
static void C_fcall f_8073(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8080)
static void C_ccall f_8080(C_word c,C_word *av) C_noret;
C_noret_decl(f_8090)
static void C_ccall f_8090(C_word c,C_word *av) C_noret;
C_noret_decl(f_8094)
static void C_ccall f_8094(C_word c,C_word *av) C_noret;
C_noret_decl(f_8112)
static void C_fcall f_8112(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8119)
static void C_ccall f_8119(C_word c,C_word *av) C_noret;
C_noret_decl(f_8129)
static void C_ccall f_8129(C_word c,C_word *av) C_noret;
C_noret_decl(f_8133)
static void C_ccall f_8133(C_word c,C_word *av) C_noret;
C_noret_decl(f_8164)
static void C_fcall f_8164(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8175)
static void C_ccall f_8175(C_word c,C_word *av) C_noret;
C_noret_decl(f_8179)
static void C_ccall f_8179(C_word c,C_word *av) C_noret;
C_noret_decl(f_8182)
static void C_ccall f_8182(C_word c,C_word *av) C_noret;
C_noret_decl(f_8188)
static void C_ccall f_8188(C_word c,C_word *av) C_noret;
C_noret_decl(f_8191)
static void C_ccall f_8191(C_word c,C_word *av) C_noret;
C_noret_decl(f_8194)
static void C_ccall f_8194(C_word c,C_word *av) C_noret;
C_noret_decl(f_8218)
static void C_ccall f_8218(C_word c,C_word *av) C_noret;
C_noret_decl(f_8224)
static void C_ccall f_8224(C_word c,C_word *av) C_noret;
C_noret_decl(f_8227)
static void C_ccall f_8227(C_word c,C_word *av) C_noret;
C_noret_decl(f_8230)
static void C_ccall f_8230(C_word c,C_word *av) C_noret;
C_noret_decl(f_8233)
static void C_ccall f_8233(C_word c,C_word *av) C_noret;
C_noret_decl(f_8239)
static void C_ccall f_8239(C_word c,C_word *av) C_noret;
C_noret_decl(f_8242)
static void C_ccall f_8242(C_word c,C_word *av) C_noret;
C_noret_decl(f_8245)
static void C_ccall f_8245(C_word c,C_word *av) C_noret;
C_noret_decl(f_8260)
static void C_ccall f_8260(C_word c,C_word *av) C_noret;
C_noret_decl(f_8265)
static void C_ccall f_8265(C_word c,C_word *av) C_noret;
C_noret_decl(f_8269)
static void C_ccall f_8269(C_word c,C_word *av) C_noret;
C_noret_decl(f_8275)
static void C_ccall f_8275(C_word c,C_word *av) C_noret;
C_noret_decl(f_8280)
static void C_fcall f_8280(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8290)
static void C_ccall f_8290(C_word c,C_word *av) C_noret;
C_noret_decl(f_8305)
static void C_ccall f_8305(C_word c,C_word *av) C_noret;
C_noret_decl(f_8314)
static void C_ccall f_8314(C_word c,C_word *av) C_noret;
C_noret_decl(f_8324)
static void C_ccall f_8324(C_word c,C_word *av) C_noret;
C_noret_decl(f_8330)
static void C_fcall f_8330(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7,C_word t8) C_noret;
C_noret_decl(f_8337)
static void C_ccall f_8337(C_word c,C_word *av) C_noret;
C_noret_decl(f_8361)
static void C_ccall f_8361(C_word c,C_word *av) C_noret;
C_noret_decl(f_8376)
static void C_ccall f_8376(C_word c,C_word *av) C_noret;
C_noret_decl(f_8382)
static void C_ccall f_8382(C_word c,C_word *av) C_noret;
C_noret_decl(f_8385)
static void C_ccall f_8385(C_word c,C_word *av) C_noret;
C_noret_decl(f_8389)
static void C_ccall f_8389(C_word c,C_word *av) C_noret;
C_noret_decl(f_8392)
static void C_ccall f_8392(C_word c,C_word *av) C_noret;
C_noret_decl(f_8395)
static void C_ccall f_8395(C_word c,C_word *av) C_noret;
C_noret_decl(f_8407)
static void C_ccall f_8407(C_word c,C_word *av) C_noret;
C_noret_decl(f_8411)
static void C_fcall f_8411(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8439)
static void C_ccall f_8439(C_word c,C_word *av) C_noret;
C_noret_decl(f_8443)
static void C_ccall f_8443(C_word c,C_word *av) C_noret;
C_noret_decl(f_8447)
static void C_ccall f_8447(C_word c,C_word *av) C_noret;
C_noret_decl(f_8485)
static void C_ccall f_8485(C_word c,C_word *av) C_noret;
C_noret_decl(f_8518)
static void C_ccall f_8518(C_word c,C_word *av) C_noret;
C_noret_decl(f_8526)
static void C_ccall f_8526(C_word c,C_word *av) C_noret;
C_noret_decl(f_8543)
static void C_ccall f_8543(C_word c,C_word *av) C_noret;
C_noret_decl(f_8549)
static void C_ccall f_8549(C_word c,C_word *av) C_noret;
C_noret_decl(f_8552)
static void C_ccall f_8552(C_word c,C_word *av) C_noret;
C_noret_decl(f_8553)
static void C_ccall f_8553(C_word c,C_word *av) C_noret;
C_noret_decl(f_8567)
static void C_ccall f_8567(C_word c,C_word *av) C_noret;
C_noret_decl(f_8571)
static void C_ccall f_8571(C_word c,C_word *av) C_noret;
C_noret_decl(f_8585)
static void C_ccall f_8585(C_word c,C_word *av) C_noret;
C_noret_decl(f_8589)
static void C_ccall f_8589(C_word c,C_word *av) C_noret;
C_noret_decl(f_8593)
static void C_ccall f_8593(C_word c,C_word *av) C_noret;
C_noret_decl(f_8626)
static void C_ccall f_8626(C_word c,C_word *av) C_noret;
C_noret_decl(f_8631)
static void C_fcall f_8631(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8639)
static void C_ccall f_8639(C_word c,C_word *av) C_noret;
C_noret_decl(f_8643)
static void C_ccall f_8643(C_word c,C_word *av) C_noret;
C_noret_decl(f_8660)
static void C_ccall f_8660(C_word c,C_word *av) C_noret;
C_noret_decl(f_8662)
static void C_fcall f_8662(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_8687)
static void C_ccall f_8687(C_word c,C_word *av) C_noret;
C_noret_decl(f_8710)
static void C_ccall f_8710(C_word c,C_word *av) C_noret;
C_noret_decl(f_8722)
static void C_ccall f_8722(C_word c,C_word *av) C_noret;
C_noret_decl(f_8729)
static void C_ccall f_8729(C_word c,C_word *av) C_noret;
C_noret_decl(f_8732)
static void C_ccall f_8732(C_word c,C_word *av) C_noret;
C_noret_decl(f_8741)
static void C_fcall f_8741(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8754)
static void C_ccall f_8754(C_word c,C_word *av) C_noret;
C_noret_decl(f_8774)
static void C_ccall f_8774(C_word c,C_word *av) C_noret;
C_noret_decl(f_8778)
static void C_ccall f_8778(C_word c,C_word *av) C_noret;
C_noret_decl(f_8782)
static void C_ccall f_8782(C_word c,C_word *av) C_noret;
C_noret_decl(f_8795)
static void C_ccall f_8795(C_word c,C_word *av) C_noret;
C_noret_decl(f_8799)
static void C_ccall f_8799(C_word c,C_word *av) C_noret;
C_noret_decl(f_8816)
static void C_ccall f_8816(C_word c,C_word *av) C_noret;
C_noret_decl(f_8835)
static void C_fcall f_8835(C_word t0,C_word t1) C_noret;
C_noret_decl(f_8842)
static void C_ccall f_8842(C_word c,C_word *av) C_noret;
C_noret_decl(f_8855)
static void C_ccall f_8855(C_word c,C_word *av) C_noret;
C_noret_decl(f_8859)
static void C_ccall f_8859(C_word c,C_word *av) C_noret;
C_noret_decl(f_8880)
static void C_ccall f_8880(C_word c,C_word *av) C_noret;
C_noret_decl(f_8889)
static void C_ccall f_8889(C_word c,C_word *av) C_noret;
C_noret_decl(f_8892)
static void C_ccall f_8892(C_word c,C_word *av) C_noret;
C_noret_decl(f_8895)
static void C_ccall f_8895(C_word c,C_word *av) C_noret;
C_noret_decl(f_8901)
static void C_ccall f_8901(C_word c,C_word *av) C_noret;
C_noret_decl(f_8909)
static void C_fcall f_8909(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_8917)
static void C_ccall f_8917(C_word c,C_word *av) C_noret;
C_noret_decl(f_8932)
static void C_ccall f_8932(C_word c,C_word *av) C_noret;
C_noret_decl(f_8936)
static void C_ccall f_8936(C_word c,C_word *av) C_noret;
C_noret_decl(f_8938)
static void C_ccall f_8938(C_word c,C_word *av) C_noret;
C_noret_decl(f_8942)
static void C_ccall f_8942(C_word c,C_word *av) C_noret;
C_noret_decl(f_8946)
static void C_ccall f_8946(C_word c,C_word *av) C_noret;
C_noret_decl(f_8949)
static void C_ccall f_8949(C_word c,C_word *av) C_noret;
C_noret_decl(f_8955)
static void C_ccall f_8955(C_word c,C_word *av) C_noret;
C_noret_decl(f_8963)
static void C_ccall f_8963(C_word c,C_word *av) C_noret;
C_noret_decl(f_8967)
static void C_ccall f_8967(C_word c,C_word *av) C_noret;
C_noret_decl(f_8973)
static void C_ccall f_8973(C_word c,C_word *av) C_noret;
C_noret_decl(f_8977)
static void C_ccall f_8977(C_word c,C_word *av) C_noret;
C_noret_decl(f_8980)
static void C_ccall f_8980(C_word c,C_word *av) C_noret;
C_noret_decl(f_8983)
static void C_fcall f_8983(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9012)
static void C_ccall f_9012(C_word c,C_word *av) C_noret;
C_noret_decl(f_9033)
static void C_ccall f_9033(C_word c,C_word *av) C_noret;
C_noret_decl(f_9035)
static void C_fcall f_9035(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9060)
static void C_ccall f_9060(C_word c,C_word *av) C_noret;
C_noret_decl(f_9108)
static void C_ccall f_9108(C_word c,C_word *av) C_noret;
C_noret_decl(f_9112)
static void C_ccall f_9112(C_word c,C_word *av) C_noret;
C_noret_decl(f_9132)
static void C_ccall f_9132(C_word c,C_word *av) C_noret;
C_noret_decl(f_9146)
static void C_fcall f_9146(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9180)
static void C_fcall f_9180(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9224)
static void C_ccall f_9224(C_word c,C_word *av) C_noret;
C_noret_decl(f_9233)
static void C_ccall f_9233(C_word c,C_word *av) C_noret;
C_noret_decl(f_9262)
static void C_ccall f_9262(C_word c,C_word *av) C_noret;
C_noret_decl(f_9275)
static C_word C_fcall f_9275(C_word *a,C_word t0,C_word t1,C_word t2);
C_noret_decl(f_9293)
static void C_ccall f_9293(C_word c,C_word *av) C_noret;
C_noret_decl(f_9297)
static void C_ccall f_9297(C_word c,C_word *av) C_noret;
C_noret_decl(f_9309)
static void C_ccall f_9309(C_word c,C_word *av) C_noret;
C_noret_decl(f_9323)
static void C_fcall f_9323(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9371)
static void C_fcall f_9371(C_word t0,C_word t1,C_word t2,C_word t3) C_noret;
C_noret_decl(f_9419)
static void C_fcall f_9419(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9453)
static void C_fcall f_9453(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9478)
static void C_ccall f_9478(C_word c,C_word *av) C_noret;
C_noret_decl(f_9498)
static void C_fcall f_9498(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9506)
static void C_ccall f_9506(C_word c,C_word *av) C_noret;
C_noret_decl(f_9514)
static void C_ccall f_9514(C_word c,C_word *av) C_noret;
C_noret_decl(f_9517)
static void C_ccall f_9517(C_word c,C_word *av) C_noret;
C_noret_decl(f_9522)
static void C_ccall f_9522(C_word c,C_word *av) C_noret;
C_noret_decl(f_9527)
static void C_ccall f_9527(C_word c,C_word *av) C_noret;
C_noret_decl(f_9537)
static void C_ccall f_9537(C_word c,C_word *av) C_noret;
C_noret_decl(f_9542)
static void C_fcall f_9542(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9567)
static void C_ccall f_9567(C_word c,C_word *av) C_noret;
C_noret_decl(f_9588)
static void C_ccall f_9588(C_word c,C_word *av) C_noret;
C_noret_decl(f_9593)
static void C_ccall f_9593(C_word c,C_word *av) C_noret;
C_noret_decl(f_9603)
static void C_ccall f_9603(C_word c,C_word *av) C_noret;
C_noret_decl(f_9606)
static void C_ccall f_9606(C_word c,C_word *av) C_noret;
C_noret_decl(f_9612)
static void C_ccall f_9612(C_word c,C_word *av) C_noret;
C_noret_decl(f_9615)
static void C_ccall f_9615(C_word c,C_word *av) C_noret;
C_noret_decl(f_9618)
static void C_ccall f_9618(C_word c,C_word *av) C_noret;
C_noret_decl(f_9624)
static void C_ccall f_9624(C_word c,C_word *av) C_noret;
C_noret_decl(f_9633)
static void C_fcall f_9633(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9639)
static void C_ccall f_9639(C_word c,C_word *av) C_noret;
C_noret_decl(f_9646)
static void C_ccall f_9646(C_word c,C_word *av) C_noret;
C_noret_decl(f_9677)
static void C_ccall f_9677(C_word c,C_word *av) C_noret;
C_noret_decl(f_9688)
static void C_ccall f_9688(C_word c,C_word *av) C_noret;
C_noret_decl(f_9690)
static void C_ccall f_9690(C_word c,C_word *av) C_noret;
C_noret_decl(f_9694)
static void C_ccall f_9694(C_word c,C_word *av) C_noret;
C_noret_decl(f_9698)
static void C_ccall f_9698(C_word c,C_word *av) C_noret;
C_noret_decl(f_9701)
static void C_ccall f_9701(C_word c,C_word *av) C_noret;
C_noret_decl(f_9707)
static void C_ccall f_9707(C_word c,C_word *av) C_noret;
C_noret_decl(f_9711)
static void C_ccall f_9711(C_word c,C_word *av) C_noret;
C_noret_decl(f_9716)
static void C_ccall f_9716(C_word c,C_word *av) C_noret;
C_noret_decl(f_9721)
static void C_ccall f_9721(C_word c,C_word *av) C_noret;
C_noret_decl(f_9729)
static void C_fcall f_9729(C_word t0,C_word t1) C_noret;
C_noret_decl(f_9733)
static void C_ccall f_9733(C_word c,C_word *av) C_noret;
C_noret_decl(f_9746)
static void C_ccall f_9746(C_word c,C_word *av) C_noret;
C_noret_decl(f_9751)
static void C_ccall f_9751(C_word c,C_word *av) C_noret;
C_noret_decl(f_9755)
static void C_ccall f_9755(C_word c,C_word *av) C_noret;
C_noret_decl(f_9758)
static void C_ccall f_9758(C_word c,C_word *av) C_noret;
C_noret_decl(f_9763)
static void C_ccall f_9763(C_word c,C_word *av) C_noret;
C_noret_decl(f_9765)
static void C_fcall f_9765(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9790)
static void C_ccall f_9790(C_word c,C_word *av) C_noret;
C_noret_decl(f_9800)
static void C_ccall f_9800(C_word c,C_word *av) C_noret;
C_noret_decl(f_9805)
static void C_ccall f_9805(C_word c,C_word *av) C_noret;
C_noret_decl(f_9813)
static void C_ccall f_9813(C_word c,C_word *av) C_noret;
C_noret_decl(f_9815)
static void C_ccall f_9815(C_word c,C_word *av) C_noret;
C_noret_decl(f_9827)
static void C_ccall f_9827(C_word c,C_word *av) C_noret;
C_noret_decl(f_9832)
static void C_ccall f_9832(C_word c,C_word *av) C_noret;
C_noret_decl(f_9836)
static void C_ccall f_9836(C_word c,C_word *av) C_noret;
C_noret_decl(f_9840)
static void C_ccall f_9840(C_word c,C_word *av) C_noret;
C_noret_decl(f_9843)
static void C_ccall f_9843(C_word c,C_word *av) C_noret;
C_noret_decl(f_9849)
static void C_ccall f_9849(C_word c,C_word *av) C_noret;
C_noret_decl(f_9853)
static void C_ccall f_9853(C_word c,C_word *av) C_noret;
C_noret_decl(f_9863)
static void C_ccall f_9863(C_word c,C_word *av) C_noret;
C_noret_decl(f_9869)
static void C_ccall f_9869(C_word c,C_word *av) C_noret;
C_noret_decl(f_9873)
static void C_ccall f_9873(C_word c,C_word *av) C_noret;
C_noret_decl(f_9876)
static void C_ccall f_9876(C_word c,C_word *av) C_noret;
C_noret_decl(f_9894)
static void C_ccall f_9894(C_word c,C_word *av) C_noret;
C_noret_decl(f_9898)
static void C_ccall f_9898(C_word c,C_word *av) C_noret;
C_noret_decl(f_9902)
static void C_ccall f_9902(C_word c,C_word *av) C_noret;
C_noret_decl(f_9917)
static void C_ccall f_9917(C_word c,C_word *av) C_noret;
C_noret_decl(f_9921)
static void C_ccall f_9921(C_word c,C_word *av) C_noret;
C_noret_decl(f_9923)
static void C_fcall f_9923(C_word t0,C_word t1,C_word t2) C_noret;
C_noret_decl(f_9977)
static void C_ccall f_9977(C_word c,C_word *av) C_noret;
C_noret_decl(f_9981)
static void C_ccall f_9981(C_word c,C_word *av) C_noret;
C_noret_decl(f_9996)
static void C_ccall f_9996(C_word c,C_word *av) C_noret;
C_noret_decl(f_9999)
static void C_ccall f_9999(C_word c,C_word *av) C_noret;
C_noret_decl(C_compiler_toplevel)
C_externexport void C_ccall C_compiler_toplevel(C_word c,C_word *av) C_noret;
C_noret_decl(va26246)
static void C_fcall va26246(C_word t0,C_word t1) C_noret;

C_noret_decl(trf_10093)
static void C_ccall trf_10093(C_word c,C_word *av) C_noret;
static void C_ccall trf_10093(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10093(t0,t1,t2);}

C_noret_decl(trf_10140)
static void C_ccall trf_10140(C_word c,C_word *av) C_noret;
static void C_ccall trf_10140(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10140(t0,t1);}

C_noret_decl(trf_10252)
static void C_ccall trf_10252(C_word c,C_word *av) C_noret;
static void C_ccall trf_10252(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10252(t0,t1);}

C_noret_decl(trf_10329)
static void C_ccall trf_10329(C_word c,C_word *av) C_noret;
static void C_ccall trf_10329(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10329(t0,t1,t2);}

C_noret_decl(trf_10343)
static void C_ccall trf_10343(C_word c,C_word *av) C_noret;
static void C_ccall trf_10343(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10343(t0,t1);}

C_noret_decl(trf_10419)
static void C_ccall trf_10419(C_word c,C_word *av) C_noret;
static void C_ccall trf_10419(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10419(t0,t1,t2);}

C_noret_decl(trf_10478)
static void C_ccall trf_10478(C_word c,C_word *av) C_noret;
static void C_ccall trf_10478(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10478(t0,t1,t2);}

C_noret_decl(trf_10501)
static void C_ccall trf_10501(C_word c,C_word *av) C_noret;
static void C_ccall trf_10501(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10501(t0,t1,t2);}

C_noret_decl(trf_10642)
static void C_ccall trf_10642(C_word c,C_word *av) C_noret;
static void C_ccall trf_10642(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10642(t0,t1,t2);}

C_noret_decl(trf_10692)
static void C_ccall trf_10692(C_word c,C_word *av) C_noret;
static void C_ccall trf_10692(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10692(t0,t1);}

C_noret_decl(trf_10710)
static void C_ccall trf_10710(C_word c,C_word *av) C_noret;
static void C_ccall trf_10710(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10710(t0,t1);}

C_noret_decl(trf_10731)
static void C_ccall trf_10731(C_word c,C_word *av) C_noret;
static void C_ccall trf_10731(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_10731(t0,t1);}

C_noret_decl(trf_10777)
static void C_ccall trf_10777(C_word c,C_word *av) C_noret;
static void C_ccall trf_10777(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10777(t0,t1,t2);}

C_noret_decl(trf_10792)
static void C_ccall trf_10792(C_word c,C_word *av) C_noret;
static void C_ccall trf_10792(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10792(t0,t1,t2);}

C_noret_decl(trf_10877)
static void C_ccall trf_10877(C_word c,C_word *av) C_noret;
static void C_ccall trf_10877(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_10877(t0,t1,t2);}

C_noret_decl(trf_10974)
static void C_ccall trf_10974(C_word c,C_word *av) C_noret;
static void C_ccall trf_10974(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_10974(t0,t1,t2,t3);}

C_noret_decl(trf_11012)
static void C_ccall trf_11012(C_word c,C_word *av) C_noret;
static void C_ccall trf_11012(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11012(t0,t1);}

C_noret_decl(trf_11047)
static void C_ccall trf_11047(C_word c,C_word *av) C_noret;
static void C_ccall trf_11047(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11047(t0,t1,t2);}

C_noret_decl(trf_11129)
static void C_ccall trf_11129(C_word c,C_word *av) C_noret;
static void C_ccall trf_11129(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11129(t0,t1,t2);}

C_noret_decl(trf_11142)
static void C_ccall trf_11142(C_word c,C_word *av) C_noret;
static void C_ccall trf_11142(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11142(t0,t1);}

C_noret_decl(trf_11186)
static void C_ccall trf_11186(C_word c,C_word *av) C_noret;
static void C_ccall trf_11186(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11186(t0,t1,t2);}

C_noret_decl(trf_11324)
static void C_ccall trf_11324(C_word c,C_word *av) C_noret;
static void C_ccall trf_11324(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11324(t0,t1,t2);}

C_noret_decl(trf_11430)
static void C_ccall trf_11430(C_word c,C_word *av) C_noret;
static void C_ccall trf_11430(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11430(t0,t1,t2);}

C_noret_decl(trf_11482)
static void C_ccall trf_11482(C_word c,C_word *av) C_noret;
static void C_ccall trf_11482(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11482(t0,t1,t2);}

C_noret_decl(trf_11554)
static void C_ccall trf_11554(C_word c,C_word *av) C_noret;
static void C_ccall trf_11554(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_11554(t0,t1);}

C_noret_decl(trf_11783)
static void C_ccall trf_11783(C_word c,C_word *av) C_noret;
static void C_ccall trf_11783(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11783(t0,t1,t2);}

C_noret_decl(trf_11801)
static void C_ccall trf_11801(C_word c,C_word *av) C_noret;
static void C_ccall trf_11801(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11801(t0,t1,t2);}

C_noret_decl(trf_11898)
static void C_ccall trf_11898(C_word c,C_word *av) C_noret;
static void C_ccall trf_11898(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_11898(t0,t1,t2);}

C_noret_decl(trf_12037)
static void C_ccall trf_12037(C_word c,C_word *av) C_noret;
static void C_ccall trf_12037(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12037(t0,t1,t2);}

C_noret_decl(trf_12243)
static void C_ccall trf_12243(C_word c,C_word *av) C_noret;
static void C_ccall trf_12243(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_12243(t0,t1);}

C_noret_decl(trf_12329)
static void C_ccall trf_12329(C_word c,C_word *av) C_noret;
static void C_ccall trf_12329(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_12329(t0,t1);}

C_noret_decl(trf_12463)
static void C_ccall trf_12463(C_word c,C_word *av) C_noret;
static void C_ccall trf_12463(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_12463(t0,t1);}

C_noret_decl(trf_12804)
static void C_ccall trf_12804(C_word c,C_word *av) C_noret;
static void C_ccall trf_12804(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12804(t0,t1,t2);}

C_noret_decl(trf_12810)
static void C_ccall trf_12810(C_word c,C_word *av) C_noret;
static void C_ccall trf_12810(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12810(t0,t1,t2);}

C_noret_decl(trf_12827)
static void C_ccall trf_12827(C_word c,C_word *av) C_noret;
static void C_ccall trf_12827(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_12827(t0,t1,t2);}

C_noret_decl(trf_13041)
static void C_ccall trf_13041(C_word c,C_word *av) C_noret;
static void C_ccall trf_13041(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_13041(t0,t1,t2,t3);}

C_noret_decl(trf_13192)
static void C_ccall trf_13192(C_word c,C_word *av) C_noret;
static void C_ccall trf_13192(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_13192(t0,t1,t2);}

C_noret_decl(trf_13218)
static void C_ccall trf_13218(C_word c,C_word *av) C_noret;
static void C_ccall trf_13218(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_13218(t0,t1,t2);}

C_noret_decl(trf_13577)
static void C_ccall trf_13577(C_word c,C_word *av) C_noret;
static void C_ccall trf_13577(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_13577(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_13582)
static void C_ccall trf_13582(C_word c,C_word *av) C_noret;
static void C_ccall trf_13582(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_13582(t0,t1,t2);}

C_noret_decl(trf_13594)
static void C_ccall trf_13594(C_word c,C_word *av) C_noret;
static void C_ccall trf_13594(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_13594(t0,t1,t2);}

C_noret_decl(trf_13668)
static void C_ccall trf_13668(C_word c,C_word *av) C_noret;
static void C_ccall trf_13668(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_13668(t0,t1,t2,t3);}

C_noret_decl(trf_13703)
static void C_ccall trf_13703(C_word c,C_word *av) C_noret;
static void C_ccall trf_13703(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_13703(t0,t1,t2);}

C_noret_decl(trf_13722)
static void C_ccall trf_13722(C_word c,C_word *av) C_noret;
static void C_ccall trf_13722(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_13722(t0,t1,t2);}

C_noret_decl(trf_13728)
static void C_ccall trf_13728(C_word c,C_word *av) C_noret;
static void C_ccall trf_13728(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13728(t0,t1);}

C_noret_decl(trf_13756)
static void C_ccall trf_13756(C_word c,C_word *av) C_noret;
static void C_ccall trf_13756(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_13756(t0,t1);}

C_noret_decl(trf_13991)
static void C_ccall trf_13991(C_word c,C_word *av) C_noret;
static void C_ccall trf_13991(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_13991(t0,t1,t2);}

C_noret_decl(trf_14055)
static void C_ccall trf_14055(C_word c,C_word *av) C_noret;
static void C_ccall trf_14055(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14055(t0,t1,t2);}

C_noret_decl(trf_14078)
static void C_ccall trf_14078(C_word c,C_word *av) C_noret;
static void C_ccall trf_14078(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14078(t0,t1,t2);}

C_noret_decl(trf_14136)
static void C_ccall trf_14136(C_word c,C_word *av) C_noret;
static void C_ccall trf_14136(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14136(t0,t1,t2);}

C_noret_decl(trf_14159)
static void C_ccall trf_14159(C_word c,C_word *av) C_noret;
static void C_ccall trf_14159(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14159(t0,t1,t2);}

C_noret_decl(trf_14245)
static void C_ccall trf_14245(C_word c,C_word *av) C_noret;
static void C_ccall trf_14245(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14245(t0,t1,t2);}

C_noret_decl(trf_14290)
static void C_ccall trf_14290(C_word c,C_word *av) C_noret;
static void C_ccall trf_14290(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14290(t0,t1,t2);}

C_noret_decl(trf_14410)
static void C_ccall trf_14410(C_word c,C_word *av) C_noret;
static void C_ccall trf_14410(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14410(t0,t1,t2);}

C_noret_decl(trf_14499)
static void C_ccall trf_14499(C_word c,C_word *av) C_noret;
static void C_ccall trf_14499(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14499(t0,t1,t2);}

C_noret_decl(trf_14597)
static void C_ccall trf_14597(C_word c,C_word *av) C_noret;
static void C_ccall trf_14597(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14597(t0,t1,t2);}

C_noret_decl(trf_14638)
static void C_ccall trf_14638(C_word c,C_word *av) C_noret;
static void C_ccall trf_14638(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14638(t0,t1,t2);}

C_noret_decl(trf_14697)
static void C_ccall trf_14697(C_word c,C_word *av) C_noret;
static void C_ccall trf_14697(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14697(t0,t1,t2);}

C_noret_decl(trf_14797)
static void C_ccall trf_14797(C_word c,C_word *av) C_noret;
static void C_ccall trf_14797(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14797(t0,t1,t2);}

C_noret_decl(trf_14863)
static void C_ccall trf_14863(C_word c,C_word *av) C_noret;
static void C_ccall trf_14863(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14863(t0,t1);}

C_noret_decl(trf_14917)
static void C_ccall trf_14917(C_word c,C_word *av) C_noret;
static void C_ccall trf_14917(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_14917(t0,t1,t2);}

C_noret_decl(trf_14970)
static void C_ccall trf_14970(C_word c,C_word *av) C_noret;
static void C_ccall trf_14970(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_14970(t0,t1);}

C_noret_decl(trf_15027)
static void C_ccall trf_15027(C_word c,C_word *av) C_noret;
static void C_ccall trf_15027(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15027(t0,t1,t2);}

C_noret_decl(trf_15081)
static void C_ccall trf_15081(C_word c,C_word *av) C_noret;
static void C_ccall trf_15081(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15081(t0,t1,t2);}

C_noret_decl(trf_15136)
static void C_ccall trf_15136(C_word c,C_word *av) C_noret;
static void C_ccall trf_15136(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15136(t0,t1,t2);}

C_noret_decl(trf_15168)
static void C_ccall trf_15168(C_word c,C_word *av) C_noret;
static void C_ccall trf_15168(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15168(t0,t1,t2);}

C_noret_decl(trf_15175)
static void C_ccall trf_15175(C_word c,C_word *av) C_noret;
static void C_ccall trf_15175(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15175(t0,t1);}

C_noret_decl(trf_15258)
static void C_ccall trf_15258(C_word c,C_word *av) C_noret;
static void C_ccall trf_15258(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15258(t0,t1);}

C_noret_decl(trf_15332)
static void C_ccall trf_15332(C_word c,C_word *av) C_noret;
static void C_ccall trf_15332(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15332(t0,t1,t2);}

C_noret_decl(trf_15360)
static void C_ccall trf_15360(C_word c,C_word *av) C_noret;
static void C_ccall trf_15360(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15360(t0,t1,t2);}

C_noret_decl(trf_15367)
static void C_ccall trf_15367(C_word c,C_word *av) C_noret;
static void C_ccall trf_15367(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15367(t0,t1);}

C_noret_decl(trf_15454)
static void C_ccall trf_15454(C_word c,C_word *av) C_noret;
static void C_ccall trf_15454(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15454(t0,t1,t2);}

C_noret_decl(trf_15693)
static void C_ccall trf_15693(C_word c,C_word *av) C_noret;
static void C_ccall trf_15693(C_word c,C_word *av){
C_word t0=av[7];
C_word t1=av[6];
C_word t2=av[5];
C_word t3=av[4];
C_word t4=av[3];
C_word t5=av[2];
C_word t6=av[1];
C_word t7=av[0];
f_15693(t0,t1,t2,t3,t4,t5,t6,t7);}

C_noret_decl(trf_15702)
static void C_ccall trf_15702(C_word c,C_word *av) C_noret;
static void C_ccall trf_15702(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15702(t0,t1,t2);}

C_noret_decl(trf_15808)
static void C_ccall trf_15808(C_word c,C_word *av) C_noret;
static void C_ccall trf_15808(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_15808(t0,t1);}

C_noret_decl(trf_15915)
static void C_ccall trf_15915(C_word c,C_word *av) C_noret;
static void C_ccall trf_15915(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_15915(t0,t1,t2,t3);}

C_noret_decl(trf_15996)
static void C_ccall trf_15996(C_word c,C_word *av) C_noret;
static void C_ccall trf_15996(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_15996(t0,t1,t2);}

C_noret_decl(trf_16048)
static void C_ccall trf_16048(C_word c,C_word *av) C_noret;
static void C_ccall trf_16048(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16048(t0,t1,t2);}

C_noret_decl(trf_16082)
static void C_ccall trf_16082(C_word c,C_word *av) C_noret;
static void C_ccall trf_16082(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16082(t0,t1,t2);}

C_noret_decl(trf_16119)
static void C_ccall trf_16119(C_word c,C_word *av) C_noret;
static void C_ccall trf_16119(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16119(t0,t1,t2);}

C_noret_decl(trf_16160)
static void C_ccall trf_16160(C_word c,C_word *av) C_noret;
static void C_ccall trf_16160(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16160(t0,t1,t2);}

C_noret_decl(trf_16194)
static void C_ccall trf_16194(C_word c,C_word *av) C_noret;
static void C_ccall trf_16194(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16194(t0,t1,t2);}

C_noret_decl(trf_16236)
static void C_ccall trf_16236(C_word c,C_word *av) C_noret;
static void C_ccall trf_16236(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16236(t0,t1);}

C_noret_decl(trf_16276)
static void C_ccall trf_16276(C_word c,C_word *av) C_noret;
static void C_ccall trf_16276(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16276(t0,t1,t2);}

C_noret_decl(trf_16310)
static void C_ccall trf_16310(C_word c,C_word *av) C_noret;
static void C_ccall trf_16310(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16310(t0,t1,t2);}

C_noret_decl(trf_16388)
static void C_ccall trf_16388(C_word c,C_word *av) C_noret;
static void C_ccall trf_16388(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_16388(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_16439)
static void C_ccall trf_16439(C_word c,C_word *av) C_noret;
static void C_ccall trf_16439(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_16439(t0,t1,t2);}

C_noret_decl(trf_16463)
static void C_ccall trf_16463(C_word c,C_word *av) C_noret;
static void C_ccall trf_16463(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_16463(t0,t1,t2,t3);}

C_noret_decl(trf_16485)
static void C_ccall trf_16485(C_word c,C_word *av) C_noret;
static void C_ccall trf_16485(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16485(t0,t1);}

C_noret_decl(trf_16606)
static void C_ccall trf_16606(C_word c,C_word *av) C_noret;
static void C_ccall trf_16606(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_16606(t0,t1,t2,t3);}

C_noret_decl(trf_16807)
static void C_ccall trf_16807(C_word c,C_word *av) C_noret;
static void C_ccall trf_16807(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_16807(t0,t1);}

C_noret_decl(trf_17009)
static void C_ccall trf_17009(C_word c,C_word *av) C_noret;
static void C_ccall trf_17009(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_17009(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_17155)
static void C_ccall trf_17155(C_word c,C_word *av) C_noret;
static void C_ccall trf_17155(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_17155(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_17171)
static void C_ccall trf_17171(C_word c,C_word *av) C_noret;
static void C_ccall trf_17171(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_17171(t0,t1,t2,t3);}

C_noret_decl(trf_17177)
static void C_ccall trf_17177(C_word c,C_word *av) C_noret;
static void C_ccall trf_17177(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_17177(t0,t1,t2,t3);}

C_noret_decl(trf_17315)
static void C_ccall trf_17315(C_word c,C_word *av) C_noret;
static void C_ccall trf_17315(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_17315(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_17337)
static void C_ccall trf_17337(C_word c,C_word *av) C_noret;
static void C_ccall trf_17337(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17337(t0,t1);}

C_noret_decl(trf_17447)
static void C_ccall trf_17447(C_word c,C_word *av) C_noret;
static void C_ccall trf_17447(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17447(t0,t1);}

C_noret_decl(trf_17529)
static void C_ccall trf_17529(C_word c,C_word *av) C_noret;
static void C_ccall trf_17529(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_17529(t0,t1,t2,t3);}

C_noret_decl(trf_17589)
static void C_ccall trf_17589(C_word c,C_word *av) C_noret;
static void C_ccall trf_17589(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17589(t0,t1,t2);}

C_noret_decl(trf_17614)
static void C_ccall trf_17614(C_word c,C_word *av) C_noret;
static void C_ccall trf_17614(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17614(t0,t1,t2);}

C_noret_decl(trf_17664)
static void C_ccall trf_17664(C_word c,C_word *av) C_noret;
static void C_ccall trf_17664(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17664(t0,t1,t2);}

C_noret_decl(trf_17686)
static void C_ccall trf_17686(C_word c,C_word *av) C_noret;
static void C_ccall trf_17686(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17686(t0,t1);}

C_noret_decl(trf_17689)
static void C_ccall trf_17689(C_word c,C_word *av) C_noret;
static void C_ccall trf_17689(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_17689(t0,t1);}

C_noret_decl(trf_17749)
static void C_ccall trf_17749(C_word c,C_word *av) C_noret;
static void C_ccall trf_17749(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17749(t0,t1,t2);}

C_noret_decl(trf_17986)
static void C_ccall trf_17986(C_word c,C_word *av) C_noret;
static void C_ccall trf_17986(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_17986(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_17988)
static void C_ccall trf_17988(C_word c,C_word *av) C_noret;
static void C_ccall trf_17988(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_17988(t0,t1,t2);}

C_noret_decl(trf_18000)
static void C_ccall trf_18000(C_word c,C_word *av) C_noret;
static void C_ccall trf_18000(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18000(t0,t1,t2);}

C_noret_decl(trf_18023)
static void C_ccall trf_18023(C_word c,C_word *av) C_noret;
static void C_ccall trf_18023(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_18023(t0,t1,t2,t3,t4);}

C_noret_decl(trf_18036)
static void C_ccall trf_18036(C_word c,C_word *av) C_noret;
static void C_ccall trf_18036(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_18036(t0,t1,t2,t3,t4);}

C_noret_decl(trf_18049)
static void C_ccall trf_18049(C_word c,C_word *av) C_noret;
static void C_ccall trf_18049(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_18049(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_18074)
static void C_ccall trf_18074(C_word c,C_word *av) C_noret;
static void C_ccall trf_18074(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18074(t0,t1);}

C_noret_decl(trf_18131)
static void C_ccall trf_18131(C_word c,C_word *av) C_noret;
static void C_ccall trf_18131(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18131(t0,t1);}

C_noret_decl(trf_18135)
static void C_ccall trf_18135(C_word c,C_word *av) C_noret;
static void C_ccall trf_18135(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18135(t0,t1,t2);}

C_noret_decl(trf_18159)
static void C_ccall trf_18159(C_word c,C_word *av) C_noret;
static void C_ccall trf_18159(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18159(t0,t1);}

C_noret_decl(trf_18204)
static void C_ccall trf_18204(C_word c,C_word *av) C_noret;
static void C_ccall trf_18204(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18204(t0,t1);}

C_noret_decl(trf_18359)
static void C_ccall trf_18359(C_word c,C_word *av) C_noret;
static void C_ccall trf_18359(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_18359(t0,t1,t2,t3);}

C_noret_decl(trf_18552)
static void C_ccall trf_18552(C_word c,C_word *av) C_noret;
static void C_ccall trf_18552(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18552(t0,t1);}

C_noret_decl(trf_18558)
static void C_ccall trf_18558(C_word c,C_word *av) C_noret;
static void C_ccall trf_18558(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18558(t0,t1);}

C_noret_decl(trf_18564)
static void C_ccall trf_18564(C_word c,C_word *av) C_noret;
static void C_ccall trf_18564(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18564(t0,t1);}

C_noret_decl(trf_18573)
static void C_ccall trf_18573(C_word c,C_word *av) C_noret;
static void C_ccall trf_18573(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18573(t0,t1);}

C_noret_decl(trf_18594)
static void C_ccall trf_18594(C_word c,C_word *av) C_noret;
static void C_ccall trf_18594(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18594(t0,t1);}

C_noret_decl(trf_18615)
static void C_ccall trf_18615(C_word c,C_word *av) C_noret;
static void C_ccall trf_18615(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18615(t0,t1);}

C_noret_decl(trf_18716)
static void C_ccall trf_18716(C_word c,C_word *av) C_noret;
static void C_ccall trf_18716(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18716(t0,t1);}

C_noret_decl(trf_18880)
static void C_ccall trf_18880(C_word c,C_word *av) C_noret;
static void C_ccall trf_18880(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18880(t0,t1);}

C_noret_decl(trf_18908)
static void C_ccall trf_18908(C_word c,C_word *av) C_noret;
static void C_ccall trf_18908(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18908(t0,t1,t2);}

C_noret_decl(trf_18915)
static void C_ccall trf_18915(C_word c,C_word *av) C_noret;
static void C_ccall trf_18915(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18915(t0,t1);}

C_noret_decl(trf_18941)
static void C_ccall trf_18941(C_word c,C_word *av) C_noret;
static void C_ccall trf_18941(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_18941(t0,t1,t2);}

C_noret_decl(trf_18975)
static void C_ccall trf_18975(C_word c,C_word *av) C_noret;
static void C_ccall trf_18975(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_18975(t0,t1);}

C_noret_decl(trf_19100)
static void C_ccall trf_19100(C_word c,C_word *av) C_noret;
static void C_ccall trf_19100(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19100(t0,t1);}

C_noret_decl(trf_19148)
static void C_ccall trf_19148(C_word c,C_word *av) C_noret;
static void C_ccall trf_19148(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19148(t0,t1,t2);}

C_noret_decl(trf_19185)
static void C_ccall trf_19185(C_word c,C_word *av) C_noret;
static void C_ccall trf_19185(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19185(t0,t1);}

C_noret_decl(trf_19259)
static void C_ccall trf_19259(C_word c,C_word *av) C_noret;
static void C_ccall trf_19259(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19259(t0,t1);}

C_noret_decl(trf_19263)
static void C_ccall trf_19263(C_word c,C_word *av) C_noret;
static void C_ccall trf_19263(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19263(t0,t1,t2);}

C_noret_decl(trf_19293)
static void C_ccall trf_19293(C_word c,C_word *av) C_noret;
static void C_ccall trf_19293(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19293(t0,t1,t2);}

C_noret_decl(trf_19358)
static void C_ccall trf_19358(C_word c,C_word *av) C_noret;
static void C_ccall trf_19358(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_19358(t0,t1,t2,t3);}

C_noret_decl(trf_19364)
static void C_ccall trf_19364(C_word c,C_word *av) C_noret;
static void C_ccall trf_19364(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_19364(t0,t1,t2,t3);}

C_noret_decl(trf_19374)
static void C_ccall trf_19374(C_word c,C_word *av) C_noret;
static void C_ccall trf_19374(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19374(t0,t1,t2);}

C_noret_decl(trf_19383)
static void C_ccall trf_19383(C_word c,C_word *av) C_noret;
static void C_ccall trf_19383(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_19383(t0,t1,t2,t3,t4);}

C_noret_decl(trf_19423)
static void C_ccall trf_19423(C_word c,C_word *av) C_noret;
static void C_ccall trf_19423(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19423(t0,t1);}

C_noret_decl(trf_19525)
static void C_ccall trf_19525(C_word c,C_word *av) C_noret;
static void C_ccall trf_19525(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19525(t0,t1,t2);}

C_noret_decl(trf_19537)
static void C_ccall trf_19537(C_word c,C_word *av) C_noret;
static void C_ccall trf_19537(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19537(t0,t1,t2);}

C_noret_decl(trf_19599)
static void C_ccall trf_19599(C_word c,C_word *av) C_noret;
static void C_ccall trf_19599(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19599(t0,t1);}

C_noret_decl(trf_19617)
static void C_ccall trf_19617(C_word c,C_word *av) C_noret;
static void C_ccall trf_19617(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19617(t0,t1);}

C_noret_decl(trf_19623)
static void C_ccall trf_19623(C_word c,C_word *av) C_noret;
static void C_ccall trf_19623(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19623(t0,t1);}

C_noret_decl(trf_19817)
static void C_ccall trf_19817(C_word c,C_word *av) C_noret;
static void C_ccall trf_19817(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19817(t0,t1,t2);}

C_noret_decl(trf_19829)
static void C_ccall trf_19829(C_word c,C_word *av) C_noret;
static void C_ccall trf_19829(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_19829(t0,t1,t2);}

C_noret_decl(trf_19914)
static void C_ccall trf_19914(C_word c,C_word *av) C_noret;
static void C_ccall trf_19914(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_19914(t0,t1,t2,t3,t4);}

C_noret_decl(trf_19933)
static void C_ccall trf_19933(C_word c,C_word *av) C_noret;
static void C_ccall trf_19933(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19933(t0,t1);}

C_noret_decl(trf_19967)
static void C_ccall trf_19967(C_word c,C_word *av) C_noret;
static void C_ccall trf_19967(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_19967(t0,t1);}

C_noret_decl(trf_20053)
static void C_ccall trf_20053(C_word c,C_word *av) C_noret;
static void C_ccall trf_20053(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20053(t0,t1);}

C_noret_decl(trf_20203)
static void C_ccall trf_20203(C_word c,C_word *av) C_noret;
static void C_ccall trf_20203(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20203(t0,t1);}

C_noret_decl(trf_20226)
static void C_ccall trf_20226(C_word c,C_word *av) C_noret;
static void C_ccall trf_20226(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20226(t0,t1,t2);}

C_noret_decl(trf_20283)
static void C_ccall trf_20283(C_word c,C_word *av) C_noret;
static void C_ccall trf_20283(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20283(t0,t1,t2);}

C_noret_decl(trf_20369)
static void C_ccall trf_20369(C_word c,C_word *av) C_noret;
static void C_ccall trf_20369(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20369(t0,t1,t2,t3);}

C_noret_decl(trf_20405)
static void C_ccall trf_20405(C_word c,C_word *av) C_noret;
static void C_ccall trf_20405(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20405(t0,t1,t2);}

C_noret_decl(trf_20493)
static void C_ccall trf_20493(C_word c,C_word *av) C_noret;
static void C_ccall trf_20493(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20493(t0,t1,t2);}

C_noret_decl(trf_20570)
static void C_ccall trf_20570(C_word c,C_word *av) C_noret;
static void C_ccall trf_20570(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_20570(t0,t1,t2,t3);}

C_noret_decl(trf_20618)
static void C_ccall trf_20618(C_word c,C_word *av) C_noret;
static void C_ccall trf_20618(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20618(t0,t1,t2);}

C_noret_decl(trf_20677)
static void C_ccall trf_20677(C_word c,C_word *av) C_noret;
static void C_ccall trf_20677(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_20677(t0,t1);}

C_noret_decl(trf_20684)
static void C_ccall trf_20684(C_word c,C_word *av) C_noret;
static void C_ccall trf_20684(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_20684(t0,t1,t2);}

C_noret_decl(trf_21100)
static void C_ccall trf_21100(C_word c,C_word *av) C_noret;
static void C_ccall trf_21100(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_21100(t0,t1,t2,t3,t4);}

C_noret_decl(trf_21105)
static void C_ccall trf_21105(C_word c,C_word *av) C_noret;
static void C_ccall trf_21105(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21105(t0,t1,t2);}

C_noret_decl(trf_21117)
static void C_ccall trf_21117(C_word c,C_word *av) C_noret;
static void C_ccall trf_21117(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21117(t0,t1,t2);}

C_noret_decl(trf_21151)
static void C_ccall trf_21151(C_word c,C_word *av) C_noret;
static void C_ccall trf_21151(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_21151(t0,t1,t2,t3);}

C_noret_decl(trf_21162)
static void C_ccall trf_21162(C_word c,C_word *av) C_noret;
static void C_ccall trf_21162(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21162(t0,t1,t2);}

C_noret_decl(trf_21382)
static void C_ccall trf_21382(C_word c,C_word *av) C_noret;
static void C_ccall trf_21382(C_word c,C_word *av){
C_word t0=av[5];
C_word t1=av[4];
C_word t2=av[3];
C_word t3=av[2];
C_word t4=av[1];
C_word t5=av[0];
f_21382(t0,t1,t2,t3,t4,t5);}

C_noret_decl(trf_21390)
static void C_ccall trf_21390(C_word c,C_word *av) C_noret;
static void C_ccall trf_21390(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_21390(t0,t1,t2);}

C_noret_decl(trf_21431)
static void C_ccall trf_21431(C_word c,C_word *av) C_noret;
static void C_ccall trf_21431(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_21431(t0,t1,t2,t3);}

C_noret_decl(trf_21438)
static void C_ccall trf_21438(C_word c,C_word *av) C_noret;
static void C_ccall trf_21438(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21438(t0,t1);}

C_noret_decl(trf_21441)
static void C_ccall trf_21441(C_word c,C_word *av) C_noret;
static void C_ccall trf_21441(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21441(t0,t1);}

C_noret_decl(trf_21487)
static void C_ccall trf_21487(C_word c,C_word *av) C_noret;
static void C_ccall trf_21487(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_21487(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_21506)
static void C_ccall trf_21506(C_word c,C_word *av) C_noret;
static void C_ccall trf_21506(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21506(t0,t1);}

C_noret_decl(trf_21534)
static void C_ccall trf_21534(C_word c,C_word *av) C_noret;
static void C_ccall trf_21534(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21534(t0,t1);}

C_noret_decl(trf_21733)
static void C_ccall trf_21733(C_word c,C_word *av) C_noret;
static void C_ccall trf_21733(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21733(t0,t1);}

C_noret_decl(trf_21866)
static void C_ccall trf_21866(C_word c,C_word *av) C_noret;
static void C_ccall trf_21866(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_21866(t0,t1);}

C_noret_decl(trf_22089)
static void C_ccall trf_22089(C_word c,C_word *av) C_noret;
static void C_ccall trf_22089(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22089(t0,t1,t2);}

C_noret_decl(trf_22128)
static void C_ccall trf_22128(C_word c,C_word *av) C_noret;
static void C_ccall trf_22128(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22128(t0,t1);}

C_noret_decl(trf_22131)
static void C_ccall trf_22131(C_word c,C_word *av) C_noret;
static void C_ccall trf_22131(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22131(t0,t1);}

C_noret_decl(trf_22218)
static void C_ccall trf_22218(C_word c,C_word *av) C_noret;
static void C_ccall trf_22218(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22218(t0,t1);}

C_noret_decl(trf_22225)
static void C_ccall trf_22225(C_word c,C_word *av) C_noret;
static void C_ccall trf_22225(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22225(t0,t1);}

C_noret_decl(trf_22228)
static void C_ccall trf_22228(C_word c,C_word *av) C_noret;
static void C_ccall trf_22228(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22228(t0,t1);}

C_noret_decl(trf_22266)
static void C_ccall trf_22266(C_word c,C_word *av) C_noret;
static void C_ccall trf_22266(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22266(t0,t1);}

C_noret_decl(trf_22303)
static void C_ccall trf_22303(C_word c,C_word *av) C_noret;
static void C_ccall trf_22303(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22303(t0,t1);}

C_noret_decl(trf_22330)
static void C_ccall trf_22330(C_word c,C_word *av) C_noret;
static void C_ccall trf_22330(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22330(t0,t1);}

C_noret_decl(trf_22351)
static void C_ccall trf_22351(C_word c,C_word *av) C_noret;
static void C_ccall trf_22351(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22351(t0,t1);}

C_noret_decl(trf_22538)
static void C_ccall trf_22538(C_word c,C_word *av) C_noret;
static void C_ccall trf_22538(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_22538(t0,t1,t2,t3,t4);}

C_noret_decl(trf_22697)
static void C_ccall trf_22697(C_word c,C_word *av) C_noret;
static void C_ccall trf_22697(C_word c,C_word *av){
C_word t0=av[6];
C_word t1=av[5];
C_word t2=av[4];
C_word t3=av[3];
C_word t4=av[2];
C_word t5=av[1];
C_word t6=av[0];
f_22697(t0,t1,t2,t3,t4,t5,t6);}

C_noret_decl(trf_22702)
static void C_ccall trf_22702(C_word c,C_word *av) C_noret;
static void C_ccall trf_22702(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22702(t0,t1,t2);}

C_noret_decl(trf_22714)
static void C_ccall trf_22714(C_word c,C_word *av) C_noret;
static void C_ccall trf_22714(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22714(t0,t1,t2);}

C_noret_decl(trf_22748)
static void C_ccall trf_22748(C_word c,C_word *av) C_noret;
static void C_ccall trf_22748(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22748(t0,t1,t2);}

C_noret_decl(trf_22805)
static void C_ccall trf_22805(C_word c,C_word *av) C_noret;
static void C_ccall trf_22805(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22805(t0,t1,t2);}

C_noret_decl(trf_22833)
static void C_ccall trf_22833(C_word c,C_word *av) C_noret;
static void C_ccall trf_22833(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_22833(t0,t1,t2);}

C_noret_decl(trf_22849)
static void C_ccall trf_22849(C_word c,C_word *av) C_noret;
static void C_ccall trf_22849(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_22849(t0,t1);}

C_noret_decl(trf_6440)
static void C_ccall trf_6440(C_word c,C_word *av) C_noret;
static void C_ccall trf_6440(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_6440(t0,t1,t2,t3,t4);}

C_noret_decl(trf_6643)
static void C_ccall trf_6643(C_word c,C_word *av) C_noret;
static void C_ccall trf_6643(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6643(t0,t1,t2);}

C_noret_decl(trf_6649)
static void C_ccall trf_6649(C_word c,C_word *av) C_noret;
static void C_ccall trf_6649(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6649(t0,t1,t2);}

C_noret_decl(trf_6707)
static void C_ccall trf_6707(C_word c,C_word *av) C_noret;
static void C_ccall trf_6707(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6707(t0,t1,t2);}

C_noret_decl(trf_6713)
static void C_ccall trf_6713(C_word c,C_word *av) C_noret;
static void C_ccall trf_6713(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_6713(t0,t1,t2,t3);}

C_noret_decl(trf_6735)
static void C_ccall trf_6735(C_word c,C_word *av) C_noret;
static void C_ccall trf_6735(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_6735(t0,t1);}

C_noret_decl(trf_6741)
static void C_ccall trf_6741(C_word c,C_word *av) C_noret;
static void C_ccall trf_6741(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6741(t0,t1,t2);}

C_noret_decl(trf_6763)
static void C_ccall trf_6763(C_word c,C_word *av) C_noret;
static void C_ccall trf_6763(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_6763(t0,t1,t2,t3);}

C_noret_decl(trf_6769)
static void C_ccall trf_6769(C_word c,C_word *av) C_noret;
static void C_ccall trf_6769(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6769(t0,t1,t2);}

C_noret_decl(trf_6844)
static void C_ccall trf_6844(C_word c,C_word *av) C_noret;
static void C_ccall trf_6844(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6844(t0,t1,t2);}

C_noret_decl(trf_6883)
static void C_ccall trf_6883(C_word c,C_word *av) C_noret;
static void C_ccall trf_6883(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6883(t0,t1,t2);}

C_noret_decl(trf_6892)
static void C_ccall trf_6892(C_word c,C_word *av) C_noret;
static void C_ccall trf_6892(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6892(t0,t1,t2);}

C_noret_decl(trf_6900)
static void C_ccall trf_6900(C_word c,C_word *av) C_noret;
static void C_ccall trf_6900(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_6900(t0,t1,t2,t3);}

C_noret_decl(trf_6936)
static void C_ccall trf_6936(C_word c,C_word *av) C_noret;
static void C_ccall trf_6936(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_6936(t0,t1,t2);}

C_noret_decl(trf_6944)
static void C_ccall trf_6944(C_word c,C_word *av) C_noret;
static void C_ccall trf_6944(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_6944(t0,t1,t2,t3);}

C_noret_decl(trf_6992)
static void C_ccall trf_6992(C_word c,C_word *av) C_noret;
static void C_ccall trf_6992(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_6992(t0,t1);}

C_noret_decl(trf_7009)
static void C_ccall trf_7009(C_word c,C_word *av) C_noret;
static void C_ccall trf_7009(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7009(t0,t1,t2);}

C_noret_decl(trf_7074)
static void C_ccall trf_7074(C_word c,C_word *av) C_noret;
static void C_ccall trf_7074(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7074(t0,t1,t2,t3);}

C_noret_decl(trf_7102)
static void C_ccall trf_7102(C_word c,C_word *av) C_noret;
static void C_ccall trf_7102(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7102(t0,t1,t2);}

C_noret_decl(trf_7108)
static void C_ccall trf_7108(C_word c,C_word *av) C_noret;
static void C_ccall trf_7108(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7108(t0,t1,t2,t3);}

C_noret_decl(trf_7143)
static void C_ccall trf_7143(C_word c,C_word *av) C_noret;
static void C_ccall trf_7143(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7143(t0,t1,t2);}

C_noret_decl(trf_7149)
static void C_ccall trf_7149(C_word c,C_word *av) C_noret;
static void C_ccall trf_7149(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7149(t0,t1,t2,t3);}

C_noret_decl(trf_7188)
static void C_ccall trf_7188(C_word c,C_word *av) C_noret;
static void C_ccall trf_7188(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7188(t0,t1,t2);}

C_noret_decl(trf_7194)
static void C_ccall trf_7194(C_word c,C_word *av) C_noret;
static void C_ccall trf_7194(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7194(t0,t1,t2,t3);}

C_noret_decl(trf_7219)
static void C_ccall trf_7219(C_word c,C_word *av) C_noret;
static void C_ccall trf_7219(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7219(t0,t1,t2,t3);}

C_noret_decl(trf_7267)
static void C_ccall trf_7267(C_word c,C_word *av) C_noret;
static void C_ccall trf_7267(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7267(t0,t1,t2);}

C_noret_decl(trf_7486)
static void C_ccall trf_7486(C_word c,C_word *av) C_noret;
static void C_ccall trf_7486(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7486(t0,t1,t2);}

C_noret_decl(trf_7675)
static void C_ccall trf_7675(C_word c,C_word *av) C_noret;
static void C_ccall trf_7675(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7675(t0,t1,t2);}

C_noret_decl(trf_7749)
static void C_ccall trf_7749(C_word c,C_word *av) C_noret;
static void C_ccall trf_7749(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7749(t0,t1,t2);}

C_noret_decl(trf_7775)
static void C_ccall trf_7775(C_word c,C_word *av) C_noret;
static void C_ccall trf_7775(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7775(t0,t1,t2,t3);}

C_noret_decl(trf_7788)
static void C_ccall trf_7788(C_word c,C_word *av) C_noret;
static void C_ccall trf_7788(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7788(t0,t1);}

C_noret_decl(trf_7810)
static void C_ccall trf_7810(C_word c,C_word *av) C_noret;
static void C_ccall trf_7810(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7810(t0,t1,t2);}

C_noret_decl(trf_7844)
static void C_ccall trf_7844(C_word c,C_word *av) C_noret;
static void C_ccall trf_7844(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7844(t0,t1,t2);}

C_noret_decl(trf_7857)
static void C_ccall trf_7857(C_word c,C_word *av) C_noret;
static void C_ccall trf_7857(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_7857(t0,t1);}

C_noret_decl(trf_7884)
static void C_ccall trf_7884(C_word c,C_word *av) C_noret;
static void C_ccall trf_7884(C_word c,C_word *av){
C_word t0=av[4];
C_word t1=av[3];
C_word t2=av[2];
C_word t3=av[1];
C_word t4=av[0];
f_7884(t0,t1,t2,t3,t4);}

C_noret_decl(trf_7913)
static void C_ccall trf_7913(C_word c,C_word *av) C_noret;
static void C_ccall trf_7913(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7913(t0,t1,t2);}

C_noret_decl(trf_7930)
static void C_ccall trf_7930(C_word c,C_word *av) C_noret;
static void C_ccall trf_7930(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_7930(t0,t1,t2,t3);}

C_noret_decl(trf_7979)
static void C_ccall trf_7979(C_word c,C_word *av) C_noret;
static void C_ccall trf_7979(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_7979(t0,t1,t2);}

C_noret_decl(trf_8022)
static void C_ccall trf_8022(C_word c,C_word *av) C_noret;
static void C_ccall trf_8022(C_word c,C_word *av){
C_word t0=av[7];
C_word t1=av[6];
C_word t2=av[5];
C_word t3=av[4];
C_word t4=av[3];
C_word t5=av[2];
C_word t6=av[1];
C_word t7=av[0];
f_8022(t0,t1,t2,t3,t4,t5,t6,t7);}

C_noret_decl(trf_8045)
static void C_ccall trf_8045(C_word c,C_word *av) C_noret;
static void C_ccall trf_8045(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8045(t0,t1,t2);}

C_noret_decl(trf_8059)
static void C_ccall trf_8059(C_word c,C_word *av) C_noret;
static void C_ccall trf_8059(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8059(t0,t1,t2);}

C_noret_decl(trf_8073)
static void C_ccall trf_8073(C_word c,C_word *av) C_noret;
static void C_ccall trf_8073(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8073(t0,t1,t2);}

C_noret_decl(trf_8112)
static void C_ccall trf_8112(C_word c,C_word *av) C_noret;
static void C_ccall trf_8112(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8112(t0,t1,t2);}

C_noret_decl(trf_8164)
static void C_ccall trf_8164(C_word c,C_word *av) C_noret;
static void C_ccall trf_8164(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8164(t0,t1,t2);}

C_noret_decl(trf_8280)
static void C_ccall trf_8280(C_word c,C_word *av) C_noret;
static void C_ccall trf_8280(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8280(t0,t1,t2);}

C_noret_decl(trf_8330)
static void C_ccall trf_8330(C_word c,C_word *av) C_noret;
static void C_ccall trf_8330(C_word c,C_word *av){
C_word t0=av[8];
C_word t1=av[7];
C_word t2=av[6];
C_word t3=av[5];
C_word t4=av[4];
C_word t5=av[3];
C_word t6=av[2];
C_word t7=av[1];
C_word t8=av[0];
f_8330(t0,t1,t2,t3,t4,t5,t6,t7,t8);}

C_noret_decl(trf_8411)
static void C_ccall trf_8411(C_word c,C_word *av) C_noret;
static void C_ccall trf_8411(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8411(t0,t1,t2);}

C_noret_decl(trf_8631)
static void C_ccall trf_8631(C_word c,C_word *av) C_noret;
static void C_ccall trf_8631(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8631(t0,t1,t2);}

C_noret_decl(trf_8662)
static void C_ccall trf_8662(C_word c,C_word *av) C_noret;
static void C_ccall trf_8662(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_8662(t0,t1,t2);}

C_noret_decl(trf_8741)
static void C_ccall trf_8741(C_word c,C_word *av) C_noret;
static void C_ccall trf_8741(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8741(t0,t1);}

C_noret_decl(trf_8835)
static void C_ccall trf_8835(C_word c,C_word *av) C_noret;
static void C_ccall trf_8835(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_8835(t0,t1);}

C_noret_decl(trf_8909)
static void C_ccall trf_8909(C_word c,C_word *av) C_noret;
static void C_ccall trf_8909(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8909(t0,t1,t2,t3);}

C_noret_decl(trf_8983)
static void C_ccall trf_8983(C_word c,C_word *av) C_noret;
static void C_ccall trf_8983(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_8983(t0,t1,t2,t3);}

C_noret_decl(trf_9035)
static void C_ccall trf_9035(C_word c,C_word *av) C_noret;
static void C_ccall trf_9035(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9035(t0,t1,t2);}

C_noret_decl(trf_9146)
static void C_ccall trf_9146(C_word c,C_word *av) C_noret;
static void C_ccall trf_9146(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9146(t0,t1,t2);}

C_noret_decl(trf_9180)
static void C_ccall trf_9180(C_word c,C_word *av) C_noret;
static void C_ccall trf_9180(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9180(t0,t1,t2);}

C_noret_decl(trf_9323)
static void C_ccall trf_9323(C_word c,C_word *av) C_noret;
static void C_ccall trf_9323(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9323(t0,t1,t2,t3);}

C_noret_decl(trf_9371)
static void C_ccall trf_9371(C_word c,C_word *av) C_noret;
static void C_ccall trf_9371(C_word c,C_word *av){
C_word t0=av[3];
C_word t1=av[2];
C_word t2=av[1];
C_word t3=av[0];
f_9371(t0,t1,t2,t3);}

C_noret_decl(trf_9419)
static void C_ccall trf_9419(C_word c,C_word *av) C_noret;
static void C_ccall trf_9419(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9419(t0,t1,t2);}

C_noret_decl(trf_9453)
static void C_ccall trf_9453(C_word c,C_word *av) C_noret;
static void C_ccall trf_9453(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9453(t0,t1,t2);}

C_noret_decl(trf_9498)
static void C_ccall trf_9498(C_word c,C_word *av) C_noret;
static void C_ccall trf_9498(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9498(t0,t1,t2);}

C_noret_decl(trf_9542)
static void C_ccall trf_9542(C_word c,C_word *av) C_noret;
static void C_ccall trf_9542(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9542(t0,t1,t2);}

C_noret_decl(trf_9633)
static void C_ccall trf_9633(C_word c,C_word *av) C_noret;
static void C_ccall trf_9633(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9633(t0,t1);}

C_noret_decl(trf_9729)
static void C_ccall trf_9729(C_word c,C_word *av) C_noret;
static void C_ccall trf_9729(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
f_9729(t0,t1);}

C_noret_decl(trf_9765)
static void C_ccall trf_9765(C_word c,C_word *av) C_noret;
static void C_ccall trf_9765(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9765(t0,t1,t2);}

C_noret_decl(trf_9923)
static void C_ccall trf_9923(C_word c,C_word *av) C_noret;
static void C_ccall trf_9923(C_word c,C_word *av){
C_word t0=av[2];
C_word t1=av[1];
C_word t2=av[0];
f_9923(t0,t1,t2);}

C_noret_decl(trva26246)
static void C_ccall trva26246(C_word c,C_word *av) C_noret;
static void C_ccall trva26246(C_word c,C_word *av){
C_word t0=av[1];
C_word t1=av[0];
va26246(t0,t1);}

/* f24688 in k11366 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f24688(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f24688,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[278];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* f25357 in k12556 in k12591 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f25357(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f25357,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[345];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k10000 in k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10002(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_10002,c,av);}
a=C_alloc(29);
t2=(C_truep(t1)?t1:((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10006,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t4=C_i_check_list_2(((C_word*)t0)[4],lf[100]);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10066,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t6=(
  f_10066(t5,((C_word*)t0)[4])
);
t7=*((C_word*)lf[107]+1);
t8=((C_word*)t0)[3];
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_TRUE;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10025,a[2]=t9,a[3]=t11,a[4]=t7,tmp=(C_word)a,a+=5,tmp);
t13=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10042,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=t2,a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[11],tmp=(C_word)a,a+=10,tmp);
t14=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10056,a[2]=t9,a[3]=t7,tmp=(C_word)a,a+=4,tmp);
/* core.scm:892: ##sys#dynamic-wind */
t15=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t15;
av2[1]=((C_word*)t0)[12];
av2[2]=t12;
av2[3]=t13;
av2[4]=t14;
((C_proc)(void*)(*((C_word*)t15+1)))(5,av2);}}

/* g1652 in k10000 in k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static C_word C_fcall f_10006(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_stack_overflow_check;{}
return(C_i_set_car(C_i_cdr(t1),((C_word*)t0)[2]));}

/* a10024 in k10000 in k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_10025(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_10025,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10029,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)((C_word*)t0)[3])[1])){
/* core.scm:892: ##sys#current-environment1660 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
f_10029(2,av2);}}}

/* k10027 in a10024 in k10000 in k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_10029(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_10029,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10033,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* core.scm:892: ##sys#current-environment1660 */
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k10031 in k10027 in a10024 in k10000 in k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_10033(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_10033,c,av);}
a=C_alloc(4);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10036,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:892: ##sys#current-environment1660 */
t4=((C_word*)t0)[5];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k10034 in k10031 in k10027 in a10024 in k10000 in k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_10036(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10036,c,av);}
t2=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_FALSE);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a10041 in k10000 in k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_10042(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_10042,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_10050,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* core.scm:894: canonicalize-body/ln */
t3=((C_word*)((C_word*)t0)[8])[1];
f_7884(t3,t2,((C_word*)t0)[7],C_i_cddr(((C_word*)t0)[9]),*((C_word*)lf[52]+1));}

/* k10048 in a10041 in k10000 in k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_10050(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_10050,c,av);}
/* core.scm:893: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* a10055 in k10000 in k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_10056(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_10056,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10060,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:892: ##sys#current-environment1660 */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k10058 in a10055 in k10000 in k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_10060(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_10060,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10063,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:892: ##sys#current-environment1660 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10061 in k10058 in a10055 in k10000 in k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_10063(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10063,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* for-each-loop1651 in k10000 in k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static C_word C_fcall f_10066(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_pairp(t1))){
t2=(
/* core.scm:888: g1652 */
  f_10006(((C_word*)t0)[2],C_slot(t1,C_fix(0)))
);
t4=C_slot(t1,C_fix(1));
t1=t4;
goto loop;}
else{
t2=C_SCHEME_UNDEFINED;
return(t2);}}

/* k10089 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_10091(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10091,c,av);}
/* core.scm:886: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop1619 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_10093(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_10093,3,t0,t1,t2);}
a=C_alloc(11);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9977,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=t2,tmp=(C_word)a,a+=7,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9981,a[2]=t5,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* core.scm:883: ##sys#eval/meta */
t7=*((C_word*)lf[197]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=C_i_cadr(t3);
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k10132 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_10134(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_10134,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10137,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
t3=C_i_cadr(((C_word*)t0)[10]);
if(C_truep(C_i_pairp(t3))){
/* core.scm:905: scheme#caadr */
t4=*((C_word*)lf[164]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_u_i_car(C_u_i_cdr(((C_word*)t0)[10]));
f_10137(2,av2);}}}

/* k10135 in k10132 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_10137(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_10137,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10140,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
t3=C_u_i_cdr(((C_word*)t0)[10]);
if(C_truep(C_i_pairp(C_u_i_car(t3)))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10196,a[2]=((C_word*)t0)[10],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:907: scheme#cdadr */
t5=*((C_word*)lf[208]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=t2;
f_10140(t4,C_i_caddr(((C_word*)t0)[10]));}}

/* k10138 in k10135 in k10132 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_fcall f_10140(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_10140,2,t0,t1);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10143,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* core.scm:909: lookup */
t3=((C_word*)((C_word*)t0)[10])[1];
f_7810(t3,t2,((C_word*)t0)[2]);}

/* k10141 in k10138 in k10135 in k10132 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_10143(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_10143,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10146,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t1,tmp=(C_word)a,a+=12,tmp);
/* core.scm:910: ##sys#put/restore! */
t3=*((C_word*)lf[205]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
av2[3]=lf[206];
av2[4]=lf[207];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10144 in k10141 in k10138 in k10135 in k10132 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_10146(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_10146,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10149,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10182,a[2]=t2,a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:911: ##sys#current-module */
t4=*((C_word*)lf[204]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k10147 in k10144 in k10141 in k10138 in k10135 in k10132 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_10149(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_10149,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10152,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10174,a[2]=t2,a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:914: ##sys#current-environment */
t4=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k10150 in k10147 in k10144 in k10141 in k10138 in k10135 in k10132 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_10152(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,8)))){
C_save_and_reclaim((void *)f_10152,c,av);}
a=C_alloc(21);
if(C_truep(*((C_word*)lf[200]+1))){
t2=C_a_i_list(&a,2,lf[145],((C_word*)t0)[2]);
t3=C_a_i_list(&a,1,lf[107]);
t4=C_a_i_list(&a,4,lf[201],t2,t3,((C_word*)t0)[3]);
/* core.scm:916: walk */
t5=((C_word*)((C_word*)t0)[4])[1];
f_8330(t5,((C_word*)t0)[5],t4,((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],C_SCHEME_FALSE);}
else{
/* core.scm:916: walk */
t2=((C_word*)((C_word*)t0)[4])[1];
f_8330(t2,((C_word*)t0)[5],lf[202],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],C_SCHEME_FALSE);}}

/* k10172 in k10147 in k10144 in k10141 in k10138 in k10135 in k10132 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_10174(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_10174,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10178,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* core.scm:915: ##sys#eval/meta */
t3=*((C_word*)lf[197]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k10176 in k10172 in k10147 in k10144 in k10141 in k10138 in k10135 in k10132 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_10178(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10178,c,av);}
/* core.scm:912: ##sys#extend-macro-environment */
t2=*((C_word*)lf[201]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k10180 in k10144 in k10141 in k10138 in k10135 in k10132 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_10182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10182,c,av);}
/* core.scm:911: ##sys#register-syntax-export */
t2=*((C_word*)lf[203]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k10194 in k10135 in k10132 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10196(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_10196,c,av);}
a=C_alloc(6);
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_u_i_cdr(t2);
t4=C_a_i_cons(&a,2,t1,t3);
t5=((C_word*)t0)[3];
f_10140(t5,C_a_i_cons(&a,2,lf[97],t4));}

/* k10225 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_10227(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_10227,c,av);}
/* core.scm:899: ##sys#check-syntax */
t2=*((C_word*)lf[211]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=C_SCHEME_FALSE;
av2[6]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(7,av2);}}

/* k10247 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_10249(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_10249,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10252,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
if(C_truep(((C_word*)t0)[2])){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10319,a[2]=((C_word*)t0)[11],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:932: ##sys#get */
t4=*((C_word*)lf[103]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
av2[3]=lf[213];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t3=t2;
f_10252(t3,C_SCHEME_UNDEFINED);}}

/* k10250 in k10247 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_10252(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,4)))){
C_save_and_reclaim_args((void *)trf_10252,2,t0,t1);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10255,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
if(C_truep(((C_word*)t0)[3])){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10303,a[2]=t2,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10311,a[2]=t3,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:939: ##sys#eval/meta */
t5=*((C_word*)lf[197]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
/* core.scm:934: ##sys#put! */
t3=*((C_word*)lf[108]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
av2[3]=lf[213];
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k10253 in k10250 in k10247 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10255(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(51,c,8)))){
C_save_and_reclaim((void *)f_10255,c,av);}
a=C_alloc(51);
if(C_truep(*((C_word*)lf[200]+1))){
t2=C_a_i_list(&a,2,lf[144],((C_word*)t0)[2]);
t3=C_a_i_list(&a,2,lf[116],lf[213]);
if(C_truep(((C_word*)t0)[3])){
t4=C_a_i_list(&a,2,lf[145],((C_word*)t0)[4]);
t5=C_a_i_list(&a,3,lf[196],((C_word*)t0)[3],t4);
t6=C_a_i_list(&a,1,lf[107]);
t7=C_a_i_list(&a,3,lf[214],t5,t6);
t8=C_a_i_list(&a,4,lf[108],t2,t3,t7);
/* core.scm:942: walk */
t9=((C_word*)((C_word*)t0)[5])[1];
f_8330(t9,((C_word*)t0)[6],t8,((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11],C_SCHEME_FALSE);}
else{
t4=C_a_i_list(&a,4,lf[108],t2,t3,C_SCHEME_FALSE);
/* core.scm:942: walk */
t5=((C_word*)((C_word*)t0)[5])[1];
f_8330(t5,((C_word*)t0)[6],t4,((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11],C_SCHEME_FALSE);}}
else{
/* core.scm:942: walk */
t2=((C_word*)((C_word*)t0)[5])[1];
f_8330(t2,((C_word*)t0)[6],lf[215],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11],C_SCHEME_FALSE);}}

/* k10301 in k10250 in k10247 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10303(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_10303,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10307,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:941: ##sys#current-environment */
t3=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k10305 in k10301 in k10250 in k10247 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_10307(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_10307,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* core.scm:934: ##sys#put! */
t3=*((C_word*)lf[108]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=lf[213];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10309 in k10250 in k10247 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10311(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10311,c,av);}
/* core.scm:938: ##sys#ensure-transformer */
t2=*((C_word*)lf[196]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k10317 in k10247 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_10319(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_10319,c,av);}
a=C_alloc(6);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
t4=C_a_i_cons(&a,2,t3,t2);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,t4);
t6=((C_word*)t0)[4];
f_10252(t6,t5);}

/* g1719 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_10329(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_10329,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10333,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* core.scm:959: ##sys#check-syntax */
t4=*((C_word*)lf[211]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[217];
av2[3]=t2;
av2[4]=lf[218];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k10331 in g1719 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_10333(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_10333,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10336,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:961: lookup */
t3=((C_word*)((C_word*)t0)[4])[1];
f_7810(t3,t2,C_i_car(((C_word*)t0)[3]));}

/* k10334 in k10331 in g1719 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10336(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_10336,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10343,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[3])))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10357,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10365,a[2]=t3,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:966: ##sys#eval/meta */
t5=*((C_word*)lf[197]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_cadr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=t2;
f_10343(t3,C_SCHEME_FALSE);}}

/* k10341 in k10334 in k10331 in g1719 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_10343(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_10343,2,t0,t1);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10347,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* core.scm:969: ##sys#get */
t3=*((C_word*)lf[103]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[213];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k10345 in k10341 in k10334 in k10331 in g1719 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_10347(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_10347,c,av);}
a=C_alloc(9);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list3(&a,3,((C_word*)t0)[3],((C_word*)t0)[4],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k10355 in k10334 in k10331 in g1719 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_10357(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_10357,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10361,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:968: ##sys#current-environment */
t3=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k10359 in k10355 in k10334 in k10331 in g1719 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_10361(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_10361,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];
f_10343(t2,C_a_i_cons(&a,2,((C_word*)t0)[3],t1));}

/* k10363 in k10334 in k10331 in g1719 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_10365(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_10365,c,av);}
/* core.scm:965: ##sys#ensure-transformer */
t2=*((C_word*)lf[196]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_u_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k10384 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_10386(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_10386,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_10389,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* core.scm:971: chicken.syntax#get-line-number */
t3=*((C_word*)lf[111]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k10387 in k10384 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_10389(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,4)))){
C_save_and_reclaim((void *)f_10389,c,av);}
a=C_alloc(17);
t2=(C_truep(t1)?t1:((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10397,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10442,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=t2,a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],tmp=(C_word)a,a+=11,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10456,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* core.scm:972: scheme#dynamic-wind */
t6=*((C_word*)lf[219]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[12];
av2[2]=t3;
av2[3]=t4;
av2[4]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}

/* a10396 in k10387 in k10384 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10397(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_10397,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(((C_word*)t0)[2],lf[100]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10419,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_10419(t6,t1,((C_word*)t0)[2]);}

/* for-each-loop1746 in a10396 in k10387 in k10384 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_10419(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_10419,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10429,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
/* core.scm:976: ##sys#put! */
t5=*((C_word*)lf[108]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t3;
av2[2]=C_i_car(t4);
av2[3]=lf[213];
av2[4]=C_i_cadr(t4);
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k10427 in for-each-loop1746 in a10396 in k10387 in k10384 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_10429(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10429,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_10419(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* a10441 in k10387 in k10384 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10442(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_10442,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10450,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* core.scm:980: canonicalize-body/ln */
t3=((C_word*)((C_word*)t0)[9])[1];
f_7884(t3,t2,((C_word*)t0)[7],C_i_cddr(((C_word*)t0)[10]),*((C_word*)lf[52]+1));}

/* k10448 in a10441 in k10387 in k10384 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_10450(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_10450,c,av);}
/* core.scm:979: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}

/* a10455 in k10387 in k10384 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10456(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_10456,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(((C_word*)t0)[2],lf[100]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10478,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_10478(t6,t1,((C_word*)t0)[2]);}

/* for-each-loop1764 in a10455 in k10387 in k10384 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_10478(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_10478,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10488,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
/* core.scm:986: ##sys#put! */
t5=*((C_word*)lf[108]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t3;
av2[2]=C_i_car(t4);
av2[3]=lf[213];
av2[4]=C_i_caddr(t4);
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k10486 in for-each-loop1764 in a10455 in k10387 in k10384 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_10488(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10488,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_10478(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* map-loop1713 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_10501(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_10501,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10526,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:957: g1719 */
t4=((C_word*)t0)[4];
f_10329(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k10524 in map-loop1713 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_10526(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_10526,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_10501(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* a10551 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_10552(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_10552,c,av);}
a=C_alloc(16);
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10556,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=t1,tmp=(C_word)a,a+=11,tmp);
t5=C_i_cdddr(((C_word*)t0)[9]);
if(C_truep(C_i_pairp(t5))){
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10585,a[2]=((C_word*)t0)[10],a[3]=t4,a[4]=((C_word*)t0)[7],tmp=(C_word)a,a+=5,tmp);
/* core.scm:999: scheme#append */
t7=*((C_word*)lf[5]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=t2;
av2[3]=C_i_cadddr(((C_word*)t0)[9]);
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t6=t4;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_a_i_cons(&a,2,lf[190],t2);
f_10556(2,av2);}}}

/* k10554 in a10551 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_10556(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,4)))){
C_save_and_reclaim((void *)f_10556,c,av);}
a=C_alloc(22);
t2=((C_word*)t0)[2];
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10561,a[2]=t5,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10566,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10572,a[2]=t3,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1002: ##sys#dynamic-wind */
t9=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[10];
av2[2]=t6;
av2[3]=t7;
av2[4]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* a10560 in k10554 in a10551 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10561(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10561,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,*((C_word*)lf[221]+1));
t3=C_mutate((C_word*)lf[221]+1 /* (set! ##sys#current-source-filename ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a10565 in k10554 in a10551 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10566(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_10566,c,av);}
/* core.scm:1003: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,t1,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}

/* a10571 in k10554 in a10551 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10572(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10572,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,*((C_word*)lf[221]+1));
t3=C_mutate((C_word*)lf[221]+1 /* (set! ##sys#current-source-filename ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k10583 in a10551 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_10585(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10585,c,av);}
/* core.scm:997: canonicalize-body/ln */
t2=((C_word*)((C_word*)t0)[2])[1];
f_7884(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,*((C_word*)lf[52]+1));}

/* k10612 in map-loop1798 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_10614(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10614,c,av);}
/* core.scm:1009: chicken.syntax#strip-syntax */
t2=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k10624 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_10626(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_10626,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_10628,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1006: ##sys#with-module-aliases */
t3=*((C_word*)lf[224]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[9];
av2[2]=t1;
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* a10627 in k10624 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_10628(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,8)))){
C_save_and_reclaim((void *)f_10628,c,av);}
a=C_alloc(3);
t2=C_i_cddr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,lf[190],t2);
/* core.scm:1012: walk */
t4=((C_word*)((C_word*)t0)[3])[1];
f_8330(t4,t1,t3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_TRUE);}

/* map-loop1798 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_10642(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,4)))){
C_save_and_reclaim_args((void *)trf_10642,3,t0,t1,t2);}
a=C_alloc(10);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10667,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10614,a[2]=t3,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1008: ##sys#check-syntax */
t6=*((C_word*)lf[211]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[225];
av2[3]=t4;
av2[4]=lf[226];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k10665 in map-loop1798 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_10667(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_10667,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_10642(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_10683(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_10683,c,av);}
a=C_alloc(12);
t2=C_i_assq(t1,*((C_word*)lf[44]+1));
t3=(C_truep(t2)?t2:*((C_word*)lf[45]+1));
t4=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10692,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t3,a[10]=t1,a[11]=((C_word*)t0)[9],tmp=(C_word)a,a+=12,tmp);
if(C_truep(C_i_not(*((C_word*)lf[48]+1)))){
if(C_truep(t3)){
t5=*((C_word*)lf[17]+1);
t6=t4;
f_10692(t6,(C_truep(*((C_word*)lf[17]+1))?*((C_word*)lf[17]+1):t1));}
else{
t5=t4;
f_10692(t5,C_SCHEME_FALSE);}}
else{
t5=t4;
f_10692(t5,C_SCHEME_FALSE);}}

/* k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_10692(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(31,0,4)))){
C_save_and_reclaim_args((void *)trf_10692,2,t0,t1);}
a=C_alloc(31);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10695,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
t3=C_i_caddr(((C_word*)t0)[11]);
t4=C_eqp(C_SCHEME_TRUE,t3);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11125,a[2]=t2,a[3]=((C_word*)t0)[10],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
if(C_truep(t4)){
/* core.scm:1018: ##sys#register-module */
t6=*((C_word*)lf[274]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t2;
av2[2]=((C_word*)t0)[10];
av2[3]=t1;
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t6=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t7=t6;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=((C_word*)t8)[1];
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11129,a[2]=((C_word*)t0)[10],tmp=(C_word)a,a+=3,tmp);
t11=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11178,a[2]=t8,a[3]=t10,a[4]=t9,a[5]=t5,tmp=(C_word)a,a+=6,tmp);
t12=C_u_i_cdr(((C_word*)t0)[11]);
t13=C_u_i_cdr(t12);
/* core.scm:1033: chicken.syntax#strip-syntax */
t14=*((C_word*)lf[146]+1);{
C_word av2[3];
av2[0]=t14;
av2[1]=t11;
av2[2]=C_u_i_car(t13);
((C_proc)(void*)(*((C_word*)t14+1)))(3,av2);}}}

/* k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_10695(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,2)))){
C_save_and_reclaim((void *)f_10695,c,av);}
a=C_alloc(18);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_10698,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t2,a[12]=((C_word*)t0)[2],a[13]=((C_word*)t0)[11],tmp=(C_word)a,a+=14,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11115,a[2]=t3,a[3]=((C_word*)t0)[10],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1035: ##sys#current-module */
t5=*((C_word*)lf[204]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_10698(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_10698,c,av);}
a=C_alloc(19);
t2=*((C_word*)lf[204]+1);
t3=*((C_word*)lf[107]+1);
t4=*((C_word*)lf[228]+1);
t5=*((C_word*)lf[229]+1);
t6=*((C_word*)lf[230]+1);
t7=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_10701,a[2]=((C_word*)t0)[2],a[3]=t6,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=t5,a[15]=t4,a[16]=t3,a[17]=t2,a[18]=((C_word*)t0)[13],tmp=(C_word)a,a+=19,tmp);
/* core.scm:1043: ##sys#module-alias-environment */
t8=*((C_word*)lf[229]+1);{
C_word *av2=av;
av2[0]=t8;
av2[1]=t7;
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}

/* k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_10701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(52,c,4)))){
C_save_and_reclaim((void *)f_10701,c,av);}
a=C_alloc(52);
t2=((C_word*)t0)[2];
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_END_OF_LIST;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t0)[3];
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=t1;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_TRUE;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_10704,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[2],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],tmp=(C_word)a,a+=13,tmp);
t13=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10902,a[2]=t3,a[3]=t5,a[4]=t7,a[5]=t9,a[6]=t11,a[7]=((C_word*)t0)[14],a[8]=((C_word*)t0)[15],a[9]=((C_word*)t0)[16],a[10]=((C_word*)t0)[17],tmp=(C_word)a,a+=11,tmp);
t14=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10958,a[2]=((C_word*)t0)[18],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
t15=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11083,a[2]=t3,a[3]=t5,a[4]=t7,a[5]=t9,a[6]=((C_word*)t0)[14],a[7]=((C_word*)t0)[15],a[8]=((C_word*)t0)[16],a[9]=((C_word*)t0)[17],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1038: ##sys#dynamic-wind */
t16=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t16;
av2[1]=t12;
av2[2]=t13;
av2[3]=t14;
av2[4]=t15;
((C_proc)(void*)(*((C_word*)t16+1)))(5,av2);}}

/* k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_10704(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,3)))){
C_save_and_reclaim((void *)f_10704,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10707,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10877,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[12],a[4]=t4,tmp=(C_word)a,a+=5,tmp));
t6=((C_word*)t4)[1];
f_10877(t6,t2,((C_word*)((C_word*)t0)[12])[1]);}

/* k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_10707(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,2)))){
C_save_and_reclaim((void *)f_10707,c,av);}
a=C_alloc(24);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10710,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
if(C_truep(((C_word*)t0)[10])){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10865,a[2]=((C_word*)t0)[10],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8239,a[2]=t3,a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[9],tmp=(C_word)a,a+=5,tmp);
if(C_truep(*((C_word*)lf[45]+1))){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8324,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* core.scm:612: scheme#symbol->string */
t6=*((C_word*)lf[257]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_cdr(((C_word*)t0)[10]);
f_8239(2,av2);}}}
else{
t3=t2;
f_10710(t3,C_SCHEME_UNDEFINED);}}

/* k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_fcall f_10710(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,2)))){
C_save_and_reclaim_args((void *)trf_10710,2,t0,t1);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10717,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10862,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* core.scm:1083: chicken.internal#module-requirement */
t4=*((C_word*)lf[236]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k10715 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_10717(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10717,c,av);}
/* core.scm:1081: chicken.compiler.support#canonicalize-begin-body */
t2=*((C_word*)lf[231]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k10723 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_10725(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_10725,c,av);}
/* core.scm:1082: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_fcall f_10731(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_10731,2,t0,t1);}
a=C_alloc(11);
if(C_truep(t1)){
t2=*((C_word*)lf[228]+1);
t3=*((C_word*)lf[107]+1);
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10734,a[2]=t3,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
/* core.scm:1088: ##sys#meta-macro-environment */
t5=*((C_word*)lf[235]+1);{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
/* core.scm:1082: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word av2[5];
av2[0]=t2;
av2[1]=((C_word*)t0)[9];
av2[2]=((C_word*)t0)[10];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}}

/* k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_10734(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_10734,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10737,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* core.scm:1090: ##sys#current-meta-environment */
t3=*((C_word*)lf[234]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_10737(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(27,c,4)))){
C_save_and_reclaim((void *)f_10737,c,av);}
a=C_alloc(27);
t2=((C_word*)t0)[2];
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=t1;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_TRUE;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10742,a[2]=t3,a[3]=t5,a[4]=t7,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
t9=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10772,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],tmp=(C_word)a,a+=8,tmp);
t10=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10830,a[2]=t3,a[3]=t5,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1087: ##sys#dynamic-wind */
t11=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t11;
av2[1]=((C_word*)t0)[11];
av2[2]=t8;
av2[3]=t9;
av2[4]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(5,av2);}}

/* a10741 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in ... */
static void C_ccall f_10742(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_10742,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10746,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
if(C_truep(((C_word*)((C_word*)t0)[4])[1])){
/* core.scm:1087: ##sys#macro-environment1970 */
t3=((C_word*)t0)[6];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
f_10746(2,av2);}}}

/* k10744 in a10741 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in ... */
static void C_ccall f_10746(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_10746,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_10749,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,tmp=(C_word)a,a+=9,tmp);
if(C_truep(((C_word*)((C_word*)t0)[4])[1])){
/* core.scm:1087: ##sys#current-environment1971 */
t3=((C_word*)t0)[6];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[3])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[3])[1];
f_10749(2,av2);}}}

/* k10747 in k10744 in a10741 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in ... */
static void C_ccall f_10749(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_10749,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10753,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1087: ##sys#macro-environment1970 */
t3=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k10751 in k10747 in k10744 in a10741 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in ... */
static void C_ccall f_10753(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_10753,c,av);}
a=C_alloc(9);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_10757,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1087: ##sys#current-environment1971 */
t4=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k10755 in k10751 in k10747 in k10744 in a10741 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in ... */
static void C_ccall f_10757(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_10757,c,av);}
a=C_alloc(6);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10760,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1087: ##sys#macro-environment1970 */
t4=((C_word*)t0)[7];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k10758 in k10755 in k10751 in k10747 in k10744 in a10741 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in ... */
static void C_ccall f_10760(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_10760,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10763,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1087: ##sys#current-environment1971 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10761 in k10758 in k10755 in k10751 in k10747 in k10744 in a10741 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in ... */
static void C_ccall f_10763(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10763,c,av);}
t2=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_FALSE);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a10771 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in ... */
static void C_ccall f_10772(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_10772,c,av);}
a=C_alloc(18);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10777,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10784,a[2]=t4,a[3]=t6,a[4]=t5,a[5]=t1,tmp=(C_word)a,a+=6,tmp);
if(C_truep(*((C_word*)lf[56]+1))){
/* core.scm:1092: ##sys#compiled-module-registration */
t8=*((C_word*)lf[233]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[7];
av2[3]=lf[170];
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}
else{
/* core.scm:1092: ##sys#compiled-module-registration */
t8=*((C_word*)lf[233]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=((C_word*)t0)[7];
av2[3]=lf[171];
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}}

/* g2001 in a10771 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in ... */
static void C_fcall f_10777(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,8)))){
C_save_and_reclaim_args((void *)trf_10777,3,t0,t1,t2);}
/* core.scm:1091: walk */
t3=((C_word*)((C_word*)t0)[2])[1];
f_8330(t3,t1,t2,((C_word*)t0)[3],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k10782 in a10771 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in ... */
static void C_ccall f_10784(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_10784,c,av);}
a=C_alloc(8);
t2=C_i_check_list_2(t1,lf[10]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10792,a[2]=((C_word*)t0)[2],a[3]=t4,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_10792(t6,((C_word*)t0)[5],t1);}

/* map-loop1995 in k10782 in a10771 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in ... */
static void C_fcall f_10792(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_10792,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10817,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:1091: g2001 */
t4=((C_word*)t0)[4];
f_10777(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k10815 in map-loop1995 in k10782 in a10771 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in ... */
static void C_ccall f_10817(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_10817,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_10792(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* a10829 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in ... */
static void C_ccall f_10830(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_10830,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10834,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1087: ##sys#macro-environment1970 */
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k10832 in a10829 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in ... */
static void C_ccall f_10834(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_10834,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10837,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* core.scm:1087: ##sys#current-environment1971 */
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k10835 in k10832 in a10829 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in ... */
static void C_ccall f_10837(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_10837,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10840,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* core.scm:1087: ##sys#macro-environment1970 */
t3=((C_word*)t0)[7];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10838 in k10835 in k10832 in a10829 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in ... */
static void C_ccall f_10840(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_10840,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_10843,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1087: ##sys#current-environment1971 */
t3=((C_word*)t0)[7];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[4])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10841 in k10838 in k10835 in k10832 in a10829 in k10735 in k10732 in k10729 in k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in ... */
static void C_ccall f_10843(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10843,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=C_mutate(((C_word *)((C_word*)t0)[4])+1,((C_word*)t0)[5]);
t4=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k10860 in k10708 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_10862(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,2)))){
C_save_and_reclaim((void *)f_10862,c,av);}
a=C_alloc(26);
t2=C_a_i_list2(&a,2,lf[162],t1);
t3=C_a_i_list1(&a,1,t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10725,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t5=C_eqp(*((C_word*)lf[47]+1),lf[232]);
t6=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10731,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=t4,a[9]=((C_word*)t0)[2],a[10]=t3,a[11]=((C_word*)t0)[3],tmp=(C_word)a,a+=12,tmp);
if(C_truep(t5)){
t7=t6;
f_10731(t7,t5);}
else{
t7=C_i_not(((C_word*)t0)[10]);
t8=t6;
f_10731(t8,(C_truep(t7)?C_i_not(*((C_word*)lf[47]+1)):C_SCHEME_FALSE));}}

/* k10863 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_10865(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_10865,c,av);}
a=C_alloc(3);
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10875,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1080: delete */
f_6763(t2,((C_word*)t0)[2],*((C_word*)lf[44]+1),*((C_word*)lf[237]+1));}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];
f_10710(t3,t2);}}

/* k10873 in k10863 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_10875(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10875,c,av);}
t2=C_mutate((C_word*)lf[44]+1 /* (set! chicken.compiler.core#import-libraries ...) */,t1);
t3=((C_word*)t0)[2];
f_10710(t3,t2);}

/* doloop1959 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_fcall f_10877(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_10877,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_eqp(t2,((C_word*)t0)[2]);
if(C_truep(t3)){
t4=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)t0)[2]);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10888,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t5=C_i_caar(t2);
t6=C_u_i_car(t2);
/* core.scm:1075: ##sys#put! */
t7=*((C_word*)lf[108]+1);{
C_word av2[5];
av2[0]=t7;
av2[1]=t4;
av2[2]=t5;
av2[3]=lf[213];
av2[4]=C_u_i_cdr(t6);
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}}

/* k10886 in doloop1959 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_10888(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_10888,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_10877(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}

/* a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_10902(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_10902,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10906,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
if(C_truep(((C_word*)((C_word*)t0)[6])[1])){
/* core.scm:1038: ##sys#current-module1884 */
t3=((C_word*)t0)[10];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
f_10906(2,av2);}}}

/* k10904 in a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_10906(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_10906,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_10909,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t1,tmp=(C_word)a,a+=13,tmp);
if(C_truep(((C_word*)((C_word*)t0)[6])[1])){
/* core.scm:1038: ##sys#current-environment1885 */
t3=((C_word*)t0)[10];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[3])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[3])[1];
f_10909(2,av2);}}}

/* k10907 in k10904 in a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_10909(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_10909,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_10912,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t1,a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
if(C_truep(((C_word*)((C_word*)t0)[6])[1])){
/* core.scm:1038: ##sys#macro-environment1886 */
t3=((C_word*)t0)[9];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[4])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[4])[1];
f_10912(2,av2);}}}

/* k10910 in k10907 in k10904 in a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_10912(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_10912,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_10915,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],tmp=(C_word)a,a+=15,tmp);
if(C_truep(((C_word*)((C_word*)t0)[6])[1])){
/* core.scm:1038: ##sys#module-alias-environment1887 */
t3=((C_word*)t0)[8];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[5])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[5])[1];
f_10915(2,av2);}}}

/* k10913 in k10910 in k10907 in k10904 in a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_10915(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_10915,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_10919,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
/* core.scm:1038: ##sys#current-module1884 */
t3=((C_word*)t0)[13];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k10917 in k10913 in k10910 in k10907 in k10904 in a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_10919(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_10919,c,av);}
a=C_alloc(15);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_10923,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=((C_word*)t0)[14],a[14]=((C_word*)t0)[15],tmp=(C_word)a,a+=15,tmp);
/* core.scm:1038: ##sys#current-environment1885 */
t4=((C_word*)t0)[12];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k10921 in k10917 in k10913 in k10910 in k10907 in k10904 in a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_10923(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_10923,c,av);}
a=C_alloc(14);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_10927,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=((C_word*)t0)[14],tmp=(C_word)a,a+=14,tmp);
/* core.scm:1038: ##sys#macro-environment1886 */
t4=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k10925 in k10921 in k10917 in k10913 in k10910 in k10907 in k10904 in a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in ... */
static void C_ccall f_10927(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_10927,c,av);}
a=C_alloc(13);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_10931,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1038: ##sys#module-alias-environment1887 */
t4=((C_word*)t0)[6];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k10929 in k10925 in k10921 in k10917 in k10913 in k10910 in k10907 in k10904 in a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in ... */
static void C_ccall f_10931(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_10931,c,av);}
a=C_alloc(10);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10934,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1038: ##sys#current-module1884 */
t4=((C_word*)t0)[11];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[12];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k10932 in k10929 in k10925 in k10921 in k10917 in k10913 in k10910 in k10907 in k10904 in a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in ... */
static void C_ccall f_10934(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_10934,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10937,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* core.scm:1038: ##sys#current-environment1885 */
t3=((C_word*)t0)[8];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10935 in k10932 in k10929 in k10925 in k10921 in k10917 in k10913 in k10910 in k10907 in k10904 in a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in ... */
static void C_ccall f_10937(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_10937,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10940,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1038: ##sys#macro-environment1886 */
t3=((C_word*)t0)[6];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10938 in k10935 in k10932 in k10929 in k10925 in k10921 in k10917 in k10913 in k10910 in k10907 in k10904 in a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in ... */
static void C_ccall f_10940(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_10940,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10943,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1038: ##sys#module-alias-environment1887 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k10941 in k10938 in k10935 in k10932 in k10929 in k10925 in k10921 in k10917 in k10913 in k10910 in k10907 in k10904 in a10901 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in ... */
static void C_ccall f_10943(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10943,c,av);}
t2=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_FALSE);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_10958(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_10958,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10964,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* core.scm:1044: ##sys#with-property-restore */
t3=*((C_word*)lf[270]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_10964(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_10964,c,av);}
a=C_alloc(10);
t2=C_i_cdddr(((C_word*)t0)[2]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_10974,a[2]=((C_word*)t0)[3],a[3]=t4,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp));
t6=((C_word*)t4)[1];
f_10974(t6,t1,t2,C_SCHEME_END_OF_LIST);}

/* loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_fcall f_10974(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,8)))){
C_save_and_reclaim_args((void *)trf_10974,4,t0,t1,t2,t3);}
a=C_alloc(7);
if(C_truep(C_i_nullp(t2))){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10984,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10989,a[2]=t3,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1048: scheme#call-with-current-continuation */
t6=*((C_word*)lf[269]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t4;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t4=C_i_cdr(t2);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11079,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* core.scm:1069: walk */
t6=((C_word*)((C_word*)t0)[4])[1];
f_8330(t6,t5,C_u_i_car(t2),((C_word*)t0)[5],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[6],((C_word*)t0)[7],C_SCHEME_TRUE);}}

/* k10982 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_10984(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_10984,c,av);}
/* core.scm:1048: g1935 */
t2=t1;{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_10989(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_10989,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10995,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11010,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1048: chicken.condition#with-exception-handler */
t5=*((C_word*)lf[268]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=t3;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* a10994 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_10995(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_10995,c,av);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11001,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1048: k1932 */
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* a11000 in a10994 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_11001(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_11001,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11005,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1051: chicken.condition#print-error-message */
t3=*((C_word*)lf[259]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
av2[3]=*((C_word*)lf[260]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k11003 in a11000 in a10994 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_11005(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11005,c,av);}
/* core.scm:1052: chicken.base#exit */
t2=*((C_word*)lf[258]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_fix(1);
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a11009 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_11010(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_11010,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11012,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11047,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11064,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* tmp15768 */
t5=t2;
f_11012(t5,t4);}

/* tmp15768 in a11009 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_fcall f_11012(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_11012,2,t0,t1);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11016,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_11021,tmp=(C_word)a,a+=2,tmp);
/* core.scm:1053: ##sys#finalize-module */
t4=*((C_word*)lf[267]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k11014 in tmp15768 in a11009 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_11016(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11016,c,av);}
/* core.scm:1066: scheme#reverse */
t2=*((C_word*)lf[261]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a11020 in tmp15768 in a11009 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_11021(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_11021,c,av);}
a=C_alloc(4);
if(C_truep(C_i_assq(t2,lf[70]))){
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[262];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11034,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1059: chicken.internal#hash-table-ref */
t4=*((C_word*)lf[133]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=*((C_word*)lf[65]+1);
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k11032 in a11020 in tmp15768 in a11009 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in ... */
static void C_ccall f_11034(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_11034,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[263];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11040,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1061: chicken.internal#hash-table-ref */
t3=*((C_word*)lf[133]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=*((C_word*)lf[66]+1);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k11038 in k11032 in a11020 in tmp15768 in a11009 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in ... */
static void C_ccall f_11040(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_11040,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[264];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11046,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1063: ##sys#get */
t3=*((C_word*)lf[103]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[266];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k11044 in k11038 in k11032 in a11020 in tmp15768 in a11009 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in ... */
static void C_ccall f_11046(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11046,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?lf[265]:C_SCHEME_FALSE);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* tmp25769 in a11009 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_fcall f_11047(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_11047,3,t0,t1,t2);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11053,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1048: k1932 */
t4=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* a11052 in tmp25769 in a11009 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_11053(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11053,c,av);}{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
C_apply_values(3,av2);}}

/* k11062 in a11009 in a10988 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_11064(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11064,c,av);}
a=C_alloc(3);
/* tmp25769 */
t2=((C_word*)t0)[2];
f_11047(t2,((C_word*)t0)[3],C_a_i_list(&a,1,t1));}

/* k11077 in loop in a10963 in a10957 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_11079(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_11079,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* core.scm:1067: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_10974(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* a11082 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_11083(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_11083,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_11087,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* core.scm:1038: ##sys#current-module1884 */
t3=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k11085 in a11082 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_11087(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_11087,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_11090,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* core.scm:1038: ##sys#current-environment1885 */
t3=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k11088 in k11085 in a11082 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_11090(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_11090,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_11093,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1038: ##sys#macro-environment1886 */
t3=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k11091 in k11088 in k11085 in a11082 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_11093(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_11093,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_11096,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* core.scm:1038: ##sys#module-alias-environment1887 */
t3=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k11094 in k11091 in k11088 in k11085 in a11082 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_11096(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_11096,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_11099,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* core.scm:1038: ##sys#current-module1884 */
t3=((C_word*)t0)[13];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11097 in k11094 in k11091 in k11088 in k11085 in a11082 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_11099(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_11099,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_11102,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1038: ##sys#current-environment1885 */
t3=((C_word*)t0)[13];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[4])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11100 in k11097 in k11094 in k11091 in k11088 in k11085 in a11082 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_11102(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_11102,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_11105,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
/* core.scm:1038: ##sys#macro-environment1886 */
t3=((C_word*)t0)[12];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[6])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11103 in k11100 in k11097 in k11094 in k11091 in k11088 in k11085 in a11082 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in ... */
static void C_ccall f_11105(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_11105,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_11108,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* core.scm:1038: ##sys#module-alias-environment1887 */
t3=((C_word*)t0)[11];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[8])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11106 in k11103 in k11100 in k11097 in k11094 in k11091 in k11088 in k11085 in a11082 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in ... */
static void C_ccall f_11108(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11108,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=C_mutate(((C_word *)((C_word*)t0)[4])+1,((C_word*)t0)[5]);
t4=C_mutate(((C_word *)((C_word*)t0)[6])+1,((C_word*)t0)[7]);
t5=C_mutate(((C_word *)((C_word*)t0)[8])+1,((C_word*)t0)[9]);
t6=((C_word*)t0)[10];{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* k11113 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_11115(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11115,c,av);}
if(C_truep(t1)){
/* core.scm:1036: ##sys#syntax-error-hook */
t2=*((C_word*)lf[271]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[272];
av2[3]=lf[273];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_10698(2,av2);}}}

/* k11123 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_11125(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11125,c,av);}
/* core.scm:1018: ##sys#register-module */
t2=*((C_word*)lf[274]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* g1850 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_fcall f_11129(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_11129,3,t0,t1,t2);}
a=C_alloc(7);
if(C_truep(C_i_symbolp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11142,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_pairp(t2))){
t4=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_11153,tmp=(C_word)a,a+=2,tmp);
t5=t3;
f_11142(t5,(
  f_11153(t2)
));}
else{
t4=t3;
f_11142(t4,C_SCHEME_FALSE);}}}

/* k11140 in g1850 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_11142(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,5)))){
C_save_and_reclaim_args((void *)trf_11142,2,t0,t1);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* core.scm:1030: ##sys#syntax-error-hook */
t2=*((C_word*)lf[271]+1);{
C_word av2[6];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[272];
av2[3]=lf[275];
av2[4]=((C_word*)t0)[3];
av2[5]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}}

/* loop in g1850 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static C_word C_fcall f_11153(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_stack_overflow_check;
loop:{}
t2=C_i_nullp(t1);
if(C_truep(t2)){
return(t2);}
else{
t3=C_i_car(t1);
if(C_truep(C_i_symbolp(t3))){
t5=C_u_i_cdr(t1);
t1=t5;
goto loop;}
else{
return(C_SCHEME_FALSE);}}}

/* k11176 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_11178(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_11178,c,av);}
a=C_alloc(8);
t2=C_i_check_list_2(t1,lf[10]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11186,a[2]=((C_word*)t0)[2],a[3]=t4,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp));
t6=((C_word*)t4)[1];
f_11186(t6,((C_word*)t0)[5],t1);}

/* map-loop1844 in k11176 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_11186(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_11186,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11211,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:1021: g1850 */
t4=((C_word*)t0)[4];
f_11129(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11209 in map-loop1844 in k11176 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11211(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11211,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_11186(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_11259(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,2)))){
C_save_and_reclaim((void *)f_11259,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_11262,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11322,a[2]=t2,a[3]=((C_word*)t0)[5],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1102: ##sys#current-environment */
t4=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_11262(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_11262,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_11265,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1103: chicken.syntax#get-line-number */
t3=*((C_word*)lf[111]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_11265(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(28,c,4)))){
C_save_and_reclaim((void *)f_11265,c,av);}
a=C_alloc(28);
t2=(C_truep(t1)?t1:((C_word*)t0)[2]);
t3=*((C_word*)lf[107]+1);
t4=((C_word*)t0)[3];
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_TRUE;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11271,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11279,a[2]=t5,a[3]=t7,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t10=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11296,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[9],a[4]=t2,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[12],tmp=(C_word)a,a+=9,tmp);
t11=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11310,a[2]=t5,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1105: ##sys#dynamic-wind */
t12=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t12;
av2[1]=t8;
av2[2]=t9;
av2[3]=t10;
av2[4]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(5,av2);}}

/* k11269 in k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_11271(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11271,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11274,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1110: set-real-names! */
f_7913(t2,((C_word*)t0)[3],((C_word*)t0)[5]);}

/* k11272 in k11269 in k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11274(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_11274,c,av);}
a=C_alloc(9);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,3,lf[97],((C_word*)t0)[3],((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a11278 in k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_11279(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_11279,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11283,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)((C_word*)t0)[3])[1])){
/* core.scm:1105: ##sys#current-environment2064 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
f_11283(2,av2);}}}

/* k11281 in a11278 in k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11283(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_11283,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11287,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* core.scm:1105: ##sys#current-environment2064 */
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k11285 in k11281 in a11278 in k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_11287(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11287,c,av);}
a=C_alloc(4);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11290,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1105: ##sys#current-environment2064 */
t4=((C_word*)t0)[5];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k11288 in k11285 in k11281 in a11278 in k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_11290(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11290,c,av);}
t2=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_FALSE);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a11295 in k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_11296(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_11296,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11304,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* core.scm:1107: canonicalize-body/ln */
t3=((C_word*)((C_word*)t0)[7])[1];
f_7884(t3,t2,((C_word*)t0)[4],((C_word*)t0)[8],*((C_word*)lf[52]+1));}

/* k11302 in a11295 in k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11304(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_11304,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11308,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1108: scheme#append */
t3=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k11306 in k11302 in a11295 in k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_11308(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_11308,c,av);}
/* core.scm:1106: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[5],((C_word*)t0)[6],C_SCHEME_FALSE);}

/* a11309 in k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_11310(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_11310,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11314,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1105: ##sys#current-environment2064 */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k11312 in a11309 in k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11314(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_11314,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11317,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1105: ##sys#current-environment2064 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11315 in k11312 in a11309 in k11263 in k11260 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_11317(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11317,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k11320 in k11257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_11322(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11322,c,av);}
/* core.scm:1102: ##sys#extend-se */
t2=*((C_word*)lf[175]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* map-loop2033 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_11324(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_11324,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11349,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:1101: g2039 */
t4=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11347 in map-loop2033 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_11349(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11349,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_11324(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k11366 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_11368(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_11368,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11371,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[3])){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f24688,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1122: ##sys#put/restore! */
t4=*((C_word*)lf[205]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
av2[3]=lf[206];
av2[4]=lf[96];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11377,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1117: chicken.syntax#get-line-number */
t4=*((C_word*)lf[111]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k11369 in k11366 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_11371(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_11371,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11374,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1122: ##sys#put/restore! */
t3=*((C_word*)lf[205]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[206];
av2[4]=lf[96];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11372 in k11369 in k11366 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_11374(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_11374,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[278];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k11375 in k11366 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_11377(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_11377,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11384,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11387,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1120: chicken.base#open-output-string */
t4=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* core.scm:1118: chicken.compiler.support#quit-compiling */
t3=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[279];
av2[3]=lf[281];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k11382 in k11375 in k11366 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_11384(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11384,c,av);}
/* core.scm:1118: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[279];
av2[3]=t1;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k11385 in k11375 in k11366 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_11387(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11387,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11393,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1120: ##sys#write-char-0 */
t4=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(40);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k11391 in k11385 in k11375 in k11366 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_11393(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11393,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11396,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1120: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11394 in k11391 in k11385 in k11375 in k11366 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11396(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11396,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11399,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1120: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[280];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11397 in k11394 in k11391 in k11385 in k11375 in k11366 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_11399(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11399,c,av);}
/* core.scm:1120: chicken.base#get-output-string */
t2=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_11414(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_11414,c,av);}
a=C_alloc(12);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11417,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1128: chicken.syntax#get-line-number */
t5=*((C_word*)lf[111]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_11417(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,2)))){
C_save_and_reclaim((void *)f_11417,c,av);}
a=C_alloc(18);
t2=C_i_caddr(((C_word*)t0)[2]);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_11423,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=t1,a[7]=t4,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
if(C_truep(C_i_memq(((C_word*)((C_word*)t0)[3])[1],lf[83]))){
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11717,a[2]=t5,a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1132: chicken.base#open-output-string */
t7=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t6=t5;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
f_11423(2,av2);}}}

/* k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_11423(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,4)))){
C_save_and_reclaim((void *)f_11423,c,av);}
a=C_alloc(17);
t2=C_i_assq(((C_word*)((C_word*)t0)[2])[1],lf[70]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11430,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1135: g2134 */
t4=t3;
f_11430(t4,((C_word*)t0)[8],t2);}
else{
t3=C_i_assq(((C_word*)((C_word*)t0)[2])[1],lf[74]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11482,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1135: g2143 */
t5=t4;
f_11482(t5,((C_word*)t0)[8],t3);}
else{
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11530,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],tmp=(C_word)a,a+=10,tmp);
if(C_truep(C_i_memq(((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[4]))){
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_11530(2,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11548,a[2]=((C_word*)t0)[2],a[3]=t4,a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1158: ##sys#alias-global-hook */
t6=*((C_word*)lf[122]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}}}}

/* g2134 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_11430(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_11430,3,t0,t1,t2);}
a=C_alloc(10);
t3=C_i_cadr(t2);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11437,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1138: chicken.base#gensym */
t5=*((C_word*)lf[109]+1);{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k11435 in g2134 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11437(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_11437,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11472,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1140: chicken.compiler.support#foreign-type-convert-argument */
t3=*((C_word*)lf[284]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[9])[1];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k11458 in k11470 in k11435 in g2134 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_11460(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,8)))){
C_save_and_reclaim((void *)f_11460,c,av);}
a=C_alloc(18);
t2=C_a_i_list(&a,3,lf[282],((C_word*)t0)[2],t1);
t3=C_a_i_list(&a,3,lf[173],((C_word*)t0)[3],t2);
/* core.scm:1139: walk */
t4=((C_word*)((C_word*)t0)[4])[1];
f_8330(t4,((C_word*)t0)[5],t3,((C_word*)t0)[6],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* k11470 in k11435 in g2134 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_11472(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,3)))){
C_save_and_reclaim((void *)f_11472,c,av);}
a=C_alloc(24);
t2=C_a_i_list(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_list(&a,1,t2);
t4=C_i_caddr(((C_word*)t0)[3]);
t5=C_a_i_list(&a,2,t4,((C_word*)t0)[4]);
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11460,a[2]=t5,a[3]=t3,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1143: chicken.compiler.support#foreign-type-check */
t7=*((C_word*)lf[283]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* g2143 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_11482(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_11482,3,t0,t1,t2);}
a=C_alloc(10);
t3=C_i_caddr(t2);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11489,a[2]=t3,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1148: chicken.base#gensym */
t5=*((C_word*)lf[109]+1);{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k11487 in g2143 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11489(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_11489,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11524,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1150: chicken.compiler.support#foreign-type-convert-argument */
t3=*((C_word*)lf[284]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[9])[1];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k11514 in k11522 in k11487 in g2143 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_11516(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,8)))){
C_save_and_reclaim((void *)f_11516,c,av);}
a=C_alloc(21);
t2=C_a_i_list(&a,4,lf[285],((C_word*)t0)[2],((C_word*)t0)[3],t1);
t3=C_a_i_list(&a,3,lf[173],((C_word*)t0)[4],t2);
/* core.scm:1149: walk */
t4=((C_word*)((C_word*)t0)[5])[1];
f_8330(t4,((C_word*)t0)[6],t3,((C_word*)t0)[7],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[8],((C_word*)t0)[9],C_SCHEME_FALSE);}

/* k11522 in k11487 in g2143 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_11524(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,3)))){
C_save_and_reclaim((void *)f_11524,c,av);}
a=C_alloc(22);
t2=C_a_i_list(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_list(&a,1,t2);
t4=C_a_i_list(&a,1,((C_word*)t0)[3]);
t5=C_i_cadr(((C_word*)t0)[4]);
t6=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11516,a[2]=t4,a[3]=t5,a[4]=t3,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1154: chicken.compiler.support#foreign-type-check */
t7=*((C_word*)lf[283]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k11528 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_11530(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,8)))){
C_save_and_reclaim((void *)f_11530,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11537,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1180: walk */
t3=((C_word*)((C_word*)t0)[4])[1];
f_8330(t3,t2,((C_word*)((C_word*)t0)[5])[1],((C_word*)t0)[6],((C_word*)t0)[7],C_i_memq(((C_word*)((C_word*)t0)[3])[1],((C_word*)t0)[6]),((C_word*)t0)[8],((C_word*)t0)[9],C_SCHEME_FALSE);}

/* k11535 in k11528 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11537(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_11537,c,av);}
a=C_alloc(9);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,3,lf[286],((C_word*)((C_word*)t0)[3])[1],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_11548(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_11548,c,av);}
a=C_alloc(11);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_11551,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
if(C_truep(lf[35])){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11704,a[2]=t3,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1160: chicken.compiler.support#mark-variable */
t5=*((C_word*)lf[158]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=lf[297];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_11551(2,av2);}}}

/* k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11551(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(41,c,2)))){
C_save_and_reclaim((void *)f_11551,c,av);}
a=C_alloc(41);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11554,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(*((C_word*)lf[24]+1))){
t3=C_a_i_list(&a,2,((C_word*)((C_word*)t0)[5])[1],((C_word*)((C_word*)t0)[6])[1]);
t4=C_a_i_list(&a,1,t3);
t5=C_a_i_list(&a,2,lf[145],((C_word*)((C_word*)t0)[5])[1]);
t6=C_a_i_list(&a,3,lf[188],lf[296],t5);
t7=C_a_i_list(&a,4,lf[173],t4,t6,((C_word*)((C_word*)t0)[5])[1]);
t8=C_mutate(((C_word *)((C_word*)t0)[6])+1,t7);
t9=t2;
f_11554(t9,t8);}
else{
t3=t2;
f_11554(t3,C_SCHEME_UNDEFINED);}}

/* k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_11554(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_11554,2,t0,t1);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11560,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11681,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1169: ##sys#current-environment */
t4=*((C_word*)lf[107]+1);{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_11560(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_11560,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11563,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11580,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1171: chicken.base#open-output-string */
t4=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11677,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1176: ##sys#current-environment */
t3=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11561 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_11563(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_11563,c,av);}
a=C_alloc(4);
if(C_truep(*((C_word*)lf[42]+1))){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11569,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1174: ##sys#undefine-macro! */
t3=*((C_word*)lf[288]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_11530(2,av2);}}}

/* k11567 in k11561 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_11569(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_11569,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11576,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1175: ##sys#current-module */
t3=*((C_word*)lf[204]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k11574 in k11567 in k11561 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_11576(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11576,c,av);}
/* core.scm:1175: ##sys#unregister-syntax-export */
t2=*((C_word*)lf[287]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k11578 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_11580(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_11580,c,av);}
a=C_alloc(13);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11586,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11602,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[4])){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11605,a[2]=t4,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1172: chicken.base#open-output-string */
t6=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
/* core.scm:1171: ##sys#print */
t5=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[291];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* k11584 in k11578 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_11586(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_11586,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11589,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1171: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[289];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11587 in k11584 in k11578 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_11589(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11589,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11592,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1171: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11590 in k11587 in k11584 in k11578 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_11592(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_11592,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11595,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1171: ##sys#write-char-0 */
t3=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(39);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k11593 in k11590 in k11587 in k11584 in k11578 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_11595(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11595,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11598,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1171: chicken.base#get-output-string */
t3=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11596 in k11593 in k11590 in k11587 in k11584 in k11578 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in ... */
static void C_ccall f_11598(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11598,c,av);}
/* core.scm:1170: chicken.base#warning */
t2=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k11600 in k11578 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_11602(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11602,c,av);}
/* core.scm:1171: ##sys#print */
t2=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k11603 in k11578 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_11605(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11605,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11611,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1172: ##sys#write-char-0 */
t4=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(40);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k11609 in k11603 in k11578 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_11611(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11611,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11614,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1172: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11612 in k11609 in k11603 in k11578 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_11614(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11614,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11617,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1172: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[290];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11615 in k11612 in k11609 in k11603 in k11578 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_11617(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11617,c,av);}
/* core.scm:1172: chicken.base#get-output-string */
t2=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k11631 in k11675 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_11633(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_11633,c,av);}
a=C_alloc(13);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11639,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11655,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[4])){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11658,a[2]=t4,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1179: chicken.base#open-output-string */
t6=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
/* core.scm:1178: ##sys#print */
t5=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[294];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* k11637 in k11631 in k11675 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_11639(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_11639,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11642,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1178: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[292];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11640 in k11637 in k11631 in k11675 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_11642(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11642,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11645,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1178: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11643 in k11640 in k11637 in k11631 in k11675 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_11645(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_11645,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11648,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1178: ##sys#write-char-0 */
t3=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(39);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k11646 in k11643 in k11640 in k11637 in k11631 in k11675 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in ... */
static void C_ccall f_11648(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11648,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11651,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1178: chicken.base#get-output-string */
t3=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11649 in k11646 in k11643 in k11640 in k11637 in k11631 in k11675 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in ... */
static void C_ccall f_11651(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11651,c,av);}
/* core.scm:1177: chicken.base#warning */
t2=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k11653 in k11631 in k11675 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_11655(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11655,c,av);}
/* core.scm:1178: ##sys#print */
t2=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k11656 in k11631 in k11675 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_11658(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11658,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11664,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1179: ##sys#write-char-0 */
t4=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(40);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k11662 in k11656 in k11631 in k11675 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_11664(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11664,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11667,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1179: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11665 in k11662 in k11656 in k11631 in k11675 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_11667(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11667,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11670,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1179: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[293];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11668 in k11665 in k11662 in k11656 in k11631 in k11675 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in ... */
static void C_ccall f_11670(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11670,c,av);}
/* core.scm:1179: chicken.base#get-output-string */
t2=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k11675 in k11558 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_11677(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_11677,c,av);}
a=C_alloc(5);
if(C_truep(C_i_assq(((C_word*)t0)[2],t1))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11633,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1178: chicken.base#open-output-string */
t3=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_11530(2,av2);}}}

/* k11679 in k11552 in k11549 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_11681(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11681,c,av);}
/* core.scm:1169: ##sys#macro? */
t2=*((C_word*)lf[295]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k11702 in k11546 in k11421 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11704(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_11704,c,av);}
/* core.scm:1161: chicken.compiler.support#mark-variable */
t2=*((C_word*)lf[158]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)((C_word*)t0)[3])[1];
av2[3]=lf[159];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k11715 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_11717(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_11717,c,av);}
a=C_alloc(13);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11723,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11739,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[4])){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11742,a[2]=t4,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1133: chicken.base#open-output-string */
t6=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
/* core.scm:1132: ##sys#print */
t5=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[301];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* k11721 in k11715 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_11723(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_11723,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11726,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1132: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[299];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11724 in k11721 in k11715 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11726(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11726,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11729,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1132: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[4])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11727 in k11724 in k11721 in k11715 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_11729(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11729,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11732,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1132: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[298];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11730 in k11727 in k11724 in k11721 in k11715 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_11732(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11732,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_11735,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1132: chicken.base#get-output-string */
t3=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k11733 in k11730 in k11727 in k11724 in k11721 in k11715 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_11735(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11735,c,av);}
/* core.scm:1131: chicken.base#warning */
t2=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k11737 in k11715 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_11739(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_11739,c,av);}
/* core.scm:1132: ##sys#print */
t2=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k11740 in k11715 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_11742(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_11742,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11748,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1133: ##sys#write-char-0 */
t4=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(40);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k11746 in k11740 in k11715 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_11748(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11748,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11751,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1133: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11749 in k11746 in k11740 in k11715 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_11751(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_11751,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11754,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1133: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[300];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k11752 in k11749 in k11746 in k11740 in k11715 in k11415 in k11412 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_11754(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11754,c,av);}
/* core.scm:1133: chicken.base#get-output-string */
t2=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* g2230 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_11783(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,8)))){
C_save_and_reclaim_args((void *)trf_11783,3,t0,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11791,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1187: walk */
t4=((C_word*)((C_word*)t0)[3])[1];
f_8330(t4,t3,t2,((C_word*)t0)[4],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k11789 in g2230 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_11791(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_11791,c,av);}
/* core.scm:1187: unquotify */
t2=((C_word*)((C_word*)t0)[2])[1];
f_7979(t2,((C_word*)t0)[3],t1);}

/* k11797 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_11799(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_11799,c,av);}
a=C_alloc(9);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t2);
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_cons(&a,2,lf[188],t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* map-loop2224 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_11801(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_11801,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11826,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:1186: g2230 */
t4=((C_word*)t0)[4];
f_11783(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11824 in map-loop2224 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_11826(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11826,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_11801(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k11848 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_11850(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,6)))){
C_save_and_reclaim((void *)f_11850,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11854,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1192: mapwalk */
t3=((C_word*)((C_word*)t0)[3])[1];
f_13577(t3,t2,C_i_cddr(((C_word*)t0)[4]),((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],C_SCHEME_FALSE);}

/* k11852 in k11848 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_11854(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_11854,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,lf[302],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k11886 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_11888(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,6)))){
C_save_and_reclaim((void *)f_11888,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11892,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1197: mapwalk */
t3=((C_word*)((C_word*)t0)[3])[1];
f_13577(t3,t2,C_i_cddr(((C_word*)t0)[4]),((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],C_SCHEME_FALSE);}

/* k11890 in k11886 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_11892(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_11892,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,lf[303],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* map-loop2257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_11898(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_11898,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11923,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:1196: g2263 */
t4=((C_word*)((C_word*)t0)[4])[1];
f_7979(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k11921 in map-loop2257 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_11923(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_11923,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_11898(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k11945 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_11947(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_11947,c,av);}
a=C_alloc(9);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,3,lf[282],((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k11966 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_11968(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,8)))){
C_save_and_reclaim((void *)f_11968,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11972,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1206: walk */
t3=((C_word*)((C_word*)t0)[4])[1];
f_8330(t3,t2,C_i_cadddr(((C_word*)t0)[5]),((C_word*)t0)[6],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* k11970 in k11966 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_11972(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_11972,c,av);}
a=C_alloc(12);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,4,lf[285],((C_word*)t0)[3],((C_word*)t0)[4],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k11993 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_11995(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_11995,c,av);}
/* core.scm:1211: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],C_SCHEME_FALSE,((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}

/* k12008 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12010(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12010,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[308];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k12031 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12033(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12033,c,av);}
/* core.scm:1219: chicken.compiler.support#canonicalize-begin-body */
t2=*((C_word*)lf[231]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* fold in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_12037(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,8)))){
C_save_and_reclaim_args((void *)trf_12037,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_i_car(t2);
t4=C_u_i_cdr(t2);
if(C_truep(C_i_nullp(t4))){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12055,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1224: walk */
t6=((C_word*)((C_word*)t0)[2])[1];
f_8330(t6,t5,t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}
else{
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12062,a[2]=t1,a[3]=((C_word*)t0)[9],a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1225: walk */
t6=((C_word*)((C_word*)t0)[2])[1];
f_8330(t6,t5,t3,((C_word*)t0)[3],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}}

/* k12053 in fold in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12055(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_12055,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list1(&a,1,t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k12060 in fold in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12062(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_12062,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12066,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1225: fold */
t3=((C_word*)((C_word*)t0)[3])[1];
f_12037(t3,t2,((C_word*)t0)[4]);}

/* k12064 in k12060 in fold in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12066(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_12066,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k12079 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12081(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_12081,c,av);}
/* core.scm:1229: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* k12092 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12094(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_12094,c,av);}
/* core.scm:1232: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* k12105 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12107(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_12107,c,av);}
/* core.scm:1235: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* k12118 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12120(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_12120,c,av);}
/* core.scm:1238: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* k12131 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12133(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_12133,c,av);}
/* core.scm:1241: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* k12140 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12142(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_12142,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12145,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1245: chicken.syntax#strip-syntax */
t3=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_caddr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12143 in k12140 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12145(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_12145,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12148,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_i_cdddr(((C_word*)t0)[4]);
if(C_truep(C_i_pairp(t3))){
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_cadddr(((C_word*)t0)[4]);
f_12148(2,av2);}}
else{
/* core.scm:1248: scheme#symbol->string */
t4=*((C_word*)lf[257]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k12146 in k12143 in k12140 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12148(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_12148,c,av);}
a=C_alloc(12);
t2=C_a_i_list3(&a,3,((C_word*)t0)[2],((C_word*)t0)[3],t1);
t3=C_a_i_cons(&a,2,t2,lf[70]);
t4=C_mutate(&lf[70] /* (set! chicken.compiler.core#foreign-variables ...) */,t3);
t5=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t5;
av2[1]=lf[322];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12189(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,4)))){
C_save_and_reclaim((void *)f_12189,c,av);}
a=C_alloc(21);
t2=C_i_cdddr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12195,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t1,tmp=(C_word)a,a+=13,tmp);
if(C_truep(((C_word*)t0)[10])){
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_12195(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12277,a[2]=t3,a[3]=((C_word*)t0)[11],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[9])){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12280,a[2]=t4,a[3]=((C_word*)t0)[9],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1261: chicken.base#open-output-string */
t6=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
/* core.scm:1259: chicken.compiler.support#quit-compiling */
t5=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[328];
av2[3]=lf[330];
av2[4]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}}

/* k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12195(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_12195,c,av);}
a=C_alloc(13);
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12204,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1264: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12270,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1284: chicken.compiler.support#register-foreign-type! */
t3=*((C_word*)lf[326]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[11];
av2[3]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k12202 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12204(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_12204,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_12207,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* core.scm:1265: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k12205 in k12202 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12207(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,5)))){
C_save_and_reclaim((void *)f_12207,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12210,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t1,tmp=(C_word)a,a+=13,tmp);
/* core.scm:1266: chicken.compiler.support#register-foreign-type! */
t3=*((C_word*)lf[326]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[12];
av2[3]=((C_word*)t0)[13];
av2[4]=((C_word*)t0)[3];
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* k12208 in k12205 in k12202 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_12210(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_12210,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12213,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1267: chicken.compiler.support#mark-variable */
t3=*((C_word*)lf[158]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[159];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k12211 in k12208 in k12205 in k12202 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_12213(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_12213,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12216,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1268: chicken.compiler.support#mark-variable */
t3=*((C_word*)lf[158]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[12];
av2[3]=lf[159];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k12214 in k12211 in k12208 in k12205 in k12202 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_12216(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_12216,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12219,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1269: chicken.compiler.support#hide-variable */
t3=*((C_word*)lf[157]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12217 in k12214 in k12211 in k12208 in k12205 in k12202 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_12219(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_12219,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12222,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1270: chicken.compiler.support#hide-variable */
t3=*((C_word*)lf[157]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12220 in k12217 in k12214 in k12211 in k12208 in k12205 in k12202 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_12222(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_12222,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12225,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12267,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1274: ##sys#current-module */
t4=*((C_word*)lf[204]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k12223 in k12220 in k12217 in k12214 in k12211 in k12208 in k12205 in k12202 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_12225(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,2)))){
C_save_and_reclaim((void *)f_12225,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12228,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12263,a[2]=t2,a[3]=((C_word*)t0)[12],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1275: ##sys#current-module */
t4=*((C_word*)lf[204]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k12226 in k12223 in k12220 in k12217 in k12214 in k12211 in k12208 in k12205 in k12202 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_12228(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,2)))){
C_save_and_reclaim((void *)f_12228,c,av);}
a=C_alloc(29);
t2=C_i_car(((C_word*)t0)[2]);
t3=C_a_i_list(&a,3,lf[177],((C_word*)t0)[3],t2);
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_12243,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],tmp=(C_word)a,a+=11,tmp);
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[2])))){
t5=C_i_cadr(((C_word*)t0)[2]);
t6=t4;
f_12243(t6,C_a_i_list(&a,3,lf[177],((C_word*)t0)[12],t5));}
else{
t5=t4;
f_12243(t5,C_a_i_list(&a,3,lf[177],((C_word*)t0)[12],lf[324]));}}

/* k12241 in k12226 in k12223 in k12220 in k12217 in k12214 in k12211 in k12208 in k12205 in k12202 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_fcall f_12243(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,8)))){
C_save_and_reclaim_args((void *)trf_12243,2,t0,t1);}
a=C_alloc(9);
t2=C_a_i_list(&a,3,lf[190],((C_word*)t0)[2],t1);
/* core.scm:1276: walk */
t3=((C_word*)((C_word*)t0)[3])[1];
f_8330(t3,((C_word*)t0)[4],t2,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10]);}

/* k12261 in k12223 in k12220 in k12217 in k12214 in k12211 in k12208 in k12205 in k12202 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_12263(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12263,c,av);}
/* core.scm:1275: ##sys#register-export */
t2=*((C_word*)lf[325]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k12265 in k12220 in k12217 in k12214 in k12211 in k12208 in k12205 in k12202 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_12267(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_12267,c,av);}
/* core.scm:1274: ##sys#register-export */
t2=*((C_word*)lf[325]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k12268 in k12193 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12270(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12270,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[327];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k12275 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_12277,c,av);}
/* core.scm:1259: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[328];
av2[3]=t1;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k12278 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12280(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_12280,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12286,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1261: ##sys#write-char-0 */
t4=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(40);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k12284 in k12278 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12286,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12289,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1261: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12287 in k12284 in k12278 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12289(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12289,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12292,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1261: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[329];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12290 in k12287 in k12284 in k12278 in k12187 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_12292(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12292,c,av);}
/* core.scm:1261: chicken.base#get-output-string */
t2=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12309 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12311(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_12311,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12314,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* core.scm:1290: scheme#symbol->string */
t3=*((C_word*)lf[257]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12312 in k12309 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12314(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_12314,c,av);}
a=C_alloc(12);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_i_caddr(((C_word*)t0)[2]);
t5=C_i_cadddr(((C_word*)t0)[2]);
t6=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12323,a[2]=t3,a[3]=t4,a[4]=t5,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1293: chicken.compiler.support#make-random-name */
t7=*((C_word*)lf[339]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* k12321 in k12312 in k12309 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12323(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,4)))){
C_save_and_reclaim((void *)f_12323,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12326,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
if(C_truep(((C_word*)t0)[8])){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_12326(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12368,a[2]=t2,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[9])){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12371,a[2]=t3,a[3]=((C_word*)t0)[9],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1297: chicken.base#open-output-string */
t5=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
/* core.scm:1295: chicken.compiler.support#quit-compiling */
t4=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[336];
av2[3]=lf[338];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}}

/* k12324 in k12321 in k12312 in k12309 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12326(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_12326,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_12329,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep(((C_word*)t0)[4])){
t3=t2;
f_12329(t3,C_SCHEME_UNDEFINED);}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12357,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=C_i_cddddr(((C_word*)t0)[8]);
/* core.scm:1299: scheme#symbol->string */
t5=*((C_word*)lf[257]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=C_i_car(t4);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k12327 in k12324 in k12321 in k12312 in k12309 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_fcall f_12329(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,3)))){
C_save_and_reclaim_args((void *)trf_12329,2,t0,t1);}
a=C_alloc(12);
t2=C_a_i_vector3(&a,3,((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[3],((C_word*)t0)[4]);
t3=C_a_i_cons(&a,2,t2,*((C_word*)lf[72]+1));
t4=C_mutate((C_word*)lf[72]+1 /* (set! chicken.compiler.core#external-variables ...) */,t3);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12349,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1302: scheme#string-append */
t6=*((C_word*)lf[334]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[335];
av2[3]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}

/* k12347 in k12327 in k12324 in k12321 in k12312 in k12309 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_12349(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,1)))){
C_save_and_reclaim((void *)f_12349,c,av);}
a=C_alloc(18);
t2=C_a_i_list3(&a,3,((C_word*)t0)[2],lf[332],t1);
t3=C_a_i_cons(&a,2,t2,lf[70]);
t4=C_mutate(&lf[70] /* (set! chicken.compiler.core#foreign-variables ...) */,t3);
t5=lf[73];
t6=C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[2]);
t7=C_a_i_cons(&a,2,t6,lf[73]);
t8=C_mutate(&lf[73] /* (set! chicken.compiler.core#external-to-pointer ...) */,t7);
t9=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t9;
av2[1]=lf[333];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}

/* k12355 in k12324 in k12321 in k12312 in k12309 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_12357(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12357,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)t0)[3];
f_12329(t3,t2);}

/* k12366 in k12321 in k12312 in k12309 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12368(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_12368,c,av);}
/* core.scm:1295: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[336];
av2[3]=t1;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k12369 in k12321 in k12312 in k12309 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12371(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_12371,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12377,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1297: ##sys#write-char-0 */
t4=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(40);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k12375 in k12369 in k12321 in k12312 in k12309 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_12377(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12377,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12380,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1297: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12378 in k12375 in k12369 in k12321 in k12312 in k12309 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_12380(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12380,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12383,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1297: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[337];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12381 in k12378 in k12375 in k12369 in k12321 in k12312 in k12309 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_12383(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12383,c,av);}
/* core.scm:1297: chicken.base#get-output-string */
t2=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12398(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_12398,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_12401,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* core.scm:1310: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12401(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_12401,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12404,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1311: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12404(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_12404,c,av);}
a=C_alloc(15);
t2=C_i_cddddr(((C_word*)t0)[2]);
t3=C_i_pairp(t2);
t4=(C_truep(t3)?C_i_cadddr(((C_word*)t0)[2]):C_SCHEME_FALSE);
t5=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_12410,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t4,a[13]=((C_word*)t0)[2],a[14]=((C_word*)t0)[12],tmp=(C_word)a,a+=15,tmp);
/* core.scm:1313: chicken.compiler.support#set-real-name! */
t6=*((C_word*)lf[115]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}

/* k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12410(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(28,c,2)))){
C_save_and_reclaim((void *)f_12410,c,av);}
a=C_alloc(28);
t2=C_a_i_list3(&a,3,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
t3=C_a_i_cons(&a,2,t2,lf[74]);
t4=C_mutate(&lf[74] /* (set! chicken.compiler.core#location-pointer-map ...) */,t3);
t5=*((C_word*)lf[107]+1);
t6=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_12525,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=t5,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[4],a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
/* core.scm:1317: ##sys#current-environment */
t7=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}

/* a12421 in k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_12422(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_12422,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12426,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)((C_word*)t0)[3])[1])){
/* core.scm:1316: ##sys#current-environment2368 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
f_12426(2,av2);}}}

/* k12424 in a12421 in k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_12426(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_12426,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12430,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* core.scm:1316: ##sys#current-environment2368 */
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k12428 in k12424 in a12421 in k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_12430(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12430,c,av);}
a=C_alloc(4);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12433,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1316: ##sys#current-environment2368 */
t4=((C_word*)t0)[5];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k12431 in k12428 in k12424 in a12421 in k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_12433(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12433,c,av);}
t2=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_FALSE);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a12438 in k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_12439(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_12439,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12488,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12511,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1319: chicken.compiler.support#estimate-foreign-result-location-size */
t4=*((C_word*)lf[343]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k12457 in k12486 in a12438 in k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_12459(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,8)))){
C_save_and_reclaim((void *)f_12459,c,av);}
a=C_alloc(12);
t2=C_a_i_cons(&a,2,lf[190],t1);
t3=C_a_i_list(&a,3,lf[173],((C_word*)t0)[2],t2);
/* core.scm:1318: walk */
t4=((C_word*)((C_word*)t0)[3])[1];
f_8330(t4,((C_word*)t0)[4],t3,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],C_SCHEME_FALSE);}

/* k12461 in k12486 in a12438 in k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_fcall f_12463(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_12463,2,t0,t1);}
a=C_alloc(3);
t2=(C_truep(((C_word*)t0)[2])?C_i_car(C_i_cddddr(((C_word*)t0)[3])):C_i_cadddr(((C_word*)t0)[3]));
t3=C_a_i_list(&a,1,t2);
/* core.scm:1319: ##sys#append */
t4=*((C_word*)lf[154]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=((C_word*)t0)[4];
av2[2]=t1;
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k12486 in a12438 in k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_12488(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(86,c,2)))){
C_save_and_reclaim((void *)f_12488,c,av);}
a=C_alloc(86);
t2=C_s_a_i_plus(&a,2,C_fix(2),t1);
t3=C_a_i_list(&a,2,lf[341],t2);
t4=C_a_i_list(&a,2,lf[116],t1);
t5=C_a_i_list(&a,3,lf[303],t3,t4);
t6=C_a_i_list2(&a,2,((C_word*)t0)[2],t5);
t7=C_a_i_list(&a,1,t6);
t8=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12459,a[2]=t7,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12463,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[11],a[4]=t8,tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[10])){
t10=C_a_i_list(&a,3,lf[177],((C_word*)t0)[12],((C_word*)t0)[10]);
t11=t9;
f_12463(t11,C_a_i_list(&a,1,t10));}
else{
t10=t9;
f_12463(t10,C_SCHEME_END_OF_LIST);}}

/* k12509 in a12438 in k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_12511(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12511,c,av);}
/* core.scm:1319: chicken.compiler.support#bytes->words */
t2=*((C_word*)lf[342]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a12512 in k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_12513(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_12513,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12517,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1316: ##sys#current-environment2368 */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k12515 in a12512 in k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_12517(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_12517,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12520,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1316: ##sys#current-environment2368 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12518 in k12515 in a12512 in k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_12520(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12520,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k12523 in k12408 in k12402 in k12399 in k12396 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_12525(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,4)))){
C_save_and_reclaim((void *)f_12525,c,av);}
a=C_alloc(32);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=C_a_i_cons(&a,2,t2,t1);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_TRUE;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12422,a[2]=t5,a[3]=t7,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t9=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12439,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[11],a[9]=((C_word*)t0)[12],a[10]=((C_word*)t0)[13],a[11]=((C_word*)t0)[3],a[12]=((C_word*)t0)[14],tmp=(C_word)a,a+=13,tmp);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12513,a[2]=t5,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1316: ##sys#dynamic-wind */
t11=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t11;
av2[1]=((C_word*)t0)[15];
av2[2]=t8;
av2[3]=t9;
av2[4]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(5,av2);}}

/* k12556 in k12591 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12558(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_12558,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12561,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[5])){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f25357,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1344: chicken.internal#hash-table-set! */
t4=*((C_word*)lf[346]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=*((C_word*)lf[65]+1);
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12571,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(t1)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12574,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1342: chicken.base#open-output-string */
t5=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
/* core.scm:1340: chicken.compiler.support#quit-compiling */
t4=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[347];
av2[3]=lf[349];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}}

/* k12559 in k12556 in k12591 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12561(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_12561,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12564,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1344: chicken.internal#hash-table-set! */
t3=*((C_word*)lf[346]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=*((C_word*)lf[65]+1);
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12562 in k12559 in k12556 in k12591 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12564(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12564,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[345];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k12569 in k12556 in k12591 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12571(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_12571,c,av);}
/* core.scm:1340: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[347];
av2[3]=t1;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k12572 in k12556 in k12591 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12574(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_12574,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12580,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1342: ##sys#write-char-0 */
t4=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(40);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k12578 in k12572 in k12556 in k12591 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12580(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12580,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12583,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1342: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12581 in k12578 in k12572 in k12556 in k12591 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_12583(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12583,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12586,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1342: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[348];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12584 in k12581 in k12578 in k12572 in k12556 in k12591 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_12586(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12586,c,av);}
/* core.scm:1342: chicken.base#get-output-string */
t2=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12591 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12593(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_12593,c,av);}
a=C_alloc(9);
t2=C_a_i_cons(&a,2,lf[97],t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12558,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1338: chicken.syntax#get-line-number */
t4=*((C_word*)lf[111]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12605(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_12605,c,av);}
a=C_alloc(13);
t2=C_i_caddr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12611,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=t1,a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12726,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1351: scheme#call-with-current-continuation */
t5=*((C_word*)lf[269]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12611(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_12611,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12614,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1351: g2421 */
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12614(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,4)))){
C_save_and_reclaim((void *)f_12614,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12617,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
if(C_truep(((C_word*)t0)[8])){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_12617(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12706,a[2]=t2,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[7])){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12709,a[2]=t3,a[3]=((C_word*)t0)[7],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1364: chicken.base#open-output-string */
t5=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
/* core.scm:1362: chicken.compiler.support#quit-compiling */
t4=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[361];
av2[3]=lf[363];
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}}

/* k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12617(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,2)))){
C_save_and_reclaim((void *)f_12617,c,av);}
a=C_alloc(25);
t2=C_a_i_list(&a,2,lf[145],((C_word*)t0)[2]);
t3=C_a_i_list2(&a,2,((C_word*)t0)[3],t2);
t4=C_a_i_cons(&a,2,t3,lf[76]);
t5=C_mutate(&lf[76] /* (set! chicken.compiler.core#defconstant-bindings ...) */,t4);
t6=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12627,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1368: chicken.compiler.support#collapsable-literal? */
t7=*((C_word*)lf[360]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_12627(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_12627,c,av);}
a=C_alloc(10);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12630,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_a_i_list(&a,2,lf[145],((C_word*)t0)[3]);
/* core.scm:1369: chicken.internal#hash-table-set! */
t4=*((C_word*)lf[346]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=*((C_word*)lf[66]+1);
av2[3]=((C_word*)t0)[4];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12640,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[4],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1371: chicken.compiler.support#basic-literal? */
t3=*((C_word*)lf[359]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k12628 in k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_12630(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12630,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[352];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k12638 in k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_12640(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_12640,c,av);}
a=C_alloc(10);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12643,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1372: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[355];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12673,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[9],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[7])){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12676,a[2]=t2,a[3]=((C_word*)t0)[7],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1381: chicken.base#open-output-string */
t4=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* core.scm:1379: chicken.compiler.support#quit-compiling */
t3=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[356];
av2[3]=lf[358];
av2[4]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}}

/* k12641 in k12638 in k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_12643(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_12643,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12646,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1373: chicken.internal#hash-table-set! */
t3=*((C_word*)lf[346]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=*((C_word*)lf[66]+1);
av2[3]=((C_word*)t0)[9];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12644 in k12641 in k12638 in k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_12646(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_12646,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12649,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1374: chicken.compiler.support#hide-variable */
t3=*((C_word*)lf[157]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k12647 in k12644 in k12641 in k12638 in k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_12649(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_12649,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12652,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1375: chicken.compiler.support#mark-variable */
t3=*((C_word*)lf[158]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[354];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k12650 in k12647 in k12644 in k12641 in k12638 in k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_12652(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_12652,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12655,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1376: chicken.compiler.support#mark-variable */
t3=*((C_word*)lf[158]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[159];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k12653 in k12650 in k12647 in k12644 in k12641 in k12638 in k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_12655(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,8)))){
C_save_and_reclaim((void *)f_12655,c,av);}
a=C_alloc(15);
t2=C_a_i_list(&a,2,lf[145],((C_word*)t0)[2]);
t3=C_a_i_list(&a,3,lf[353],((C_word*)t0)[3],t2);
/* core.scm:1377: walk */
t4=((C_word*)((C_word*)t0)[4])[1];
f_8330(t4,((C_word*)t0)[5],t3,((C_word*)t0)[6],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}

/* k12671 in k12638 in k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_12673(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_12673,c,av);}
/* core.scm:1379: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[356];
av2[3]=t1;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k12674 in k12638 in k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_12676(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_12676,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12682,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1381: ##sys#write-char-0 */
t4=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(40);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k12680 in k12674 in k12638 in k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_12682(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12682,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12685,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1381: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12683 in k12680 in k12674 in k12638 in k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_12685(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12685,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12688,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1381: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[357];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12686 in k12683 in k12680 in k12674 in k12638 in k12625 in k12615 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_12688(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12688,c,av);}
/* core.scm:1381: chicken.base#get-output-string */
t2=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k12704 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12706(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_12706,c,av);}
/* core.scm:1362: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[361];
av2[3]=t1;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k12707 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12709(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_12709,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12715,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1364: ##sys#write-char-0 */
t4=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(40);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k12713 in k12707 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_12715(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12715,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12718,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1364: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12716 in k12713 in k12707 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_12718(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_12718,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12721,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1364: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[362];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k12719 in k12716 in k12713 in k12707 in k12612 in k12609 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_12721(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12721,c,av);}
/* core.scm:1364: chicken.base#get-output-string */
t2=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a12725 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12726(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_12726,c,av);}
a=C_alloc(9);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_12732,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12744,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1351: chicken.condition#with-exception-handler */
t5=*((C_word*)lf[268]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t1;
av2[2]=t3;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* a12731 in a12725 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12732(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_12732,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12738,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1351: k2418 */
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* a12737 in a12731 in a12725 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12738(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_12738,c,av);}
/* core.scm:1353: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=lf[364];
av2[3]=((C_word*)t0)[2];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* a12743 in a12725 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12744(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_12744,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12750,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12776,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1351: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t1;
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}

/* a12749 in a12743 in a12725 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12750(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_12750,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12757,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=C_i_symbolp(((C_word*)t0)[2]);
if(C_truep(C_i_not(t3))){
/* core.scm:1356: chicken.compiler.support#collapsable-literal? */
t4=*((C_word*)lf[360]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_12757(2,av2);}}}

/* k12755 in a12749 in a12743 in a12725 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_12757(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_12757,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_a_i_list(&a,3,lf[173],lf[76],((C_word*)t0)[3]);
/* core.scm:1358: scheme#eval */
t3=*((C_word*)lf[365]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* a12775 in a12743 in a12725 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12776(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +3,c,2)))){
C_save_and_reclaim((void*)f_12776,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+3);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12782,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1351: k2418 */
t4=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* a12781 in a12775 in a12743 in a12725 in k12603 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_12782(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_12782,c,av);}{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=0;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
C_apply_values(3,av2);}}

/* g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_12804(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,0,5)))){
C_save_and_reclaim_args((void *)trf_12804,3,t0,t1,t2);}
a=C_alloc(32);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12810,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13668,tmp=(C_word)a,a+=2,tmp));
t13=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13703,a[2]=t11,a[3]=((C_word*)t0)[3],a[4]=t3,tmp=(C_word)a,a+=5,tmp));
t14=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13722,a[2]=t7,tmp=(C_word)a,a+=3,tmp));
t15=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_13728,tmp=(C_word)a,a+=2,tmp));
t16=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13756,a[2]=t2,a[3]=t5,a[4]=t9,a[5]=t11,a[6]=t3,a[7]=t7,tmp=(C_word)a,a+=8,tmp);
t17=t16;
f_13756(t17,t1);}

/* a12809 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_12810(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_12810,3,t0,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12818,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1388: lookup */
t4=((C_word*)((C_word*)t0)[3])[1];
f_7810(t4,t3,t2);}

/* k12816 in a12809 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12818(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_12818,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_memq(t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k12823 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12825(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,8)))){
C_save_and_reclaim((void *)f_12825,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[190],t1);
/* core.scm:1385: walk */
t3=((C_word*)((C_word*)t0)[2])[1];
f_8330(t3,((C_word*)t0)[3],t2,((C_word*)t0)[4],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[5],((C_word*)t0)[6],C_SCHEME_FALSE);}

/* map-loop2480 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_12827(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_12827,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12852,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:1387: g2486 */
t4=((C_word*)t0)[4];
f_12804(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k12850 in map-loop2480 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12852(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_12852,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_12827(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* a12869 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12870(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,5)))){
C_save_and_reclaim((void *)f_12870,c,av);}
a=C_alloc(5);
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6440,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_6440(t6,t1,C_fix(4),C_SCHEME_END_OF_LIST,t2);}

/* a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_12880(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_12880,c,av);}
a=C_alloc(13);
t4=C_i_car(t3);
t5=C_i_car(t2);
t6=C_i_cadr(t5);
t7=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12890,a[2]=t2,a[3]=t4,a[4]=t1,a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],a[10]=((C_word*)t0)[7],a[11]=t6,a[12]=((C_word*)t0)[8],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1396: ##sys#alias-global-hook */
t8=*((C_word*)lf[122]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=t6;
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t8+1)))(5,av2);}}

/* k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_12890(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,2)))){
C_save_and_reclaim((void *)f_12890,c,av);}
a=C_alloc(21);
t2=C_i_caddr(((C_word*)t0)[2]);
t3=C_i_cadr(t2);
t4=C_i_cadddr(((C_word*)t0)[2]);
t5=C_i_cadr(t4);
t6=C_i_cadr(((C_word*)t0)[3]);
t7=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_12902,a[2]=((C_word*)t0)[4],a[3]=t6,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=t3,a[9]=((C_word*)t0)[3],a[10]=t1,a[11]=((C_word*)t0)[9],a[12]=t5,a[13]=((C_word*)t0)[10],a[14]=((C_word*)t0)[2],tmp=(C_word)a,a+=15,tmp);
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13122,a[2]=((C_word*)t0)[11],a[3]=t1,a[4]=t7,a[5]=((C_word*)t0)[12],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1400: chicken.compiler.support#valid-c-identifier? */
t9=*((C_word*)lf[472]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}

/* k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_12902(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_12902,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_12905,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],tmp=(C_word)a,a+=15,tmp);
t3=C_i_listp(((C_word*)t0)[3]);
t4=C_i_not(t3);
if(C_truep(t4)){
if(C_truep(t4)){
/* core.scm:1411: chicken.syntax#syntax-error */
t5=*((C_word*)lf[367]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=lf[468];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t5=t2;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_12905(2,av2);}}}
else{
t5=C_i_listp(((C_word*)t0)[12]);
t6=C_i_not(t5);
if(C_truep(t6)){
if(C_truep(t6)){
/* core.scm:1411: chicken.syntax#syntax-error */
t7=*((C_word*)lf[367]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t2;
av2[2]=lf[468];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t7=t2;{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_SCHEME_UNDEFINED;
f_12905(2,av2);}}}
else{
t7=C_i_length(((C_word*)t0)[3]);
t8=C_i_length(((C_word*)t0)[12]);
t9=C_eqp(t7,t8);
if(C_truep(C_i_not(t9))){
/* core.scm:1411: chicken.syntax#syntax-error */
t10=*((C_word*)lf[367]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t10;
av2[1]=t2;
av2[2]=lf[468];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}
else{
t10=t2;{
C_word *av2=av;
av2[0]=t10;
av2[1]=C_SCHEME_UNDEFINED;
f_12905(2,av2);}}}}}

/* k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_12905(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,6)))){
C_save_and_reclaim((void *)f_12905,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12912,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_12916,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1415: mapwalk */
t4=((C_word*)((C_word*)t0)[13])[1];
f_13577(t4,t3,((C_word*)t0)[14],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],C_SCHEME_FALSE);}

/* k12910 in k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_12912(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_12912,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,lf[449],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k12914 in k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_12916(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,4)))){
C_save_and_reclaim((void *)f_12916,c,av);}
a=C_alloc(21);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12924,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_12936,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13041,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_13041(t7,t3,((C_word*)t0)[3],((C_word*)t0)[12]);}

/* k12922 in k12914 in k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_12924(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_12924,c,av);}
a=C_alloc(3);
t2=C_a_i_list(&a,1,t1);
/* core.scm:1414: ##sys#append */
t3=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k12934 in k12914 in k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_12936(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(43,c,4)))){
C_save_and_reclaim((void *)f_12936,c,av);}
a=C_alloc(43);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12940,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12952,a[2]=t2,a[3]=((C_word*)t0)[8],tmp=(C_word)a,a+=4,tmp);
if(C_truep((C_truep(C_i_equalp(((C_word*)t0)[8],lf[450]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(((C_word*)t0)[8],lf[451]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(((C_word*)t0)[8],lf[452]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(((C_word*)t0)[8],lf[453]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))))){
t4=C_i_cddr(((C_word*)t0)[9]);
t5=C_a_i_cons(&a,2,C_SCHEME_END_OF_LIST,t4);
t6=C_a_i_cons(&a,2,lf[173],t5);
t7=C_a_i_list(&a,2,lf[145],((C_word*)t0)[10]);
t8=C_a_i_list(&a,3,lf[454],t6,t7);
t9=C_a_i_list(&a,1,t8);
t10=C_a_i_cons(&a,2,C_SCHEME_END_OF_LIST,t9);
t11=C_a_i_cons(&a,2,lf[173],t10);
/* core.scm:1433: chicken.compiler.support#foreign-type-convert-argument */
t12=*((C_word*)lf[284]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t12;
av2[1]=t2;
av2[2]=t11;
av2[3]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t12+1)))(4,av2);}}
else{
if(C_truep((C_truep(C_i_equalp(((C_word*)t0)[8],lf[455]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(((C_word*)t0)[8],lf[456]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(((C_word*)t0)[8],lf[457]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(((C_word*)t0)[8],lf[458]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(((C_word*)t0)[8],lf[459]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(((C_word*)t0)[8],lf[460]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))))))){
/* core.scm:1455: chicken.syntax#syntax-error */
t4=*((C_word*)lf[367]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[461];
av2[3]=((C_word*)t0)[8];
av2[4]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
if(C_truep((C_truep(C_i_equalp(((C_word*)t0)[8],lf[462]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(((C_word*)t0)[8],lf[463]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(((C_word*)t0)[8],lf[464]))?C_SCHEME_TRUE:(C_truep(C_i_equalp(((C_word*)t0)[8],lf[465]))?C_SCHEME_TRUE:C_SCHEME_FALSE)))))){
t4=C_i_cddr(((C_word*)t0)[9]);
t5=C_a_i_cons(&a,2,C_SCHEME_END_OF_LIST,t4);
t6=C_a_i_cons(&a,2,lf[173],t5);
t7=C_a_i_list(&a,2,lf[466],t6);
t8=C_a_i_list(&a,1,t7);
t9=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13012,a[2]=((C_word*)t0)[10],a[3]=t8,a[4]=t2,a[5]=((C_word*)t0)[8],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1467: macro-alias */
t10=((C_word*)((C_word*)t0)[11])[1];
f_7844(t10,t9,lf[467]);}
else{
t4=C_i_cddr(((C_word*)t0)[9]);
t5=C_a_i_cons(&a,2,C_SCHEME_END_OF_LIST,t4);
t6=C_a_i_cons(&a,2,lf[173],t5);
/* core.scm:1433: chicken.compiler.support#foreign-type-convert-argument */
t7=*((C_word*)lf[284]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t2;
av2[2]=t6;
av2[3]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}}}

/* k12938 in k12934 in k12914 in k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_12940(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,8)))){
C_save_and_reclaim((void *)f_12940,c,av);}
a=C_alloc(18);
t2=C_a_i_list(&a,3,lf[173],((C_word*)t0)[2],t1);
t3=C_a_i_list(&a,3,lf[97],((C_word*)t0)[3],t2);
/* core.scm:1416: walk */
t4=((C_word*)((C_word*)t0)[4])[1];
f_8330(t4,((C_word*)t0)[5],t3,((C_word*)t0)[6],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* k12950 in k12934 in k12914 in k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_12952(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_12952,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,C_SCHEME_END_OF_LIST,t1);
t3=C_a_i_cons(&a,2,lf[173],t2);
/* core.scm:1433: chicken.compiler.support#foreign-type-convert-argument */
t4=*((C_word*)lf[284]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=t3;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k13010 in k12934 in k12914 in k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_13012(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(42,c,3)))){
C_save_and_reclaim((void *)f_13012,c,av);}
a=C_alloc(42);
t2=C_a_i_list(&a,2,lf[145],((C_word*)t0)[2]);
t3=C_a_i_list(&a,3,lf[454],lf[466],t2);
t4=C_a_i_list(&a,3,t1,lf[466],t3);
t5=C_a_i_list(&a,3,lf[173],((C_word*)t0)[3],t4);
t6=C_a_i_list(&a,1,t5);
t7=C_a_i_cons(&a,2,C_SCHEME_END_OF_LIST,t6);
t8=C_a_i_cons(&a,2,lf[173],t7);
/* core.scm:1433: chicken.compiler.support#foreign-type-convert-argument */
t9=*((C_word*)lf[284]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[4];
av2[2]=t8;
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}

/* loop in k12914 in k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_13041(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,2)))){
C_save_and_reclaim_args((void *)trf_13041,4,t0,t1,t2,t3);}
a=C_alloc(15);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
t5=C_i_car(t3);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13073,a[2]=t4,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=t2,a[6]=t3,tmp=(C_word)a,a+=7,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13077,a[2]=t6,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13081,a[2]=t7,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1429: chicken.compiler.support#final-foreign-type */
t9=*((C_word*)lf[120]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}}

/* k13063 in k13071 in loop in k12914 in k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_13065(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_13065,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k13071 in loop in k12914 in k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_13073(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_13073,c,av);}
a=C_alloc(10);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13065,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1432: loop */
t4=((C_word*)((C_word*)t0)[4])[1];
f_13041(t4,t3,C_u_i_cdr(((C_word*)t0)[5]),C_u_i_cdr(((C_word*)t0)[6]));}

/* k13075 in loop in k12914 in k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_13077(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13077,c,av);}
/* core.scm:1427: chicken.compiler.support#foreign-type-convert-result */
t2=*((C_word*)lf[118]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k13079 in loop in k12914 in k12903 in k12900 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_13081(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13081,c,av);}
/* core.scm:1428: chicken.compiler.support#finish-foreign-result */
t2=*((C_word*)lf[119]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k13120 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_13122(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_13122,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=C_a_i_cons(&a,2,t2,lf[77]);
t4=C_mutate(&lf[77] /* (set! chicken.compiler.core#callback-names ...) */,t3);
t5=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
f_12902(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13133,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1403: chicken.syntax#get-line-number */
t3=*((C_word*)lf[111]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k13131 in k13120 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_13133(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_13133,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13140,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13143,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1406: chicken.base#open-output-string */
t4=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* core.scm:1404: chicken.compiler.support#quit-compiling */
t3=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[469];
av2[3]=lf[471];
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k13138 in k13131 in k13120 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_13140(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13140,c,av);}
/* core.scm:1404: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[469];
av2[3]=t1;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k13141 in k13131 in k13120 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_13143(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_13143,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13149,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1406: ##sys#write-char-0 */
t4=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(40);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k13147 in k13141 in k13131 in k13120 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_13149(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_13149,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13152,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1406: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k13150 in k13147 in k13141 in k13131 in k13120 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_13152(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_13152,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13155,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1406: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[470];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k13153 in k13150 in k13147 in k13141 in k13131 in k13120 in k12888 in a12879 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_13155(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_13155,c,av);}
/* core.scm:1406: chicken.base#get-output-string */
t2=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* g2573 in k13259 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_13192(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,8)))){
C_save_and_reclaim_args((void *)trf_13192,3,t0,t1,t2);}
a=C_alloc(21);
t3=C_i_cadr(t2);
t4=C_a_i_list(&a,2,lf[145],lf[474]);
t5=C_a_i_list(&a,5,lf[475],t3,C_fix(0),C_SCHEME_FALSE,t4);
/* core.scm:1479: walk */
t6=((C_word*)((C_word*)t0)[2])[1];
f_8330(t6,t1,t5,((C_word*)t0)[3],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[4],((C_word*)t0)[5],C_SCHEME_FALSE);}

/* g2580 in k13259 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_13218(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,8)))){
C_save_and_reclaim_args((void *)trf_13218,3,t0,t1,t2);}
/* core.scm:1483: walk */
t3=((C_word*)((C_word*)t0)[2])[1];
f_8330(t3,t1,C_i_cdr(t2),((C_word*)t0)[3],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[4],((C_word*)t0)[5],C_SCHEME_FALSE);}

/* k13244 in k13259 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_13246(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_13246,c,av);}
a=C_alloc(12);
t2=C_a_i_list(&a,2,t1,lf[332]);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list(&a,2,lf[117],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k13259 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_13261(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,8)))){
C_save_and_reclaim((void *)f_13261,c,av);}
a=C_alloc(21);
t2=C_i_assq(t1,lf[74]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13192,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1477: g2573 */
t4=t3;
f_13192(t4,((C_word*)t0)[6],t2);}
else{
t3=C_i_assq(((C_word*)t0)[7],lf[73]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13218,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1477: g2580 */
t5=t4;
f_13218(t5,((C_word*)t0)[6],t3);}
else{
if(C_truep(C_i_assq(((C_word*)t0)[7],lf[77]))){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13246,a[2]=((C_word*)t0)[6],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1485: scheme#symbol->string */
t5=*((C_word*)lf[257]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=C_a_i_list(&a,2,lf[145],lf[474]);
t5=C_a_i_list(&a,5,lf[475],((C_word*)t0)[7],C_fix(0),C_SCHEME_FALSE,t4);
/* core.scm:1487: walk */
t6=((C_word*)((C_word*)t0)[2])[1];
f_8330(t6,((C_word*)t0)[6],t5,((C_word*)t0)[3],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[4],((C_word*)t0)[5],C_SCHEME_FALSE);}}}}

/* k13276 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_13278(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_13278,c,av);}
a=C_alloc(7);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13284,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* core.scm:1499: chicken.internal#hash-table-ref */
t4=*((C_word*)lf[133]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=*((C_word*)lf[63]+1);
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k13282 in k13276 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_13284(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_13284,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13287,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
if(C_truep(((C_word*)t0)[4])){
if(C_truep(t1)){
t3=C_i_cdr(t1);
t4=C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
t5=C_a_i_cons(&a,2,t4,t3);
t6=C_a_i_cons(&a,2,((C_word*)t0)[5],t5);
/* core.scm:1501: chicken.internal#hash-table-set! */
t7=*((C_word*)lf[346]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t7;
av2[1]=t2;
av2[2]=*((C_word*)lf[63]+1);
av2[3]=((C_word*)t0)[6];
av2[4]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]);
t4=C_a_i_cons(&a,2,t3,C_SCHEME_END_OF_LIST);
t5=C_a_i_cons(&a,2,((C_word*)t0)[5],t4);
/* core.scm:1501: chicken.internal#hash-table-set! */
t6=*((C_word*)lf[346]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t2;
av2[2]=*((C_word*)lf[63]+1);
av2[3]=((C_word*)t0)[6];
av2[4]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k13285 in k13282 in k13276 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_13287(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13287,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a13306 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_13307(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13307,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,*((C_word*)lf[476]+1));
t3=C_mutate((C_word*)lf[476]+1 /* (set! ##sys#syntax-context ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a13311 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_13312(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_13312,c,av);}
/* core.scm:1497: mapwalk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13577(t2,t1,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}

/* a13317 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_13318(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13318,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,*((C_word*)lf[476]+1));
t3=C_mutate((C_word*)lf[476]+1 /* (set! ##sys#syntax-context ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a13456 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13457(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13457,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,*((C_word*)lf[112]+1));
t3=C_mutate((C_word*)lf[112]+1 /* (set! chicken.syntax#expansion-result-hook ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a13461 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13462(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13462,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13470,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:652: ##sys#current-environment */
t3=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k13468 in a13461 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13470(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13470,c,av);}
/* core.scm:652: chicken.syntax#expand */
t2=*((C_word*)lf[479]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=*((C_word*)lf[52]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* a13471 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13472(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13472,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,*((C_word*)lf[112]+1));
t3=C_mutate((C_word*)lf[112]+1 /* (set! chicken.syntax#expansion-result-hook ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k13488 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13490(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_13490,c,av);}
a=C_alloc(6);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13496,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* core.scm:645: ##sys#write-char-0 */
t4=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(40);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k13494 in k13488 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13496(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_13496,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13499,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:645: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k13497 in k13494 in k13488 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13499(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_13499,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13502,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:645: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[480];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k13500 in k13497 in k13494 in k13488 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13502(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13502,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13505,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:645: chicken.base#get-output-string */
t3=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13503 in k13500 in k13497 in k13494 in k13488 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13505(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13505,c,av);}
/* core.scm:645: ##sys#syntax-error/context */
t2=*((C_word*)lf[137]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k13521 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13523(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_13523,c,av);}
a=C_alloc(10);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13526,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1511: chicken.compiler.support#emit-syntax-trace-info */
t3=*((C_word*)lf[482]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_13535,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1516: chicken.compiler.support#emit-syntax-trace-info */
t3=*((C_word*)lf[482]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k13524 in k13521 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13526(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_13526,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13529,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1512: chicken.base#warning */
t3=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[484];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k13527 in k13524 in k13521 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13529(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_13529,c,av);}
/* core.scm:1513: mapwalk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_13577(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k13533 in k13521 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13535(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_13535,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_13538,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1517: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k13536 in k13533 in k13521 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13538(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,8)))){
C_save_and_reclaim((void *)f_13538,c,av);}
a=C_alloc(21);
t2=C_u_i_car(((C_word*)t0)[2]);
t3=C_a_i_list(&a,2,t1,t2);
t4=C_a_i_list(&a,1,t3);
t5=C_u_i_cdr(((C_word*)t0)[2]);
t6=C_a_i_cons(&a,2,t1,t5);
t7=C_a_i_list(&a,3,lf[173],t4,t6);
/* core.scm:1518: walk */
t8=((C_word*)((C_word*)t0)[3])[1];
f_8330(t8,((C_word*)t0)[4],t7,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],C_SCHEME_FALSE);}

/* mapwalk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_13577(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,3)))){
C_save_and_reclaim_args((void *)trf_13577,7,t0,t1,t2,t3,t4,t5,t6);}
a=C_alloc(20);
t7=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t8=t7;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=((C_word*)t9)[1];
t11=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_13582,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t4,a[5]=t5,a[6]=t6,tmp=(C_word)a,a+=7,tmp);
t12=C_i_check_list_2(t2,lf[10]);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13594,a[2]=t9,a[3]=t14,a[4]=t11,a[5]=t10,tmp=(C_word)a,a+=6,tmp));
t16=((C_word*)t14)[1];
f_13594(t16,t1,t2);}

/* g2629 in mapwalk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_13582(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,8)))){
C_save_and_reclaim_args((void *)trf_13582,3,t0,t1,t2);}
/* core.scm:1525: walk */
t3=((C_word*)((C_word*)t0)[2])[1];
f_8330(t3,t1,t2,((C_word*)t0)[3],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6]);}

/* map-loop2623 in mapwalk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_13594(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_13594,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13619,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:1525: g2629 */
t4=((C_word*)t0)[4];
f_13582(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k13617 in map-loop2623 in mapwalk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13619(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_13619,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_13594(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k13627 in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13629(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_13629,c,av);}
a=C_alloc(8);
t2=code_817();
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13640,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13644,a[2]=((C_word*)t0)[4],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1532: scheme#reverse */
t5=*((C_word*)lf[261]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[75];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k13638 in k13627 in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13640(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,8)))){
C_save_and_reclaim((void *)f_13640,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,lf[190],t1);
/* core.scm:1530: walk */
t3=((C_word*)((C_word*)t0)[2])[1];
f_8330(t3,((C_word*)t0)[3],t2,C_SCHEME_END_OF_LIST,C_SCHEME_FALSE,C_SCHEME_FALSE,C_SCHEME_FALSE,C_SCHEME_FALSE,C_SCHEME_TRUE);}

/* k13642 in k13627 in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13644(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_13644,c,av);}
a=C_alloc(5);
t2=lf[75] /* chicken.compiler.core#pending-canonicalizations */ =C_SCHEME_END_OF_LIST;;
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13654,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1536: scheme#append */
t4=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=*((C_word*)lf[87]+1);
av2[3]=*((C_word*)lf[19]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k13652 in k13642 in k13627 in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13654(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_13654,c,av);}
a=C_alloc(3);
t2=C_mutate((C_word*)lf[19]+1 /* (set! chicken.compiler.core#extended-bindings ...) */,t1);
t3=C_a_i_list(&a,1,((C_word*)t0)[2]);
/* core.scm:1531: ##sys#append */
t4=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k13658 in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_13660(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_13660,c,av);}
/* core.scm:1527: chicken.pretty-print#pretty-print */
t2=*((C_word*)lf[242]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* check-decl in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_13668(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_13668,4,t1,t2,t3,t4);}
t5=C_i_cdr(t2);
t6=C_i_length(t5);
t7=C_i_lessp(t6,t3);
if(C_truep(t7)){
if(C_truep(t7)){
/* core.scm:1545: chicken.syntax#syntax-error */
t8=*((C_word*)lf[367]+1);{
C_word av2[4];
av2[0]=t8;
av2[1]=t1;
av2[2]=lf[368];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}
else{
t8=C_SCHEME_UNDEFINED;
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
if(C_truep(C_i_nullp(t4))){
if(C_truep(C_i_greaterp(t6,C_fix(99999)))){
/* core.scm:1545: chicken.syntax#syntax-error */
t8=*((C_word*)lf[367]+1);{
C_word av2[4];
av2[0]=t8;
av2[1]=t1;
av2[2]=lf[368];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}
else{
t8=C_SCHEME_UNDEFINED;
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
t8=C_i_car(t4);
if(C_truep(C_i_greaterp(t6,t8))){
/* core.scm:1545: chicken.syntax#syntax-error */
t9=*((C_word*)lf[367]+1);{
C_word av2[4];
av2[0]=t9;
av2[1]=t1;
av2[2]=lf[368];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}
else{
t9=C_SCHEME_UNDEFINED;
t10=t1;{
C_word av2[2];
av2[0]=t10;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}}}}

/* globalize in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_13703(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_13703,3,t0,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_13710,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1547: local? */
t4=((C_word*)t0)[4];
f_12810(t4,t3,t2);}

/* k13708 in globalize in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_13710(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_13710,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13713,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1548: note-local */
f_13728(t2,((C_word*)t0)[4]);}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13720,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1550: lookup */
t3=((C_word*)((C_word*)t0)[5])[1];
f_7810(t3,t2,((C_word*)t0)[4]);}}

/* k13711 in k13708 in globalize in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_13713(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13713,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k13718 in k13708 in globalize in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_13720(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_13720,c,av);}
/* core.scm:1550: ##sys#alias-global-hook */
t2=*((C_word*)lf[122]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* globalize-all in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_13722(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_13722,3,t0,t1,t2);}
a=C_alloc(6);
t3=C_i_check_list_2(t2,lf[8]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6936,a[2]=((C_word*)t0)[2],a[3]=t5,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_6936(t7,t1,t2);}

/* note-local in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_13728(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_13728,2,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13736,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1555: chicken.base#open-output-string */
t4=*((C_word*)lf[131]+1);{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k13734 in note-local in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_13736(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_13736,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13742,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1555: ##sys#print */
t4=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[370];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k13740 in k13734 in note-local in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_13742(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_13742,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13745,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1555: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k13743 in k13740 in k13734 in note-local in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_13745(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_13745,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13748,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1555: ##sys#write-char-0 */
t3=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_make_character(39);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k13746 in k13743 in k13740 in k13734 in note-local in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_13748(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_13748,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13751,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1555: chicken.base#get-output-string */
t3=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13749 in k13746 in k13743 in k13740 in k13734 in note-local in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_13751(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_13751,c,av);}
/* core.scm:1554: ##sys#notice */
t2=*((C_word*)lf[369]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_13756(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_13756,2,t0,t1);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13760,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t3=t2;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_13760(2,av2);}}
else{
/* core.scm:1559: chicken.syntax#syntax-error */
t3=*((C_word*)lf[367]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[448];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_13760(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_13760,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_13763,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1560: chicken.syntax#strip-syntax */
t3=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_13763(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_13763,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13766,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_eqp(t1,lf[372]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13772,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1562: chicken.syntax#strip-syntax */
t5=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=C_u_i_cdr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=C_eqp(t1,lf[373]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13791,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1566: check-decl */
f_13668(t5,((C_word*)t0)[3],C_fix(1),C_a_i_list(&a,1,C_fix(1)));}
else{
t5=C_eqp(t1,lf[375]);
if(C_truep(t5)){
if(C_truep(C_i_nullp(C_u_i_cdr(((C_word*)t0)[3])))){
t6=C_mutate((C_word*)lf[18]+1 /* (set! chicken.compiler.core#standard-bindings ...) */,*((C_word*)lf[86]+1));
t7=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t7;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13833,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13837,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1575: globalize-all */
t8=((C_word*)((C_word*)t0)[5])[1];
f_13722(t8,t7,C_u_i_cdr(((C_word*)t0)[3]));}}
else{
t6=C_eqp(t1,lf[376]);
if(C_truep(t6)){
if(C_truep(C_i_nullp(C_u_i_cdr(((C_word*)t0)[3])))){
t7=C_mutate((C_word*)lf[19]+1 /* (set! chicken.compiler.core#extended-bindings ...) */,*((C_word*)lf[85]+1));
t8=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t8;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13858,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13862,a[2]=t7,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1579: globalize-all */
t9=((C_word*)((C_word*)t0)[5])[1];
f_13722(t9,t8,C_u_i_cdr(((C_word*)t0)[3]));}}
else{
t7=C_eqp(t1,lf[377]);
if(C_truep(t7)){
if(C_truep(C_i_nullp(C_u_i_cdr(((C_word*)t0)[3])))){
t8=C_mutate((C_word*)lf[18]+1 /* (set! chicken.compiler.core#standard-bindings ...) */,*((C_word*)lf[86]+1));
t9=C_mutate((C_word*)lf[19]+1 /* (set! chicken.compiler.core#extended-bindings ...) */,*((C_word*)lf[85]+1));
t10=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t10;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13883,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1585: globalize-all */
t9=((C_word*)((C_word*)t0)[5])[1];
f_13722(t9,t8,C_u_i_cdr(((C_word*)t0)[3]));}}
else{
t8=C_eqp(t1,lf[378]);
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13904,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1589: check-decl */
f_13668(t9,((C_word*)t0)[3],C_fix(1),C_a_i_list(&a,1,C_fix(1)));}
else{
t9=C_eqp(t1,lf[380]);
t10=(C_truep(t9)?t9:C_eqp(t1,lf[381]));
if(C_truep(t10)){
t11=C_mutate((C_word*)lf[379]+1 /* (set! chicken.compiler.support#number-type ...) */,lf[380]);
t12=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t12;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}
else{
t11=C_eqp(t1,lf[382]);
if(C_truep(t11)){
t12=C_mutate((C_word*)lf[379]+1 /* (set! chicken.compiler.support#number-type ...) */,lf[382]);
t13=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t13;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t13+1)))(2,av2);}}
else{
t12=C_eqp(t1,lf[383]);
if(C_truep(t12)){
t13=C_set_block_item(lf[148] /* chicken.compiler.support#unsafe */,0,C_SCHEME_TRUE);
t14=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t14;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t14+1)))(2,av2);}}
else{
t13=C_eqp(t1,lf[384]);
if(C_truep(t13)){
t14=C_set_block_item(lf[148] /* chicken.compiler.support#unsafe */,0,C_SCHEME_FALSE);
t15=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t15;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t15+1)))(2,av2);}}
else{
t14=C_eqp(t1,lf[385]);
if(C_truep(t14)){
t15=C_set_block_item(lf[31] /* chicken.compiler.core#no-bound-checks */,0,C_SCHEME_TRUE);
t16=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t16;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t16+1)))(2,av2);}}
else{
t15=C_eqp(t1,lf[386]);
if(C_truep(t15)){
t16=C_set_block_item(lf[32] /* chicken.compiler.core#no-argc-checks */,0,C_SCHEME_TRUE);
t17=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t17;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t17+1)))(2,av2);}}
else{
t16=C_eqp(t1,lf[387]);
if(C_truep(t16)){
t17=C_set_block_item(lf[33] /* chicken.compiler.core#no-procedure-checks */,0,C_SCHEME_TRUE);
t18=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t18;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t18+1)))(2,av2);}}
else{
t17=C_eqp(t1,lf[388]);
if(C_truep(t17)){
t18=C_set_block_item(lf[20] /* chicken.compiler.core#insert-timer-checks */,0,C_SCHEME_FALSE);
t19=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t19;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t19+1)))(2,av2);}}
else{
t18=C_eqp(t1,lf[389]);
if(C_truep(t18)){
t19=C_u_i_cdr(((C_word*)t0)[3]);
t20=C_i_check_list_2(t19,lf[100]);
t21=C_SCHEME_UNDEFINED;
t22=(*a=C_VECTOR_TYPE|1,a[1]=t21,tmp=(C_word)a,a+=2,tmp);
t23=C_set_block_item(t22,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13991,a[2]=t22,tmp=(C_word)a,a+=3,tmp));
t24=((C_word*)t22)[1];
f_13991(t24,t2,t19);}
else{
t19=C_eqp(t1,lf[390]);
if(C_truep(t19)){
t20=lf[35] /* chicken.compiler.core#safe-globals-flag */ =C_SCHEME_TRUE;;
t21=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t21;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t21+1)))(2,av2);}}
else{
t20=C_eqp(t1,lf[391]);
if(C_truep(t20)){
t21=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14033,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1605: scheme#append */
t22=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t22;
av2[1]=t21;
av2[2]=*((C_word*)lf[86]+1);
av2[3]=*((C_word*)lf[85]+1);
((C_proc)(void*)(*((C_word*)t22+1)))(4,av2);}}
else{
t21=C_eqp(t1,lf[392]);
if(C_truep(t21)){
t22=C_set_block_item(lf[34] /* chicken.compiler.core#no-global-procedure-checks */,0,C_SCHEME_TRUE);
t23=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t23;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t23+1)))(2,av2);}}
else{
t22=C_eqp(t1,lf[393]);
if(C_truep(t22)){
t23=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14115,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1612: globalize-all */
t24=((C_word*)((C_word*)t0)[5])[1];
f_13722(t24,t23,C_u_i_cdr(((C_word*)t0)[3]));}
else{
t23=C_eqp(t1,lf[394]);
if(C_truep(t23)){
t24=C_u_i_cdr(((C_word*)t0)[3]);
t25=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14195,a[2]=((C_word*)t0)[2],a[3]=t24,a[4]=t2,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1617: every */
f_6643(t25,*((C_word*)lf[397]+1),t24);}
else{
t24=C_eqp(t1,lf[398]);
if(C_truep(t24)){
t25=C_set_block_item(lf[25] /* chicken.compiler.core#block-compilation */,0,C_SCHEME_TRUE);
t26=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t26;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t26+1)))(2,av2);}}
else{
t25=C_eqp(t1,lf[399]);
if(C_truep(t25)){
t26=C_set_block_item(lf[25] /* chicken.compiler.core#block-compilation */,0,C_SCHEME_FALSE);
t27=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t27;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t27+1)))(2,av2);}}
else{
t26=C_eqp(t1,lf[400]);
if(C_truep(t26)){
t27=C_set_block_item(lf[42] /* chicken.compiler.core#undefine-shadowed-macros */,0,C_SCHEME_FALSE);
t28=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t28;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t28+1)))(2,av2);}}
else{
t27=C_eqp(t1,lf[401]);
if(C_truep(t27)){
t28=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14237,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1624: globalize-all */
t29=((C_word*)((C_word*)t0)[5])[1];
f_13722(t29,t28,C_u_i_cdr(((C_word*)t0)[3]));}
else{
t28=C_eqp(t1,lf[403]);
if(C_truep(t28)){
t29=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14282,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1628: globalize-all */
t30=((C_word*)((C_word*)t0)[5])[1];
f_13722(t30,t29,C_u_i_cdr(((C_word*)t0)[3]));}
else{
t29=C_eqp(t1,lf[405]);
if(C_truep(t29)){
t30=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_14322,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],a[5]=t2,a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1630: check-decl */
f_13668(t30,((C_word*)t0)[3],C_fix(1),C_SCHEME_END_OF_LIST);}
else{
t30=C_eqp(t1,lf[412]);
if(C_truep(t30)){
t31=C_set_block_item(lf[200] /* ##sys#enable-runtime-macros */,0,C_SCHEME_TRUE);
t32=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t32;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t32+1)))(2,av2);}}
else{
t31=C_eqp(t1,lf[413]);
t32=(C_truep(t31)?t31:C_eqp(t1,lf[414]));
if(C_truep(t32)){
t33=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14582,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1673: globalize-all */
t34=((C_word*)((C_word*)t0)[5])[1];
f_13722(t34,t33,C_u_i_cdr(((C_word*)t0)[3]));}
else{
t33=C_eqp(t1,lf[415]);
if(C_truep(t33)){
t34=C_set_block_item(lf[25] /* chicken.compiler.core#block-compilation */,0,C_SCHEME_TRUE);
t35=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14630,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1679: globalize-all */
t36=((C_word*)((C_word*)t0)[5])[1];
f_13722(t36,t35,C_u_i_cdr(((C_word*)t0)[3]));}
else{
t34=C_eqp(t1,lf[417]);
if(C_truep(t34)){
t35=C_set_block_item(lf[38] /* chicken.compiler.core#external-protos-first */,0,C_SCHEME_TRUE);
t36=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t36;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t36+1)))(2,av2);}}
else{
t35=C_eqp(t1,lf[406]);
if(C_truep(t35)){
if(C_truep(C_i_nullp(C_u_i_cdr(((C_word*)t0)[3])))){
t36=C_set_block_item(lf[50] /* chicken.compiler.core#inline-locally */,0,C_SCHEME_TRUE);
t37=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t37;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t37+1)))(2,av2);}}
else{
t36=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14689,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1688: globalize-all */
t37=((C_word*)((C_word*)t0)[5])[1];
f_13722(t37,t36,C_u_i_cdr(((C_word*)t0)[3]));}}
else{
t36=C_eqp(t1,lf[419]);
if(C_truep(t36)){
t37=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14731,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1690: check-decl */
f_13668(t37,((C_word*)t0)[3],C_fix(1),C_a_i_list(&a,1,C_fix(1)));}
else{
t37=C_eqp(t1,lf[421]);
if(C_truep(t37)){
t38=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14753,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1698: check-decl */
f_13668(t38,((C_word*)t0)[3],C_fix(1),C_a_i_list(&a,1,C_fix(1)));}
else{
t38=C_eqp(t1,lf[423]);
if(C_truep(t38)){
t39=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14775,a[2]=t2,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1706: globalize-all */
t40=((C_word*)((C_word*)t0)[5])[1];
f_13722(t40,t39,C_u_i_cdr(((C_word*)t0)[3]));}
else{
t39=C_eqp(t1,lf[426]);
if(C_truep(t39)){
t40=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14833,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t41=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t42=t41;
t43=(*a=C_VECTOR_TYPE|1,a[1]=t42,tmp=(C_word)a,a+=2,tmp);
t44=((C_word*)t43)[1];
t45=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14909,a[2]=t40,a[3]=t43,a[4]=t44,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1725: chicken.syntax#strip-syntax */
t46=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t46;
av2[1]=t45;
av2[2]=C_u_i_cdr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t46+1)))(3,av2);}}
else{
t40=C_eqp(t1,lf[429]);
if(C_truep(t40)){
if(C_truep(*((C_word*)lf[58]+1))){
t41=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t41;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t41+1)))(2,av2);}}
else{
t41=C_i_nullp(C_u_i_cdr(((C_word*)t0)[3]));
t42=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14967,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(t41)){
t43=C_mutate((C_word*)lf[58]+1 /* (set! chicken.compiler.core#types-output-file ...) */,t41);
t44=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t44;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t44+1)))(2,av2);}}
else{
t43=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14970,a[2]=((C_word*)t0)[2],a[3]=t42,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t44=C_i_cadr(((C_word*)t0)[3]);
if(C_truep(C_i_stringp(t44))){
t45=C_u_i_cdr(((C_word*)t0)[3]);
t46=C_i_nullp(C_u_i_cdr(t45));
t47=t43;
f_14970(t47,(C_truep(t46)?C_u_i_car(C_u_i_cdr(((C_word*)t0)[3])):C_SCHEME_FALSE));}
else{
t45=t43;
f_14970(t45,C_SCHEME_FALSE);}}}}
else{
t41=C_eqp(t1,lf[431]);
if(C_truep(t41)){
t42=C_set_block_item(lf[30] /* chicken.compiler.core#emit-profile */,0,C_SCHEME_TRUE);
if(C_truep(C_i_nullp(C_u_i_cdr(((C_word*)t0)[3])))){
t43=C_mutate((C_word*)lf[43]+1 /* (set! chicken.compiler.core#profiled-procedures ...) */,lf[183]);
t44=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t44;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t44+1)))(2,av2);}}
else{
t43=C_mutate((C_word*)lf[43]+1 /* (set! chicken.compiler.core#profiled-procedures ...) */,lf[184]);
t44=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15019,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1740: globalize-all */
t45=((C_word*)((C_word*)t0)[5])[1];
f_13722(t45,t44,C_u_i_cdr(((C_word*)t0)[3]));}}
else{
t42=C_eqp(t1,lf[432]);
if(C_truep(t42)){
if(C_truep(C_i_nullp(C_u_i_cdr(((C_word*)t0)[3])))){
t43=C_set_block_item(lf[49] /* chicken.compiler.core#local-definitions */,0,C_SCHEME_TRUE);
t44=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t44;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t44+1)))(2,av2);}}
else{
t43=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15073,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1747: globalize-all */
t44=((C_word*)((C_word*)t0)[5])[1];
f_13722(t44,t43,C_u_i_cdr(((C_word*)t0)[3]));}}
else{
t43=C_eqp(t1,lf[409]);
if(C_truep(t43)){
t44=C_set_block_item(lf[51] /* chicken.compiler.core#enable-inline-files */,0,C_SCHEME_TRUE);
t45=C_set_block_item(lf[50] /* chicken.compiler.core#inline-locally */,0,C_SCHEME_TRUE);
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[3])))){
t46=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15128,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1754: globalize-all */
t47=((C_word*)((C_word*)t0)[5])[1];
f_13722(t47,t46,C_u_i_cdr(((C_word*)t0)[3]));}
else{
t46=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t46;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t46+1)))(2,av2);}}}
else{
t44=C_eqp(t1,lf[433]);
if(C_truep(t44)){
t45=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15168,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[8],tmp=(C_word)a,a+=5,tmp);
t46=C_u_i_cdr(((C_word*)t0)[3]);
t47=C_i_check_list_2(t46,lf[100]);
t48=C_SCHEME_UNDEFINED;
t49=(*a=C_VECTOR_TYPE|1,a[1]=t48,tmp=(C_word)a,a+=2,tmp);
t50=C_set_block_item(t49,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15332,a[2]=t49,a[3]=t45,tmp=(C_word)a,a+=4,tmp));
t51=((C_word*)t49)[1];
f_15332(t51,t2,t46);}
else{
t45=C_eqp(t1,lf[442]);
if(C_truep(t45)){
t46=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15360,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[8],tmp=(C_word)a,a+=5,tmp);
t47=C_u_i_cdr(((C_word*)t0)[3]);
t48=C_i_check_list_2(t47,lf[100]);
t49=C_SCHEME_UNDEFINED;
t50=(*a=C_VECTOR_TYPE|1,a[1]=t49,tmp=(C_word)a,a+=2,tmp);
t51=C_set_block_item(t50,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15454,a[2]=t50,a[3]=t46,tmp=(C_word)a,a+=4,tmp));
t52=((C_word*)t50)[1];
f_15454(t52,t2,t47);}
else{
t46=C_eqp(t1,lf[445]);
if(C_truep(t46)){
t47=C_set_block_item(lf[55] /* chicken.compiler.core#enable-specialization */,0,C_SCHEME_TRUE);
t48=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t48;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t48+1)))(2,av2);}}
else{
t47=C_eqp(t1,lf[446]);
if(C_truep(t47)){
t48=C_set_block_item(lf[54] /* chicken.compiler.core#strict-variable-types */,0,C_SCHEME_TRUE);
t49=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t49;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t49+1)))(2,av2);}}
else{
/* core.scm:1809: chicken.base#warning */
t48=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t48;
av2[1]=t2;
av2[2]=lf[447];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t48+1)))(4,av2);}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}

/* k13764 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_13766(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13766,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k13770 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_13772(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_13772,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13776,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1563: lset-union/eq? */
f_7188(t2,*((C_word*)lf[82]+1),C_a_i_list(&a,1,t1));}

/* k13774 in k13770 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_13776(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_13776,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[82]+1 /* (set! chicken.compiler.core#used-libraries ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13780,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1564: lset-union/eq? */
f_7188(t3,*((C_word*)lf[81]+1),C_a_i_list(&a,1,((C_word*)t0)[3]));}

/* k13778 in k13774 in k13770 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_13780(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13780,c,av);}
t2=C_mutate((C_word*)lf[81]+1 /* (set! chicken.compiler.core#linked-libraries ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k13789 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_13791(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_13791,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13794,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1567: chicken.syntax#strip-syntax */
t3=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cadr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13792 in k13789 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_13794(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_13794,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13797,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=(C_truep(*((C_word*)lf[17]+1))?C_i_not(C_eqp(*((C_word*)lf[17]+1),t1)):C_SCHEME_FALSE);
if(C_truep(t3)){
/* core.scm:1569: chicken.base#warning */
t4=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[374];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=C_mutate((C_word*)lf[17]+1 /* (set! chicken.compiler.core#unit-name ...) */,t1);
t5=C_set_block_item(lf[48] /* chicken.compiler.core#standalone-executable */,0,C_SCHEME_FALSE);
t6=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t6;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k13795 in k13792 in k13789 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_13797(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13797,c,av);}
t2=C_mutate((C_word*)lf[17]+1 /* (set! chicken.compiler.core#unit-name ...) */,((C_word*)t0)[2]);
t3=C_set_block_item(lf[48] /* chicken.compiler.core#standalone-executable */,0,C_SCHEME_FALSE);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k13831 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_13833(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13833,c,av);}
t2=C_mutate((C_word*)lf[18]+1 /* (set! chicken.compiler.core#standard-bindings ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k13835 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_13837(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13837,c,av);}
/* core.scm:1575: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=*((C_word*)lf[18]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k13856 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_13858(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13858,c,av);}
t2=C_mutate((C_word*)lf[19]+1 /* (set! chicken.compiler.core#extended-bindings ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k13860 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_13862(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_13862,c,av);}
/* core.scm:1579: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=*((C_word*)lf[19]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k13881 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_13883(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_13883,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13887,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1586: lset-intersection/eq? */
f_7267(t2,t1,C_a_i_list(&a,1,*((C_word*)lf[86]+1)));}

/* k13885 in k13881 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_13887(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_13887,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[18]+1 /* (set! chicken.compiler.core#standard-bindings ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13891,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1587: lset-intersection/eq? */
f_7267(t3,((C_word*)t0)[3],C_a_i_list(&a,1,*((C_word*)lf[85]+1)));}

/* k13889 in k13885 in k13881 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_13891(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13891,c,av);}
t2=C_mutate((C_word*)lf[19]+1 /* (set! chicken.compiler.core#extended-bindings ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k13902 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_13904(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_13904,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13908,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1590: chicken.syntax#strip-syntax */
t3=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cadr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k13906 in k13902 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_13908(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_13908,c,av);}
t2=C_mutate((C_word*)lf[379]+1 /* (set! chicken.compiler.support#number-type ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* for-each-loop2735 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_fcall f_13991(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_13991,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14001,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1600: g2751 */
t6=*((C_word*)lf[158]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[159];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k13999 in for-each-loop2735 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_14001(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14001,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_13991(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k14031 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14033(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_14033,c,av);}
a=C_alloc(8);
t2=C_i_check_list_2(t1,lf[100]);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14039,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14078,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_14078(t7,t3,t1);}

/* k14037 in k14031 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_14039(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_14039,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14047,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1608: scheme#append */
t3=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=*((C_word*)lf[86]+1);
av2[3]=*((C_word*)lf[85]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k14045 in k14037 in k14031 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14047(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_14047,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(t1,lf[100]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14055,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_14055(t6,((C_word*)t0)[2],t1);}

/* for-each-loop2785 in k14045 in k14037 in k14031 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_fcall f_14055(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_14055,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14065,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1607: g2801 */
t6=*((C_word*)lf[158]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[159];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14063 in for-each-loop2785 in k14045 in k14037 in k14031 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_14065(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14065,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_14055(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* for-each-loop2760 in k14031 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_14078(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_14078,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14088,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1604: g2776 */
t6=*((C_word*)lf[158]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[297];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14086 in for-each-loop2760 in k14031 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14088(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14088,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_14078(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k14113 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14115(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_14115,c,av);}
a=C_alloc(9);
t2=C_i_check_list_2(t1,lf[100]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14126,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14159,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_14159(t7,t3,t1);}

/* k14124 in k14113 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_14126(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_14126,c,av);}
a=C_alloc(5);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14136,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t5=((C_word*)t3)[1];
f_14136(t5,((C_word*)t0)[2],((C_word*)t0)[3]);}

/* for-each-loop2822 in k14124 in k14113 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_fcall f_14136(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_14136,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14146,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1614: g2853 */
t6=*((C_word*)lf[158]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[159];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14144 in for-each-loop2822 in k14124 in k14113 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_14146(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14146,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_14136(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* for-each-loop2812 in k14113 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_14159(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_14159,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14169,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1613: g2838 */
t6=*((C_word*)lf[158]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[297];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14167 in for-each-loop2812 in k14113 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14169(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14169,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_14159(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k14193 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14195(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_14195,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14199,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1618: scheme#append */
t3=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=*((C_word*)lf[22]+1);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
/* core.scm:1619: chicken.syntax#syntax-error */
t2=*((C_word*)lf[367]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[395];
av2[3]=lf[396];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}}

/* k14197 in k14193 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_14199(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_14199,c,av);}
t2=C_mutate((C_word*)lf[22]+1 /* (set! chicken.compiler.core#foreign-declarations ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k14235 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14237(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_14237,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(t1,lf[100]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14245,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_14245(t6,((C_word*)t0)[2],t1);}

/* for-each-loop2864 in k14235 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_14245(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_14245,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14255,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1624: g2880 */
t6=*((C_word*)lf[158]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[402];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14253 in for-each-loop2864 in k14235 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14255(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14255,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_14245(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k14280 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14282(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_14282,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(t1,lf[100]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14290,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_14290(t6,((C_word*)t0)[2],t1);}

/* for-each-loop2889 in k14280 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_14290(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_14290,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14300,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1627: g2905 */
t6=*((C_word*)lf[158]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[404];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14298 in for-each-loop2889 in k14280 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14300(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14300,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_14290(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14322(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_14322,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_14325,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1631: chicken.syntax#strip-syntax */
t3=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cadr(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_14325(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_14325,c,av);}
a=C_alloc(8);
t2=C_eqp(t1,lf[375]);
if(C_truep(t2)){
t3=C_i_cddr(((C_word*)t0)[2]);
if(C_truep(C_i_nullp(t3))){
t4=C_set_block_item(lf[18] /* chicken.compiler.core#standard-bindings */,0,C_SCHEME_END_OF_LIST);
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14342,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14346,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t6=C_u_i_cdr(((C_word*)t0)[2]);
/* core.scm:1637: globalize-all */
t7=((C_word*)((C_word*)t0)[4])[1];
f_13722(t7,t5,C_u_i_cdr(t6));}}
else{
t3=C_eqp(t1,lf[376]);
if(C_truep(t3)){
t4=C_i_cddr(((C_word*)t0)[2]);
if(C_truep(C_i_nullp(t4))){
t5=C_set_block_item(lf[19] /* chicken.compiler.core#extended-bindings */,0,C_SCHEME_END_OF_LIST);
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14370,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14374,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
t7=C_u_i_cdr(((C_word*)t0)[2]);
/* core.scm:1643: globalize-all */
t8=((C_word*)((C_word*)t0)[4])[1];
f_13722(t8,t6,C_u_i_cdr(t7));}}
else{
t4=C_eqp(t1,lf[406]);
if(C_truep(t4)){
t5=C_i_cddr(((C_word*)t0)[2]);
if(C_truep(C_i_nullp(t5))){
t6=C_set_block_item(lf[50] /* chicken.compiler.core#inline-locally */,0,C_SCHEME_FALSE);
t7=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t7;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14402,a[2]=((C_word*)t0)[5],tmp=(C_word)a,a+=3,tmp);
t7=C_u_i_cdr(((C_word*)t0)[2]);
/* core.scm:1649: globalize-all */
t8=((C_word*)((C_word*)t0)[4])[1];
f_13722(t8,t6,C_u_i_cdr(t7));}}
else{
t5=C_eqp(t1,lf[377]);
if(C_truep(t5)){
t6=C_i_cddr(((C_word*)t0)[2]);
if(C_truep(C_i_nullp(t6))){
t7=C_set_block_item(lf[18] /* chicken.compiler.core#standard-bindings */,0,C_SCHEME_END_OF_LIST);
t8=C_set_block_item(lf[19] /* chicken.compiler.core#extended-bindings */,0,C_SCHEME_END_OF_LIST);
t9=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t9;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14455,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t8=C_u_i_cdr(((C_word*)t0)[2]);
/* core.scm:1655: globalize-all */
t9=((C_word*)((C_word*)t0)[4])[1];
f_13722(t9,t7,C_u_i_cdr(t8));}}
else{
t6=C_eqp(t1,lf[409]);
if(C_truep(t6)){
t7=C_set_block_item(lf[51] /* chicken.compiler.core#enable-inline-files */,0,C_SCHEME_TRUE);
t8=C_i_cddr(((C_word*)t0)[2]);
if(C_truep(C_i_pairp(t8))){
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14491,a[2]=((C_word*)t0)[5],tmp=(C_word)a,a+=3,tmp);
t10=C_u_i_cdr(((C_word*)t0)[2]);
/* core.scm:1663: globalize-all */
t11=((C_word*)((C_word*)t0)[4])[1];
f_13722(t11,t9,C_u_i_cdr(t10));}
else{
t9=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t9;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}}
else{
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14530,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1665: check-decl */
f_13668(t7,((C_word*)t0)[2],C_fix(1),C_a_i_list(&a,1,C_fix(1)));}}}}}}

/* k14340 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14342(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_14342,c,av);}
t2=C_mutate((C_word*)lf[18]+1 /* (set! chicken.compiler.core#standard-bindings ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k14344 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14346(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_14346,c,av);}
a=C_alloc(3);
/* core.scm:1636: lset-difference/eq? */
f_7143(((C_word*)t0)[2],*((C_word*)lf[86]+1),C_a_i_list(&a,1,t1));}

/* k14368 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14370(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_14370,c,av);}
t2=C_mutate((C_word*)lf[19]+1 /* (set! chicken.compiler.core#extended-bindings ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k14372 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14374(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_14374,c,av);}
a=C_alloc(3);
/* core.scm:1642: lset-difference/eq? */
f_7143(((C_word*)t0)[2],*((C_word*)lf[85]+1),C_a_i_list(&a,1,t1));}

/* k14400 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14402(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_14402,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(t1,lf[100]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14410,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_14410(t6,((C_word*)t0)[2],t1);}

/* for-each-loop2920 in k14400 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_fcall f_14410(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_14410,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14420,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1648: g2936 */
t6=*((C_word*)lf[158]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[407];
av2[4]=lf[408];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14418 in for-each-loop2920 in k14400 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_14420(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14420,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_14410(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k14453 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14455(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_14455,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14459,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1656: lset-difference/eq? */
f_7143(t2,*((C_word*)lf[86]+1),C_a_i_list(&a,1,t1));}

/* k14457 in k14453 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_14459(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_14459,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[18]+1 /* (set! chicken.compiler.core#standard-bindings ...) */,t1);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14463,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1657: lset-difference/eq? */
f_7143(t3,*((C_word*)lf[85]+1),C_a_i_list(&a,1,((C_word*)t0)[3]));}

/* k14461 in k14457 in k14453 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_14463(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_14463,c,av);}
t2=C_mutate((C_word*)lf[19]+1 /* (set! chicken.compiler.core#extended-bindings ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k14489 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14491(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_14491,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(t1,lf[100]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14499,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_14499(t6,((C_word*)t0)[2],t1);}

/* for-each-loop2952 in k14489 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_fcall f_14499(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_14499,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14509,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1662: g2968 */
t6=*((C_word*)lf[158]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[410];
av2[4]=lf[408];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14507 in for-each-loop2952 in k14489 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_14509(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14509,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_14499(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k14528 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14530(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_14530,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14533,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1666: chicken.syntax#strip-syntax */
t3=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cadr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k14531 in k14528 in k14323 in k14320 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_14533(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_14533,c,av);}
t2=C_eqp(t1,lf[384]);
if(C_truep(t2)){
t3=C_set_block_item(lf[148] /* chicken.compiler.support#unsafe */,0,C_SCHEME_TRUE);
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* core.scm:1669: chicken.base#warning */
t3=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[411];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k14580 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14582(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_14582,c,av);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t1))){
t2=C_set_block_item(lf[25] /* chicken.compiler.core#block-compilation */,0,C_SCHEME_TRUE);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=*((C_word*)lf[157]+1);
t3=C_i_check_list_2(t1,lf[100]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14597,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_14597(t7,((C_word*)t0)[3],t1);}}

/* for-each-loop2991 in k14580 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_14597(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_14597,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14607,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1676: g2992 */
t4=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14605 in for-each-loop2991 in k14580 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14607(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14607,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_14597(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k14628 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14630(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_14630,c,av);}
a=C_alloc(6);
t2=*((C_word*)lf[416]+1);
t3=C_i_check_list_2(t1,lf[100]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14638,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_14638(t7,((C_word*)t0)[2],t1);}

/* for-each-loop3009 in k14628 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_14638(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_14638,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14648,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1680: g3010 */
t4=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14646 in for-each-loop3009 in k14628 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14648(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14648,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_14638(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k14687 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14689(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_14689,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(t1,lf[100]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14697,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_14697(t6,((C_word*)t0)[2],t1);}

/* for-each-loop3027 in k14687 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_14697(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_14697,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14707,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1687: g3043 */
t6=*((C_word*)lf[158]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[418];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14705 in for-each-loop3027 in k14687 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14707(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14707,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_14697(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k14729 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14731(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_14731,c,av);}
t2=C_i_cadr(((C_word*)t0)[2]);
if(C_truep(C_i_numberp(t2))){
t3=C_mutate((C_word*)lf[39]+1 /* (set! chicken.compiler.core#inline-max-size ...) */,t2);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* core.scm:1694: chicken.base#warning */
t3=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[420];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k14751 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14753(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_14753,c,av);}
t2=C_i_cadr(((C_word*)t0)[2]);
if(C_truep(C_i_numberp(t2))){
t3=C_mutate((C_word*)lf[40]+1 /* (set! chicken.compiler.core#unroll-limit ...) */,t2);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* core.scm:1702: chicken.base#warning */
t3=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[422];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k14773 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14775(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_14775,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14781,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1707: every */
f_6643(t2,*((C_word*)lf[106]+1),t1);}

/* k14779 in k14773 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_14781(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_14781,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14789,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1710: globalize-all */
t3=((C_word*)((C_word*)t0)[3])[1];
f_13722(t3,t2,((C_word*)t0)[4]);}
else{
/* core.scm:1711: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[425];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k14787 in k14779 in k14773 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14789(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_14789,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(t1,lf[100]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14797,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_14797(t6,((C_word*)t0)[2],t1);}

/* for-each-loop3057 in k14787 in k14779 in k14773 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_fcall f_14797(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_14797,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14807,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1709: g3073 */
t6=*((C_word*)lf[158]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[424];
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k14805 in for-each-loop3057 in k14787 in k14779 in k14773 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_14807(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_14807,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_14797(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k14831 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14833(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_14833,c,av);}
t2=C_mutate((C_word*)lf[44]+1 /* (set! chicken.compiler.core#import-libraries ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k14850 in map-loop3082 in k14907 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14852(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_14852,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
f_14942(2,av2);}}

/* k14854 in map-loop3082 in k14907 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14856(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_14856,c,av);}
/* ##sys#string-append */
t2=*((C_word*)lf[255]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[427];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k14861 in map-loop3082 in k14907 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_fcall f_14863(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_14863,2,t0,t1);}
a=C_alloc(3);
if(C_truep(t1)){
t2=C_i_car(((C_word*)t0)[2]);
t3=C_i_cadr(((C_word*)t0)[2]);
t4=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t4;
av2[1]=C_a_i_cons(&a,2,t2,t3);
f_14942(2,av2);}}
else{
/* core.scm:1724: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[428];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k14907 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14909(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_14909,c,av);}
a=C_alloc(10);
t2=C_i_check_list_2(t1,lf[10]);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14915,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_14917,a[2]=((C_word*)t0)[3],a[3]=t5,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_14917(t7,t3,t1);}

/* k14913 in k14907 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_14915(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_14915,c,av);}
/* core.scm:1715: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[44]+1);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop3082 in k14907 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_14917(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,2)))){
C_save_and_reclaim_args((void *)trf_14917,3,t0,t1,t2);}
a=C_alloc(13);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_14942,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_slot(t2,C_fix(0));
if(C_truep(C_i_symbolp(t4))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14852,a[2]=t3,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_14856,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1719: scheme#symbol->string */
t7=*((C_word*)lf[257]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_14863,a[2]=t4,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_listp(t4))){
t6=C_eqp(C_fix(2),C_u_i_length(t4));
if(C_truep(t6)){
t7=C_i_car(t4);
t8=C_i_symbolp(t7);
t9=t5;
f_14863(t9,(C_truep(t8)?C_i_stringp(C_i_cadr(t4)):C_SCHEME_FALSE));}
else{
t7=t5;
f_14863(t7,C_SCHEME_FALSE);}}
else{
t6=t5;
f_14863(t6,C_SCHEME_FALSE);}}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k14940 in map-loop3082 in k14907 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_14942(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_14942,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_14917(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k14965 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_14967(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_14967,c,av);}
t2=C_mutate((C_word*)lf[58]+1 /* (set! chicken.compiler.core#types-output-file ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k14968 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_fcall f_14970(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_14970,2,t0,t1);}
if(C_truep(t1)){
t2=C_mutate((C_word*)lf[58]+1 /* (set! chicken.compiler.core#types-output-file ...) */,t1);
t3=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t3;
av2[1]=lf[371];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
/* core.scm:1731: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[430];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k15017 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_15019(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_15019,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(t1,lf[100]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15027,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_15027(t6,((C_word*)t0)[2],t1);}

/* for-each-loop3128 in k15017 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_15027(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_15027,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15037,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1739: g3144 */
t6=*((C_word*)lf[158]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[186];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k15035 in for-each-loop3128 in k15017 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_15037(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15037,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_15027(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k15071 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_15073(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_15073,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(t1,lf[100]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15081,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_15081(t6,((C_word*)t0)[2],t1);}

/* for-each-loop3159 in k15071 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_15081(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_15081,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15091,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1746: g3175 */
t6=*((C_word*)lf[158]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[418];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k15089 in for-each-loop3159 in k15071 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_15091(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15091,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_15081(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k15126 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_15128(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_15128,c,av);}
a=C_alloc(5);
t2=C_i_check_list_2(t1,lf[100]);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15136,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_15136(t6,((C_word*)t0)[2],t1);}

/* for-each-loop3184 in k15126 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_15136(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_15136,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15146,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_slot(t2,C_fix(0));
t5=*((C_word*)lf[158]+1);
/* core.scm:1753: g3200 */
t6=*((C_word*)lf[158]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t3;
av2[2]=t4;
av2[3]=lf[410];
av2[4]=lf[232];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k15144 in for-each-loop3184 in k15126 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_15146(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15146,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_15136(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_fcall f_15168(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_15168,3,t0,t1,t2);}
a=C_alloc(7);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15175,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_listp(t2))){
if(C_truep(C_fixnum_greater_or_equal_p(C_u_i_length(t2),C_fix(2)))){
t4=C_i_car(t2);
t5=t3;
f_15175(t5,C_i_not(C_i_symbolp(t4)));}
else{
t4=t3;
f_15175(t4,C_SCHEME_TRUE);}}
else{
t4=t3;
f_15175(t4,C_SCHEME_TRUE);}}

/* k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_15175(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_15175,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15182,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1761: chicken.syntax#strip-syntax */
t3=*((C_word*)lf[146]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15185,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1762: globalize */
t3=((C_word*)((C_word*)t0)[6])[1];
f_13703(t3,t2,C_i_car(((C_word*)t0)[3]));}}

/* k15180 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_15182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15182,c,av);}
/* core.scm:1761: chicken.base#warning */
t2=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[434];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k15183 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_15185(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_15185,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15188,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1763: chicken.syntax#strip-syntax */
t3=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cadr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k15186 in k15183 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_15188(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_15188,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15194,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1764: local? */
t3=((C_word*)t0)[6];
f_12810(t3,t2,C_u_i_car(((C_word*)t0)[4]));}

/* k15192 in k15186 in k15183 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_15194(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,5)))){
C_save_and_reclaim((void *)f_15194,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
/* core.scm:1765: note-local */
f_13728(((C_word*)t0)[3],C_u_i_car(((C_word*)t0)[4]));}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15204,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15210,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1766: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}}

/* a15203 in k15192 in k15186 in k15183 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_15204(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15204,c,av);}
/* core.scm:1766: chicken.compiler.scrutinizer#validate-type */
t2=*((C_word*)lf[435]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a15209 in k15192 in k15186 in k15183 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_15210(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_15210,c,av);}
a=C_alloc(8);
if(C_truep(t2)){
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_15258,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=t3,a[7]=t4,tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_i_pairp(t2))){
t6=C_eqp(lf[440],C_u_i_car(t2));
t7=t5;
f_15258(t7,(C_truep(t6)?C_i_symbolp(C_i_cadr(t2)):C_SCHEME_FALSE));}
else{
t6=t5;
f_15258(t6,C_SCHEME_FALSE);}}
else{
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15290,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1788: chicken.syntax#strip-syntax */
t6=*((C_word*)lf[146]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k15218 in k15256 in a15209 in k15192 in k15186 in k15183 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_15220(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_15220,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15223,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1776: chicken.compiler.support#mark-variable */
t3=*((C_word*)lf[158]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[438];
av2[4]=lf[432];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k15221 in k15218 in k15256 in a15209 in k15192 in k15186 in k15183 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in ... */
static void C_ccall f_15223(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_15223,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15226,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[6])){
/* core.scm:1778: chicken.compiler.support#mark-variable */
t3=*((C_word*)lf[158]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[424];
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_15226(2,av2);}}}

/* k15224 in k15221 in k15218 in k15256 in a15209 in k15192 in k15186 in k15183 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in ... */
static void C_ccall f_15226(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_15226,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15229,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[5])){
/* core.scm:1780: chicken.compiler.support#mark-variable */
t3=*((C_word*)lf[158]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[437];
av2[4]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_15229(2,av2);}}}

/* k15227 in k15224 in k15221 in k15218 in k15256 in a15209 in k15192 in k15186 in k15183 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in ... */
static void C_ccall f_15229(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_15229,c,av);}
a=C_alloc(4);
t2=C_i_cddr(((C_word*)t0)[2]);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15242,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
t4=C_u_i_cdr(((C_word*)t0)[2]);
/* core.scm:1784: chicken.syntax#strip-syntax */
t5=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=C_u_i_cdr(t4);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k15240 in k15227 in k15224 in k15221 in k15218 in k15256 in a15209 in k15192 in k15186 in k15183 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in ... */
static void C_ccall f_15242(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15242,c,av);}
/* core.scm:1782: chicken.compiler.scrutinizer#install-specializations */
t2=*((C_word*)lf[436]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k15256 in a15209 in k15192 in k15186 in k15183 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_fcall f_15258(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,4)))){
C_save_and_reclaim_args((void *)trf_15258,2,t0,t1);}
a=C_alloc(7);
t2=(C_truep(t1)?C_i_set_car(C_i_cdr(((C_word*)t0)[2]),((C_word*)t0)[3]):C_SCHEME_UNDEFINED);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15220,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1775: chicken.compiler.support#mark-variable */
t4=*((C_word*)lf[158]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[439];
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k15288 in a15209 in k15192 in k15186 in k15183 in k15173 in g3212 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_15290(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15290,c,av);}
/* core.scm:1786: chicken.base#warning */
t2=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[441];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* for-each-loop3211 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_fcall f_15332(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_15332,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15342,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1756: g3212 */
t4=((C_word*)t0)[3];
f_15168(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k15340 in for-each-loop3211 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_15342(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15342,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_15332(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* g3256 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_fcall f_15360(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_15360,3,t0,t1,t2);}
a=C_alloc(7);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15367,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_listp(t2))){
t4=C_i_car(t2);
t5=C_i_symbolp(t4);
t6=t3;
f_15367(t6,(C_truep(t5)?C_eqp(C_fix(2),C_i_length(t2)):C_SCHEME_FALSE));}
else{
t4=t3;
f_15367(t4,C_SCHEME_FALSE);}}

/* k15365 in g3256 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_15367(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_15367,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_15370,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1794: globalize */
t3=((C_word*)((C_word*)t0)[6])[1];
f_13703(t3,t2,C_i_car(((C_word*)t0)[4]));}
else{
/* core.scm:1803: chicken.base#warning */
t2=*((C_word*)lf[134]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[444];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k15368 in k15365 in g3256 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_15370(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_15370,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15373,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1795: chicken.syntax#strip-syntax */
t3=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_i_cadr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k15371 in k15368 in k15365 in g3256 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_15373(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_15373,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15379,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1796: local? */
t3=((C_word*)t0)[6];
f_12810(t3,t2,C_u_i_car(((C_word*)t0)[4]));}

/* k15377 in k15371 in k15368 in k15365 in g3256 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_15379(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,5)))){
C_save_and_reclaim((void *)f_15379,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
/* core.scm:1797: note-local */
f_13728(((C_word*)t0)[3],C_u_i_car(((C_word*)t0)[4]));}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15389,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15395,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1798: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}}

/* a15388 in k15377 in k15371 in k15368 in k15365 in g3256 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_15389(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15389,c,av);}
/* core.scm:1798: chicken.compiler.scrutinizer#validate-type */
t2=*((C_word*)lf[435]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a15394 in k15377 in k15371 in k15368 in k15365 in g3256 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_15395(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_15395,c,av);}
t5=(C_truep(t2)?C_i_not(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
/* core.scm:1800: chicken.compiler.support#mark-variable */
t6=*((C_word*)lf[158]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=lf[437];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
/* core.scm:1801: chicken.base#warning */
t6=*((C_word*)lf[134]+1);{
C_word *av2=av;
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[443];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}

/* for-each-loop3255 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_fcall f_15454(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_15454,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15464,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1791: g3256 */
t4=((C_word*)t0)[3];
f_15360(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k15462 in for-each-loop3255 in k13761 in k13758 in a13755 in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_15464(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15464,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_15454(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* chicken.compiler.core#build-toplevel-procedure in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15598(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_15598,c,av);}
a=C_alloc(3);
t3=C_a_i_list1(&a,1,t2);
/* core.scm:1816: chicken.compiler.support#make-node */
t4=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t1;
av2[2]=lf[490];
av2[3]=lf[491];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* chicken.compiler.core#foreign-stub-id in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15621(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_15621,c,av);}
t3=C_i_check_structure_2(t2,lf[493],lf[494]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(1));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#foreign-stub-return-type in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15630(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_15630,c,av);}
t3=C_i_check_structure_2(t2,lf[493],lf[496]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(2));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#foreign-stub-name in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15639(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_15639,c,av);}
t3=C_i_check_structure_2(t2,lf[493],lf[498]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(3));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#foreign-stub-argument-types in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15648(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_15648,c,av);}
t3=C_i_check_structure_2(t2,lf[493],lf[500]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(4));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#foreign-stub-argument-names in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15657(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_15657,c,av);}
t3=C_i_check_structure_2(t2,lf[493],lf[502]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(5));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#foreign-stub-body in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15666(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_15666,c,av);}
t3=C_i_check_structure_2(t2,lf[493],lf[504]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(6));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#foreign-stub-cps in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15675(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_15675,c,av);}
t3=C_i_check_structure_2(t2,lf[493],lf[506]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(7));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#foreign-stub-callback in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15684(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_15684,c,av);}
t3=C_i_check_structure_2(t2,lf[493],lf[508]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(8));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_15693(C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7,C_word t8){
C_word tmp;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_15693,8,t1,t2,t3,t4,t5,t6,t7,t8);}
a=C_alloc(9);
t9=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_15780,a[2]=t3,a[3]=t5,a[4]=t6,a[5]=t8,a[6]=t7,a[7]=t1,a[8]=t4,tmp=(C_word)a,a+=9,tmp);
/* core.scm:1847: chicken.syntax#strip-syntax */
t10=*((C_word*)lf[146]+1);{
C_word av2[3];
av2[0]=t10;
av2[1]=t9;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t10+1)))(3,av2);}}

/* loop in map-loop3409 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_15702(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_15702,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=lf[515];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_listp(t2))){
t3=C_i_car(t2);
t4=C_eqp(t3,lf[332]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15731,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15735,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1842: loop */
t8=t6;
t9=C_u_i_cdr(t2);
t1=t8;
t2=t9;
goto loop;}
else{
t5=C_eqp(t3,lf[518]);
t6=(C_truep(t5)?t5:C_eqp(t3,lf[519]));
if(C_truep(t6)){
/* core.scm:1843: loop */
t8=t1;
t9=C_u_i_cdr(t2);
t1=t8;
t2=t9;
goto loop;}
else{
/* core.scm:1844: loop */
t8=t1;
t9=C_u_i_car(t2);
t1=t8;
t2=t9;
goto loop;}}}
else{
t3=C_i_symbolp(t2);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=(C_truep(t3)?t2:lf[515]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_stringp(t2);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(C_truep(t4)?t2:lf[515]);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}}}

/* k15729 in loop in map-loop3409 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15731(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_15731,c,av);}
/* core.scm:1842: scheme#string->symbol */
t2=*((C_word*)lf[512]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k15733 in loop in map-loop3409 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15735(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15735,c,av);}
/* core.scm:1842: chicken.string#conc */
t2=*((C_word*)lf[516]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[517];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15780(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_15780,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_15783,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1848: chicken.syntax#strip-syntax */
t3=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15783(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,3)))){
C_save_and_reclaim((void *)f_15783,c,av);}
a=C_alloc(22);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_15786,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
if(C_truep(((C_word*)t0)[4])){
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_check_list_2(((C_word*)t0)[4],lf[10]);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15996,a[2]=t5,a[3]=t9,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_15996(t11,t2,((C_word*)t0)[4]);}
else{
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_check_list_2(t1,lf[10]);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16048,a[2]=t5,a[3]=t9,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_16048(t11,t2,t1);}}

/* k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15786(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_15786,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_15789,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* core.scm:1852: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[514];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15789(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_15789,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_15792,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* core.scm:1853: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15792(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_15792,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_15795,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t1,tmp=(C_word)a,a+=13,tmp);
/* core.scm:1854: chicken.compiler.support#estimate-foreign-result-size */
t3=*((C_word*)lf[513]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15795(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,2)))){
C_save_and_reclaim((void *)f_15795,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_15798,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
if(C_truep(((C_word*)t0)[4])){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15985,a[2]=t2,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1855: scheme#string->symbol */
t4=*((C_word*)lf[512]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_15798(2,av2);}}}

/* k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15798(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(60,c,2)))){
C_save_and_reclaim((void *)f_15798,c,av);}
a=C_alloc(60);
t2=C_a_i_record(&a,9,lf[493],((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);
t3=C_a_i_cons(&a,2,t2,*((C_word*)lf[71]+1));
t4=C_mutate((C_word*)lf[71]+1 /* (set! chicken.compiler.core#foreign-lambda-stubs ...) */,t3);
t5=(C_truep(((C_word*)t0)[9])?C_s_a_i_plus(&a,2,((C_word*)t0)[10],C_fix(24)):((C_word*)t0)[10]);
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_15808,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[12],a[5]=((C_word*)t0)[9],a[6]=t5,a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[13],tmp=(C_word)a,a+=9,tmp);
if(C_truep(((C_word*)t0)[8])){
t7=C_a_i_list(&a,2,lf[477],((C_word*)t0)[2]);
t8=t6;
f_15808(t8,C_a_i_list(&a,1,t7));}
else{
t7=t6;
f_15808(t7,C_a_i_list(&a,2,lf[302],((C_word*)t0)[2]));}}

/* k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_15808(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,4)))){
C_save_and_reclaim_args((void *)trf_15808,2,t0,t1);}
a=C_alloc(21);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_check_list_2(((C_word*)t0)[2],lf[10]);
t7=C_i_check_list_2(((C_word*)t0)[3],lf[10]);
t8=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_15829,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=t1,a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15915,a[2]=t4,a[3]=t10,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_15915(t12,t8,((C_word*)t0)[2],((C_word*)t0)[3]);}

/* k15818 in map-loop3450 in k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15820(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15820,c,av);}
/* core.scm:1863: chicken.compiler.support#foreign-type-check */
t2=*((C_word*)lf[283]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k15827 in k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15829(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_15829,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15840,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(C_truep(((C_word*)t0)[4])?lf[509]:C_SCHEME_END_OF_LIST);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15852,a[2]=t2,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
if(C_truep(C_i_zerop(((C_word*)t0)[5]))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15860,a[2]=t4,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
t6=C_a_i_cons(&a,2,lf[510],t1);
/* core.scm:1868: scheme#append */
t7=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t5;
av2[2]=((C_word*)t0)[7];
av2[3]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_15867,a[2]=((C_word*)t0)[8],a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[6],a[6]=t1,a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[5],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1869: chicken.compiler.support#final-foreign-type */
t6=*((C_word*)lf[120]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k15838 in k15827 in k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15840(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_15840,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_cons(&a,2,lf[97],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k15850 in k15827 in k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15852(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_15852,c,av);}
a=C_alloc(3);
t2=C_a_i_list(&a,1,t1);
/* core.scm:1864: ##sys#append */
t3=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k15858 in k15827 in k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15860(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15860,c,av);}
/* core.scm:1868: chicken.compiler.support#foreign-type-convert-result */
t2=*((C_word*)lf[118]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k15865 in k15827 in k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15867(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_15867,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_15870,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1870: chicken.compiler.support#bytes->words */
t3=*((C_word*)lf[342]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k15868 in k15865 in k15827 in k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_15870(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(75,c,3)))){
C_save_and_reclaim((void *)f_15870,c,av);}
a=C_alloc(75);
t2=C_s_a_i_plus(&a,2,C_fix(2),t1);
t3=C_a_i_list(&a,2,lf[511],t2);
t4=C_a_i_list(&a,2,lf[145],t1);
t5=C_a_i_list(&a,3,lf[303],t3,t4);
t6=C_a_i_list(&a,2,((C_word*)t0)[2],t5);
t7=C_a_i_list(&a,1,t6);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_15881,a[2]=t7,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15885,a[2]=t8,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15889,a[2]=t9,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
t11=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[7]);
/* core.scm:1873: scheme#append */
t12=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t12;
av2[1]=t10;
av2[2]=((C_word*)t0)[8];
av2[3]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(4,av2);}}

/* k15879 in k15868 in k15865 in k15827 in k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_15881(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_15881,c,av);}
a=C_alloc(12);
t2=C_a_i_list(&a,3,lf[173],((C_word*)t0)[2],t1);
t3=C_a_i_list(&a,1,t2);
/* core.scm:1864: ##sys#append */
t4=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k15883 in k15868 in k15865 in k15827 in k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_15885(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15885,c,av);}
/* core.scm:1872: chicken.compiler.support#foreign-type-convert-result */
t2=*((C_word*)lf[118]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k15887 in k15868 in k15865 in k15827 in k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_15889(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15889,c,av);}
/* core.scm:1873: chicken.compiler.support#finish-foreign-result */
t2=*((C_word*)lf[119]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop3450 in k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_15915(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_15915,4,t0,t1,t2,t3);}
a=C_alloc(11);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_15944,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,a[6]=t3,tmp=(C_word)a,a+=7,tmp);
t7=C_slot(t2,C_fix(0));
t8=C_slot(t3,C_fix(0));
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_15820,a[2]=t6,a[3]=t8,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1863: chicken.compiler.support#foreign-type-convert-argument */
t10=*((C_word*)lf[284]+1);{
C_word av2[4];
av2[0]=t10;
av2[1]=t9;
av2[2]=t7;
av2[3]=t8;
((C_proc)(void*)(*((C_word*)t10+1)))(4,av2);}}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k15942 in map-loop3450 in k15806 in k15796 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15944(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_15944,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_15915(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)),C_slot(((C_word*)t0)[6],C_fix(1)));}

/* k15983 in k15793 in k15790 in k15787 in k15784 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_15985(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_15985,c,av);}
/* core.scm:1855: chicken.compiler.support#set-real-name! */
t2=*((C_word*)lf[115]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop3383 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_15996(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_15996,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16021,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:1850: g3389 */
t4=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16019 in map-loop3383 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16021(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_16021,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_15996(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k16038 in map-loop3409 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16040(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16040,c,av);}
/* core.scm:1851: chicken.base#gensym */
t2=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* map-loop3409 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_16048(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,3)))){
C_save_and_reclaim_args((void *)trf_16048,3,t0,t1,t2);}
a=C_alloc(14);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16073,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16040,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_15702,a[2]=t7,tmp=(C_word)a,a+=3,tmp));
t9=((C_word*)t7)[1];
f_15702(t9,t5,t4);}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16071 in map-loop3409 in k15781 in k15778 in chicken.compiler.core#create-foreign-stub in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16073(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_16073,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_16048(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* chicken.compiler.core#expand-foreign-lambda in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_16082(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,8)))){
C_save_and_reclaim_args((void *)trf_16082,3,t1,t2,t3);}
a=C_alloc(8);
t4=C_i_caddr(t2);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16089,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_symbolp(t4))){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16108,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1878: chicken.syntax#strip-syntax */
t7=*((C_word*)lf[146]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
if(C_truep(C_i_stringp(t4))){
/* core.scm:1885: create-foreign-stub */
f_15693(t1,C_i_cadr(t2),t4,C_i_cdddr(t2),C_SCHEME_FALSE,C_SCHEME_FALSE,t3,t3);}
else{
/* core.scm:1880: chicken.compiler.support#quit-compiling */
t6=*((C_word*)lf[123]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[520];
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}}

/* k16087 in chicken.compiler.core#expand-foreign-lambda in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16089(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_16089,c,av);}
/* core.scm:1885: create-foreign-stub */
f_15693(((C_word*)t0)[2],C_i_cadr(((C_word*)t0)[3]),t1,C_i_cdddr(((C_word*)t0)[3]),C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[4],((C_word*)t0)[4]);}

/* k16106 in chicken.compiler.core#expand-foreign-lambda in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16108(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16108,c,av);}
/* core.scm:1878: scheme#symbol->string */
t2=*((C_word*)lf[257]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* chicken.compiler.core#expand-foreign-lambda* in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_16119(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_16119,3,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_cadr(t2);
t5=C_i_caddr(t2);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16129,a[2]=t5,a[3]=t1,a[4]=t4,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* core.scm:1890: chicken.string#string-intersperse */
t7=*((C_word*)lf[319]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t6;
av2[2]=C_i_cdddr(t2);
av2[3]=lf[521];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k16127 in chicken.compiler.core#expand-foreign-lambda* in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16129(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,3)))){
C_save_and_reclaim((void *)f_16129,c,av);}
a=C_alloc(19);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_check_list_2(((C_word*)t0)[2],lf[10]);
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16143,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16194,a[2]=t4,a[3]=t9,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_16194(t11,t7,((C_word*)t0)[2]);}

/* k16141 in k16127 in chicken.compiler.core#expand-foreign-lambda* in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16143(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_16143,c,av);}
a=C_alloc(14);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_16149,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=t4,a[8]=t5,tmp=(C_word)a,a+=9,tmp);
/* core.scm:1893: chicken.syntax#strip-syntax */
t7=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k16147 in k16141 in k16127 in chicken.compiler.core#expand-foreign-lambda* in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16149(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_16149,c,av);}
a=C_alloc(14);
t2=C_i_check_list_2(t1,lf[10]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16155,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16160,a[2]=((C_word*)t0)[7],a[3]=t5,a[4]=((C_word*)t0)[8],tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_16160(t7,t3,t1);}

/* k16153 in k16147 in k16141 in k16127 in chicken.compiler.core#expand-foreign-lambda* in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16155(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_16155,c,av);}
/* core.scm:1894: create-foreign-stub */
f_15693(((C_word*)t0)[2],((C_word*)t0)[3],C_SCHEME_FALSE,((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[6]);}

/* map-loop3540 in k16147 in k16141 in k16127 in chicken.compiler.core#expand-foreign-lambda* in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_16160(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_16160,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_cadr(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* map-loop3512 in k16127 in chicken.compiler.core#expand-foreign-lambda* in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_16194(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_16194,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k16234 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_16236(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_16236,2,t0,t1);}
a=C_alloc(6);
t2=(C_truep(t1)?C_i_cadr(((C_word*)t0)[2]):lf[317]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16242,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=t1,a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
t4=(C_truep(t1)?C_i_caddr(((C_word*)t0)[2]):C_i_cadr(((C_word*)t0)[2]));
/* core.scm:1900: chicken.syntax#strip-syntax */
t5=*((C_word*)lf[146]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k16240 in k16234 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_16242(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_16242,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16245,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=(C_truep(((C_word*)t0)[4])?C_i_cdddr(((C_word*)t0)[5]):C_i_cddr(((C_word*)t0)[5]));
/* core.scm:1901: chicken.string#string-intersperse */
t4=*((C_word*)lf[319]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=t3;
av2[3]=lf[320];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k16243 in k16240 in k16234 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_16245(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_16245,c,av);}
a=C_alloc(18);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_check_list_2(((C_word*)t0)[2],lf[10]);
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16259,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16310,a[2]=t4,a[3]=t9,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_16310(t11,t7,((C_word*)t0)[2]);}

/* k16257 in k16243 in k16240 in k16234 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_16259(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_16259,c,av);}
a=C_alloc(13);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_16265,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=t4,a[7]=t5,tmp=(C_word)a,a+=8,tmp);
/* core.scm:1904: chicken.syntax#strip-syntax */
t7=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k16263 in k16257 in k16243 in k16240 in k16234 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_16265(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_16265,c,av);}
a=C_alloc(13);
t2=C_i_check_list_2(t1,lf[10]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16271,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16276,a[2]=((C_word*)t0)[6],a[3]=t5,a[4]=((C_word*)t0)[7],tmp=(C_word)a,a+=5,tmp));
t7=((C_word*)t5)[1];
f_16276(t7,t3,t1);}

/* k16269 in k16263 in k16257 in k16243 in k16240 in k16234 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_16271(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_16271,c,av);}
/* core.scm:1905: create-foreign-stub */
f_15693(((C_word*)t0)[2],((C_word*)t0)[3],C_SCHEME_FALSE,((C_word*)t0)[4],t1,((C_word*)t0)[5],C_SCHEME_FALSE,C_SCHEME_TRUE);}

/* map-loop3602 in k16263 in k16257 in k16243 in k16240 in k16234 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_16276(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_16276,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_cadr(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* map-loop3574 in k16243 in k16240 in k16234 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_16310(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_16310,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16385(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(44,c,6)))){
C_save_and_reclaim((void *)f_16385,c,av);}
a=C_alloc(44);
t3=C_SCHEME_END_OF_LIST;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_SCHEME_UNDEFINED;
t16=(*a=C_VECTOR_TYPE|1,a[1]=t15,tmp=(C_word)a,a+=2,tmp);
t17=C_SCHEME_UNDEFINED;
t18=(*a=C_VECTOR_TYPE|1,a[1]=t17,tmp=(C_word)a,a+=2,tmp);
t19=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16388,a[2]=t10,tmp=(C_word)a,a+=3,tmp));
t20=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_16439,tmp=(C_word)a,a+=2,tmp));
t21=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_16463,a[2]=t10,a[3]=t8,a[4]=t6,a[5]=t14,a[6]=t12,a[7]=t4,tmp=(C_word)a,a+=8,tmp));
t22=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17009,a[2]=t10,a[3]=t16,tmp=(C_word)a,a+=4,tmp));
t23=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17155,a[2]=t16,tmp=(C_word)a,a+=3,tmp));
t24=C_set_block_item(t16,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17171,a[2]=t8,a[3]=t10,a[4]=t18,tmp=(C_word)a,a+=5,tmp));
t25=C_set_block_item(t18,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17273,a[2]=t18,tmp=(C_word)a,a+=3,tmp));
/* core.scm:2043: walk */
t26=((C_word*)t10)[1];
f_16463(t26,t1,t2,*((C_word*)lf[105]+1));}

/* cps-lambda in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_16388(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_16388,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(8);
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_16392,a[2]=t5,a[3]=t1,a[4]=t3,a[5]=t2,a[6]=t4,a[7]=((C_word*)t0)[2],tmp=(C_word)a,a+=8,tmp);
/* core.scm:1914: chicken.base#gensym */
t7=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[525];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k16390 in cps-lambda in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16392(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,3)))){
C_save_and_reclaim((void *)f_16392,c,av);}
a=C_alloc(26);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16399,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_a_i_cons(&a,2,t1,((C_word*)t0)[4]);
t4=C_a_i_list4(&a,4,((C_word*)t0)[5],C_SCHEME_TRUE,t3,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16411,a[2]=t2,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
t6=C_i_car(((C_word*)t0)[6]);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16417,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* core.scm:1917: walk */
t8=((C_word*)((C_word*)t0)[7])[1];
f_16463(t8,t5,t6,t7);}

/* k16397 in k16390 in cps-lambda in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16399(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16399,c,av);}
/* core.scm:1915: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k16409 in k16390 in cps-lambda in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16411(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_16411,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:1915: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[97];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* a16416 in k16390 in cps-lambda in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16417(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_16417,c,av);}
a=C_alloc(8);
t3=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16433,a[2]=t2,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1919: chicken.compiler.support#varnode */
t5=*((C_word*)lf[524]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k16431 in a16416 in k16390 in cps-lambda in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16433(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_16433,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,t1,((C_word*)t0)[2]);
/* core.scm:1919: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[523];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* node-for-var? in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_16439(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_16439,3,t1,t2,t3);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16461,a[2]=t1,a[3]=t3,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1922: chicken.compiler.support#node-class */
t5=*((C_word*)lf[98]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k16455 in k16459 in node-for-var? in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16457(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_16457,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_eqp(C_i_car(t1),((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k16459 in node-for-var? in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16461(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_16461,c,av);}
a=C_alloc(4);
t2=C_eqp(t1,lf[526]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16457,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1923: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_16463(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_16463,4,t0,t1,t2,t3);}
a=C_alloc(11);
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_16467,a[2]=t3,a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],a[10]=((C_word*)t0)[7],tmp=(C_word)a,a+=11,tmp);
/* core.scm:1926: chicken.compiler.support#node-subexpressions */
t5=*((C_word*)lf[530]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16467(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_16467,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_16470,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* core.scm:1927: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16470(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_16470,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_16473,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* core.scm:1928: chicken.compiler.support#node-class */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16473(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_16473,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_16476,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t1,a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* core.scm:1929: chicken.compiler.support#node-class */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16476(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_16476,c,av);}
a=C_alloc(15);
t2=C_eqp(t1,lf[526]);
t3=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_16485,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],tmp=(C_word)a,a+=15,tmp);
if(C_truep(t2)){
t4=t3;
f_16485(t4,t2);}
else{
t4=C_eqp(t1,lf[116]);
if(C_truep(t4)){
t5=t3;
f_16485(t5,t4);}
else{
t5=C_eqp(t1,lf[478]);
if(C_truep(t5)){
t6=t3;
f_16485(t6,t5);}
else{
t6=C_eqp(t1,lf[477]);
t7=t3;
f_16485(t7,(C_truep(t6)?t6:C_eqp(t1,lf[162])));}}}}

/* k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_16485(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,4)))){
C_save_and_reclaim_args((void *)trf_16485,2,t0,t1);}
a=C_alloc(12);
if(C_truep(t1)){
/* core.scm:1931: k */
t2=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}
else{
t2=C_eqp(((C_word*)t0)[5],lf[142]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16497,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1932: chicken.base#gensym */
t4=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[525];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_eqp(((C_word*)t0)[5],lf[174]);
if(C_truep(t3)){
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16606,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[2],a[4]=t5,a[5]=((C_word*)t0)[8],tmp=(C_word)a,a+=6,tmp));
t7=((C_word*)t5)[1];
f_16606(t7,((C_word*)t0)[3],((C_word*)t0)[9],((C_word*)t0)[6]);}
else{
t4=C_eqp(((C_word*)t0)[5],lf[490]);
t5=(C_truep(t4)?t4:C_eqp(((C_word*)t0)[5],lf[97]));
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16693,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[2],tmp=(C_word)a,a+=7,tmp);
/* core.scm:373: chicken.base#gensym */
t7=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[528];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t6=C_eqp(((C_word*)t0)[5],lf[286]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16706,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[3],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1958: chicken.base#gensym */
t8=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=lf[529];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t7=C_eqp(((C_word*)t0)[5],lf[449]);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16777,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[10],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[9],tmp=(C_word)a,a+=7,tmp);
/* core.scm:373: chicken.base#gensym */
t9=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=lf[528];
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t8=C_eqp(((C_word*)t0)[5],lf[302]);
t9=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_16807,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[12],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[13],a[10]=((C_word*)t0)[14],a[11]=((C_word*)t0)[7],tmp=(C_word)a,a+=12,tmp);
if(C_truep(t8)){
t10=t9;
f_16807(t10,t8);}
else{
t10=C_eqp(((C_word*)t0)[5],lf[303]);
if(C_truep(t10)){
t11=t9;
f_16807(t11,t10);}
else{
t11=C_eqp(((C_word*)t0)[5],lf[117]);
if(C_truep(t11)){
t12=t9;
f_16807(t12,t11);}
else{
t12=C_eqp(((C_word*)t0)[5],lf[282]);
if(C_truep(t12)){
t13=t9;
f_16807(t13,t12);}
else{
t13=C_eqp(((C_word*)t0)[5],lf[121]);
if(C_truep(t13)){
t14=t9;
f_16807(t14,t13);}
else{
t14=C_eqp(((C_word*)t0)[5],lf[285]);
t15=t9;
f_16807(t15,(C_truep(t14)?t14:C_eqp(((C_word*)t0)[5],lf[188])));}}}}}}}}}}}}

/* k16495 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16497(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_16497,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16500,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1933: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[466];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k16498 in k16495 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16500(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_16500,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_16501,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16532,a[2]=((C_word*)t0)[3],a[3]=t3,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16591,a[2]=t1,a[3]=t4,a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* core.scm:373: chicken.base#gensym */
t6=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[528];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k1 in k16498 in k16495 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16501(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_16501,c,av);}
a=C_alloc(8);
t3=C_a_i_list1(&a,1,C_SCHEME_TRUE);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16517,a[2]=t2,a[3]=t1,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1934: chicken.compiler.support#varnode */
t5=*((C_word*)lf[524]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k16515 in k1 in k16498 in k16495 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16517(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_16517,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,t1,((C_word*)t0)[2]);
/* core.scm:1934: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[523];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k16530 in k16498 in k16495 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16532(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_16532,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16536,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_i_car(((C_word*)t0)[4]);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16542,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1940: walk */
t5=((C_word*)((C_word*)t0)[5])[1];
f_16463(t5,t2,t3,t4);}

/* k16534 in k16530 in k16498 in k16495 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16536(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_16536,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:1935: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[174];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* a16541 in k16530 in k16498 in k16495 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16542(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_16542,c,av);}
a=C_alloc(7);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16554,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1944: walk */
t4=((C_word*)((C_word*)t0)[2])[1];
f_16463(t4,t3,C_i_cadr(((C_word*)t0)[3]),((C_word*)t0)[4]);}

/* k16552 in a16541 in k16530 in k16498 in k16495 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_16554(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_16554,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16558,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1945: walk */
t3=((C_word*)((C_word*)t0)[4])[1];
f_16463(t3,t2,C_i_caddr(((C_word*)t0)[5]),((C_word*)t0)[6]);}

/* k16556 in k16552 in a16541 in k16530 in k16498 in k16495 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_16558(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_16558,c,av);}
a=C_alloc(9);
t2=C_a_i_list3(&a,3,((C_word*)t0)[2],((C_word*)t0)[3],t1);
/* core.scm:1942: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[142];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k16576 in k16589 in k16498 in k16495 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16578(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_16578,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:1938: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[97];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k16580 in k16589 in k16498 in k16495 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16582(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16582,c,av);}
/* core.scm:1939: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k16589 in k16498 in k16495 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16591(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,2)))){
C_save_and_reclaim((void *)f_16591,c,av);}
a=C_alloc(23);
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t3=C_a_i_list4(&a,4,t1,C_SCHEME_FALSE,t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16578,a[2]=((C_word*)t0)[3],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16582,a[2]=((C_word*)t0)[4],a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1939: chicken.compiler.support#varnode */
t6=*((C_word*)lf[524]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* loop in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_16606(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_16606,4,t0,t1,t2,t3);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t2))){
/* core.scm:1949: walk */
t4=((C_word*)((C_word*)t0)[2])[1];
f_16463(t4,t1,C_i_car(t3),((C_word*)t0)[3]);}
else{
t4=C_i_car(t3);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16629,a[2]=((C_word*)t0)[4],a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1950: walk */
t6=((C_word*)((C_word*)t0)[2])[1];
f_16463(t6,t1,t4,t5);}}

/* a16628 in loop in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16629(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_16629,c,av);}
a=C_alloc(7);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16636,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* core.scm:1952: node-for-var? */
f_16439(t3,t2,C_i_car(((C_word*)t0)[3]));}

/* k16634 in a16628 in loop in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16636(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_16636,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
/* core.scm:1953: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_16606(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),C_i_cdr(((C_word*)t0)[5]));}
else{
t2=C_u_i_car(((C_word*)t0)[4]);
t3=C_a_i_list1(&a,1,t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16660,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[3],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1956: loop */
t5=((C_word*)((C_word*)t0)[2])[1];
f_16606(t5,t4,C_u_i_cdr(((C_word*)t0)[4]),C_i_cdr(((C_word*)t0)[5]));}}

/* k16658 in k16634 in a16628 in loop in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16660(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_16660,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:1954: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[174];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k16691 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16693(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_16693,c,av);}
/* core.scm:1957: cps-lambda */
t2=((C_word*)((C_word*)t0)[2])[1];
f_16388(t2,((C_word*)t0)[3],t1,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5],((C_word*)t0)[6]);}

/* k16704 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16706(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_16706,c,av);}
a=C_alloc(11);
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_i_pairp(t2);
t4=(C_truep(t3)?C_i_cadr(((C_word*)t0)[2]):C_SCHEME_FALSE);
t5=C_i_car(((C_word*)t0)[2]);
t6=C_a_i_list2(&a,2,t5,t4);
t7=C_i_car(((C_word*)t0)[3]);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16721,a[2]=t1,a[3]=((C_word*)t0)[4],a[4]=t6,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1961: walk */
t9=((C_word*)((C_word*)t0)[5])[1];
f_16463(t9,((C_word*)t0)[6],t7,t8);}

/* a16720 in k16704 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16721(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_16721,c,av);}
a=C_alloc(12);
t3=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_16737,a[2]=t1,a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
t5=C_a_i_list1(&a,1,t2);
/* core.scm:1964: chicken.compiler.support#make-node */
t6=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t4;
av2[2]=lf[286];
av2[3]=((C_word*)t0)[4];
av2[4]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}

/* k16735 in a16720 in k16704 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16737(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_16737,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16741,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16745,a[2]=((C_word*)t0)[4],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1965: chicken.compiler.support#varnode */
t4=*((C_word*)lf[524]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k16739 in k16735 in a16720 in k16704 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16741(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_16741,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:1963: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[174];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k16743 in k16735 in a16720 in k16704 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16745(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_16745,c,av);}
/* core.scm:1965: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k16775 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16777(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_16777,c,av);}
a=C_alloc(7);
t2=C_i_car(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16783,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t1,a[5]=((C_word*)t0)[5],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* core.scm:1969: chicken.compiler.support#register-foreign-callback-stub! */
t4=*((C_word*)lf[531]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
av2[3]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k16781 in k16775 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16783(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_16783,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16798,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1970: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k16792 in k16796 in k16781 in k16775 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16794(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_16794,c,av);}
/* core.scm:1970: cps-lambda */
t2=((C_word*)((C_word*)t0)[2])[1];
f_16388(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1,((C_word*)t0)[6]);}

/* k16796 in k16781 in k16775 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16798(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_16798,c,av);}
a=C_alloc(7);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_16794,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:1970: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[530]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_16807(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,5)))){
C_save_and_reclaim_args((void *)trf_16807,2,t0,t1);}
a=C_alloc(21);
if(C_truep(t1)){
/* core.scm:1973: walk-inline-call */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17155(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}
else{
t2=C_eqp(((C_word*)t0)[8],lf[523]);
if(C_truep(t2)){
/* core.scm:1974: walk-call */
t3=((C_word*)((C_word*)t0)[9])[1];
f_17009(t3,((C_word*)t0)[3],C_i_car(((C_word*)t0)[6]),C_u_i_cdr(((C_word*)t0)[6]),((C_word*)t0)[5],((C_word*)t0)[7]);}
else{
t3=C_eqp(((C_word*)t0)[8],lf[163]);
if(C_truep(t3)){
t4=C_i_car(((C_word*)t0)[5]);
if(C_truep(C_i_memq(t4,((C_word*)((C_word*)t0)[10])[1]))){
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16847,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[7],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1978: chicken.compiler.support#make-node */
t6=*((C_word*)lf[489]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[478];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t5=C_a_i_cons(&a,2,t4,((C_word*)((C_word*)t0)[10])[1]);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_FALSE;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16855,a[2]=t9,a[3]=((C_word*)t0)[10],a[4]=t7,tmp=(C_word)a,a+=5,tmp);
t11=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16860,a[2]=t4,a[3]=((C_word*)t0)[7],tmp=(C_word)a,a+=4,tmp);
t12=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_16866,a[2]=t7,a[3]=((C_word*)t0)[10],a[4]=t9,tmp=(C_word)a,a+=5,tmp);
/* core.scm:1979: ##sys#dynamic-wind */
t13=*((C_word*)lf[114]+1);{
C_word av2[5];
av2[0]=t13;
av2[1]=((C_word*)t0)[3];
av2[2]=t10;
av2[3]=t11;
av2[4]=t12;
((C_proc)(void*)(*((C_word*)t13+1)))(5,av2);}}}
else{
t4=C_eqp(((C_word*)t0)[8],lf[150]);
t5=(C_truep(t4)?t4:C_eqp(((C_word*)t0)[8],lf[532]));
if(C_truep(t5)){
/* core.scm:1983: walk */
t6=((C_word*)((C_word*)t0)[11])[1];
f_16463(t6,((C_word*)t0)[3],C_i_car(((C_word*)t0)[6]),((C_word*)t0)[7]);}
else{
t6=C_eqp(((C_word*)t0)[8],lf[155]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7049,tmp=(C_word)a,a+=2,tmp);
t8=(
  f_7049(((C_word*)t0)[6])
);
/* core.scm:1986: walk */
t9=((C_word*)((C_word*)t0)[11])[1];
f_16463(t9,((C_word*)t0)[3],t8,((C_word*)t0)[7]);}
else{
/* core.scm:1987: chicken.compiler.support#bomb */
t7=*((C_word*)lf[533]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[534];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}}}}}

/* k16845 in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_16847,c,av);}
/* core.scm:1978: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_16463(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4]);}

/* a16854 in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16855(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_16855,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a16859 in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16860(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_16860,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17090,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2004: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[525];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* a16865 in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_16866(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_16866,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* walk-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17009(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_17009,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(9);
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17013,a[2]=t1,a[3]=t4,a[4]=((C_word*)t0)[2],a[5]=t2,a[6]=((C_word*)t0)[3],a[7]=t3,a[8]=t5,tmp=(C_word)a,a+=9,tmp);
/* core.scm:1990: chicken.base#gensym */
t7=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=lf[525];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k17011 in walk-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17013(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_17013,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_17016,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1991: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[466];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k17014 in k17011 in walk-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17016(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,2)))){
C_save_and_reclaim((void *)f_17016,c,av);}
a=C_alloc(18);
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_17031,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17080,a[2]=t1,a[3]=t3,a[4]=((C_word*)t0)[9],tmp=(C_word)a,a+=5,tmp);
/* core.scm:373: chicken.base#gensym */
t5=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[528];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k17029 in k17014 in k17011 in walk-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17031(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_17031,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17035,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17037,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1996: walk-arguments */
t4=((C_word*)((C_word*)t0)[8])[1];
f_17171(t4,t2,((C_word*)t0)[9],t3);}

/* k17033 in k17029 in k17014 in k17011 in walk-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17035(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_17035,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:1992: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[174];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* a17036 in k17029 in k17014 in k17011 in walk-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17037(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_17037,c,av);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17043,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1999: walk */
t4=((C_word*)((C_word*)t0)[4])[1];
f_16463(t4,t1,((C_word*)t0)[5],t3);}

/* a17042 in a17036 in k17029 in k17014 in k17011 in walk-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17043(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_17043,c,av);}
a=C_alloc(9);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17051,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17055,a[2]=t3,a[3]=t2,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2001: chicken.compiler.support#varnode */
t5=*((C_word*)lf[524]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k17049 in a17042 in a17036 in k17029 in k17014 in k17011 in walk-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17051(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_17051,c,av);}
/* core.scm:2001: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[523];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k17053 in a17042 in a17036 in k17029 in k17014 in k17011 in walk-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17055(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_17055,c,av);}
a=C_alloc(6);
/* core.scm:2001: cons* */
f_6707(((C_word*)t0)[2],((C_word*)t0)[3],C_a_i_list(&a,2,t1,((C_word*)t0)[4]));}

/* k17065 in k17078 in k17014 in k17011 in walk-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17067(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_17067,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:1994: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[97];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k17069 in k17078 in k17014 in k17011 in walk-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17071(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17071,c,av);}
/* core.scm:1995: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k17078 in k17014 in k17011 in walk-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17080(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,2)))){
C_save_and_reclaim((void *)f_17080,c,av);}
a=C_alloc(23);
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t3=C_a_i_list4(&a,4,t1,C_SCHEME_FALSE,t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17067,a[2]=((C_word*)t0)[3],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17071,a[2]=((C_word*)t0)[4],a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1995: chicken.compiler.support#varnode */
t6=*((C_word*)lf[524]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k17088 in a16859 in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17090(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_17090,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17093,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2005: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[466];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k17091 in k17088 in a16859 in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17093(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_17093,c,av);}
a=C_alloc(14);
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17108,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17149,a[2]=t1,a[3]=t3,a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* core.scm:373: chicken.base#gensym */
t5=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[528];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k17106 in k17091 in k17088 in a16859 in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_17108(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_17108,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17112,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_a_i_list1(&a,1,((C_word*)t0)[4]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17124,a[2]=t2,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* core.scm:2011: chicken.compiler.support#varnode */
t5=*((C_word*)lf[524]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k17110 in k17106 in k17091 in k17088 in a16859 in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_17112(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_17112,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:2006: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[174];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k17122 in k17106 in k17091 in k17088 in a16859 in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_17124(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_17124,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:2010: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[163];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k17134 in k17147 in k17091 in k17088 in a16859 in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_17136(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_17136,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:2008: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[97];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k17138 in k17147 in k17091 in k17088 in a16859 in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_17140(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17140,c,av);}
/* core.scm:2009: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k17147 in k17091 in k17088 in a16859 in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_17149(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,2)))){
C_save_and_reclaim((void *)f_17149,c,av);}
a=C_alloc(23);
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);
t3=C_a_i_list4(&a,4,t1,C_SCHEME_FALSE,t2,C_fix(0));
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17136,a[2]=((C_word*)t0)[3],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17140,a[2]=((C_word*)t0)[4],a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* core.scm:2009: chicken.compiler.support#varnode */
t6=*((C_word*)lf[524]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* walk-inline-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17155(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_17155,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(5);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17161,a[2]=t5,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2014: walk-arguments */
t7=((C_word*)((C_word*)t0)[2])[1];
f_17171(t7,t1,t4,t6);}

/* a17160 in walk-inline-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17161(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_17161,c,av);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17169,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:2017: chicken.compiler.support#make-node */
t4=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k17167 in a17160 in walk-inline-call in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17169(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17169,c,av);}
/* core.scm:2017: k */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* walk-arguments in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17171(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_17171,4,t0,t1,t2,t3);}
a=C_alloc(9);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17177,a[2]=t3,a[3]=t5,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],tmp=(C_word)a,a+=7,tmp));
t7=((C_word*)t5)[1];
f_17177(t7,t1,t2,C_SCHEME_END_OF_LIST);}

/* loop in walk-arguments in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17177(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_17177,4,t0,t1,t2,t3);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t2))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17191,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:2021: scheme#reverse */
t5=*((C_word*)lf[261]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17197,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2022: atomic? */
t5=((C_word*)((C_word*)t0)[6])[1];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_car(t2);
f_17273(3,av2);}}}

/* k17189 in loop in walk-arguments in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17191(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17191,c,av);}
/* core.scm:2021: wk */
t2=((C_word*)t0)[2];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k17195 in loop in walk-arguments in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17197(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_17197,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=C_u_i_cdr(((C_word*)t0)[2]);
t3=C_u_i_car(((C_word*)t0)[2]);
t4=C_a_i_cons(&a,2,t3,((C_word*)t0)[3]);
/* core.scm:2023: loop */
t5=((C_word*)((C_word*)t0)[4])[1];
f_17177(t5,((C_word*)t0)[5],t2,t4);}
else{
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17211,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2025: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[515];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k17209 in k17195 in loop in walk-arguments in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17211(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_17211,c,av);}
a=C_alloc(7);
t2=C_u_i_car(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17218,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2026: walk */
t4=((C_word*)((C_word*)t0)[6])[1];
f_16463(t4,((C_word*)t0)[7],t2,t3);}

/* a17217 in k17209 in k17195 in loop in walk-arguments in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17218(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_17218,c,av);}
a=C_alloc(8);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17225,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=t2,tmp=(C_word)a,a+=8,tmp);
/* core.scm:2028: node-for-var? */
f_16439(t3,t2,((C_word*)t0)[5]);}

/* k17223 in a17217 in k17209 in k17195 in loop in walk-arguments in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17225(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_17225,c,av);}
a=C_alloc(14);
if(C_truep(t1)){
t2=C_i_cdr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17240,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2029: chicken.compiler.support#varnode */
t4=*((C_word*)lf[524]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=C_a_i_list1(&a,1,((C_word*)t0)[6]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17255,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[5],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t4=C_i_cdr(((C_word*)t0)[2]);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17267,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2033: chicken.compiler.support#varnode */
t6=*((C_word*)lf[524]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k17238 in k17223 in a17217 in k17209 in k17195 in loop in walk-arguments in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17240(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_17240,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* core.scm:2029: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_17177(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* k17253 in k17223 in a17217 in k17209 in k17195 in loop in walk-arguments in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17255(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_17255,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:2030: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[174];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k17265 in k17223 in a17217 in k17209 in k17195 in loop in walk-arguments in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17267(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_17267,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,((C_word*)t0)[2]);
/* core.scm:2032: loop */
t3=((C_word*)((C_word*)t0)[3])[1];
f_17177(t3,((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* atomic? in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17273(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_17273,c,av);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17277,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2036: chicken.compiler.support#node-class */
t4=*((C_word*)lf[98]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k17275 in atomic? in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_17277,c,av);}
a=C_alloc(4);
t2=C_u_i_memq(t1,lf[535]);
if(C_truep(t2)){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep((C_truep(C_eqp(t1,lf[303]))?C_SCHEME_TRUE:(C_truep(C_eqp(t1,lf[117]))?C_SCHEME_TRUE:(C_truep(C_eqp(t1,lf[282]))?C_SCHEME_TRUE:(C_truep(C_eqp(t1,lf[121]))?C_SCHEME_TRUE:(C_truep(C_eqp(t1,lf[285]))?C_SCHEME_TRUE:C_SCHEME_FALSE))))))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17294,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2041: chicken.compiler.support#node-subexpressions */
t4=*((C_word*)lf[530]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}}

/* k17292 in k17275 in atomic? in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17294(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17294,c,av);}
/* core.scm:2041: every */
f_6643(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1],t1);}

/* chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17299(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_17299,c,av);}
a=C_alloc(4);
t3=C_i_fixnum_max(lf[62],C_fix(1));
t4=C_fixnum_times(t3,C_fix(3));
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17306,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:2051: scheme#make-vector */
t6=*((C_word*)lf[93]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=t4;
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}

/* k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17306(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(47,c,7)))){
C_save_and_reclaim((void *)f_17306,c,av);}
a=C_alloc(47);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_17308,tmp=(C_word)a,a+=2,tmp));
t17=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17315,a[2]=t1,a[3]=t15,a[4]=t7,a[5]=t5,a[6]=t13,a[7]=t3,tmp=(C_word)a,a+=8,tmp));
t18=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17986,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t19=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18023,a[2]=t1,tmp=(C_word)a,a+=3,tmp));
t20=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18036,a[2]=t1,tmp=(C_word)a,a+=3,tmp));
t21=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18049,a[2]=t1,a[3]=t9,a[4]=t11,tmp=(C_word)a,a+=5,tmp));
t22=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18359,a[2]=t1,tmp=(C_word)a,a+=3,tmp));
t23=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18380,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t5,a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2262: chicken.compiler.support#debugging */
t24=*((C_word*)lf[596]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t24;
av2[1]=t23;
av2[2]=lf[604];
av2[3]=lf[606];
((C_proc)(void*)(*((C_word*)t24+1)))(4,av2);}}

/* grow in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static C_word C_fcall f_17308(C_word *a,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;{}
t2=C_s_a_i_plus(&a,2,lf[61],t1);
t3=C_mutate(&lf[61] /* (set! chicken.compiler.core#current-program-size ...) */,t2);
return(t3);}

/* walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17315(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,2)))){
C_save_and_reclaim_args((void *)trf_17315,7,t0,t1,t2,t3,t4,t5,t6);}
a=C_alloc(14);
t7=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_17319,a[2]=t1,a[3]=t4,a[4]=t3,a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[3],a[7]=t2,a[8]=((C_word*)t0)[4],a[9]=t5,a[10]=t6,a[11]=((C_word*)t0)[5],a[12]=((C_word*)t0)[6],a[13]=((C_word*)t0)[7],tmp=(C_word)a,a+=14,tmp);
/* core.scm:2059: chicken.compiler.support#node-subexpressions */
t8=*((C_word*)lf[530]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}

/* k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17319(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_17319,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_17322,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],tmp=(C_word)a,a+=15,tmp);
/* core.scm:2060: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17322(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_17322,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_17325,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
/* core.scm:2061: chicken.compiler.support#node-class */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17325(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(46,c,2)))){
C_save_and_reclaim((void *)f_17325,c,av);}
a=C_alloc(46);
t2=C_s_a_i_plus(&a,2,lf[61],C_fix(1));
t3=C_mutate(&lf[61] /* (set! chicken.compiler.core#current-program-size ...) */,t2);
t4=C_eqp(t1,lf[116]);
t5=(*a=C_CLOSURE_TYPE|16,a[1]=(C_word)f_17337,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],tmp=(C_word)a,a+=17,tmp);
if(C_truep(t4)){
t6=t5;
f_17337(t6,t4);}
else{
t6=C_eqp(t1,lf[478]);
if(C_truep(t6)){
t7=t5;
f_17337(t7,t6);}
else{
t7=C_eqp(t1,lf[162]);
t8=t5;
f_17337(t8,(C_truep(t7)?t7:C_eqp(t1,lf[564])));}}}

/* k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17337(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(47,0,6)))){
C_save_and_reclaim_args((void *)trf_17337,2,t0,t1);}
a=C_alloc(47);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_eqp(((C_word*)t0)[3],lf[526]);
t3=(C_truep(t2)?t2:C_eqp(((C_word*)t0)[3],lf[537]));
if(C_truep(t3)){
t4=C_i_car(((C_word*)t0)[4]);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17352,a[2]=t4,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2069: ref */
t6=((C_word*)((C_word*)t0)[8])[1];
f_18359(t6,t5,t4,((C_word*)t0)[9]);}
else{
t4=C_eqp(((C_word*)t0)[3],lf[163]);
t5=(C_truep(t4)?t4:C_eqp(((C_word*)t0)[3],lf[541]));
if(C_truep(t5)){
t6=C_s_a_i_plus(&a,2,lf[61],C_fix(1));
t7=C_mutate(&lf[61] /* (set! chicken.compiler.core#current-program-size ...) */,t6);
/* core.scm:2079: walkeach */
t8=((C_word*)((C_word*)t0)[10])[1];
f_17986(t8,((C_word*)t0)[2],((C_word*)t0)[11],((C_word*)t0)[6],((C_word*)t0)[5],((C_word*)t0)[12],((C_word*)t0)[13]);}
else{
t6=C_eqp(((C_word*)t0)[3],lf[523]);
if(C_truep(t6)){
t7=C_s_a_i_plus(&a,2,lf[61],C_fix(1));
t8=C_mutate(&lf[61] /* (set! chicken.compiler.core#current-program-size ...) */,t7);
t9=C_i_car(((C_word*)t0)[11]);
t10=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_17413,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[11],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[12],a[8]=((C_word*)t0)[13],a[9]=((C_word*)t0)[14],tmp=(C_word)a,a+=10,tmp);
t11=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17512,a[2]=((C_word*)t0)[13],a[3]=((C_word*)t0)[9],a[4]=t10,a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[11],a[7]=t9,tmp=(C_word)a,a+=8,tmp);
/* core.scm:2084: chicken.compiler.support#node-class */
t12=*((C_word*)lf[98]+1);{
C_word av2[3];
av2[0]=t12;
av2[1]=t11;
av2[2]=t9;
((C_proc)(void*)(*((C_word*)t12+1)))(3,av2);}}
else{
t7=C_eqp(((C_word*)t0)[3],lf[174]);
t8=(C_truep(t7)?t7:C_eqp(((C_word*)t0)[3],lf[173]));
if(C_truep(t8)){
t9=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_17524,a[2]=((C_word*)t0)[14],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[13],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[12],a[8]=((C_word*)t0)[15],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[2],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
/* core.scm:2102: scheme#append */
t10=*((C_word*)lf[5]+1);{
C_word av2[4];
av2[0]=t10;
av2[1]=t9;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t10+1)))(4,av2);}}
else{
t9=C_eqp(((C_word*)t0)[3],lf[490]);
if(C_truep(t9)){
t10=(
/* core.scm:2114: grow */
  f_17308(C_a_i(&a,29),C_fix(1))
);
t11=C_i_car(((C_word*)t0)[4]);
t12=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17587,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[14],a[5]=((C_word*)t0)[12],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2115: ##sys#decompose-lambda-list */
t13=*((C_word*)lf[191]+1);{
C_word av2[4];
av2[0]=t13;
av2[1]=((C_word*)t0)[2];
av2[2]=t11;
av2[3]=t12;
((C_proc)(void*)(*((C_word*)t13+1)))(4,av2);}}
else{
t10=C_eqp(((C_word*)t0)[3],lf[97]);
t11=(C_truep(t10)?t10:C_eqp(((C_word*)t0)[3],lf[548]));
if(C_truep(t11)){
t12=(
/* core.scm:2127: grow */
  f_17308(C_a_i(&a,29),C_fix(1))
);
t13=C_i_caddr(((C_word*)t0)[4]);
t14=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17656,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[13],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[11],a[7]=((C_word*)t0)[14],a[8]=((C_word*)t0)[12],tmp=(C_word)a,a+=9,tmp);
/* core.scm:2128: ##sys#decompose-lambda-list */
t15=*((C_word*)lf[191]+1);{
C_word av2[4];
av2[0]=t15;
av2[1]=((C_word*)t0)[2];
av2[2]=t13;
av2[3]=t14;
((C_proc)(void*)(*((C_word*)t15+1)))(4,av2);}}
else{
t12=C_eqp(((C_word*)t0)[3],lf[286]);
t13=(C_truep(t12)?t12:C_eqp(((C_word*)t0)[3],lf[177]));
if(C_truep(t13)){
t14=C_i_car(((C_word*)t0)[4]);
t15=C_i_car(((C_word*)t0)[11]);
t16=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_17794,a[2]=((C_word*)t0)[14],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[11],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[12],a[8]=((C_word*)t0)[13],a[9]=((C_word*)t0)[7],a[10]=t14,a[11]=((C_word*)t0)[15],a[12]=t15,tmp=(C_word)a,a+=13,tmp);
t17=(C_truep(*((C_word*)lf[69]+1))?C_i_not(*((C_word*)lf[53]+1)):C_SCHEME_FALSE);
if(C_truep(t17)){
t18=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17851,a[2]=t16,a[3]=t14,tmp=(C_word)a,a+=4,tmp);
/* core.scm:2158: chicken.compiler.support#variable-mark */
t19=*((C_word*)lf[185]+1);{
C_word av2[4];
av2[0]=t19;
av2[1]=t18;
av2[2]=t14;
av2[3]=lf[563];
((C_proc)(void*)(*((C_word*)t19+1)))(4,av2);}}
else{
t18=t16;{
C_word av2[2];
av2[0]=t18;
av2[1]=C_SCHEME_UNDEFINED;
f_17794(2,av2);}}}
else{
t14=C_eqp(((C_word*)t0)[3],lf[477]);
t15=(C_truep(t14)?t14:C_eqp(((C_word*)t0)[3],lf[302]));
if(C_truep(t15)){
t16=C_i_car(((C_word*)t0)[4]);
t17=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17891,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[11],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[12],a[8]=((C_word*)t0)[13],tmp=(C_word)a,a+=9,tmp);
t18=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_17897,a[2]=t17,a[3]=t16,a[4]=((C_word*)t0)[13],a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[5],a[10]=((C_word*)t0)[12],tmp=(C_word)a,a+=11,tmp);
if(C_truep(*((C_word*)lf[69]+1))){
if(C_truep(((C_word*)t0)[13])){
if(C_truep(C_i_symbolp(t16))){
/* core.scm:2177: chicken.compiler.support#get-real-name */
t19=*((C_word*)lf[125]+1);{
C_word av2[3];
av2[0]=t19;
av2[1]=t18;
av2[2]=t16;
((C_proc)(void*)(*((C_word*)t19+1)))(3,av2);}}
else{
t19=t18;{
C_word av2[2];
av2[0]=t19;
av2[1]=C_SCHEME_FALSE;
f_17897(2,av2);}}}
else{
t19=t18;{
C_word av2[2];
av2[0]=t19;
av2[1]=C_SCHEME_FALSE;
f_17897(2,av2);}}}
else{
t19=t18;{
C_word av2[2];
av2[0]=t19;
av2[1]=C_SCHEME_FALSE;
f_17897(2,av2);}}}
else{
/* core.scm:2181: walkeach */
t16=((C_word*)((C_word*)t0)[10])[1];
f_17986(t16,((C_word*)t0)[2],((C_word*)t0)[11],((C_word*)t0)[6],((C_word*)t0)[5],((C_word*)t0)[12],((C_word*)t0)[13]);}}}}}}}}}}

/* k17350 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17352(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(34,c,5)))){
C_save_and_reclaim((void *)f_17352,c,av);}
a=C_alloc(34);
if(C_truep(C_i_memq(((C_word*)t0)[2],((C_word*)t0)[3]))){
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=C_s_a_i_plus(&a,2,lf[61],C_fix(1));
t3=C_mutate(&lf[61] /* (set! chicken.compiler.core#current-program-size ...) */,t2);
if(C_truep(C_i_memq(((C_word*)t0)[2],((C_word*)t0)[5]))){
/* core.scm:2073: chicken.compiler.support#db-put! */
t4=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[2];
av2[4]=lf[539];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17383,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2074: chicken.compiler.support#db-get */
t5=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[2];
av2[4]=lf[95];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}}

/* k17381 in k17350 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17383(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_17383,c,av);}
if(C_truep(C_i_not(t1))){
/* core.scm:2075: chicken.compiler.support#db-put! */
t2=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[95];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k17411 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17413(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,6)))){
C_save_and_reclaim((void *)f_17413,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17416,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* core.scm:2098: walk */
t3=((C_word*)((C_word*)t0)[9])[1];
f_17315(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k17414 in k17411 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17416(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_17416,c,av);}
/* core.scm:2099: walkeach */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17986(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k17432 in k17506 in k17510 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17434(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,4)))){
C_save_and_reclaim((void *)f_17434,c,av);}
a=C_alloc(22);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17437,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17447,a[2]=t2,a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
if(C_truep(*((C_word*)lf[69]+1))){
if(C_truep(t1)){
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17504,a[2]=t3,a[3]=((C_word*)t0)[7],a[4]=t1,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2089: chicken.compiler.support#db-get */
t5=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=lf[95];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t4=t3;
f_17447(t4,C_SCHEME_FALSE);}}
else{
t4=t3;
f_17447(t4,C_SCHEME_FALSE);}}

/* k17435 in k17432 in k17506 in k17510 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17437(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_17437,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
/* core.scm:2097: chicken.compiler.support#collect! */
t3=*((C_word*)lf[542]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=lf[99];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* k17445 in k17432 in k17506 in k17510 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17447(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,5)))){
C_save_and_reclaim_args((void *)trf_17447,2,t0,t1);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17454,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2096: chicken.compiler.support#real-name */
t3=*((C_word*)lf[544]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=C_a_i_cons(&a,2,((C_word*)t0)[4],((C_word*)t0)[5]);
/* core.scm:2097: chicken.compiler.support#collect! */
t3=*((C_word*)lf[542]+1);{
C_word av2[6];
av2[0]=t3;
av2[1]=((C_word*)t0)[6];
av2[2]=((C_word*)t0)[7];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[99];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}}

/* k17452 in k17445 in k17432 in k17506 in k17510 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_17454(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17454,c,av);}
/* core.scm:2094: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[543];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k17480 in k17494 in k17498 in k17502 in k17432 in k17506 in k17510 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_17482(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_17482,c,av);}
t2=((C_word*)t0)[2];
f_17447(t2,C_i_not(t1));}

/* k17490 in k17494 in k17498 in k17502 in k17432 in k17506 in k17510 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_17492(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17492,c,av);}
/* core.scm:2092: chicken.compiler.support#llist-match? */
t2=*((C_word*)lf[545]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_i_caddr(t1);
av2[3]=C_u_i_cdr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k17494 in k17498 in k17502 in k17432 in k17506 in k17510 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_17496(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_17496,c,av);}
a=C_alloc(7);
t2=C_eqp(lf[97],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17482,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17492,a[2]=t3,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2092: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];
f_17447(t3,C_SCHEME_FALSE);}}

/* k17498 in k17502 in k17432 in k17506 in k17510 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_17500(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_17500,c,av);}
a=C_alloc(5);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17496,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2091: chicken.compiler.support#node-class */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[2];
f_17447(t2,C_SCHEME_FALSE);}}

/* k17502 in k17432 in k17506 in k17510 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17504(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_17504,c,av);}
a=C_alloc(5);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17500,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2090: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=lf[546];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[2];
f_17447(t2,C_SCHEME_FALSE);}}

/* k17506 in k17510 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17508(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_17508,c,av);}
a=C_alloc(8);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17434,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2086: chicken.compiler.support#db-get */
t4=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
av2[3]=t2;
av2[4]=lf[96];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k17510 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17512(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_17512,c,av);}
a=C_alloc(7);
t2=C_eqp(lf[526],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17508,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2085: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_17413(2,av2);}}}

/* k17522 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17524(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,4)))){
C_save_and_reclaim((void *)f_17524,c,av);}
a=C_alloc(14);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_17529,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=t3,a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=((C_word*)t0)[9],tmp=(C_word)a,a+=12,tmp));
t5=((C_word*)t3)[1];
f_17529(t5,((C_word*)t0)[10],((C_word*)t0)[5],((C_word*)t0)[11]);}

/* loop in k17522 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17529(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,5)))){
C_save_and_reclaim_args((void *)trf_17529,4,t0,t1,t2,t3);}
a=C_alloc(15);
if(C_truep(C_i_nullp(t2))){
t4=C_i_car(t3);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17547,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2105: scheme#append */
t6=*((C_word*)lf[5]+1);{
C_word av2[4];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}
else{
t4=C_i_car(t2);
t5=C_i_car(t3);
t6=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_17556,a[2]=((C_word*)t0)[8],a[3]=t1,a[4]=t2,a[5]=t3,a[6]=((C_word*)t0)[2],a[7]=t5,a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[5],a[12]=((C_word*)t0)[10],a[13]=t4,a[14]=((C_word*)t0)[4],tmp=(C_word)a,a+=15,tmp);
/* core.scm:2108: chicken.compiler.support#db-put! */
t7=*((C_word*)lf[538]+1);{
C_word av2[6];
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[11];
av2[3]=t4;
av2[4]=lf[547];
av2[5]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t7+1)))(6,av2);}}}

/* k17545 in loop in k17522 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17547(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_17547,c,av);}
/* core.scm:2105: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17315(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1,((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k17554 in loop in k17522 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17556(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,5)))){
C_save_and_reclaim((void *)f_17556,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_17559,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
/* core.scm:2109: assign */
t3=((C_word*)((C_word*)t0)[12])[1];
f_18049(t3,t2,((C_word*)t0)[13],((C_word*)t0)[7],((C_word*)t0)[14],((C_word*)t0)[11]);}

/* k17557 in k17554 in loop in k17522 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17559(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,6)))){
C_save_and_reclaim((void *)f_17559,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17562,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2110: walk */
t3=((C_word*)((C_word*)t0)[6])[1];
f_17315(t3,t2,((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11]);}

/* k17560 in k17557 in k17554 in loop in k17522 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_17562(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17562,c,av);}
/* core.scm:2111: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17529(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]),C_u_i_cdr(((C_word*)t0)[5]));}

/* a17586 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17587(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_17587,c,av);}
a=C_alloc(16);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_17589,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t6=C_i_check_list_2(t2,lf[100]);
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17599,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17614,a[2]=t9,a[3]=t5,tmp=(C_word)a,a+=4,tmp));
t11=((C_word*)t9)[1];
f_17614(t11,t7,t2);}

/* g3856 in a17586 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17589(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,5)))){
C_save_and_reclaim_args((void *)trf_17589,3,t0,t1,t2);}
/* core.scm:2119: chicken.compiler.support#db-put! */
t3=*((C_word*)lf[538]+1);{
C_word av2[6];
av2[0]=t3;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=lf[546];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* k17597 in a17586 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17599(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_17599,c,av);}
a=C_alloc(11);
t2=lf[78];
t3=lf[78] /* chicken.compiler.core#toplevel-scope */ =C_SCHEME_FALSE;;
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17603,a[2]=t2,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t5=C_i_car(((C_word*)t0)[3]);
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17612,a[2]=((C_word*)t0)[4],a[3]=t4,a[4]=t5,a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2123: scheme#append */
t7=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k17601 in k17597 in a17586 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17603(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_17603,c,av);}
t2=C_mutate(&lf[78] /* (set! chicken.compiler.core#toplevel-scope ...) */,((C_word*)t0)[2]);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k17610 in k17597 in a17586 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17612(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_17612,c,av);}
/* core.scm:2123: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17315(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t1,C_SCHEME_FALSE);}

/* for-each-loop3855 in a17586 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17614(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_17614,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17624,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2118: g3856 */
t4=((C_word*)t0)[3];
f_17589(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k17622 in for-each-loop3855 in a17586 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17624(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17624,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_17614(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17656(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,5)))){
C_save_and_reclaim((void *)f_17656,c,av);}
a=C_alloc(20);
t5=C_i_car(((C_word*)t0)[2]);
t6=lf[61];
t7=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_17663,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=t6,a[6]=t1,a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=t5,a[12]=((C_word*)t0)[2],a[13]=t4,tmp=(C_word)a,a+=14,tmp);
if(C_truep(((C_word*)t0)[4])){
t8=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17773,a[2]=t7,a[3]=((C_word*)t0)[3],a[4]=t5,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2134: chicken.compiler.support#collect! */
t9=*((C_word*)lf[542]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[555];
av2[5]=t5;
((C_proc)(void*)(*((C_word*)t9+1)))(6,av2);}}
else{
t8=t7;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_UNDEFINED;
f_17663(2,av2);}}}

/* k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17663(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,3)))){
C_save_and_reclaim((void *)f_17663,c,av);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17664,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=C_i_check_list_2(((C_word*)t0)[4],lf[100]);
t4=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_17677,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[4],a[9]=((C_word*)t0)[11],a[10]=((C_word*)t0)[12],a[11]=((C_word*)t0)[2],a[12]=((C_word*)t0)[13],tmp=(C_word)a,a+=13,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17749,a[2]=t6,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_17749(t8,t4,((C_word*)t0)[4]);}

/* g3887 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17664(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,5)))){
C_save_and_reclaim_args((void *)trf_17664,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17668,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2138: chicken.compiler.support#db-put! */
t4=*((C_word*)lf[538]+1);{
C_word av2[6];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=lf[547];
av2[5]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}

/* k17666 in g3887 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17668(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_17668,c,av);}
/* core.scm:2139: chicken.compiler.support#db-put! */
t2=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[546];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k17675 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17677(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,5)))){
C_save_and_reclaim((void *)f_17677,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_17680,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
if(C_truep(((C_word*)t0)[12])){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17740,a[2]=((C_word*)t0)[12],a[3]=t2,a[4]=((C_word*)t0)[11],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2142: chicken.compiler.support#db-put! */
t4=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[11];
av2[3]=((C_word*)t0)[12];
av2[4]=lf[552];
av2[5]=lf[553];
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_17680(2,av2);}}}

/* k17678 in k17675 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17680(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_17680,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_17683,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17734,a[2]=t2,a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[9],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2144: chicken.compiler.support#simple-lambda-node? */
t4=*((C_word*)lf[550]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k17681 in k17678 in k17675 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_17683(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_17683,c,av);}
a=C_alloc(12);
t2=lf[78];
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_17686,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
if(C_truep(lf[79])){
t4=t3;
f_17686(t4,C_SCHEME_UNDEFINED);}
else{
t4=C_mutate(&lf[79] /* (set! chicken.compiler.core#toplevel-lambda-id ...) */,((C_word*)t0)[9]);
t5=t3;
f_17686(t5,t4);}}

/* k17684 in k17681 in k17678 in k17675 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_17686(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_17686,2,t0,t1);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_17689,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
if(C_truep(C_i_cadr(((C_word*)t0)[11]))){
t3=C_eqp(lf[79],((C_word*)t0)[10]);
if(C_truep(C_i_not(t3))){
t4=lf[78] /* chicken.compiler.core#toplevel-scope */ =C_SCHEME_FALSE;;
t5=t2;
f_17689(t5,t4);}
else{
t4=t2;
f_17689(t4,C_SCHEME_UNDEFINED);}}
else{
t3=t2;
f_17689(t3,C_SCHEME_UNDEFINED);}}

/* k17687 in k17684 in k17681 in k17678 in k17675 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_fcall f_17689(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,3)))){
C_save_and_reclaim_args((void *)trf_17689,2,t0,t1);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_17692,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=C_i_car(((C_word*)t0)[6]);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_17716,a[2]=((C_word*)t0)[7],a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2149: scheme#append */
t5=*((C_word*)lf[5]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k17690 in k17687 in k17684 in k17681 in k17678 in k17675 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_17692(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_17692,c,av);}
a=C_alloc(4);
t2=C_mutate(&lf[78] /* (set! chicken.compiler.core#toplevel-scope ...) */,((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_17708,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2152: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k17706 in k17690 in k17687 in k17684 in k17681 in k17678 in k17675 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_17708(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_17708,c,av);}
a=C_alloc(29);
t2=C_i_cdddr(t1);
t3=C_s_a_i_minus(&a,2,lf[61],((C_word*)t0)[2]);
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_set_car(t2,t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k17714 in k17687 in k17684 in k17681 in k17678 in k17675 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_17716(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_17716,c,av);}
/* core.scm:2149: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17315(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],t1,((C_word*)t0)[7]);}

/* k17732 in k17678 in k17675 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_17734(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_17734,c,av);}
if(C_truep(t1)){
/* core.scm:2144: chicken.compiler.support#db-put! */
t2=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[549];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_17683(2,av2);}}}

/* k17738 in k17675 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17740(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,5)))){
C_save_and_reclaim((void *)f_17740,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],C_fix(0));
/* core.scm:2143: chicken.compiler.support#db-put! */
t3=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[2];
av2[4]=lf[551];
av2[5]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* for-each-loop3886 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17749(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_17749,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17759,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2136: g3887 */
t4=((C_word*)t0)[3];
f_17664(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k17757 in for-each-loop3886 in k17661 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17759(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_17759,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_17749(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k17771 in a17655 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17773(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_17773,c,av);}
/* core.scm:2135: chicken.compiler.support#db-put! */
t2=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[554];
av2[5]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k17792 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17794(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,5)))){
C_save_and_reclaim((void *)f_17794,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_17797,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
/* core.scm:2163: chicken.compiler.support#collect! */
t3=*((C_word*)lf[542]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[10];
av2[4]=lf[558];
av2[5]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* k17795 in k17792 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17797(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(47,c,5)))){
C_save_and_reclaim((void *)f_17797,c,av);}
a=C_alloc(47);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_17800,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],tmp=(C_word)a,a+=13,tmp);
if(C_truep(C_i_memq(((C_word*)t0)[10],((C_word*)t0)[6]))){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_17800(2,av2);}}
else{
t3=C_s_a_i_plus(&a,2,lf[61],C_fix(1));
t4=C_mutate(&lf[61] /* (set! chicken.compiler.core#current-program-size ...) */,t3);
if(C_truep(C_i_memq(((C_word*)t0)[10],((C_word*)t0)[5]))){
/* core.scm:2167: chicken.compiler.support#db-put! */
t5=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[10];
av2[4]=lf[539];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t5+1)))(6,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_17845,a[2]=t2,a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[10],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2168: chicken.compiler.support#db-get */
t6=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[10];
av2[4]=lf[95];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}}}

/* k17798 in k17795 in k17792 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17800(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,5)))){
C_save_and_reclaim((void *)f_17800,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_17803,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* core.scm:2170: assign */
t3=((C_word*)((C_word*)t0)[11])[1];
f_18049(t3,t2,((C_word*)t0)[10],((C_word*)t0)[12],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k17801 in k17798 in k17795 in k17792 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17803(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,5)))){
C_save_and_reclaim((void *)f_17803,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_17806,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
if(C_truep(lf[78])){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_17806(2,av2);}}
else{
/* core.scm:2171: chicken.compiler.support#db-put! */
t3=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[10];
av2[4]=lf[557];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}}

/* k17804 in k17801 in k17798 in k17795 in k17792 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_17806(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,5)))){
C_save_and_reclaim((void *)f_17806,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_17809,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* core.scm:2172: chicken.compiler.support#db-put! */
t3=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[10];
av2[4]=lf[556];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* k17807 in k17804 in k17801 in k17798 in k17795 in k17792 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_17809(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_17809,c,av);}
/* core.scm:2173: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17315(t2,((C_word*)t0)[3],C_u_i_car(((C_word*)t0)[4]),((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k17843 in k17795 in k17792 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17845(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_17845,c,av);}
if(C_truep(C_i_not(t1))){
/* core.scm:2169: chicken.compiler.support#db-put! */
t2=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[95];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_17800(2,av2);}}}

/* k17849 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17851(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_17851,c,av);}
t2=C_eqp(t1,lf[559]);
if(C_truep(t2)){
/* core.scm:2160: chicken.base#warning */
t3=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[560];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t3=C_eqp(t1,lf[561]);
if(C_truep(t3)){
/* core.scm:2162: chicken.base#warning */
t4=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[562];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_17794(2,av2);}}}}

/* k17889 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17891(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_17891,c,av);}
/* core.scm:2179: walkeach */
t2=((C_word*)((C_word*)t0)[2])[1];
f_17986(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k17895 in k17335 in k17323 in k17320 in k17317 in walk in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_17897(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_17897,c,av);}
if(C_truep(t1)){
/* core.scm:2178: chicken.compiler.support#set-real-name! */
t2=*((C_word*)lf[115]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
/* core.scm:2179: walkeach */
t2=((C_word*)((C_word*)t0)[5])[1];
f_17986(t2,((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[4]);}}

/* walkeach in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17986(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,3)))){
C_save_and_reclaim_args((void *)trf_17986,7,t0,t1,t2,t3,t4,t5,t6);}
a=C_alloc(13);
t7=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_17988,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t4,a[5]=t5,a[6]=t6,tmp=(C_word)a,a+=7,tmp);
t8=C_i_check_list_2(t2,lf[100]);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18000,a[2]=t10,a[3]=t7,tmp=(C_word)a,a+=4,tmp));
t12=((C_word*)t10)[1];
f_18000(t12,t1,t2);}

/* g3956 in walkeach in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_17988(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,6)))){
C_save_and_reclaim_args((void *)trf_17988,3,t0,t1,t2);}
/* core.scm:2184: walk */
t3=((C_word*)((C_word*)t0)[2])[1];
f_17315(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6]);}

/* for-each-loop3955 in walkeach in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_18000(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_18000,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18010,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2184: g3956 */
t4=((C_word*)t0)[3];
f_17988(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k18008 in for-each-loop3955 in walkeach in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18010(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_18010,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_18000(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* mark-rest-cdr in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_18023(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,5)))){
C_save_and_reclaim_args((void *)trf_18023,5,t0,t1,t2,t3,t4);}
a=C_alloc(9);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18027,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t6=C_a_i_cons(&a,2,t3,t4);
/* core.scm:2187: chicken.compiler.support#db-put! */
t7=*((C_word*)lf[538]+1);{
C_word av2[6];
av2[0]=t7;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=lf[551];
av2[5]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(6,av2);}}

/* k18025 in mark-rest-cdr in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18027(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_18027,c,av);}
/* core.scm:2188: chicken.compiler.support#collect! */
t2=*((C_word*)lf[542]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[565];
av2[5]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* mark-rest-null? in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_18036(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,5)))){
C_save_and_reclaim_args((void *)trf_18036,5,t0,t1,t2,t3,t4);}
a=C_alloc(9);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18040,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t3,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t6=C_a_i_cons(&a,2,t3,t4);
/* core.scm:2191: chicken.compiler.support#db-put! */
t7=*((C_word*)lf[538]+1);{
C_word av2[6];
av2[0]=t7;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=lf[566];
av2[5]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(6,av2);}}

/* k18038 in mark-rest-null? in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18040(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_18040,c,av);}
/* core.scm:2192: chicken.compiler.support#collect! */
t2=*((C_word*)lf[542]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[565];
av2[5]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_18049(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_18049,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(10);
t6=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_18357,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=t3,a[7]=((C_word*)t0)[4],a[8]=t4,a[9]=t5,tmp=(C_word)a,a+=10,tmp);
/* core.scm:2196: chicken.compiler.support#node-class */
t7=*((C_word*)lf[98]+1);{
C_word av2[3];
av2[0]=t7;
av2[1]=t6;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}

/* k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18056(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_18056,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_18330,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:2200: chicken.compiler.support#node-class */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18062(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_18062,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_18303,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:2204: chicken.compiler.support#node-class */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_18074(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_18074,2,t0,t1);}
a=C_alloc(10);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_18281,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:2210: chicken.compiler.support#node-class */
t3=*((C_word*)lf[98]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* k18096 in k18100 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_18098(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_18098,c,av);}
a=C_alloc(29);
t2=C_i_cadr(t1);
t3=C_s_a_i_plus(&a,2,t2,C_fix(1));
/* core.scm:2213: mark-rest-cdr */
t4=((C_word*)((C_word*)t0)[2])[1];
f_18023(t4,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t3);}

/* k18100 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18102(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_18102,c,av);}
a=C_alloc(6);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18098,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2212: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k18119 in k18123 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_18121(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_18121,c,av);}
/* core.scm:2218: mark-rest-null? */
t2=((C_word*)((C_word*)t0)[2])[1];
f_18036(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],C_i_cadr(t1));}

/* k18123 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_18125(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_18125,c,av);}
a=C_alloc(6);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18121,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2217: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_18128(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_18128,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_18131,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18266,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18273,a[2]=t3,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2226: chicken.base#alist-ref */
t5=*((C_word*)lf[569]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[575];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t3=t2;
f_18131(t3,C_SCHEME_FALSE);}}

/* k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_18131(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_18131,2,t0,t1);}
a=C_alloc(11);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18135,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2204: g4012 */
t3=t2;
f_18135(t3,((C_word*)t0)[4],t1);}
else{
t2=C_i_memq(((C_word*)t0)[3],((C_word*)t0)[5]);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18159,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],tmp=(C_word)a,a+=7,tmp);
if(C_truep(t2)){
t4=t3;
f_18159(t4,t2);}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18253,a[2]=t3,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2234: chicken.compiler.support#variable-mark */
t5=*((C_word*)lf[185]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[354];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}}

/* g4012 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_fcall f_18135(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_18135,3,t0,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18139,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2229: chicken.base#alist-ref */
t4=*((C_word*)lf[569]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[571];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k18137 in g4012 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_18139(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_18139,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18142,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2230: chicken.base#alist-ref */
t3=*((C_word*)lf[569]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[570];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18140 in k18137 in g4012 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_18142(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_18142,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,t1,C_fix(1));
/* core.scm:2231: mark-rest-cdr */
t3=((C_word*)((C_word*)t0)[2])[1];
f_18023(t3,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t2);}

/* k18157 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_fcall f_18159(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,5)))){
C_save_and_reclaim_args((void *)trf_18159,2,t0,t1);}
a=C_alloc(12);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18162,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2236: chicken.compiler.support#db-get-all */
t3=*((C_word*)lf[572]+1);{
C_word av2[6];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[546];
av2[5]=lf[96];
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18204,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t3=*((C_word*)lf[49]+1);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18240,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(*((C_word*)lf[49]+1))){
t5=t4;{
C_word av2[2];
av2[0]=t5;
av2[1]=*((C_word*)lf[49]+1);
f_18240(2,av2);}}
else{
/* core.scm:2245: chicken.compiler.support#variable-mark */
t5=*((C_word*)lf[185]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[418];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}}

/* k18160 in k18157 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_18162(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_18162,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_18165,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2237: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[547];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k18163 in k18160 in k18157 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_18165(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_18165,c,av);}
if(C_truep(C_i_assq(lf[546],((C_word*)t0)[2]))){
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
if(C_truep(C_i_assq(lf[96],((C_word*)t0)[2]))){
/* core.scm:2240: chicken.compiler.support#db-put! */
t2=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[546];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
t2=C_i_not(t1);
t3=(C_truep(t2)?t2:C_eqp(((C_word*)t0)[6],t1));
if(C_truep(t3)){
/* core.scm:2242: chicken.compiler.support#db-put! */
t4=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[96];
av2[5]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}
else{
/* core.scm:2243: chicken.compiler.support#db-put! */
t4=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[546];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}}}}

/* k18202 in k18157 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_18204(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,5)))){
C_save_and_reclaim_args((void *)trf_18204,2,t0,t1);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18207,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2247: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[547];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
/* core.scm:2253: chicken.compiler.support#db-put! */
t2=*((C_word*)lf[538]+1);{
C_word av2[6];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[546];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}}

/* k18205 in k18202 in k18157 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_18207(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_18207,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_18213,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2248: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[573];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k18211 in k18205 in k18202 in k18157 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_18213(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_18213,c,av);}
if(C_truep(t1)){
/* core.scm:2249: chicken.compiler.support#db-put! */
t2=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[546];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
t2=C_i_not(((C_word*)t0)[5]);
t3=(C_truep(t2)?t2:C_eqp(((C_word*)t0)[6],((C_word*)t0)[5]));
if(C_truep(t3)){
/* core.scm:2251: chicken.compiler.support#db-put! */
t4=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[573];
av2[5]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}
else{
/* core.scm:2252: chicken.compiler.support#db-put! */
t4=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[546];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}}}

/* k18238 in k18157 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_18240(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_18240,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18247,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2246: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[546];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[2];
f_18204(t2,C_SCHEME_FALSE);}}

/* k18245 in k18238 in k18157 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_18247(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18247,c,av);}
t2=((C_word*)t0)[2];
f_18204(t2,C_i_not(t1));}

/* k18251 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_18253(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_18253,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=((C_word*)t0)[2];
f_18159(t2,t1);}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18263,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2235: chicken.compiler.support#variable-visible? */
t3=*((C_word*)lf[574]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=*((C_word*)lf[25]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* k18261 in k18251 in k18129 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_18263(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18263,c,av);}
t2=((C_word*)t0)[2];
f_18159(t2,C_i_not(t1));}

/* k18264 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_18266(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18266,c,av);}
t2=((C_word*)t0)[2];
f_18131(t2,(C_truep(t1)?((C_word*)t0)[3]:C_SCHEME_FALSE));}

/* k18271 in k18126 in k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_18273(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_18273,c,av);}
/* core.scm:2226: chicken.compiler.support#db-get */
t2=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=lf[566];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k18275 in k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_18277,c,av);}
a=C_alloc(9);
t2=C_eqp(lf[568],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18125,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2216: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_18128,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[5],tmp=(C_word)a,a+=9,tmp);
/* core.scm:2221: chicken.compiler.support#match-node */
t4=*((C_word*)lf[576]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
av2[3]=lf[577];
av2[4]=lf[578];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}

/* k18279 in k18072 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18281(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_18281,c,av);}
a=C_alloc(10);
t2=C_eqp(lf[537],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18102,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2211: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_18277,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:2215: chicken.compiler.support#node-class */
t4=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k18293 in k18297 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18295(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18295,c,av);}
t2=((C_word*)t0)[2];
f_18074(t2,C_eqp(((C_word*)t0)[3],C_i_car(t1)));}

/* k18297 in k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18299(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_18299,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[526],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18295,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2207: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];
f_18074(t3,C_SCHEME_FALSE);}}

/* k18301 in k18060 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18303(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,5)))){
C_save_and_reclaim((void *)f_18303,c,av);}
a=C_alloc(15);
t2=C_eqp(lf[478],t1);
if(C_truep(t2)){
/* core.scm:2205: chicken.compiler.support#db-put! */
t3=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[567];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_18074,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18299,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2206: chicken.compiler.support#node-class */
t5=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k18304 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18306(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_18306,c,av);}
if(C_truep(t1)){
/* core.scm:2202: mark-rest-null? */
t2=((C_word*)((C_word*)t0)[2])[1];
f_18036(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_i_car(t1),C_u_i_cdr(t1));}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_18062(2,av2);}}}

/* k18324 in k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18326(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_18326,c,av);}
/* core.scm:2201: chicken.compiler.support#db-get */
t2=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=C_i_car(t1);
av2[4]=lf[566];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k18328 in k18054 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18330(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_18330,c,av);}
a=C_alloc(19);
t2=C_eqp(lf[526],t1);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_18062,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
if(C_truep(t2)){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18306,a[2]=((C_word*)t0)[7],a[3]=t3,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18326,a[2]=t4,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2201: chicken.compiler.support#node-parameters */
t6=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_18062(2,av2);}}}

/* k18331 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18333(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_18333,c,av);}
if(C_truep(t1)){
/* core.scm:2198: mark-rest-cdr */
t2=((C_word*)((C_word*)t0)[2])[1];
f_18023(t2,((C_word*)t0)[3],((C_word*)t0)[4],C_i_car(t1),C_u_i_cdr(t1));}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_18056(2,av2);}}}

/* k18351 in k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18353(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_18353,c,av);}
/* core.scm:2197: chicken.compiler.support#db-get */
t2=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=C_i_car(t1);
av2[4]=lf[551];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k18355 in assign in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18357(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_18357,c,av);}
a=C_alloc(19);
t2=C_eqp(lf[526],t1);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_18056,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
if(C_truep(t2)){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18333,a[2]=((C_word*)t0)[5],a[3]=t3,a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18353,a[2]=t4,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2197: chicken.compiler.support#node-parameters */
t6=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_18056(2,av2);}}}

/* ref in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_18359(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,5)))){
C_save_and_reclaim_args((void *)trf_18359,4,t0,t1,t2,t3);}
/* core.scm:2256: chicken.compiler.support#collect! */
t4=*((C_word*)lf[542]+1);{
C_word av2[6];
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=lf[579];
av2[5]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}

/* k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18380(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,6)))){
C_save_and_reclaim((void *)f_18380,c,av);}
a=C_alloc(4);
t2=lf[61] /* chicken.compiler.core#current-program-size */ =C_fix(0);;
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18384,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2264: walk */
t4=((C_word*)((C_word*)t0)[4])[1];
f_17315(t4,t3,((C_word*)t0)[5],C_SCHEME_END_OF_LIST,C_SCHEME_END_OF_LIST,C_SCHEME_END_OF_LIST,C_SCHEME_FALSE);}

/* k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18384(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_18384,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18387,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2267: chicken.compiler.support#debugging */
t3=*((C_word*)lf[596]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[604];
av2[3]=lf[605];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18387(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_18387,c,av);}
a=C_alloc(7);
t2=lf[62] /* chicken.compiler.core#current-analysis-database-size */ =C_fix(0);;
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18391,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18397,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2269: chicken.internal#hash-table-for-each */
t5=*((C_word*)lf[101]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t3;
av2[2]=t4;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k18389 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18391(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18391,c,av);}
if(C_truep(lf[60])){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_mutate(&lf[60] /* (set! chicken.compiler.core#original-program-size ...) */,lf[61]);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18397(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(67,c,2)))){
C_save_and_reclaim((void *)f_18397,c,av);}
a=C_alloc(67);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_FALSE;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_FALSE;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_FALSE;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_SCHEME_END_OF_LIST;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_SCHEME_FALSE;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_SCHEME_END_OF_LIST;
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=C_SCHEME_FALSE;
t19=(*a=C_VECTOR_TYPE|1,a[1]=t18,tmp=(C_word)a,a+=2,tmp);
t20=C_SCHEME_FALSE;
t21=(*a=C_VECTOR_TYPE|1,a[1]=t20,tmp=(C_word)a,a+=2,tmp);
t22=C_SCHEME_FALSE;
t23=(*a=C_VECTOR_TYPE|1,a[1]=t22,tmp=(C_word)a,a+=2,tmp);
t24=C_fix(0);
t25=(*a=C_VECTOR_TYPE|1,a[1]=t24,tmp=(C_word)a,a+=2,tmp);
t26=C_SCHEME_FALSE;
t27=(*a=C_VECTOR_TYPE|1,a[1]=t26,tmp=(C_word)a,a+=2,tmp);
t28=C_fix(0);
t29=(*a=C_VECTOR_TYPE|1,a[1]=t28,tmp=(C_word)a,a+=2,tmp);
t30=C_fixnum_plus(lf[62],C_fix(1));
t31=lf[62] /* chicken.compiler.core#current-analysis-database-size */ =t30;;
t32=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_18403,a[2]=t5,a[3]=t13,a[4]=t25,a[5]=t15,a[6]=t11,a[7]=t17,a[8]=t29,a[9]=t19,a[10]=t21,a[11]=t23,a[12]=t7,a[13]=t9,a[14]=t27,tmp=(C_word)a,a+=15,tmp);
t33=C_i_check_list_2(t3,lf[100]);
t34=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19328,a[2]=t32,tmp=(C_word)a,a+=3,tmp);
t35=(
  f_19328(t34,t3)
);
t36=C_i_not(((C_word*)t5)[1]);
t37=(C_truep(t36)?((C_word*)t7)[1]:C_SCHEME_FALSE);
t38=C_set_block_item(t7,0,t37);
t39=C_i_not(((C_word*)t5)[1]);
t40=(C_truep(t39)?((C_word*)t9)[1]:C_SCHEME_FALSE);
t41=C_set_block_item(t9,0,t40);
t42=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_18546,a[2]=t3,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=t7,a[6]=t23,a[7]=t19,a[8]=t13,a[9]=t21,a[10]=t27,a[11]=t25,a[12]=t29,a[13]=t2,a[14]=t9,a[15]=t15,tmp=(C_word)a,a+=16,tmp);
if(C_truep(*((C_word*)lf[69]+1))){
t43=(C_truep(((C_word*)t7)[1])?C_a_i_list1(&a,1,((C_word*)t7)[1]):C_SCHEME_FALSE);
t44=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19259,a[2]=t2,a[3]=t42,tmp=(C_word)a,a+=4,tmp);
if(C_truep(t43)){
t45=t44;
f_19259(t45,t43);}
else{
if(C_truep(((C_word*)t23)[1])){
t45=((C_word*)t11)[1];
t46=t44;
f_19259(t46,t45);}
else{
t45=t44;
f_19259(t45,C_SCHEME_FALSE);}}}
else{
t43=t42;{
C_word *av2=av;
av2[0]=t43;
av2[1]=C_SCHEME_UNDEFINED;
f_18546(2,av2);}}}

/* g4066 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static C_word C_fcall f_18403(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_stack_overflow_check;{}
t2=C_i_car(t1);
t3=C_eqp(t2,lf[546]);
if(C_truep(t3)){
t4=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_TRUE);
return(t4);}
else{
t4=C_eqp(t2,lf[579]);
if(C_truep(t4)){
t5=C_mutate(((C_word *)((C_word*)t0)[3])+1,C_u_i_cdr(t1));
t6=C_i_length(((C_word*)((C_word*)t0)[3])[1]);
t7=C_set_block_item(((C_word*)t0)[4],0,t6);
return(t7);}
else{
t5=C_eqp(t2,lf[539]);
if(C_truep(t5)){
t6=C_set_block_item(((C_word*)t0)[5],0,C_SCHEME_TRUE);
return(t6);}
else{
t6=C_eqp(t2,lf[558]);
if(C_truep(t6)){
t7=C_mutate(((C_word *)((C_word*)t0)[6])+1,C_u_i_cdr(t1));
return(t7);}
else{
t7=C_eqp(t2,lf[99]);
if(C_truep(t7)){
t8=C_mutate(((C_word *)((C_word*)t0)[7])+1,C_u_i_cdr(t1));
t9=C_i_length(((C_word*)((C_word*)t0)[7])[1]);
t10=C_set_block_item(((C_word*)t0)[8],0,t9);
return(t10);}
else{
t8=C_eqp(t2,lf[556]);
if(C_truep(t8)){
t9=C_set_block_item(((C_word*)t0)[9],0,C_SCHEME_TRUE);
return(t9);}
else{
t9=C_eqp(t2,lf[557]);
if(C_truep(t9)){
t10=C_SCHEME_UNDEFINED;
return(t10);}
else{
t10=C_eqp(t2,lf[567]);
if(C_truep(t10)){
t11=C_set_block_item(((C_word*)t0)[10],0,C_SCHEME_TRUE);
return(t11);}
else{
t11=C_eqp(t2,lf[95]);
if(C_truep(t11)){
t12=C_set_block_item(((C_word*)t0)[11],0,C_SCHEME_TRUE);
return(t12);}
else{
t12=C_eqp(t2,lf[96]);
if(C_truep(t12)){
t13=C_mutate(((C_word *)((C_word*)t0)[12])+1,C_u_i_cdr(t1));
return(t13);}
else{
t13=C_eqp(t2,lf[573]);
if(C_truep(t13)){
t14=C_mutate(((C_word *)((C_word*)t0)[13])+1,C_u_i_cdr(t1));
return(t14);}
else{
t14=C_eqp(t2,lf[551]);
if(C_truep(t14)){
t15=C_mutate(((C_word *)((C_word*)t0)[14])+1,C_u_i_cdr(t1));
return(t15);}
else{
return(C_SCHEME_UNDEFINED);}}}}}}}}}}}}}

/* k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18546(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,3)))){
C_save_and_reclaim((void *)f_18546,c,av);}
a=C_alloc(24);
t2=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_18549,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],tmp=(C_word)a,a+=16,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19185,a[2]=t2,a[3]=((C_word*)t0)[13],tmp=(C_word)a,a+=4,tmp);
if(C_truep(*((C_word*)lf[69]+1))){
if(C_truep(((C_word*)((C_word*)t0)[6])[1])){
if(C_truep(C_i_nullp(((C_word*)((C_word*)t0)[8])[1]))){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19253,a[2]=t3,a[3]=((C_word*)t0)[13],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2329: chicken.compiler.support#variable-mark */
t5=*((C_word*)lf[185]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[13];
av2[3]=lf[402];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t4=t3;
f_19185(t4,C_SCHEME_FALSE);}}
else{
t4=t3;
f_19185(t4,C_SCHEME_FALSE);}}
else{
t4=t3;
f_19185(t4,C_SCHEME_FALSE);}}

/* k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18549(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,2)))){
C_save_and_reclaim((void *)f_18549,c,av);}
a=C_alloc(21);
t2=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_18552,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],tmp=(C_word)a,a+=15,tmp);
if(C_truep(((C_word*)((C_word*)t0)[7])[1])){
t3=((C_word*)((C_word*)t0)[15])[1];
if(C_truep(t3)){
t4=C_i_cdr(((C_word*)t0)[2]);
t5=C_a_i_cons(&a,2,lf[600],C_SCHEME_TRUE);
t6=C_a_i_cons(&a,2,t5,t4);
t7=t2;
f_18552(t7,C_i_set_cdr(((C_word*)t0)[2],t6));}
else{
t4=t2;
f_18552(t4,C_SCHEME_UNDEFINED);}}
else{
t3=t2;
f_18552(t3,C_SCHEME_UNDEFINED);}}

/* k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_18552(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,0,3)))){
C_save_and_reclaim_args((void *)trf_18552,2,t0,t1);}
a=C_alloc(22);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_18555,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],tmp=(C_word)a,a+=14,tmp);
if(C_truep(((C_word*)((C_word*)t0)[5])[1])){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19007,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[12],a[4]=((C_word*)t0)[2],a[5]=t2,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2346: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)((C_word*)t0)[5])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
if(C_truep(((C_word*)((C_word*)t0)[14])[1])){
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19079,a[2]=((C_word*)t0)[14],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[13],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* core.scm:2358: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)((C_word*)t0)[14])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19144,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[13],a[4]=((C_word*)t0)[2],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2370: chicken.compiler.support#variable-mark */
t4=*((C_word*)lf[185]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[13];
av2[3]=lf[410];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}}

/* k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_18555(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,2)))){
C_save_and_reclaim((void *)f_18555,c,av);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_18558,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],tmp=(C_word)a,a+=14,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18975,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[11],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)((C_word*)t0)[5])[1])){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19004,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2386: chicken.compiler.support#node-class */
t5=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)((C_word*)t0)[5])[1];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=t3;
f_18975(t4,C_SCHEME_FALSE);}}

/* k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_18558(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,0,2)))){
C_save_and_reclaim_args((void *)trf_18558,2,t0,t1);}
a=C_alloc(22);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_18561,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
if(C_truep(((C_word*)((C_word*)t0)[5])[1])){
t3=C_SCHEME_FALSE;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_18972,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[12],a[4]=((C_word*)t0)[4],a[5]=t4,a[6]=((C_word*)t0)[13],a[7]=t2,a[8]=((C_word*)t0)[5],tmp=(C_word)a,a+=9,tmp);
/* core.scm:2400: chicken.compiler.support#node-class */
t6=*((C_word*)lf[98]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)((C_word*)t0)[5])[1];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t3=t2;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_18561(2,av2);}}}

/* k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_18561(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_18561,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_18564,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[7])[1]))){
if(C_truep(C_i_nullp(((C_word*)((C_word*)t0)[8])[1]))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18797,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[10],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)((C_word*)t0)[5])[1])){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18846,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2430: chicken.compiler.support#node-class */
t5=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)((C_word*)t0)[5])[1];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=t3;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_18797(2,av2);}}}
else{
t3=t2;
f_18564(t3,C_SCHEME_UNDEFINED);}}
else{
t3=t2;
f_18564(t3,C_SCHEME_UNDEFINED);}}

/* k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_18564(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,0,2)))){
C_save_and_reclaim_args((void *)trf_18564,2,t0,t1);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18567,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(C_truep(((C_word*)((C_word*)t0)[5])[1])?C_i_not(((C_word*)((C_word*)t0)[6])[1]):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18776,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2452: chicken.compiler.support#node-class */
t5=*((C_word*)lf[98]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)((C_word*)t0)[5])[1];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=t2;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_18567(2,av2);}}}

/* k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_18567(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_18567,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18573,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)((C_word*)t0)[5])[1])){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18698,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2466: chicken.compiler.support#node-class */
t4=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)((C_word*)t0)[5])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t2;
f_18573(t3,C_SCHEME_FALSE);}}

/* k18571 in k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_18573(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_18573,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18576,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2467: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[527]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[5])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18574 in k18571 in k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_18576(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_18576,c,av);}
a=C_alloc(6);
t2=C_i_cadr(t1);
if(C_truep(C_i_not(t2))){
t3=C_i_caddr(t1);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18687,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2470: chicken.compiler.support#node-subexpressions */
t5=*((C_word*)lf[530]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)((C_word*)t0)[5])[1];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18592 in k18685 in k18574 in k18571 in k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_fcall f_18594(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_18594,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18597,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2474: chicken.compiler.support#node-subexpressions */
t3=*((C_word*)lf[530]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18595 in k18592 in k18685 in k18574 in k18571 in k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_18597(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_18597,c,av);}
a=C_alloc(11);
t2=C_i_length(t1);
t3=C_eqp(C_fix(2),t2);
if(C_truep(t3)){
t4=C_i_car(t1);
t5=C_i_cadr(t1);
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18615,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18660,a[2]=((C_word*)t0)[5],a[3]=t6,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2478: chicken.compiler.support#node-class */
t8=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=t4;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k18613 in k18595 in k18592 in k18685 in k18574 in k18571 in k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in ... */
static void C_fcall f_18615(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_18615,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18628,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2481: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[527]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k18626 in k18613 in k18595 in k18592 in k18685 in k18574 in k18571 in k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in ... */
static void C_ccall f_18628(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_18628,c,av);}
a=C_alloc(6);
t2=C_i_car(t1);
t3=C_i_cdr(((C_word*)t0)[2]);
t4=C_a_i_cons(&a,2,lf[580],t2);
t5=C_a_i_cons(&a,2,t4,t3);
t6=C_i_set_cdr(((C_word*)t0)[2],t5);
/* core.scm:2483: chicken.compiler.support#db-put! */
t7=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t7;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
av2[4]=lf[581];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t7+1)))(6,av2);}}

/* k18650 in k18654 in k18658 in k18595 in k18592 in k18685 in k18574 in k18571 in k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in ... */
static void C_ccall f_18652(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18652,c,av);}
t2=((C_word*)t0)[2];
f_18615(t2,C_eqp(((C_word*)t0)[3],C_i_car(t1)));}

/* k18654 in k18658 in k18595 in k18592 in k18685 in k18574 in k18571 in k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in ... */
static void C_ccall f_18656(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_18656,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[526],t1);
if(C_truep(t2)){
t3=C_i_car(((C_word*)t0)[2]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18652,a[2]=((C_word*)t0)[3],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* core.scm:2480: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];
f_18615(t3,C_SCHEME_FALSE);}}

/* k18658 in k18595 in k18592 in k18685 in k18574 in k18571 in k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in ... */
static void C_ccall f_18660(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_18660,c,av);}
a=C_alloc(5);
t2=C_eqp(lf[526],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18656,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2479: chicken.compiler.support#node-class */
t4=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[3];
f_18615(t3,C_SCHEME_FALSE);}}

/* k18679 in k18685 in k18574 in k18571 in k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_18681(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18681,c,av);}
t2=((C_word*)t0)[2];
f_18594(t2,C_eqp(lf[523],t1));}

/* k18685 in k18574 in k18571 in k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_18687(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_18687,c,av);}
a=C_alloc(10);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_18594,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[5]))){
if(C_truep(C_i_nullp(C_u_i_cdr(((C_word*)t0)[5])))){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18681,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2473: chicken.compiler.support#node-class */
t5=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=t3;
f_18594(t4,C_SCHEME_FALSE);}}
else{
t4=t3;
f_18594(t4,C_SCHEME_FALSE);}}

/* k18696 in k18565 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_18698(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18698,c,av);}
t2=((C_word*)t0)[2];
f_18573(t2,C_eqp(lf[97],t1));}

/* k18714 in k18770 in k18774 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_fcall f_18716(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,5)))){
C_save_and_reclaim_args((void *)trf_18716,2,t0,t1);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,lf[580],((C_word*)t0)[3]);
t4=C_a_i_cons(&a,2,t3,t2);
t5=C_i_set_cdr(((C_word*)t0)[2],t4);
/* core.scm:2462: chicken.compiler.support#db-put! */
t6=*((C_word*)lf[538]+1);{
C_word av2[6];
av2[0]=t6;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[581];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t6+1)))(6,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_18567(2,av2);}}}

/* k18726 in k18770 in k18774 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_18728(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_18728,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=((C_word*)t0)[2];
f_18716(t2,t1);}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18758,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2457: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[556];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k18748 in k18752 in k18756 in k18726 in k18770 in k18774 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_18750(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18750,c,av);}
t2=((C_word*)t0)[2];
f_18716(t2,C_i_not(t1));}

/* k18752 in k18756 in k18726 in k18770 in k18774 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_18754(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_18754,c,av);}
a=C_alloc(3);
t2=C_i_not(t1);
if(C_truep(t2)){
t3=((C_word*)t0)[2];
f_18716(t3,t2);}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18750,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2460: chicken.compiler.support#db-get */
t4=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[95];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}

/* k18756 in k18726 in k18770 in k18774 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_18758(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_18758,c,av);}
a=C_alloc(5);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18754,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2458: chicken.compiler.support#variable-visible? */
t3=*((C_word*)lf[574]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=*((C_word*)lf[25]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=((C_word*)t0)[2];
f_18716(t2,C_SCHEME_FALSE);}}

/* k18766 in k18770 in k18774 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_18768(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_18768,c,av);}
if(C_truep(C_i_not(t1))){
/* core.scm:2456: chicken.compiler.support#db-get */
t2=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[96];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_18728(2,av2);}}}

/* k18770 in k18774 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_18772(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_18772,c,av);}
a=C_alloc(16);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18716,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_not(((C_word*)((C_word*)t0)[5])[1]))){
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18728,a[2]=t3,a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18768,a[2]=t4,a[3]=((C_word*)t0)[4],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2455: chicken.compiler.support#db-get */
t6=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[4];
av2[3]=t2;
av2[4]=lf[546];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t4=t3;
f_18716(t4,C_SCHEME_FALSE);}}

/* k18774 in k18562 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_18776(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_18776,c,av);}
a=C_alloc(6);
t2=C_eqp(lf[526],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18772,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2453: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)((C_word*)t0)[6])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
f_18567(2,av2);}}}

/* k18795 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_18797(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_18797,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
if(C_truep(t1)){
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,lf[582],C_SCHEME_TRUE);
t4=C_a_i_cons(&a,2,t3,t2);
t5=((C_word*)t0)[3];
f_18564(t5,C_i_set_cdr(((C_word*)t0)[2],t4));}
else{
t2=((C_word*)t0)[3];
f_18564(t2,C_SCHEME_UNDEFINED);}}
else{
t2=((C_word*)((C_word*)t0)[4])[1];
if(C_truep(t2)){
if(C_truep(t2)){
t3=C_i_cdr(((C_word*)t0)[2]);
t4=C_a_i_cons(&a,2,lf[582],C_SCHEME_TRUE);
t5=C_a_i_cons(&a,2,t4,t3);
t6=((C_word*)t0)[3];
f_18564(t6,C_i_set_cdr(((C_word*)t0)[2],t5));}
else{
t3=((C_word*)t0)[3];
f_18564(t3,C_SCHEME_UNDEFINED);}}
else{
t3=((C_word*)((C_word*)t0)[5])[1];
if(C_truep(t3)){
t4=C_i_cdr(((C_word*)t0)[2]);
t5=C_a_i_cons(&a,2,lf[582],C_SCHEME_TRUE);
t6=C_a_i_cons(&a,2,t5,t4);
t7=((C_word*)t0)[3];
f_18564(t7,C_i_set_cdr(((C_word*)t0)[2],t6));}
else{
t4=((C_word*)t0)[3];
f_18564(t4,C_SCHEME_UNDEFINED);}}}}

/* k18819 in k18829 in k18833 in k18844 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_18821(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_18821,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
f_18797(2,av2);}}
else{
/* core.scm:2434: chicken.compiler.support#intrinsic? */
t2=*((C_word*)lf[583]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}}

/* k18829 in k18833 in k18844 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_18831(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_18831,c,av);}
a=C_alloc(4);
t2=C_i_not(t1);
if(C_truep(t2)){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
f_18797(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18821,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2433: chicken.compiler.support#variable-mark */
t4=*((C_word*)lf[185]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[584];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k18833 in k18844 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_18835(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_18835,c,av);}
a=C_alloc(4);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18831,a[2]=((C_word*)t0)[2],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:2432: chicken.compiler.support#db-get */
t4=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
av2[4]=lf[95];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k18840 in k18844 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_18842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18842,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_i_not(t1);
f_18797(2,av2);}}

/* k18844 in k18559 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_18846(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_18846,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[526],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18835,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2431: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)((C_word*)t0)[4])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18842,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2435: chicken.compiler.support#expression-has-side-effects? */
t4=*((C_word*)lf[585]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)((C_word*)t0)[4])[1];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_18855(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_18855,c,av);}
a=C_alloc(6);
if(C_truep(C_i_cadr(t1))){
t2=C_i_caddr(t1);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18870,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2404: ##sys#decompose-lambda-list */
t4=*((C_word*)lf[191]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[5];
av2[2]=t2;
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_18561(2,av2);}}}

/* a18869 in k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_18870(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_18870,c,av);}
a=C_alloc(18);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_18874,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t4,a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t4)){
t6=t5;{
C_word *av2=av;
av2[0]=t6;
av2[1]=C_SCHEME_UNDEFINED;
f_18874(2,av2);}}
else{
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18908,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t7=C_i_check_list_2(t2,lf[100]);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18941,a[2]=t9,a[3]=t6,tmp=(C_word)a,a+=4,tmp));
t11=((C_word*)t9)[1];
f_18941(t11,t5,t2);}}

/* k18872 in a18869 in k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_18874(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_18874,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18880,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)((C_word*)t0)[6])[1])){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18907,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2417: chicken.base#rassoc */
t4=*((C_word*)lf[589]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
av2[3]=lf[77];
av2[4]=*((C_word*)lf[590]+1);
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=t2;
f_18880(t3,C_SCHEME_FALSE);}}

/* k18878 in k18872 in a18869 in k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_fcall f_18880(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,5)))){
C_save_and_reclaim_args((void *)trf_18880,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
/* core.scm:2418: chicken.compiler.support#db-put! */
t2=*((C_word*)lf[538]+1);{
C_word av2[6];
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=C_i_car(((C_word*)t0)[4]);
av2[4]=lf[586];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}
else{
if(C_truep(((C_word*)t0)[5])){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18893,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2420: chicken.compiler.support#db-put! */
t3=*((C_word*)lf[538]+1);{
C_word av2[6];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=C_i_car(((C_word*)t0)[4]);
av2[4]=lf[588];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}}

/* k18891 in k18878 in k18872 in a18869 in k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_18893(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_18893,c,av);}
/* core.scm:2421: chicken.compiler.support#db-put! */
t2=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[587];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* k18905 in k18872 in a18869 in k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_18907(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18907,c,av);}
t2=((C_word*)t0)[2];
f_18880(t2,C_i_not(t1));}

/* g4193 in a18869 in k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_18908(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,4)))){
C_save_and_reclaim_args((void *)trf_18908,3,t0,t1,t2);}
a=C_alloc(11);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18915,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18933,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2410: chicken.compiler.support#db-get */
t5=*((C_word*)lf[540]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
av2[4]=lf[579];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* k18913 in g4193 in a18869 in k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_fcall f_18915(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,5)))){
C_save_and_reclaim_args((void *)trf_18915,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_18918,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2412: chicken.compiler.support#db-put! */
t3=*((C_word*)lf[538]+1);{
C_word av2[6];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[401];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k18916 in k18913 in g4193 in a18869 in k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_18918(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18918,c,av);}
t2=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_TRUE);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k18927 in k18931 in g4193 in a18869 in k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_18929(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_18929,c,av);}
t2=((C_word*)t0)[2];
f_18915(t2,C_i_not(t1));}

/* k18931 in g4193 in a18869 in k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_18933(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_18933,c,av);}
a=C_alloc(3);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_18929,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2411: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[556];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[2];
f_18915(t2,C_SCHEME_FALSE);}}

/* for-each-loop4192 in a18869 in k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_18941(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_18941,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18951,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2408: g4193 */
t4=((C_word*)t0)[3];
f_18908(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k18949 in for-each-loop4192 in a18869 in k18853 in k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_18951(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_18951,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_18941(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k18970 in k18556 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_18972(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_18972,c,av);}
a=C_alloc(6);
t2=C_eqp(lf[97],t1);
t3=(C_truep(t2)?C_i_nequalp(((C_word*)((C_word*)t0)[2])[1],((C_word*)((C_word*)t0)[3])[1]):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_18855,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2402: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)((C_word*)t0)[8])[1];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=C_SCHEME_UNDEFINED;
t5=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
f_18561(2,av2);}}}

/* k18973 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_18975(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_18975,2,t0,t1);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18997,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2387: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[527]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[5])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[3];
f_18558(t2,C_SCHEME_UNDEFINED);}}

/* k18982 in k18995 in k18973 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_18984(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_18984,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
if(C_truep(t1)){
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,lf[591],C_SCHEME_TRUE);
t4=C_a_i_cons(&a,2,t3,t2);
t5=((C_word*)t0)[3];
f_18558(t5,C_i_set_cdr(((C_word*)t0)[2],t4));}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];
f_18558(t3,t2);}}
else{
if(C_truep(C_i_nequalp(C_fix(1),((C_word*)((C_word*)t0)[4])[1]))){
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,lf[591],C_SCHEME_TRUE);
t4=C_a_i_cons(&a,2,t3,t2);
t5=((C_word*)t0)[3];
f_18558(t5,C_i_set_cdr(((C_word*)t0)[2],t4));}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];
f_18558(t3,t2);}}}

/* k18995 in k18973 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_18997(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_18997,c,av);}
a=C_alloc(5);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_18984,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2388: chicken.compiler.support#collapsable-literal? */
t4=*((C_word*)lf[360]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19002 in k18553 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19004(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19004,c,av);}
t2=((C_word*)t0)[2];
f_18975(t2,C_eqp(lf[116],t1));}

/* k19005 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19007(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_19007,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19013,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19073,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2347: chicken.compiler.support#node-class */
t4=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)((C_word*)t0)[7])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19011 in k19005 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19013(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_19013,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_i_nequalp(C_fix(1),((C_word*)((C_word*)t0)[2])[1]);
t3=(C_truep(t2)?C_i_nequalp(C_fix(1),((C_word*)((C_word*)t0)[3])[1]):C_SCHEME_FALSE);
if(C_truep(t3)){
t4=C_i_cdr(((C_word*)t0)[4]);
t5=C_a_i_cons(&a,2,lf[592],C_SCHEME_TRUE);
t6=C_a_i_cons(&a,2,t5,t4);
t7=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_i_set_cdr(((C_word*)t0)[4],t6);
f_18555(2,av2);}}
else{
t4=C_i_cdr(((C_word*)t0)[4]);
t5=C_a_i_cons(&a,2,lf[593],C_SCHEME_TRUE);
t6=C_a_i_cons(&a,2,t5,t4);
t7=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t7;
av2[1]=C_i_set_cdr(((C_word*)t0)[4],t6);
f_18555(2,av2);}}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
f_18555(2,av2);}}}

/* a19044 in k19071 in k19005 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_19045(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19045,c,av);}
/* core.scm:2350: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=lf[95];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k19051 in k19071 in k19005 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_19053(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19053,c,av);}
/* core.scm:2349: every */
f_6643(((C_word*)t0)[2],((C_word*)t0)[3],t1);}

/* a19054 in k19071 in k19005 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_19055(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19055,c,av);}
/* core.scm:2351: chicken.compiler.support#scan-free-variables */
t2=*((C_word*)lf[594]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=*((C_word*)lf[25]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a19060 in k19071 in k19005 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_19061(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +0,c,1)))){
C_save_and_reclaim((void*)f_19061,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+0);
t2=C_build_rest(&a,c,2,av);
C_word t3;
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_list_ref(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k19071 in k19005 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19073(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_19073,c,av);}
a=C_alloc(12);
t2=C_eqp(lf[97],t1);
if(C_truep(t2)){
t3=C_i_cadr(((C_word*)t0)[2]);
t4=C_i_not(t3);
if(C_truep(t4)){
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
f_19013(2,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19045,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19053,a[2]=((C_word*)t0)[3],a[3]=t5,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19055,a[2]=((C_word*)t0)[5],tmp=(C_word)a,a+=3,tmp);
t8=(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_19061,tmp=(C_word)a,a+=2,tmp);
/* core.scm:2351: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t6;
av2[2]=t7;
av2[3]=t8;
C_call_with_values(4,av2);}}}
else{
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_19013(2,av2);}}}

/* k19077 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19079(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_19079,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19141,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2359: chicken.compiler.support#node-class */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* a19089 in k19139 in k19077 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_19090(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19090,c,av);}
/* core.scm:2360: chicken.compiler.support#scan-free-variables */
t2=*((C_word*)lf[594]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=*((C_word*)lf[25]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a19095 in k19139 in k19077 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_19096(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_19096,c,av);}
a=C_alloc(12);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19100,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19134,a[2]=t3,a[3]=((C_word*)t0)[3],a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2362: chicken.compiler.support#db-get */
t6=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[95];
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}

/* k19098 in a19095 in k19139 in k19077 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_19100(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_19100,2,t0,t1);}
a=C_alloc(10);
t2=C_i_cadr(((C_word*)t0)[2]);
t3=C_i_not(t2);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19109,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
if(C_truep(t3)){
if(C_truep(t3)){
t5=C_i_cdr(((C_word*)t0)[3]);
t6=C_a_i_cons(&a,2,lf[593],C_SCHEME_TRUE);
t7=C_a_i_cons(&a,2,t6,t5);
t8=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t8;
av2[1]=C_i_set_cdr(((C_word*)t0)[3],t7);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t5=C_SCHEME_UNDEFINED;
t6=((C_word*)t0)[4];{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}
else{
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19117,a[2]=((C_word*)t0)[5],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2366: every */
f_6643(t4,t5,((C_word*)t0)[6]);}}

/* k19107 in k19098 in a19095 in k19139 in k19077 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_19109(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_19109,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,lf[593],C_SCHEME_TRUE);
t4=C_a_i_cons(&a,2,t3,t2);
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_i_set_cdr(((C_word*)t0)[2],t4);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* a19116 in k19098 in a19095 in k19139 in k19077 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_19117(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19117,c,av);}
/* core.scm:2367: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=lf[95];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k19132 in a19095 in k19139 in k19077 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_19134(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_19134,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
if(C_truep(C_i_pairp(((C_word*)t0)[2]))){
t2=C_i_cdr(((C_word*)t0)[3]);
t3=C_a_i_cons(&a,2,lf[595],C_SCHEME_TRUE);
t4=C_a_i_cons(&a,2,t3,t2);
t5=((C_word*)t0)[4];
f_19100(t5,C_i_set_cdr(((C_word*)t0)[3],t4));}
else{
t2=((C_word*)t0)[4];
f_19100(t2,C_SCHEME_UNDEFINED);}}
else{
t2=((C_word*)t0)[4];
f_19100(t2,C_SCHEME_UNDEFINED);}}

/* k19139 in k19077 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19141(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_19141,c,av);}
a=C_alloc(9);
t2=C_eqp(lf[97],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19090,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19096,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2360: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[7];
av2[2]=t3;
av2[3]=t4;
C_call_with_values(4,av2);}}
else{
t3=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_18555(2,av2);}}}

/* k19142 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19144(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_19144,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19148,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2345: g4166 */
t3=t2;
f_19148(t3,((C_word*)t0)[5],t1);}
else{
t2=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_18555(2,av2);}}}

/* g4166 in k19142 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19148(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,2)))){
C_save_and_reclaim_args((void *)trf_19148,3,t0,t1,t2);}
a=C_alloc(7);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19155,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=t2,tmp=(C_word)a,a+=7,tmp);
/* core.scm:2372: chicken.compiler.support#node? */
t4=*((C_word*)lf[599]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19153 in g4166 in k19142 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_19155(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_19155,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
if(C_truep(((C_word*)((C_word*)t0)[2])[1])){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19161,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2374: chicken.compiler.support#debugging */
t3=*((C_word*)lf[596]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[597];
av2[3]=lf[598];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19167,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2380: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}
else{
t2=C_SCHEME_UNDEFINED;
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k19159 in k19153 in g4166 in k19142 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_19161(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19161,c,av);}
/* core.scm:2378: chicken.compiler.support#mark-variable */
t2=*((C_word*)lf[158]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[410];
av2[4]=lf[408];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k19165 in k19153 in g4166 in k19142 in k18550 in k18547 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_19167(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_19167,c,av);}
a=C_alloc(12);
t2=C_i_cdr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,lf[593],C_SCHEME_TRUE);
t4=C_a_i_cons(&a,2,t3,t2);
t5=C_i_set_cdr(((C_word*)t0)[2],t4);
t6=C_i_cdr(((C_word*)t0)[2]);
t7=C_a_i_cons(&a,2,lf[573],((C_word*)t0)[3]);
t8=C_a_i_cons(&a,2,t7,t6);
t9=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t9;
av2[1]=C_i_set_cdr(((C_word*)t0)[2],t8);
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}

/* k19183 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19185(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_19185,2,t0,t1);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19192,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2334: chicken.base#open-output-string */
t3=*((C_word*)lf[131]+1);{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_18549(2,av2);}}}

/* k19190 in k19183 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19192(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_19192,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19198,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2334: ##sys#print */
t4=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[602];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k19196 in k19190 in k19183 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19198(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_19198,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19201,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2334: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k19199 in k19196 in k19190 in k19183 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19201(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_19201,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19204,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2334: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[601];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k19202 in k19199 in k19196 in k19190 in k19183 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_19204(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_19204,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19207,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2334: chicken.base#get-output-string */
t3=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k19205 in k19202 in k19199 in k19196 in k19190 in k19183 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_19207(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19207,c,av);}
/* core.scm:2333: ##sys#notice */
t2=*((C_word*)lf[369]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k19239 in k19243 in k19247 in k19251 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19241(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19241,c,av);}
t2=((C_word*)t0)[2];
f_19185(t2,C_i_not(t1));}

/* k19243 in k19247 in k19251 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19245(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_19245,c,av);}
a=C_alloc(3);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19241,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2332: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[185]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=lf[354];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=((C_word*)t0)[2];
f_19185(t2,C_SCHEME_FALSE);}}

/* k19247 in k19251 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19249(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_19249,c,av);}
a=C_alloc(4);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19245,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2331: chicken.compiler.support#variable-visible? */
t3=*((C_word*)lf[574]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=*((C_word*)lf[25]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=((C_word*)t0)[2];
f_19185(t2,C_SCHEME_FALSE);}}

/* k19251 in k18544 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19253(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_19253,c,av);}
a=C_alloc(4);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19249,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2330: chicken.compiler.support#variable-hidden? */
t3=*((C_word*)lf[603]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[2];
f_19185(t2,C_SCHEME_FALSE);}}

/* k19257 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19259(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_19259,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19263,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t3=C_i_check_list_2(t1,lf[100]);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19293,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_19293(t7,((C_word*)t0)[3],t1);}
else{
t2=((C_word*)t0)[3];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_18546(2,av2);}}}

/* g4105 in k19257 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19263(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_19263,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19285,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2320: chicken.compiler.support#node-class */
t4=*((C_word*)lf[98]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k19279 in k19283 in g4105 in k19257 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19281(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19281,c,av);}
/* core.scm:2321: chicken.compiler.support#set-real-name! */
t2=*((C_word*)lf[115]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_i_car(t1);
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k19283 in g4105 in k19257 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19285(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_19285,c,av);}
a=C_alloc(4);
t2=C_eqp(t1,lf[97]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19281,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2321: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* for-each-loop4104 in k19257 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19293(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_19293,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19303,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2318: g4105 */
t4=((C_word*)t0)[3];
f_19263(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k19301 in for-each-loop4104 in k19257 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19303(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19303,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_19293(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* for-each-loop4065 in a18396 in k18385 in k18382 in k18378 in k17304 in chicken.compiler.core#analyze-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static C_word C_fcall f_19328(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_pairp(t1))){
t2=(
/* core.scm:2288: g4066 */
  f_18403(((C_word*)t0)[2],C_slot(t1,C_fix(0)))
);
t4=C_slot(t1,C_fix(1));
t1=t4;
goto loop;}
else{
t2=C_SCHEME_UNDEFINED;
return(t2);}}

/* chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19355(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(58,c,5)))){
C_save_and_reclaim((void *)f_19355,c,av);}
a=C_alloc(58);
t4=C_fix(0);
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_SCHEME_END_OF_LIST;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_END_OF_LIST;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_SCHEME_UNDEFINED;
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=C_SCHEME_UNDEFINED;
t19=(*a=C_VECTOR_TYPE|1,a[1]=t18,tmp=(C_word)a,a+=2,tmp);
t20=C_SCHEME_UNDEFINED;
t21=(*a=C_VECTOR_TYPE|1,a[1]=t20,tmp=(C_word)a,a+=2,tmp);
t22=C_SCHEME_UNDEFINED;
t23=(*a=C_VECTOR_TYPE|1,a[1]=t22,tmp=(C_word)a,a+=2,tmp);
t24=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19358,a[2]=t3,tmp=(C_word)a,a+=3,tmp));
t25=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19364,a[2]=t7,a[3]=t3,tmp=(C_word)a,a+=4,tmp));
t26=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19374,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t27=C_set_block_item(t17,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19383,a[2]=t9,a[3]=t17,a[4]=t13,a[5]=t15,a[6]=t11,a[7]=t3,tmp=(C_word)a,a+=8,tmp));
t28=C_set_block_item(t19,0,(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19914,a[2]=t11,a[3]=t23,a[4]=t19,a[5]=t21,a[6]=t3,tmp=(C_word)a,a+=7,tmp));
t29=C_set_block_item(t21,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21100,a[2]=t19,tmp=(C_word)a,a+=3,tmp));
t30=C_set_block_item(t23,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21151,tmp=(C_word)a,a+=2,tmp));
t31=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21192,a[2]=t1,a[3]=t5,a[4]=t19,a[5]=t2,a[6]=t7,a[7]=t17,tmp=(C_word)a,a+=8,tmp);
/* core.scm:2783: chicken.compiler.support#debugging */
t32=*((C_word*)lf[596]+1);{
C_word *av2=av;
av2[0]=t32;
av2[1]=t31;
av2[2]=lf[604];
av2[3]=lf[647];
((C_proc)(void*)(*((C_word*)t32+1)))(4,av2);}}

/* test in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19358(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_19358,4,t0,t1,t2,t3);}
/* core.scm:2505: chicken.compiler.support#db-get */
t4=*((C_word*)lf[540]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=t2;
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* register-customizable! in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19364(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_19364,4,t0,t1,t2,t3);}
a=C_alloc(9);
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19369,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2508: lset-adjoin/eq? */
f_7102(t4,((C_word*)((C_word*)t0)[2])[1],C_a_i_list(&a,1,t2));}

/* k19367 in register-customizable! in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19369(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_19369,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
/* core.scm:2509: chicken.compiler.support#db-put! */
t3=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[608];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* register-direct-call! in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19374(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(35,0,3)))){
C_save_and_reclaim_args((void *)trf_19374,3,t0,t1,t2);}
a=C_alloc(35);
t3=((C_word*)((C_word*)t0)[2])[1];
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_s_a_i_plus(&a,2,t3,C_fix(1)));
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19381,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2513: lset-adjoin/eq? */
f_7102(t5,lf[68],C_a_i_list(&a,1,t2));}

/* k19379 in register-direct-call! in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19381(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19381,c,av);}
t2=C_mutate(&lf[68] /* (set! chicken.compiler.core#direct-call-ids ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19383(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_19383,5,t0,t1,t2,t3,t4);}
a=C_alloc(12);
t5=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_19387,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,a[5]=((C_word*)t0)[3],a[6]=t3,a[7]=t2,a[8]=((C_word*)t0)[4],a[9]=((C_word*)t0)[5],a[10]=((C_word*)t0)[6],a[11]=((C_word*)t0)[7],tmp=(C_word)a,a+=12,tmp);
/* core.scm:2519: chicken.compiler.support#node-subexpressions */
t6=*((C_word*)lf[530]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19387(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_19387,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_19390,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* core.scm:2520: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19390(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_19390,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_19393,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* core.scm:2521: chicken.compiler.support#node-class */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19393(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_19393,c,av);}
a=C_alloc(15);
t2=C_eqp(t1,lf[526]);
t3=(C_truep(t2)?t2:C_eqp(t1,lf[537]));
if(C_truep(t3)){
t4=C_i_car(((C_word*)t0)[2]);
t5=C_i_memq(t4,((C_word*)((C_word*)t0)[3])[1]);
t6=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t6;
av2[1]=(C_truep(t5)?C_a_i_list1(&a,1,t4):C_SCHEME_END_OF_LIST);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t4=C_eqp(t1,lf[116]);
t5=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_19423,a[2]=((C_word*)t0)[4],a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[3],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],tmp=(C_word)a,a+=15,tmp);
if(C_truep(t4)){
t6=t5;
f_19423(t6,t4);}
else{
t6=C_eqp(t1,lf[478]);
if(C_truep(t6)){
t7=t5;
f_19423(t7,t6);}
else{
t7=C_eqp(t1,lf[162]);
if(C_truep(t7)){
t8=t5;
f_19423(t8,t7);}
else{
t8=C_eqp(t1,lf[564]);
t9=t5;
f_19423(t9,(C_truep(t8)?t8:C_eqp(t1,lf[477])));}}}}}

/* k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19423(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,5)))){
C_save_and_reclaim_args((void *)trf_19423,2,t0,t1);}
a=C_alloc(21);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_eqp(((C_word*)t0)[3],lf[174]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19432,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
t4=C_i_cdr(((C_word*)t0)[4]);
if(C_truep(C_i_pairp(t4))){
/* core.scm:2534: chicken.compiler.support#bomb */
t5=*((C_word*)lf[533]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t3;
av2[2]=lf[609];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t5=t3;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_19432(2,av2);}}}
else{
t3=C_eqp(((C_word*)t0)[3],lf[286]);
if(C_truep(t3)){
t4=C_i_car(((C_word*)t0)[4]);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19483,a[2]=t4,a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2541: gather */
t6=((C_word*)((C_word*)t0)[7])[1];
f_19383(t6,t5,C_i_car(((C_word*)t0)[5]),((C_word*)t0)[8],((C_word*)t0)[6]);}
else{
t4=C_eqp(((C_word*)t0)[3],lf[523]);
if(C_truep(t4)){
t5=C_i_car(((C_word*)t0)[5]);
t6=C_i_car(((C_word*)t0)[4]);
t7=C_i_cdr(((C_word*)t0)[4]);
t8=C_i_pairp(t7);
t9=(C_truep(t8)?C_i_cadr(((C_word*)t0)[4]):C_SCHEME_FALSE);
t10=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_19731,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[2],a[7]=t9,a[8]=t6,a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=t5,tmp=(C_word)a,a+=14,tmp);
/* core.scm:2550: chicken.compiler.support#node-class */
t11=*((C_word*)lf[98]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t10;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t5=C_eqp(((C_word*)t0)[3],lf[97]);
t6=(C_truep(t5)?t5:C_eqp(((C_word*)t0)[3],lf[548]));
if(C_truep(t6)){
t7=C_i_caddr(((C_word*)t0)[4]);
t8=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_19759,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[14],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[5],tmp=(C_word)a,a+=9,tmp);
/* core.scm:2591: ##sys#decompose-lambda-list */
t9=*((C_word*)lf[191]+1);{
C_word av2[4];
av2[0]=t9;
av2[1]=((C_word*)t0)[2];
av2[2]=t7;
av2[3]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(4,av2);}}
else{
t7=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t8=t7;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=((C_word*)t9)[1];
t11=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19817,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
t12=C_i_check_list_2(((C_word*)t0)[5],lf[10]);
t13=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19827,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19829,a[2]=t9,a[3]=t15,a[4]=t11,a[5]=t10,tmp=(C_word)a,a+=6,tmp));
t17=((C_word*)t15)[1];
f_19829(t17,t13,((C_word*)t0)[5]);}}}}}}

/* k19430 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19432(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_19432,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19435,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2535: gather */
t3=((C_word*)((C_word*)t0)[6])[1];
f_19383(t3,t2,C_i_car(((C_word*)t0)[4]),((C_word*)t0)[7],((C_word*)t0)[5]);}

/* k19433 in k19430 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19435(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,4)))){
C_save_and_reclaim((void *)f_19435,c,av);}
a=C_alloc(11);
t2=C_i_car(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19445,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19449,a[2]=t3,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t5=C_i_cadr(((C_word*)t0)[4]);
t6=C_a_i_cons(&a,2,t2,((C_word*)t0)[5]);
/* core.scm:2537: gather */
t7=((C_word*)((C_word*)t0)[6])[1];
f_19383(t7,t4,t5,((C_word*)t0)[7],t6);}

/* k19443 in k19433 in k19430 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19445(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19445,c,av);}
/* core.scm:2537: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k19447 in k19433 in k19430 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19449(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19449,c,av);}
/* core.scm:2537: delete */
f_6763(((C_word*)t0)[2],((C_word*)t0)[3],t1,*((C_word*)lf[590]+1));}

/* k19481 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19483(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_19483,c,av);}
a=C_alloc(3);
t2=C_i_memq(((C_word*)t0)[2],((C_word*)((C_word*)t0)[3])[1]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?C_a_i_cons(&a,2,((C_word*)t0)[2],t1):t1);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k19515 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19517(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,3)))){
C_save_and_reclaim((void *)f_19517,c,av);}
a=C_alloc(21);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19525,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t7=C_i_check_list_2(((C_word*)t0)[5],lf[10]);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19535,a[2]=((C_word*)t0)[6],tmp=(C_word)a,a+=3,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19537,a[2]=t4,a[3]=t10,a[4]=t6,a[5]=t5,tmp=(C_word)a,a+=6,tmp));
t12=((C_word*)t10)[1];
f_19537(t12,t8,((C_word*)t0)[5]);}

/* g4380 in k19515 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19525(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_19525,3,t0,t1,t2);}
/* core.scm:2588: gather */
t3=((C_word*)((C_word*)t0)[2])[1];
f_19383(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k19533 in k19515 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19535(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19535,c,av);}
/* core.scm:2588: concatenate */
f_6735(((C_word*)t0)[2],t1);}

/* map-loop4374 in k19515 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19537(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_19537,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19562,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2588: g4380 */
t4=((C_word*)t0)[4];
f_19525(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k19560 in map-loop4374 in k19515 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19562(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_19562,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_19537(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k19591 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19593(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,2)))){
C_save_and_reclaim((void *)f_19593,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_19599,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t1,tmp=(C_word)a,a+=12,tmp);
if(C_truep(t1)){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19679,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2567: chicken.compiler.support#node-class */
t4=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t2;
f_19599(t3,C_SCHEME_FALSE);}}

/* k19597 in k19591 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19599(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,3)))){
C_save_and_reclaim_args((void *)trf_19599,2,t0,t1);}
a=C_alloc(11);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_19602,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* core.scm:2568: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[527]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],C_SCHEME_END_OF_LIST);
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t2);
/* core.scm:2551: chicken.compiler.support#node-parameters-set! */
t4=*((C_word*)lf[610]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k19600 in k19597 in k19591 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19602(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_19602,c,av);}
a=C_alloc(13);
t2=C_i_caddr(t1);
t3=C_i_car(t1);
t4=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_19611,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t3,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=t2,a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[10],tmp=(C_word)a,a+=13,tmp);
/* core.scm:2571: test */
t5=((C_word*)((C_word*)t0)[10])[1];
f_19358(t5,t4,((C_word*)t0)[7],lf[579]);}

/* k19609 in k19600 in k19597 in k19591 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_19611(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_19611,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_19614,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t1,a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
/* core.scm:2572: test */
t3=((C_word*)((C_word*)t0)[12])[1];
f_19358(t3,t2,((C_word*)t0)[8],lf[99]);}

/* k19612 in k19609 in k19600 in k19597 in k19591 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_19614(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_19614,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_19617,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
if(C_truep(((C_word*)t0)[12])){
if(C_truep(t1)){
t3=C_i_length(((C_word*)t0)[12]);
t4=C_i_length(t1);
t5=C_eqp(t3,t4);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19661,a[2]=t2,a[3]=((C_word*)t0)[10],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2576: test */
t7=((C_word*)((C_word*)t0)[13])[1];
f_19358(t7,t6,((C_word*)t0)[8],lf[96]);}
else{
t6=t2;
f_19617(t6,C_SCHEME_FALSE);}}
else{
t3=t2;
f_19617(t3,C_SCHEME_FALSE);}}
else{
t3=t2;
f_19617(t3,C_SCHEME_FALSE);}}

/* k19615 in k19612 in k19609 in k19600 in k19597 in k19591 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_fcall f_19617(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,3)))){
C_save_and_reclaim_args((void *)trf_19617,2,t0,t1);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_19623,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
if(C_truep(((C_word*)t0)[2])){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19642,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2579: chicken.compiler.support#llist-match? */
t4=*((C_word*)lf[545]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[10];
av2[3]=C_i_cdr(((C_word*)t0)[11]);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t3=t2;
f_19623(t3,C_SCHEME_FALSE);}}

/* k19621 in k19615 in k19612 in k19609 in k19600 in k19597 in k19591 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_19623(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_19623,2,t0,t1);}
a=C_alloc(10);
if(C_truep(t1)){
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],C_SCHEME_END_OF_LIST);
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t2);
/* core.scm:2551: chicken.compiler.support#node-parameters-set! */
t4=*((C_word*)lf[610]+1);{
C_word av2[4];
av2[0]=t4;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_19626,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:2582: register-direct-call! */
t3=((C_word*)((C_word*)t0)[10])[1];
f_19374(t3,t2,((C_word*)t0)[6]);}}

/* k19624 in k19621 in k19615 in k19612 in k19609 in k19600 in k19597 in k19591 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_19626(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,3)))){
C_save_and_reclaim((void *)f_19626,c,av);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19629,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep(((C_word*)t0)[3])){
/* core.scm:2583: register-customizable! */
t3=((C_word*)((C_word*)t0)[8])[1];
f_19364(t3,t2,((C_word*)t0)[9],((C_word*)t0)[2]);}
else{
t3=C_a_i_list2(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t4=C_a_i_cons(&a,2,((C_word*)t0)[4],t3);
t5=C_a_i_cons(&a,2,((C_word*)t0)[5],t4);
/* core.scm:2551: chicken.compiler.support#node-parameters-set! */
t6=*((C_word*)lf[610]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[6];
av2[2]=((C_word*)t0)[7];
av2[3]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}

/* k19627 in k19624 in k19621 in k19615 in k19612 in k19609 in k19600 in k19597 in k19591 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_19629(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,3)))){
C_save_and_reclaim((void *)f_19629,c,av);}
a=C_alloc(12);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=C_a_i_cons(&a,2,((C_word*)t0)[4],t2);
t4=C_a_i_cons(&a,2,((C_word*)t0)[5],t3);
/* core.scm:2551: chicken.compiler.support#node-parameters-set! */
t5=*((C_word*)lf[610]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[6];
av2[2]=((C_word*)t0)[7];
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k19640 in k19615 in k19612 in k19609 in k19600 in k19597 in k19591 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_19642(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19642,c,av);}
t2=((C_word*)t0)[2];
f_19623(t2,C_i_not(t1));}

/* k19659 in k19612 in k19609 in k19600 in k19597 in k19591 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_19661(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19661,c,av);}
t2=((C_word*)t0)[2];
f_19617(t2,(C_truep(t1)?C_i_listp(((C_word*)t0)[3]):C_SCHEME_FALSE));}

/* k19677 in k19591 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19679(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19679,c,av);}
t2=((C_word*)t0)[2];
f_19599(t2,C_eqp(lf[97],t1));}

/* k19695 in k19705 in k19717 in k19721 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_19697(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_19697,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
f_19593(2,av2);}}
else{
/* core.scm:2566: test */
t2=((C_word*)((C_word*)t0)[3])[1];
f_19358(t2,((C_word*)t0)[2],((C_word*)t0)[4],lf[573]);}}

/* k19705 in k19717 in k19721 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19707(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_19707,c,av);}
a=C_alloc(5);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19697,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2565: test */
t3=((C_word*)((C_word*)t0)[3])[1];
f_19358(t3,t2,((C_word*)t0)[4],lf[96]);}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_19593(2,av2);}}}

/* k19709 in k19717 in k19721 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19711(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19711,c,av);}
/* core.scm:2564: chicken.compiler.support#node? */
t2=*((C_word*)lf[599]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k19717 in k19721 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19719(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_19719,c,av);}
a=C_alloc(8);
t2=C_eqp(lf[408],t1);
if(C_truep(C_i_not(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19707,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19711,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2564: chicken.compiler.support#variable-mark */
t5=*((C_word*)lf[185]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[410];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_19593(2,av2);}}}

/* k19721 in k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19723(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_19723,c,av);}
a=C_alloc(5);
if(C_truep(C_i_not(t1))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19719,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2561: chicken.compiler.support#variable-mark */
t3=*((C_word*)lf[185]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[407];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_19593(2,av2);}}}

/* k19725 in k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19727(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_19727,c,av);}
a=C_alloc(16);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_19593,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t2,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19723,a[2]=t3,a[3]=((C_word*)t0)[9],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2558: test */
t5=((C_word*)((C_word*)t0)[9])[1];
f_19358(t5,t4,t2,lf[546]);}

/* k19729 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19731(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_19731,c,av);}
a=C_alloc(17);
t2=C_eqp(lf[526],t1);
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19517,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t4=(C_truep(((C_word*)t0)[7])?((C_word*)t0)[7]:t2);
if(C_truep(t4)){
if(C_truep(t2)){
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_19727,a[2]=((C_word*)t0)[7],a[3]=((C_word*)t0)[8],a[4]=t3,a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[12],tmp=(C_word)a,a+=10,tmp);
/* core.scm:2557: chicken.compiler.support#node-parameters */
t6=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[13];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=C_a_i_cons(&a,2,((C_word*)t0)[7],C_SCHEME_END_OF_LIST);
t6=C_a_i_cons(&a,2,((C_word*)t0)[8],t5);
/* core.scm:2551: chicken.compiler.support#node-parameters-set! */
t7=*((C_word*)lf[610]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t3;
av2[2]=((C_word*)t0)[9];
av2[3]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}}
else{
t5=C_a_i_cons(&a,2,((C_word*)t0)[8],C_SCHEME_END_OF_LIST);
/* core.scm:2551: chicken.compiler.support#node-parameters-set! */
t6=*((C_word*)lf[610]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t6;
av2[1]=t3;
av2[2]=((C_word*)t0)[9];
av2[3]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(4,av2);}}}

/* a19758 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19759(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_19759,c,av);}
a=C_alloc(10);
t5=(C_truep(((C_word*)t0)[2])?C_i_car(((C_word*)t0)[3]):lf[611]);
t6=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_19766,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t2,a[5]=((C_word*)t0)[6],a[6]=t5,a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,tmp=(C_word)a,a+=10,tmp);
/* core.scm:2595: scheme#append */
t7=*((C_word*)lf[5]+1);{
C_word *av2=av;
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)((C_word*)t0)[4])[1];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k19764 in a19758 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19766(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,4)))){
C_save_and_reclaim((void *)f_19766,c,av);}
a=C_alloc(22);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19771,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19776,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19803,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2595: ##sys#dynamic-wind */
t9=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[9];
av2[2]=t6;
av2[3]=t7;
av2[4]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* a19770 in k19764 in a19758 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19771(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19771,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a19775 in k19764 in a19758 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19776(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_19776,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_19780,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_19797,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2596: gather */
t4=((C_word*)((C_word*)t0)[6])[1];
f_19383(t4,t3,C_i_car(((C_word*)t0)[7]),((C_word*)t0)[5],((C_word*)t0)[3]);}

/* k19778 in a19775 in k19764 in a19758 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19780(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,5)))){
C_save_and_reclaim((void *)f_19780,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_19783,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2597: chicken.compiler.support#db-put! */
t3=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=((C_word*)t0)[6];
av2[4]=lf[613];
av2[5]=C_i_length(t1);
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* k19781 in k19778 in a19775 in k19764 in a19758 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19783(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,5)))){
C_save_and_reclaim((void *)f_19783,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19786,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2598: chicken.compiler.support#db-put! */
t3=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[7];
av2[4]=lf[612];
av2[5]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}

/* k19784 in k19781 in k19778 in a19775 in k19764 in a19758 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_19786(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_19786,c,av);}
a=C_alloc(6);
/* core.scm:2599: lset-difference/eq? */
f_7143(((C_word*)t0)[2],((C_word*)t0)[3],C_a_i_list(&a,2,((C_word*)t0)[4],((C_word*)t0)[5]));}

/* k19795 in a19775 in k19764 in a19758 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19797(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_19797,c,av);}
a=C_alloc(6);
t2=*((C_word*)lf[590]+1);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6844,a[2]=t4,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t6=((C_word*)t4)[1];
f_6844(t6,((C_word*)t0)[2],t1);}

/* a19802 in k19764 in a19758 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19803(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_19803,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* g4428 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19817(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_19817,3,t0,t1,t2);}
/* core.scm:2601: gather */
t3=((C_word*)((C_word*)t0)[2])[1];
f_19383(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* k19825 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19827(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_19827,c,av);}
/* core.scm:2601: concatenate */
f_6735(((C_word*)t0)[2],t1);}

/* map-loop4422 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19829(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_19829,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19854,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2601: g4428 */
t4=((C_word*)t0)[4];
f_19817(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k19852 in map-loop4422 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19854(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_19854,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_19829(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19914(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_19914,5,t0,t1,t2,t3,t4);}
a=C_alloc(11);
t5=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_19918,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=t3,a[7]=t4,a[8]=((C_word*)t0)[4],a[9]=((C_word*)t0)[5],a[10]=((C_word*)t0)[6],tmp=(C_word)a,a+=11,tmp);
/* core.scm:2605: chicken.compiler.support#node-subexpressions */
t6=*((C_word*)lf[530]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19918(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_19918,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_19921,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
/* core.scm:2606: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19921(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_19921,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_19924,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* core.scm:2607: chicken.compiler.support#node-class */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19924(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_19924,c,av);}
a=C_alloc(14);
t2=C_eqp(t1,lf[116]);
t3=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_19933,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
if(C_truep(t2)){
t4=t3;
f_19933(t4,t2);}
else{
t4=C_eqp(t1,lf[478]);
if(C_truep(t4)){
t5=t3;
f_19933(t5,t4);}
else{
t5=C_eqp(t1,lf[162]);
if(C_truep(t5)){
t6=t3;
f_19933(t6,t5);}
else{
t6=C_eqp(t1,lf[564]);
if(C_truep(t6)){
t7=t3;
f_19933(t7,t6);}
else{
t7=C_eqp(t1,lf[641]);
t8=t3;
f_19933(t8,(C_truep(t7)?t7:C_eqp(t1,lf[642])));}}}}}

/* k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19933(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,4)))){
C_save_and_reclaim_args((void *)trf_19933,2,t0,t1);}
a=C_alloc(14);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[526]);
if(C_truep(t2)){
t3=C_i_car(((C_word*)t0)[5]);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_19945,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[6],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2616: ref-var */
f_21151(t4,((C_word*)t0)[3],((C_word*)t0)[8],((C_word*)t0)[9]);}
else{
t3=C_eqp(((C_word*)t0)[4],lf[537]);
t4=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_19967,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[10],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[6],a[13]=((C_word*)t0)[13],tmp=(C_word)a,a+=14,tmp);
if(C_truep(t3)){
t5=t4;
f_19967(t5,t3);}
else{
t5=C_eqp(((C_word*)t0)[4],lf[639]);
if(C_truep(t5)){
t6=t4;
f_19967(t6,t5);}
else{
t6=C_eqp(((C_word*)t0)[4],lf[568]);
t7=t4;
f_19967(t7,(C_truep(t6)?t6:C_eqp(((C_word*)t0)[4],lf[640])));}}}}}

/* k19943 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19945(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_19945,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_19951,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2617: test */
t3=((C_word*)((C_word*)t0)[3])[1];
f_19358(t3,t2,((C_word*)t0)[4],lf[600]);}

/* k19949 in k19943 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19951(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_19951,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=C_a_i_list1(&a,1,((C_word*)t0)[2]);
/* core.scm:2618: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[614];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_19967(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,4)))){
C_save_and_reclaim_args((void *)trf_19967,2,t0,t1);}
a=C_alloc(14);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_19970,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* core.scm:2622: ref-var */
f_21151(t2,((C_word*)t0)[8],((C_word*)t0)[5],((C_word*)t0)[6]);}
else{
t2=C_eqp(((C_word*)t0)[2],lf[142]);
t3=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_20053,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[11],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[2],a[10]=((C_word*)t0)[3],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[9],a[13]=((C_word*)t0)[13],tmp=(C_word)a,a+=14,tmp);
if(C_truep(t2)){
t4=t3;
f_20053(t4,t2);}
else{
t4=C_eqp(((C_word*)t0)[2],lf[523]);
if(C_truep(t4)){
t5=t3;
f_20053(t5,t4);}
else{
t5=C_eqp(((C_word*)t0)[2],lf[302]);
if(C_truep(t5)){
t6=t3;
f_20053(t6,t5);}
else{
t6=C_eqp(((C_word*)t0)[2],lf[303]);
if(C_truep(t6)){
t7=t3;
f_20053(t7,t6);}
else{
t7=C_eqp(((C_word*)t0)[2],lf[163]);
if(C_truep(t7)){
t8=t3;
f_20053(t8,t7);}
else{
t8=C_eqp(((C_word*)t0)[2],lf[117]);
if(C_truep(t8)){
t9=t3;
f_20053(t9,t8);}
else{
t9=C_eqp(((C_word*)t0)[2],lf[282]);
if(C_truep(t9)){
t10=t3;
f_20053(t10,t9);}
else{
t10=C_eqp(((C_word*)t0)[2],lf[188]);
if(C_truep(t10)){
t11=t3;
f_20053(t11,t10);}
else{
t11=C_eqp(((C_word*)t0)[2],lf[632]);
if(C_truep(t11)){
t12=t3;
f_20053(t12,t11);}
else{
t12=C_eqp(((C_word*)t0)[2],lf[633]);
if(C_truep(t12)){
t13=t3;
f_20053(t13,t12);}
else{
t13=C_eqp(((C_word*)t0)[2],lf[634]);
if(C_truep(t13)){
t14=t3;
f_20053(t14,t13);}
else{
t14=C_eqp(((C_word*)t0)[2],lf[541]);
if(C_truep(t14)){
t15=t3;
f_20053(t15,t14);}
else{
t15=C_eqp(((C_word*)t0)[2],lf[635]);
if(C_truep(t15)){
t16=t3;
f_20053(t16,t15);}
else{
t16=C_eqp(((C_word*)t0)[2],lf[636]);
if(C_truep(t16)){
t17=t3;
f_20053(t17,t16);}
else{
t17=C_eqp(((C_word*)t0)[2],lf[637]);
if(C_truep(t17)){
t18=t3;
f_20053(t18,t17);}
else{
t18=C_eqp(((C_word*)t0)[2],lf[638]);
if(C_truep(t18)){
t19=t3;
f_20053(t19,t18);}
else{
t19=C_eqp(((C_word*)t0)[2],lf[121]);
t20=t3;
f_20053(t20,(C_truep(t19)?t19:C_eqp(((C_word*)t0)[2],lf[285])));}}}}}}}}}}}}}}}}}}

/* k19968 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19970(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_19970,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_19973,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
t3=C_eqp(t1,((C_word*)t0)[8]);
if(C_truep(t3)){
/* core.scm:2623: chicken.compiler.support#varnode */
t4=*((C_word*)lf[524]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=C_i_car(((C_word*)t0)[7]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
f_19973(2,av2);}}}

/* k19971 in k19968 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19973(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(36,c,4)))){
C_save_and_reclaim((void *)f_19973,c,av);}
a=C_alloc(36);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_19976,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
t3=C_eqp(((C_word*)t0)[8],((C_word*)t0)[9]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20012,a[2]=t2,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
if(C_truep(t3)){
if(C_truep(t3)){
t5=t2;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_19976(2,av2);}}
else{
/* core.scm:2627: chicken.compiler.support#bomb */
t5=*((C_word*)lf[533]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=lf[616];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}}
else{
t5=C_a_i_list(&a,1,lf[597]);
t6=C_a_i_list(&a,1,((C_word*)t0)[5]);
t7=C_a_i_list(&a,2,lf[526],t6);
t8=C_a_i_list(&a,3,lf[617],t5,t7);
/* core.scm:2625: chicken.compiler.support#match-node */
t9=*((C_word*)lf[576]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=t4;
av2[2]=((C_word*)t0)[8];
av2[3]=t8;
av2[4]=lf[618];
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}}

/* k19974 in k19971 in k19968 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19976(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_19976,c,av);}
a=C_alloc(6);
t2=C_eqp(((C_word*)t0)[2],lf[537]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_19989,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2633: chicken.compiler.support#replace-rest-op-with-list-ops */
t4=*((C_word*)lf[615]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[7];
av2[4]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t3=C_eqp(((C_word*)t0)[9],((C_word*)t0)[10]);
if(C_truep(C_i_not(t3))){
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20002,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2638: chicken.compiler.support#replace-rest-op-with-list-ops */
t5=*((C_word*)lf[615]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[2];
av2[3]=((C_word*)t0)[7];
av2[4]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}}

/* k19987 in k19974 in k19971 in k19968 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_19989(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_19989,c,av);}
/* core.scm:2633: transform */
t2=((C_word*)((C_word*)t0)[2])[1];
f_19914(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k20000 in k19974 in k19971 in k19968 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20002(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_20002,c,av);}
/* core.scm:2638: transform */
t2=((C_word*)((C_word*)t0)[2])[1];
f_19914(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k20010 in k19971 in k19968 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20012(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20012,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_19976(2,av2);}}
else{
/* core.scm:2627: chicken.compiler.support#bomb */
t2=*((C_word*)lf[533]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[616];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_20053(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,5)))){
C_save_and_reclaim_args((void *)trf_20053,2,t0,t1);}
a=C_alloc(14);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20060,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2648: chicken.compiler.support#node-class */
t3=*((C_word*)lf[98]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=C_eqp(((C_word*)t0)[9],lf[174]);
if(C_truep(t2)){
t3=C_i_car(((C_word*)t0)[3]);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_20076,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[4],tmp=(C_word)a,a+=10,tmp);
/* core.scm:2652: test */
t5=((C_word*)((C_word*)t0)[11])[1];
f_19358(t5,t4,t3,lf[600]);}
else{
t3=C_eqp(((C_word*)t0)[9],lf[97]);
t4=(C_truep(t3)?t3:C_eqp(((C_word*)t0)[9],lf[548]));
if(C_truep(t4)){
t5=C_i_caddr(((C_word*)t0)[3]);
t6=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_20157,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[12],a[5]=((C_word*)t0)[7],a[6]=t5,a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[5],a[10]=((C_word*)t0)[13],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
/* core.scm:2668: ##sys#decompose-lambda-list */
t7=*((C_word*)lf[191]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=((C_word*)t0)[2];
av2[2]=t5;
av2[3]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t5=C_eqp(((C_word*)t0)[9],lf[286]);
if(C_truep(t5)){
t6=C_i_car(((C_word*)t0)[3]);
t7=C_i_car(((C_word*)t0)[5]);
t8=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_20671,a[2]=((C_word*)t0)[10],a[3]=t7,a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[11],a[7]=t6,a[8]=((C_word*)t0)[2],a[9]=((C_word*)t0)[3],tmp=(C_word)a,a+=10,tmp);
/* core.scm:2732: chicken.compiler.support#node-class */
t9=*((C_word*)lf[98]+1);{
C_word av2[3];
av2[0]=t9;
av2[1]=t8;
av2[2]=t7;
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}
else{
t6=C_eqp(((C_word*)t0)[9],lf[477]);
if(C_truep(t6)){
t7=(C_truep(*((C_word*)lf[41]+1))?C_a_i_list1(&a,1,C_fix(2)):C_a_i_list1(&a,1,C_fix(1)));
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20846,a[2]=((C_word*)t0)[2],a[3]=t7,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t9=C_i_car(((C_word*)t0)[3]);
t10=C_a_i_list2(&a,2,t9,C_SCHEME_TRUE);
/* core.scm:2763: chicken.compiler.support#make-node */
t11=*((C_word*)lf[489]+1);{
C_word av2[5];
av2[0]=t11;
av2[1]=t8;
av2[2]=lf[564];
av2[3]=t10;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t11+1)))(5,av2);}}
else{
t7=C_eqp(((C_word*)t0)[9],lf[617]);
if(C_truep(t7)){
t8=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t8;
av2[1]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
/* core.scm:2770: chicken.compiler.support#bomb */
t8=*((C_word*)lf[533]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[631];
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}}}}}}}

/* k20058 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20060(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_20060,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20064,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2648: maptransform */
t3=((C_word*)((C_word*)t0)[4])[1];
f_21100(t3,t2,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k20062 in k20058 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20064(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_20064,c,av);}
/* core.scm:2648: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k20074 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20076(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_20076,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_20079,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* core.scm:2653: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k20077 in k20074 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20079(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,4)))){
C_save_and_reclaim((void *)f_20079,c,av);}
a=C_alloc(13);
if(C_truep(((C_word*)t0)[2])){
t2=C_a_i_list1(&a,1,t1);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_20097,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,tmp=(C_word)a,a+=10,tmp);
/* core.scm:2657: transform */
t4=((C_word*)((C_word*)t0)[5])[1];
f_19914(t4,t3,C_i_car(((C_word*)t0)[6]),((C_word*)t0)[7],((C_word*)t0)[8]);}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20140,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[9],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2664: maptransform */
t3=((C_word*)((C_word*)t0)[10])[1];
f_21100(t3,t2,((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}}

/* k20095 in k20077 in k20074 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20097(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_20097,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20101,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_a_i_list1(&a,1,((C_word*)t0)[4]);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20113,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20129,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2660: chicken.compiler.support#varnode */
t6=*((C_word*)lf[524]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k20099 in k20095 in k20077 in k20074 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_20101(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20101,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:2655: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[174];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20111 in k20095 in k20077 in k20074 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_20113(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_20113,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20117,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2661: transform */
t3=((C_word*)((C_word*)t0)[4])[1];
f_19914(t3,t2,C_i_cadr(((C_word*)t0)[5]),((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k20115 in k20111 in k20095 in k20077 in k20074 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_20117(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20117,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:2658: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[174];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20127 in k20095 in k20077 in k20074 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_20129(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_20129,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:2660: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[619];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20138 in k20077 in k20074 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20140(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_20140,c,av);}
/* core.scm:2662: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[174];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20157(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,3)))){
C_save_and_reclaim((void *)f_20157,c,av);}
a=C_alloc(19);
t5=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_20161,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=t2,a[12]=t4,a[13]=t3,a[14]=((C_word*)t0)[10],a[15]=((C_word*)t0)[11],tmp=(C_word)a,a+=16,tmp);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20652,a[2]=((C_word*)t0)[11],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2671: filter */
f_6883(t5,t6,t2);}

/* k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20161(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(36,c,3)))){
C_save_and_reclaim((void *)f_20161,c,av);}
a=C_alloc(36);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t7=t6;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=((C_word*)t8)[1];
t10=C_i_check_list_2(t1,lf[10]);
t11=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_20173,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=t4,a[18]=t5,tmp=(C_word)a,a+=19,tmp);
t12=C_SCHEME_UNDEFINED;
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_set_block_item(t13,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20618,a[2]=t8,a[3]=t13,a[4]=t9,tmp=(C_word)a,a+=5,tmp));
t15=((C_word*)t13)[1];
f_20618(t15,t11,t1);}

/* k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20173(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,4)))){
C_save_and_reclaim((void *)f_20173,c,av);}
a=C_alloc(24);
t2=C_i_check_list_2(((C_word*)t0)[2],lf[10]);
t3=C_i_check_list_2(t1,lf[10]);
t4=(*a=C_CLOSURE_TYPE|16,a[1]=(C_word)f_20182,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[2],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],tmp=(C_word)a,a+=17,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20570,a[2]=((C_word*)t0)[17],a[3]=t6,a[4]=((C_word*)t0)[18],tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_20570(t8,t4,((C_word*)t0)[2],t1);}

/* k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_20182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,2)))){
C_save_and_reclaim((void *)f_20182,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_20185,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],tmp=(C_word)a,a+=18,tmp);
/* core.scm:2673: chicken.base#gensym */
t3=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[160];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_20185(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,3)))){
C_save_and_reclaim((void *)f_20185,c,av);}
a=C_alloc(20);
t2=(C_truep(((C_word*)t0)[2])?C_i_car(((C_word*)t0)[3]):lf[611]);
t3=(*a=C_CLOSURE_TYPE|19,a[1]=(C_word)f_20191,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=t2,a[8]=((C_word*)t0)[3],a[9]=t1,a[10]=((C_word*)t0)[8],a[11]=((C_word*)t0)[9],a[12]=((C_word*)t0)[10],a[13]=((C_word*)t0)[11],a[14]=((C_word*)t0)[12],a[15]=((C_word*)t0)[13],a[16]=((C_word*)t0)[14],a[17]=((C_word*)t0)[15],a[18]=((C_word*)t0)[16],a[19]=((C_word*)t0)[17],tmp=(C_word)a,a+=20,tmp);
/* core.scm:2675: test */
t4=((C_word*)((C_word*)t0)[17])[1];
f_19358(t4,t3,t2,lf[612]);}

/* k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_20191(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,3)))){
C_save_and_reclaim((void *)f_20191,c,av);}
a=C_alloc(21);
t2=(C_truep(t1)?t1:C_SCHEME_END_OF_LIST);
t3=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_20197,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t2,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],tmp=(C_word)a,a+=21,tmp);
/* core.scm:2676: test */
t4=((C_word*)((C_word*)t0)[19])[1];
f_19358(t4,t3,((C_word*)t0)[7],lf[613]);}

/* k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_20197(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,2)))){
C_save_and_reclaim((void *)f_20197,c,av);}
a=C_alloc(22);
t2=(C_truep(t1)?t1:C_fix(0));
t3=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_20203,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],tmp=(C_word)a,a+=22,tmp);
if(C_truep(*((C_word*)lf[41]+1))){
t4=C_i_cadr(((C_word*)t0)[9]);
t5=t3;
f_20203(t5,(C_truep(t4)?C_i_pairp(((C_word*)t0)[7]):C_SCHEME_FALSE));}
else{
t4=t3;
f_20203(t4,C_SCHEME_FALSE);}}

/* k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_fcall f_20203(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(28,0,3)))){
C_save_and_reclaim_args((void *)trf_20203,2,t0,t1);}
a=C_alloc(28);
t2=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_20206,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],tmp=(C_word)a,a+=21,tmp);
if(C_truep(((C_word*)t0)[18])){
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_20536,a[2]=((C_word*)t0)[18],a[3]=((C_word*)t0)[14],a[4]=t2,a[5]=((C_word*)t0)[20],a[6]=((C_word*)t0)[21],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2682: test */
t4=((C_word*)((C_word*)t0)[21])[1];
f_19358(t4,t3,((C_word*)t0)[18],lf[600]);}
else{
t3=t2;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_20206(2,av2);}}}

/* k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_20206(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(78,c,3)))){
C_save_and_reclaim((void *)f_20206,c,av);}
a=C_alloc(78);
t2=(C_truep(((C_word*)t0)[2])?C_s_a_i_plus(&a,2,((C_word*)t0)[3],C_fix(2)):C_s_a_i_plus(&a,2,((C_word*)t0)[3],C_fix(1)));
t3=C_a_i_list1(&a,1,t2);
t4=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_20221,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=t3,a[8]=((C_word*)t0)[2],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
t5=C_i_cadr(((C_word*)t0)[11]);
t6=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_20457,a[2]=((C_word*)t0)[12],a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[10],a[5]=t5,a[6]=t4,a[7]=((C_word*)t0)[13],a[8]=((C_word*)t0)[14],a[9]=((C_word*)t0)[15],a[10]=((C_word*)t0)[16],a[11]=((C_word*)t0)[17],a[12]=((C_word*)t0)[7],tmp=(C_word)a,a+=13,tmp);
t7=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t8=t7;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=((C_word*)t9)[1];
t11=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20462,a[2]=((C_word*)t0)[15],tmp=(C_word)a,a+=3,tmp);
t12=C_i_check_list_2(((C_word*)t0)[18],lf[10]);
t13=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20478,a[2]=((C_word*)t0)[19],a[3]=((C_word*)t0)[15],a[4]=t6,a[5]=((C_word*)t0)[20],tmp=(C_word)a,a+=6,tmp);
t14=C_SCHEME_UNDEFINED;
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_set_block_item(t15,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20493,a[2]=t11,a[3]=t9,a[4]=t15,a[5]=t10,tmp=(C_word)a,a+=6,tmp));
t17=((C_word*)t15)[1];
f_20493(t17,t13,((C_word*)t0)[18]);}

/* k20219 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_20221(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,3)))){
C_save_and_reclaim((void *)f_20221,c,av);}
a=C_alloc(26);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20226,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t7=C_i_check_list_2(((C_word*)t0)[5],lf[10]);
t8=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20240,a[2]=t1,a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],tmp=(C_word)a,a+=8,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20283,a[2]=t4,a[3]=t10,a[4]=t6,a[5]=t5,tmp=(C_word)a,a+=6,tmp));
t12=((C_word*)t10)[1];
f_20283(t12,t8,((C_word*)t0)[5]);}

/* g4721 in k20219 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in ... */
static void C_fcall f_20226(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20226,3,t0,t1,t2);}
a=C_alloc(6);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20234,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2716: chicken.compiler.support#varnode */
t4=*((C_word*)lf[524]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k20232 in g4721 in k20219 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in ... */
static void C_ccall f_20234(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_20234,c,av);}
/* core.scm:2716: ref-var */
f_21151(((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5]);}

/* k20238 in k20219 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in ... */
static void C_ccall f_20240(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,4)))){
C_save_and_reclaim((void *)f_20240,c,av);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20243,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(((C_word*)t0)[5])){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20254,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20258,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20262,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20270,a[2]=t5,a[3]=((C_word*)t0)[6],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2724: chicken.compiler.support#real-name */
t7=*((C_word*)lf[544]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t3=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* core.scm:2685: chicken.compiler.support#make-node */
t4=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[620];
av2[3]=((C_word*)t0)[4];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}

/* k20241 in k20238 in k20219 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in ... */
static void C_ccall f_20243(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_20243,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* core.scm:2685: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[620];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20252 in k20238 in k20219 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in ... */
static void C_ccall f_20254(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_20254,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:2719: scheme#append */
t3=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k20256 in k20238 in k20219 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in ... */
static void C_ccall f_20258(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20258,c,av);}
/* core.scm:2722: chicken.compiler.support#qnode */
t2=*((C_word*)lf[621]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k20260 in k20238 in k20219 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in ... */
static void C_ccall f_20262(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20262,c,av);}
/* core.scm:2723: ##sys#make-lambda-info */
t2=*((C_word*)lf[622]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k20268 in k20238 in k20219 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in ... */
static void C_ccall f_20270(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_20270,c,av);}
a=C_alloc(4);
t2=(C_truep(t1)?t1:lf[623]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20277,a[2]=t2,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2726: chicken.syntax#strip-syntax */
t4=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_cdr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k20275 in k20268 in k20238 in k20219 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in ... */
static void C_ccall f_20277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20277,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* core.scm:2724: chicken.string#->string */
t3=*((C_word*)lf[624]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* map-loop4715 in k20219 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in ... */
static void C_fcall f_20283(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20283,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20308,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2716: g4721 */
t4=((C_word*)t0)[4];
f_20226(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20306 in map-loop4715 in k20219 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in ... */
static void C_ccall f_20308(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20308,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_20283(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k20325 in k20455 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in ... */
static void C_ccall f_20327(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_20327,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20330,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_pairp(((C_word*)t0)[5]))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20340,a[2]=((C_word*)t0)[6],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2705: unzip1 */
f_6992(t3,((C_word*)t0)[6]);}
else{
t3=C_a_i_list1(&a,1,t1);
/* core.scm:2688: chicken.compiler.support#make-node */
t4=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}

/* k20328 in k20325 in k20455 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in ... */
static void C_ccall f_20330(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_20330,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:2688: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20338 in k20325 in k20455 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in ... */
static void C_ccall f_20340(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_20340,c,av);}
a=C_alloc(17);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_check_list_2(((C_word*)t0)[2],lf[10]);
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20367,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20405,a[2]=t4,a[3]=t9,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_20405(t11,t7,((C_word*)t0)[2]);}

/* k20355 in map-loop4687 in k20338 in k20325 in k20455 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in ... */
static void C_ccall f_20357(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_20357,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:2708: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[619];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20365 in k20338 in k20325 in k20455 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in ... */
static void C_ccall f_20367(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20367,c,av);}
a=C_alloc(6);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_set_block_item(t3,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20369,a[2]=((C_word*)t0)[2],a[3]=t3,tmp=(C_word)a,a+=4,tmp));
t5=((C_word*)t3)[1];
f_20369(t5,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* loop in k20365 in k20338 in k20325 in k20455 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in ... */
static void C_fcall f_20369(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_20369,4,t0,t1,t2,t3);}
a=C_alloc(8);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
t5=C_a_i_list1(&a,1,t4);
t6=C_i_car(t3);
t7=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20395,a[2]=t6,a[3]=t1,a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2714: loop */
t9=t7;
t10=C_u_i_cdr(t2);
t11=C_u_i_cdr(t3);
t1=t9;
t2=t10;
t3=t11;
goto loop;}}

/* k20393 in loop in k20365 in k20338 in k20325 in k20455 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in ... */
static void C_ccall f_20395(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20395,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:2712: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[174];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* map-loop4687 in k20338 in k20325 in k20455 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in ... */
static void C_fcall f_20405(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_20405,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20430,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20357,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2708: chicken.compiler.support#varnode */
t6=*((C_word*)lf[524]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=C_i_cdr(t4);
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20428 in map-loop4687 in k20338 in k20325 in k20455 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in ... */
static void C_ccall f_20430(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20430,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_20405(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k20455 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_20457(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,4)))){
C_save_and_reclaim((void *)f_20457,c,av);}
a=C_alloc(22);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=C_i_cadddr(((C_word*)t0)[3]);
t4=C_a_i_list4(&a,4,((C_word*)t0)[4],((C_word*)t0)[5],t2,t3);
t5=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_20327,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[7],a[4]=t4,a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2703: transform */
t6=((C_word*)((C_word*)t0)[10])[1];
f_19914(t6,t5,C_i_car(((C_word*)t0)[11]),((C_word*)t0)[2],((C_word*)t0)[12]);}

/* g4648 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in ... */
static C_word C_fcall f_20462(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_stack_overflow_check;{}
t2=C_i_assq(t1,((C_word*)t0)[2]);
return((C_truep(t2)?C_i_cdr(t2):t1));}

/* k20476 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_20478(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_20478,c,av);}
t2=(C_truep(((C_word*)t0)[2])?C_i_assq(((C_word*)t0)[2],((C_word*)t0)[3]):C_SCHEME_FALSE);
if(C_truep(t2)){
/* core.scm:2694: chicken.compiler.support#build-lambda-list */
t3=*((C_word*)lf[187]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=t1;
av2[3]=((C_word*)t0)[5];
av2[4]=C_i_cdr(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
/* core.scm:2694: chicken.compiler.support#build-lambda-list */
t3=*((C_word*)lf[187]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=t1;
av2[3]=((C_word*)t0)[5];
av2[4]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* map-loop4642 in k20204 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in ... */
static void C_fcall f_20493(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_20493,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=(
/* core.scm:2695: g4648 */
  f_20462(((C_word*)t0)[2],C_slot(t2,C_fix(0)))
);
t4=C_a_i_cons(&a,2,t3,C_SCHEME_END_OF_LIST);
t5=C_i_setslot(((C_word*)((C_word*)t0)[3])[1],C_fix(1),t4);
t6=C_mutate(((C_word *)((C_word*)t0)[3])+1,t4);
t8=t1;
t9=C_slot(t2,C_fix(1));
t1=t8;
t2=t9;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20534 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_20536(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_20536,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20542,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2683: test */
t3=((C_word*)((C_word*)t0)[6])[1];
f_19358(t3,t2,((C_word*)t0)[2],lf[552]);}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_20206(2,av2);}}}

/* k20540 in k20534 in k20201 in k20195 in k20189 in k20183 in k20180 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_20542(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_20542,c,av);}
if(C_truep(t1)){
t2=C_i_assq(((C_word*)t0)[2],((C_word*)t0)[3]);
/* core.scm:2684: chicken.compiler.support#db-put! */
t3=*((C_word*)lf[538]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[5];
av2[3]=C_i_cdr(t2);
av2[4]=lf[625];
av2[5]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(6,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_20206(2,av2);}}}

/* map-loop4564 in k20171 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_20570(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_20570,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=C_slot(t2,C_fix(0));
t7=C_slot(t3,C_fix(0));
t8=C_a_i_cons(&a,2,t6,t7);
t9=C_a_i_cons(&a,2,t8,C_SCHEME_END_OF_LIST);
t10=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t9);
t11=C_mutate(((C_word *)((C_word*)t0)[2])+1,t9);
t13=t1;
t14=C_slot(t2,C_fix(1));
t15=C_slot(t3,C_fix(1));
t1=t13;
t2=t14;
t3=t15;
goto loop;}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* map-loop4585 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_20618(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_20618,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20643,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2672: g4591 */
t4=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k20641 in map-loop4585 in k20159 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_20643(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_20643,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_20618(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* a20651 in a20156 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20652(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_20652,c,av);}
/* core.scm:2671: test */
t3=((C_word*)((C_word*)t0)[2])[1];
f_19358(t3,t1,t2,lf[600]);}

/* k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20671(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_20671,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_20674,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=t1,tmp=(C_word)a,a+=11,tmp);
t3=C_eqp(lf[116],t1);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20825,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2733: chicken.compiler.support#node-parameters */
t5=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
f_20674(2,av2);}}}

/* k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20674(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,2)))){
C_save_and_reclaim((void *)f_20674,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20677,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
if(C_truep(t1)){
t3=t2;
f_20677(t3,t1);}
else{
t3=C_i_cdr(((C_word*)t0)[9]);
if(C_truep(C_i_pairp(t3))){
t4=C_i_cadr(((C_word*)t0)[9]);
t5=t2;
f_20677(t5,(C_truep(t4)?t4:C_eqp(lf[478],((C_word*)t0)[10])));}
else{
t4=t2;
f_20677(t4,C_eqp(lf[478],((C_word*)t0)[10]));}}}

/* k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_20677(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,3)))){
C_save_and_reclaim_args((void *)trf_20677,2,t0,t1);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_20680,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* core.scm:2736: posq */
f_7486(t2,((C_word*)t0)[7],((C_word*)t0)[5]);}

/* k20678 in k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_20680(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_20680,c,av);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20684,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* core.scm:2736: g4762 */
t3=t2;
f_20684(t3,((C_word*)t0)[9],t1);}
else{
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20758,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* core.scm:2750: test */
t3=((C_word*)((C_word*)t0)[7])[1];
f_19358(t3,t2,((C_word*)t0)[8],lf[600]);}}

/* g4762 in k20678 in k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_20684(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_20684,3,t0,t1,t2);}
a=C_alloc(9);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20691,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=t2,tmp=(C_word)a,a+=9,tmp);
/* core.scm:2738: test */
t4=((C_word*)((C_word*)t0)[7])[1];
f_19358(t4,t3,((C_word*)t0)[8],lf[600]);}

/* k20689 in g4762 in k20678 in k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_20691(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(44,c,2)))){
C_save_and_reclaim((void *)f_20691,c,av);}
a=C_alloc(44);
if(C_truep(t1)){
t2=(C_truep(((C_word*)t0)[2])?lf[626]:lf[627]);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20706,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
t4=C_s_a_i_plus(&a,2,((C_word*)t0)[8],C_fix(1));
t5=C_a_i_list1(&a,1,t4);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20722,a[2]=t3,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* core.scm:2742: chicken.compiler.support#varnode */
t7=*((C_word*)lf[524]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
t2=(C_truep(((C_word*)t0)[2])?lf[628]:lf[629]);
t3=C_s_a_i_plus(&a,2,((C_word*)t0)[8],C_fix(1));
t4=C_a_i_list1(&a,1,t3);
t5=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_20743,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=t4,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* core.scm:2748: chicken.compiler.support#varnode */
t6=*((C_word*)lf[524]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}

/* k20704 in k20689 in g4762 in k20678 in k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_20706(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_20706,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20710,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2743: transform */
t3=((C_word*)((C_word*)t0)[4])[1];
f_19914(t3,t2,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k20708 in k20704 in k20689 in g4762 in k20678 in k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_20710(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20710,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:2739: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20720 in k20689 in g4762 in k20678 in k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_20722(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_20722,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:2742: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[617];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20741 in k20689 in g4762 in k20678 in k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_20743(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20743,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_20747,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2749: transform */
t3=((C_word*)((C_word*)t0)[5])[1];
f_19914(t3,t2,((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k20745 in k20741 in k20689 in g4762 in k20678 in k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_20747(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20747,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:2745: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20756 in k20678 in k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_20758(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_20758,c,av);}
a=C_alloc(10);
if(C_truep(t1)){
t2=(C_truep(((C_word*)t0)[2])?lf[626]:lf[627]);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_20773,a[2]=((C_word*)t0)[3],a[3]=t2,a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* core.scm:2754: chicken.compiler.support#varnode */
t4=*((C_word*)lf[524]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=C_a_i_list2(&a,2,((C_word*)t0)[8],((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_20792,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:2758: transform */
t4=((C_word*)((C_word*)t0)[4])[1];
f_19914(t4,t3,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}}

/* k20771 in k20756 in k20678 in k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_20773(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_20773,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20777,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2755: transform */
t3=((C_word*)((C_word*)t0)[4])[1];
f_19914(t3,t2,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k20775 in k20771 in k20756 in k20678 in k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_20777(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20777,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:2751: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20790 in k20756 in k20678 in k20675 in k20672 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_20792(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_20792,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:2756: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[286];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k20823 in k20669 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20825(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20825,c,av);}
/* core.scm:2733: chicken.compiler.support#immediate? */
t2=*((C_word*)lf[630]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_i_car(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k20844 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20846(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_20846,c,av);}
a=C_alloc(8);
if(C_truep(*((C_word*)lf[41]+1))){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_20857,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_20861,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2765: ##sys#make-lambda-info */
t4=*((C_word*)lf[622]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_u_i_car(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
/* core.scm:2761: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[620];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k20855 in k20844 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20857(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_20857,c,av);}
a=C_alloc(6);
t2=C_a_i_list1(&a,1,t1);
t3=C_a_i_cons(&a,2,((C_word*)t0)[2],t2);
/* core.scm:2761: chicken.compiler.support#make-node */
t4=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[620];
av2[3]=((C_word*)t0)[4];
av2[4]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k20859 in k20844 in k20051 in k19965 in k19931 in k19922 in k19919 in k19916 in transform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_20861(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_20861,c,av);}
/* core.scm:2765: chicken.compiler.support#qnode */
t2=*((C_word*)lf[621]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* maptransform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21100(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,3)))){
C_save_and_reclaim_args((void *)trf_21100,5,t0,t1,t2,t3,t4);}
a=C_alloc(18);
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21105,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t10=C_i_check_list_2(t2,lf[10]);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21117,a[2]=t7,a[3]=t12,a[4]=t9,a[5]=t8,tmp=(C_word)a,a+=6,tmp));
t14=((C_word*)t12)[1];
f_21117(t14,t1,t2);}

/* g4776 in maptransform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21105(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,4)))){
C_save_and_reclaim_args((void *)trf_21105,3,t0,t1,t2);}
/* core.scm:2773: transform */
t3=((C_word*)((C_word*)t0)[2])[1];
f_19914(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4]);}

/* map-loop4770 in maptransform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21117(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_21117,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21142,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2773: g4776 */
t4=((C_word*)t0)[4];
f_21105(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k21140 in map-loop4770 in maptransform in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21142(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_21142,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_21117(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* ref-var in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21151(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_21151,4,t1,t2,t3,t4);}
a=C_alloc(6);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21189,a[2]=t3,a[3]=t1,a[4]=t2,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* core.scm:2776: chicken.compiler.support#node-parameters */
t6=*((C_word*)lf[527]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k21156 in k21187 in ref-var in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21158(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21158,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21162,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2777: g4805 */
t3=t2;
f_21162(t3,((C_word*)t0)[3],t1);}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* g4805 in k21156 in k21187 in ref-var in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21162(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(36,0,2)))){
C_save_and_reclaim_args((void *)trf_21162,3,t0,t1,t2);}
a=C_alloc(36);
t3=C_s_a_i_plus(&a,2,t2,C_fix(1));
t4=C_a_i_list1(&a,1,t3);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21178,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* core.scm:2780: chicken.compiler.support#varnode */
t6=*((C_word*)lf[524]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k21176 in g4805 in k21156 in k21187 in ref-var in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21178(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_21178,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:2779: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[617];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21187 in ref-var in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21189(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_21189,c,av);}
a=C_alloc(5);
t2=C_i_car(t1);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21158,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2777: posq */
f_7486(t3,t2,((C_word*)t0)[5]);}

/* k21190 in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21192(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_21192,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21195,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2784: gather */
t3=((C_word*)((C_word*)t0)[7])[1];
f_19383(t3,t2,((C_word*)t0)[5],C_SCHEME_FALSE,C_SCHEME_END_OF_LIST);}

/* k21193 in k21190 in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21195(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_21195,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21198,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_i_pairp(((C_word*)((C_word*)t0)[6])[1]))){
/* core.scm:2786: chicken.compiler.support#debugging */
t3=*((C_word*)lf[596]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[643];
av2[3]=lf[646];
av2[4]=((C_word*)((C_word*)t0)[6])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_21198(2,av2);}}}

/* k21196 in k21193 in k21190 in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21198(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_21198,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21201,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2787: chicken.compiler.support#debugging */
t3=*((C_word*)lf[596]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[604];
av2[3]=lf[645];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k21199 in k21196 in k21193 in k21190 in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21201(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_21201,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21204,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2788: transform */
t3=((C_word*)((C_word*)t0)[4])[1];
f_19914(t3,t2,((C_word*)t0)[5],C_SCHEME_FALSE,C_SCHEME_FALSE);}

/* k21202 in k21199 in k21196 in k21193 in k21190 in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21204(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_21204,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21207,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=((C_word*)((C_word*)t0)[3])[1];
if(C_truep(C_i_zerop(t3))){
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* core.scm:2790: chicken.compiler.support#debugging */
t4=*((C_word*)lf[596]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[643];
av2[3]=lf[644];
av2[4]=((C_word*)((C_word*)t0)[3])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}}

/* k21205 in k21202 in k21199 in k21196 in k21193 in k21190 in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21207(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21207,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-id in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21232(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21232,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[650]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(1));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-external in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21241(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21241,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[652]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(2));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-argument-count in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21259(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21259,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[654]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(4));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-rest-argument in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21268(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21268,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[656]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(5));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-temporaries in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21277(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21277,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[658]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(6));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-float-temporaries in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21286(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21286,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[660]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(7));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-callee-signatures in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21295(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21295,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[662]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(8));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-allocated in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21304(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21304,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[664]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(9));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-closure-size in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21322(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21322,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[666]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(11));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-looping in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21331(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21331,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[668]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(12));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-customizable in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21340(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21340,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[670]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(13));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-rest-argument-mode in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21349(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21349,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[672]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(14));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-body in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21358(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21358,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[674]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(15));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#lambda-literal-direct in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21367(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21367,c,av);}
t3=C_i_check_structure_2(t2,lf[649],lf[676]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_i_block_ref(t2,C_fix(16));
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21376(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,3)))){
C_save_and_reclaim((void *)f_21376,c,av);}
a=C_alloc(17);
t4=C_SCHEME_END_OF_LIST;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_fix(0);
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_SCHEME_END_OF_LIST;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_fix(0);
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_21380,a[2]=t3,a[3]=t11,a[4]=t9,a[5]=t5,a[6]=t7,a[7]=t1,a[8]=t2,tmp=(C_word)a,a+=9,tmp);
t13=C_i_fixnum_max(lf[62],C_fix(1));
/* core.scm:2826: scheme#make-vector */
t14=*((C_word*)lf[93]+1);{
C_word *av2=av;
av2[0]=t14;
av2[1]=t12;
av2[2]=C_fixnum_times(t13,C_fix(3));
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t14+1)))(4,av2);}}

/* k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21380(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(99,c,7)))){
C_save_and_reclaim((void *)f_21380,c,av);}
a=C_alloc(99);
t2=C_fix(0);
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_END_OF_LIST;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_fix(0);
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_fix(0);
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_SCHEME_END_OF_LIST;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_fix(0);
t13=(*a=C_VECTOR_TYPE|1,a[1]=t12,tmp=(C_word)a,a+=2,tmp);
t14=C_fix(0);
t15=(*a=C_VECTOR_TYPE|1,a[1]=t14,tmp=(C_word)a,a+=2,tmp);
t16=C_fix(0);
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=C_fix(0);
t19=(*a=C_VECTOR_TYPE|1,a[1]=t18,tmp=(C_word)a,a+=2,tmp);
t20=C_SCHEME_END_OF_LIST;
t21=(*a=C_VECTOR_TYPE|1,a[1]=t20,tmp=(C_word)a,a+=2,tmp);
t22=C_SCHEME_UNDEFINED;
t23=(*a=C_VECTOR_TYPE|1,a[1]=t22,tmp=(C_word)a,a+=2,tmp);
t24=C_SCHEME_UNDEFINED;
t25=(*a=C_VECTOR_TYPE|1,a[1]=t24,tmp=(C_word)a,a+=2,tmp);
t26=C_SCHEME_UNDEFINED;
t27=(*a=C_VECTOR_TYPE|1,a[1]=t26,tmp=(C_word)a,a+=2,tmp);
t28=C_SCHEME_UNDEFINED;
t29=(*a=C_VECTOR_TYPE|1,a[1]=t28,tmp=(C_word)a,a+=2,tmp);
t30=C_SCHEME_UNDEFINED;
t31=(*a=C_VECTOR_TYPE|1,a[1]=t30,tmp=(C_word)a,a+=2,tmp);
t32=C_SCHEME_UNDEFINED;
t33=(*a=C_VECTOR_TYPE|1,a[1]=t32,tmp=(C_word)a,a+=2,tmp);
t34=C_SCHEME_UNDEFINED;
t35=(*a=C_VECTOR_TYPE|1,a[1]=t34,tmp=(C_word)a,a+=2,tmp);
t36=C_SCHEME_UNDEFINED;
t37=(*a=C_VECTOR_TYPE|1,a[1]=t36,tmp=(C_word)a,a+=2,tmp);
t38=C_set_block_item(t23,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21382,a[2]=t31,a[3]=t25,tmp=(C_word)a,a+=4,tmp));
t39=C_set_block_item(t25,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21431,a[2]=t35,a[3]=t31,a[4]=t15,a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp));
t40=C_set_block_item(t27,0,(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_21487,a[2]=t23,a[3]=t7,a[4]=t29,a[5]=t19,a[6]=t21,a[7]=t27,a[8]=t13,a[9]=t31,a[10]=t3,a[11]=t5,a[12]=t11,a[13]=t9,a[14]=t1,a[15]=((C_word*)t0)[2],a[16]=t35,a[17]=t17,a[18]=t37,tmp=(C_word)a,a+=19,tmp));
t41=C_set_block_item(t29,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22697,a[2]=t27,tmp=(C_word)a,a+=3,tmp));
t42=C_set_block_item(t31,0,(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22748,a[2]=t37,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=t33,tmp=(C_word)a,a+=8,tmp));
t43=C_set_block_item(t33,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22796,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp));
t44=C_set_block_item(t35,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22805,a[2]=((C_word*)t0)[6],a[3]=t33,a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp));
t45=C_set_block_item(t37,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_22849,tmp=(C_word)a,a+=2,tmp));
t46=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_22915,a[2]=((C_word*)t0)[7],a[3]=t1,a[4]=t21,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=t17,a[8]=t15,a[9]=t13,a[10]=t27,a[11]=((C_word*)t0)[8],tmp=(C_word)a,a+=12,tmp);
/* core.scm:3168: chicken.compiler.support#debugging */
t47=*((C_word*)lf[596]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t47;
av2[1]=t46;
av2[2]=lf[604];
av2[3]=lf[715];
((C_proc)(void*)(*((C_word*)t47+1)))(4,av2);}}

/* walk-var in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21382(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5){
C_word tmp;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_21382,6,t0,t1,t2,t3,t4,t5);}
a=C_alloc(8);
t6=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21386,a[2]=t4,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=t2,a[6]=((C_word*)t0)[3],a[7]=t5,tmp=(C_word)a,a+=8,tmp);
/* core.scm:2839: posq */
f_7486(t6,t2,t3);}

/* k21384 in walk-var in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21386(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,3)))){
C_save_and_reclaim((void *)f_21386,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21390,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2839: g4946 */
t3=t2;
f_21390(t3,((C_word*)t0)[3],t1);}
else{
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21415,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2842: chicken.keyword#keyword? */
t3=*((C_word*)lf[485]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* g4946 in k21384 in walk-var in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21390(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,4)))){
C_save_and_reclaim_args((void *)trf_21390,3,t0,t1,t2);}
a=C_alloc(3);
t3=C_fixnum_plus(t2,C_fix(1));
t4=C_fixnum_difference(((C_word*)t0)[2],t3);
t5=C_a_i_list1(&a,1,t4);
/* core.scm:2841: chicken.compiler.support#make-node */
t6=*((C_word*)lf[489]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[678];
av2[3]=t5;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}

/* k21413 in k21384 in walk-var in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21415(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21415,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21426,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2842: literal */
t3=((C_word*)((C_word*)t0)[3])[1];
f_22748(t3,t2,((C_word*)t0)[4]);}
else{
/* core.scm:2843: walk-global */
t2=((C_word*)((C_word*)t0)[5])[1];
f_21431(t2,((C_word*)t0)[2],((C_word*)t0)[4],((C_word*)t0)[6]);}}

/* k21424 in k21413 in k21384 in walk-var in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21426(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_21426,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:2842: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[679];
av2[3]=t2;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* walk-global in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21431(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,3)))){
C_save_and_reclaim_args((void *)trf_21431,4,t0,t1,t2,t3);}
a=C_alloc(12);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21435,a[2]=t2,a[3]=t1,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t3)){
t5=t4;{
C_word av2[2];
av2[0]=t5;
av2[1]=t3;
f_21435(2,av2);}}
else{
t5=*((C_word*)lf[31]+1);
if(C_truep(*((C_word*)lf[31]+1))){
t6=*((C_word*)lf[31]+1);
t7=t4;{
C_word av2[2];
av2[0]=t7;
av2[1]=*((C_word*)lf[31]+1);
f_21435(2,av2);}}
else{
t6=*((C_word*)lf[148]+1);
if(C_truep(*((C_word*)lf[148]+1))){
t7=t4;{
C_word av2[2];
av2[0]=t7;
av2[1]=*((C_word*)lf[148]+1);
f_21435(2,av2);}}
else{
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21479,a[2]=t4,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:2849: chicken.compiler.support#variable-mark */
t8=*((C_word*)lf[185]+1);{
C_word av2[4];
av2[0]=t8;
av2[1]=t7;
av2[2]=t2;
av2[3]=lf[159];
((C_proc)(void*)(*((C_word*)t8+1)))(4,av2);}}}}}

/* k21433 in walk-global in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21435(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_21435,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21438,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21463,a[2]=t2,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2851: chicken.compiler.support#db-get */
t4=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
av2[3]=((C_word*)t0)[2];
av2[4]=lf[556];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k21436 in k21433 in walk-global in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21438(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(37,0,2)))){
C_save_and_reclaim_args((void *)trf_21438,2,t0,t1);}
a=C_alloc(37);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21441,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t1)){
t3=((C_word*)((C_word*)t0)[7])[1];
t4=C_mutate(((C_word *)((C_word*)t0)[7])+1,C_s_a_i_plus(&a,2,t3,C_fix(1)));
t5=t2;
f_21441(t5,t4);}
else{
t3=t2;
f_21441(t3,C_SCHEME_UNDEFINED);}}

/* k21439 in k21436 in k21433 in walk-global in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21441(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_21441,2,t0,t1);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21452,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)t0)[3])){
/* core.scm:2857: blockvar-literal */
t3=((C_word*)((C_word*)t0)[6])[1];
f_22805(t3,t2,((C_word*)t0)[4]);}
else{
/* core.scm:2858: literal */
t3=((C_word*)((C_word*)t0)[7])[1];
f_22748(t3,t2,((C_word*)t0)[4]);}}

/* k21450 in k21439 in k21436 in k21433 in walk-global in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21452(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,4)))){
C_save_and_reclaim((void *)f_21452,c,av);}
a=C_alloc(12);
t2=C_a_i_list4(&a,4,t1,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[4]);
/* core.scm:2854: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[5];
av2[2]=lf[680];
av2[3]=t2;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21461 in k21433 in walk-global in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21463(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_21463,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21470,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:2852: chicken.compiler.support#variable-visible? */
t3=*((C_word*)lf[574]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=*((C_word*)lf[25]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t2=((C_word*)t0)[2];
f_21438(t2,C_SCHEME_FALSE);}}

/* k21468 in k21461 in k21433 in walk-global in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21470(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21470,c,av);}
t2=((C_word*)t0)[2];
f_21438(t2,C_i_not(t1));}

/* k21477 in walk-global in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21479(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21479,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
f_21435(2,av2);}}
else{
/* core.scm:2850: chicken.compiler.support#intrinsic? */
t2=*((C_word*)lf[583]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}}

/* walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21487(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(25,0,2)))){
C_save_and_reclaim_args((void *)trf_21487,7,t0,t1,t2,t3,t4,t5,t6);}
a=C_alloc(25);
t7=(*a=C_CLOSURE_TYPE|24,a[1]=(C_word)f_21491,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=t3,a[6]=t4,a[7]=((C_word*)t0)[3],a[8]=((C_word*)t0)[4],a[9]=t5,a[10]=t6,a[11]=((C_word*)t0)[5],a[12]=((C_word*)t0)[6],a[13]=((C_word*)t0)[7],a[14]=((C_word*)t0)[8],a[15]=((C_word*)t0)[9],a[16]=((C_word*)t0)[10],a[17]=((C_word*)t0)[11],a[18]=((C_word*)t0)[12],a[19]=((C_word*)t0)[13],a[20]=((C_word*)t0)[14],a[21]=((C_word*)t0)[15],a[22]=((C_word*)t0)[16],a[23]=((C_word*)t0)[17],a[24]=((C_word*)t0)[18],tmp=(C_word)a,a+=25,tmp);
/* core.scm:2865: chicken.compiler.support#node-subexpressions */
t8=*((C_word*)lf[530]+1);{
C_word av2[3];
av2[0]=t8;
av2[1]=t7;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}

/* k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21491(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,2)))){
C_save_and_reclaim((void *)f_21491,c,av);}
a=C_alloc(26);
t2=(*a=C_CLOSURE_TYPE|25,a[1]=(C_word)f_21494,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=t1,a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],a[22]=((C_word*)t0)[21],a[23]=((C_word*)t0)[22],a[24]=((C_word*)t0)[23],a[25]=((C_word*)t0)[24],tmp=(C_word)a,a+=26,tmp);
/* core.scm:2866: chicken.compiler.support#node-parameters */
t3=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21494(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,2)))){
C_save_and_reclaim((void *)f_21494,c,av);}
a=C_alloc(29);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|26,a[1]=(C_word)f_21497,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],a[22]=((C_word*)t0)[21],a[23]=((C_word*)t0)[22],a[24]=((C_word*)t0)[23],a[25]=((C_word*)t0)[24],a[26]=((C_word*)t0)[25],tmp=(C_word)a,a+=27,tmp);
/* core.scm:2867: chicken.compiler.support#node-class */
t5=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21497(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(28,c,2)))){
C_save_and_reclaim((void *)f_21497,c,av);}
a=C_alloc(28);
t2=C_eqp(t1,lf[478]);
t3=(*a=C_CLOSURE_TYPE|27,a[1]=(C_word)f_21506,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],a[22]=((C_word*)t0)[21],a[23]=((C_word*)t0)[22],a[24]=((C_word*)t0)[23],a[25]=((C_word*)t0)[24],a[26]=((C_word*)t0)[25],a[27]=((C_word*)t0)[26],tmp=(C_word)a,a+=28,tmp);
if(C_truep(t2)){
t4=t3;
f_21506(t4,t2);}
else{
t4=C_eqp(t1,lf[564]);
t5=t3;
f_21506(t5,(C_truep(t4)?t4:C_eqp(t1,lf[641])));}}

/* k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21506(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(40,0,6)))){
C_save_and_reclaim_args((void *)trf_21506,2,t0,t1);}
a=C_alloc(40);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[526]);
if(C_truep(t2)){
t3=((C_word*)((C_word*)t0)[5])[1];
/* core.scm:2873: walk-var */
t4=((C_word*)((C_word*)t0)[6])[1];
f_21382(t4,((C_word*)t0)[2],C_i_car(t3),((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}
else{
t3=C_eqp(((C_word*)t0)[4],lf[634]);
if(C_truep(t3)){
t4=((C_word*)((C_word*)t0)[5])[1];
t5=C_i_cadr(t4);
t6=((C_word*)((C_word*)t0)[5])[1];
t7=C_i_cadddr(t6);
t8=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_21534,a[2]=((C_word*)t0)[9],a[3]=t7,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[11],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],tmp=(C_word)a,a+=13,tmp);
t9=(C_truep(*((C_word*)lf[24]+1))?t5:C_SCHEME_FALSE);
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21565,a[2]=((C_word*)t0)[14],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[15],a[5]=t8,a[6]=t5,tmp=(C_word)a,a+=7,tmp);
/* core.scm:2880: chicken.compiler.support#source-info->line */
t11=*((C_word*)lf[683]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t10;
av2[2]=t5;
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t10=C_a_i_cons(&a,2,C_SCHEME_FALSE,((C_word*)((C_word*)t0)[5])[1]);
t11=C_mutate(((C_word *)((C_word*)t0)[5])+1,t10);
t12=t8;
f_21534(t12,t11);}}
else{
t4=C_eqp(((C_word*)t0)[4],lf[303]);
if(C_truep(t4)){
t5=((C_word*)((C_word*)t0)[5])[1];
t6=C_i_cadr(t5);
t7=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[9])[1],t6);
t8=C_mutate(((C_word *)((C_word*)t0)[9])+1,t7);
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21590,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2891: mapwalk */
t10=((C_word*)((C_word*)t0)[10])[1];
f_22697(t10,t9,((C_word*)t0)[11],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[12],((C_word*)t0)[13]);}
else{
t5=C_eqp(((C_word*)t0)[4],lf[637]);
if(C_truep(t5)){
t6=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[9])[1],C_fix(4));
t7=C_mutate(((C_word *)((C_word*)t0)[9])+1,t6);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21611,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2895: mapwalk */
t9=((C_word*)((C_word*)t0)[10])[1];
f_22697(t9,t8,((C_word*)t0)[11],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[12],((C_word*)t0)[13]);}
else{
t6=C_eqp(((C_word*)t0)[4],lf[117]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21628,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21632,a[2]=t7,tmp=(C_word)a,a+=3,tmp);
t9=((C_word*)((C_word*)t0)[5])[1];
/* core.scm:2898: chicken.compiler.support#estimate-foreign-result-size */
t10=*((C_word*)lf[513]+1);{
C_word av2[3];
av2[0]=t10;
av2[1]=t8;
av2[2]=C_i_cadr(t9);
((C_proc)(void*)(*((C_word*)t10+1)))(3,av2);}}
else{
t7=C_eqp(((C_word*)t0)[4],lf[121]);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_21657,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[12],a[11]=((C_word*)t0)[13],tmp=(C_word)a,a+=12,tmp);
t9=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21661,a[2]=t8,tmp=(C_word)a,a+=3,tmp);
t10=((C_word*)((C_word*)t0)[5])[1];
/* core.scm:2902: chicken.compiler.support#estimate-foreign-result-size */
t11=*((C_word*)lf[513]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t9;
av2[2]=C_i_car(t10);
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t8=C_eqp(((C_word*)t0)[4],lf[620]);
if(C_truep(t8)){
t9=((C_word*)((C_word*)t0)[5])[1];
t10=C_i_car(t9);
t11=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)va26246,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[11],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[12],a[10]=((C_word*)t0)[13],tmp=(C_word)a,a+=11,tmp);
t12=t11;
va26246(t12,C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[9])[1],t10));}
else{
t9=C_eqp(((C_word*)t0)[4],lf[619]);
if(C_truep(t9)){
t10=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[9])[1],C_fix(2));
t11=C_mutate(((C_word *)((C_word*)t0)[9])+1,t10);
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21707,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2911: walk */
t13=((C_word*)((C_word*)t0)[16])[1];
f_21487(t13,t12,C_i_car(((C_word*)t0)[11]),((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[12],((C_word*)t0)[13]);}
else{
t10=C_eqp(((C_word*)t0)[4],lf[627]);
if(C_truep(t10)){
t11=C_i_car(((C_word*)t0)[11]);
t12=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21723,a[2]=((C_word*)t0)[17],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[13],a[6]=t11,tmp=(C_word)a,a+=7,tmp);
/* core.scm:2915: mapwalk */
t13=((C_word*)((C_word*)t0)[10])[1];
f_22697(t13,t12,((C_word*)t0)[11],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[12],((C_word*)t0)[13]);}
else{
t11=C_eqp(((C_word*)t0)[4],lf[162]);
if(C_truep(t11)){
t12=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21762,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t13=((C_word*)((C_word*)t0)[5])[1];
/* core.scm:2927: literal */
t14=((C_word*)((C_word*)t0)[18])[1];
f_22748(t14,t12,C_i_car(t13));}
else{
t12=C_eqp(((C_word*)t0)[4],lf[97]);
t13=(C_truep(t12)?t12:C_eqp(((C_word*)t0)[4],lf[548]));
if(C_truep(t13)){
t14=((C_word*)((C_word*)t0)[19])[1];
t15=((C_word*)((C_word*)t0)[20])[1];
t16=((C_word*)((C_word*)t0)[21])[1];
t17=((C_word*)((C_word*)t0)[22])[1];
t18=((C_word*)((C_word*)t0)[9])[1];
t19=C_eqp(((C_word*)t0)[4],lf[548]);
t20=C_set_block_item(((C_word*)t0)[19],0,C_fix(0));
t21=C_set_block_item(((C_word*)t0)[20],0,C_SCHEME_END_OF_LIST);
t22=C_set_block_item(((C_word*)t0)[9],0,C_fix(0));
t23=C_set_block_item(((C_word*)t0)[21],0,C_SCHEME_END_OF_LIST);
t24=C_set_block_item(((C_word*)t0)[22],0,C_fix(0));
t25=((C_word*)((C_word*)t0)[5])[1];
t26=C_i_caddr(t25);
t27=(*a=C_CLOSURE_TYPE|17,a[1]=(C_word)f_21803,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[22],a[4]=t17,a[5]=((C_word*)t0)[19],a[6]=t14,a[7]=((C_word*)t0)[20],a[8]=t15,a[9]=((C_word*)t0)[9],a[10]=t18,a[11]=((C_word*)t0)[21],a[12]=t16,a[13]=t19,a[14]=((C_word*)t0)[23],a[15]=((C_word*)t0)[24],a[16]=((C_word*)t0)[11],a[17]=((C_word*)t0)[16],tmp=(C_word)a,a+=18,tmp);
/* core.scm:2943: ##sys#decompose-lambda-list */
t28=*((C_word*)lf[191]+1);{
C_word av2[4];
av2[0]=t28;
av2[1]=((C_word*)t0)[2];
av2[2]=t26;
av2[3]=t27;
((C_proc)(void*)(*((C_word*)t28+1)))(4,av2);}}
else{
t14=C_eqp(((C_word*)t0)[4],lf[174]);
if(C_truep(t14)){
t15=((C_word*)((C_word*)t0)[5])[1];
t16=C_i_car(t15);
t17=C_i_car(((C_word*)t0)[11]);
t18=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22035,a[2]=t16,a[3]=((C_word*)t0)[19],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[11],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[16],a[8]=((C_word*)t0)[12],a[9]=((C_word*)t0)[13],a[10]=((C_word*)t0)[7],a[11]=((C_word*)t0)[5],a[12]=t17,tmp=(C_word)a,a+=13,tmp);
/* core.scm:3002: chicken.compiler.support#node-class */
t19=*((C_word*)lf[98]+1);{
C_word av2[3];
av2[0]=t19;
av2[1]=t18;
av2[2]=t17;
((C_proc)(void*)(*((C_word*)t19+1)))(3,av2);}}
else{
t15=C_eqp(((C_word*)t0)[4],lf[636]);
if(C_truep(t15)){
t16=((C_word*)((C_word*)t0)[5])[1];
t17=C_i_car(t16);
t18=C_i_car(((C_word*)t0)[11]);
t19=C_a_i_cons(&a,2,t17,((C_word*)((C_word*)t0)[20])[1]);
t20=C_mutate(((C_word *)((C_word*)t0)[20])+1,t19);
t21=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22062,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[16],a[5]=((C_word*)t0)[11],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[12],a[9]=((C_word*)t0)[13],tmp=(C_word)a,a+=10,tmp);
/* core.scm:3017: walk */
t22=((C_word*)((C_word*)t0)[16])[1];
f_21487(t22,t21,t18,((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[12],((C_word*)t0)[13]);}
else{
t16=C_eqp(((C_word*)t0)[4],lf[286]);
if(C_truep(t16)){
t17=((C_word*)((C_word*)t0)[5])[1];
t18=C_i_car(t17);
t19=C_i_car(((C_word*)t0)[11]);
t20=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_22085,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[16],a[4]=t19,a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[12],a[7]=((C_word*)t0)[13],a[8]=((C_word*)t0)[2],a[9]=t18,a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[25],a[12]=((C_word*)t0)[18],a[13]=((C_word*)t0)[26],a[14]=((C_word*)t0)[5],tmp=(C_word)a,a+=15,tmp);
/* core.scm:3023: posq */
f_7486(t20,t18,((C_word*)t0)[7]);}
else{
t17=C_eqp(((C_word*)t0)[4],lf[523]);
if(C_truep(t17)){
t18=C_i_cdr(((C_word*)t0)[11]);
t19=C_i_length(t18);
t20=C_i_cdr(((C_word*)((C_word*)t0)[5])[1]);
t21=C_i_pairp(t20);
t22=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_22218,a[2]=((C_word*)t0)[21],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[11],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[12],a[11]=((C_word*)t0)[13],a[12]=((C_word*)t0)[14],a[13]=((C_word*)t0)[15],a[14]=((C_word*)t0)[22],a[15]=t19,tmp=(C_word)a,a+=16,tmp);
if(C_truep(t21)){
t23=((C_word*)((C_word*)t0)[5])[1];
t24=t22;
f_22218(t24,C_i_cadr(t23));}
else{
t23=t22;
f_22218(t23,C_SCHEME_FALSE);}}
else{
t18=C_eqp(((C_word*)t0)[4],lf[541]);
if(C_truep(t18)){
t19=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22303,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[11],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[12],a[10]=((C_word*)t0)[13],tmp=(C_word)a,a+=11,tmp);
t20=((C_word*)((C_word*)t0)[5])[1];
if(C_truep(C_i_car(t20))){
t21=((C_word*)((C_word*)t0)[22])[1];
t22=C_mutate(((C_word *)((C_word*)t0)[22])+1,C_s_a_i_plus(&a,2,t21,C_fix(1)));
t23=t19;
f_22303(t23,t22);}
else{
t21=t19;
f_22303(t21,C_SCHEME_UNDEFINED);}}
else{
t19=C_eqp(((C_word*)t0)[4],lf[116]);
if(C_truep(t19)){
t20=((C_word*)((C_word*)t0)[5])[1];
t21=C_i_car(t20);
t22=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22330,a[2]=((C_word*)t0)[27],a[3]=((C_word*)t0)[2],a[4]=t21,a[5]=((C_word*)t0)[18],tmp=(C_word)a,a+=6,tmp);
if(C_truep(C_fixnump(t21))){
t23=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22439,a[2]=t22,tmp=(C_word)a,a+=3,tmp);
/* core.scm:3068: chicken.compiler.support#big-fixnum? */
t24=*((C_word*)lf[698]+1);{
C_word av2[3];
av2[0]=t24;
av2[1]=t23;
av2[2]=t21;
((C_proc)(void*)(*((C_word*)t24+1)))(3,av2);}}
else{
t23=t22;
f_22330(t23,C_SCHEME_FALSE);}}
else{
t20=C_eqp(((C_word*)t0)[4],lf[142]);
t21=(C_truep(t20)?t20:C_eqp(((C_word*)t0)[4],lf[633]));
if(C_truep(t21)){
t22=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22451,a[2]=((C_word*)t0)[19],a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[16],a[8]=((C_word*)t0)[11],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],tmp=(C_word)a,a+=13,tmp);
/* core.scm:3084: walk */
t23=((C_word*)((C_word*)t0)[16])[1];
f_21487(t23,t22,C_i_car(((C_word*)t0)[11]),((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[12],((C_word*)t0)[13]);}
else{
t22=C_eqp(((C_word*)t0)[4],lf[632]);
if(C_truep(t22)){
t23=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_22517,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[11],a[7]=((C_word*)t0)[16],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[12],a[11]=((C_word*)t0)[13],tmp=(C_word)a,a+=12,tmp);
/* core.scm:3096: walk */
t24=((C_word*)((C_word*)t0)[16])[1];
f_21487(t24,t23,C_i_car(((C_word*)t0)[11]),((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[12],((C_word*)t0)[13]);}
else{
t23=C_eqp(((C_word*)t0)[4],lf[188]);
if(C_truep(t23)){
t24=((C_word*)((C_word*)t0)[14])[1];
t25=C_a_i_cons(&a,2,t24,((C_word*)((C_word*)t0)[5])[1]);
t26=C_a_i_cons(&a,2,t25,((C_word*)((C_word*)t0)[15])[1]);
t27=C_mutate(((C_word *)((C_word*)t0)[15])+1,t26);
t28=((C_word*)((C_word*)t0)[14])[1];
t29=C_mutate(((C_word *)((C_word*)t0)[14])+1,C_s_a_i_plus(&a,2,t28,C_fix(1)));
/* core.scm:3120: chicken.compiler.support#make-node */
t30=*((C_word*)lf[489]+1);{
C_word av2[5];
av2[0]=t30;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[4];
av2[3]=t25;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t30+1)))(5,av2);}}
else{
t24=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22630,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* core.scm:3122: mapwalk */
t25=((C_word*)((C_word*)t0)[10])[1];
f_22697(t25,t24,((C_word*)t0)[11],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[12],((C_word*)t0)[13]);}}}}}}}}}}}}}}}}}}}}}}

/* k21532 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21534(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(34,0,6)))){
C_save_and_reclaim_args((void *)trf_21534,2,t0,t1);}
a=C_alloc(34);
t2=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[2])[1],((C_word*)t0)[3]);
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21545,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2887: mapwalk */
t5=((C_word*)((C_word*)t0)[7])[1];
f_22697(t5,t4,((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11],((C_word*)t0)[12]);}

/* k21543 in k21532 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21545(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21545,c,av);}
/* core.scm:2887: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)((C_word*)t0)[4])[1];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k21563 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21565(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_21565,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_21569,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:2881: chicken.compiler.support#source-info->name */
t3=*((C_word*)lf[682]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k21567 in k21563 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21569(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(47,c,1)))){
C_save_and_reclaim((void *)f_21569,c,av);}
a=C_alloc(47);
t2=C_a_i_list4(&a,4,((C_word*)((C_word*)t0)[2])[1],lf[681],((C_word*)t0)[3],t1);
t3=C_a_i_cons(&a,2,((C_word*)((C_word*)t0)[2])[1],((C_word*)((C_word*)t0)[4])[1]);
t4=C_mutate(((C_word *)((C_word*)t0)[4])+1,t3);
t5=C_a_i_cons(&a,2,t2,((C_word*)((C_word*)t0)[5])[1]);
t6=C_mutate(((C_word *)((C_word*)t0)[5])+1,t5);
t7=((C_word*)((C_word*)t0)[2])[1];
t8=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_s_a_i_plus(&a,2,t7,C_fix(1)));
t9=((C_word*)t0)[6];
f_21534(t9,t8);}

/* k21588 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21590(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21590,c,av);}
/* core.scm:2891: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)((C_word*)t0)[4])[1];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k21609 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21611(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21611,c,av);}
/* core.scm:2895: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)((C_word*)t0)[4])[1];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k21626 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21628(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,4)))){
C_save_and_reclaim((void *)f_21628,c,av);}
a=C_alloc(29);
t2=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[2])[1],t1);
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
/* core.scm:2899: chicken.compiler.support#make-node */
t4=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)((C_word*)t0)[5])[1];
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k21630 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21632(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21632,c,av);}
/* core.scm:2898: chicken.compiler.support#bytes->words */
t2=*((C_word*)lf[342]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k21651 in k21655 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21653(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21653,c,av);}
/* core.scm:2903: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)((C_word*)t0)[4])[1];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k21655 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21657(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(34,c,6)))){
C_save_and_reclaim((void *)f_21657,c,av);}
a=C_alloc(34);
t2=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[2])[1],t1);
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21653,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2903: mapwalk */
t5=((C_word*)((C_word*)t0)[6])[1];
f_22697(t5,t4,((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11]);}

/* k21659 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21661(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21661,c,av);}
/* core.scm:2902: chicken.compiler.support#bytes->words */
t2=*((C_word*)lf[342]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k21680 */
static void C_ccall f_21682(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21682,c,av);}
/* core.scm:2907: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[620];
av2[3]=((C_word*)((C_word*)t0)[3])[1];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k21705 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21707(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_21707,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:2911: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[619];
av2[3]=((C_word*)((C_word*)t0)[3])[1];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21721 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21723(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_21723,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21733,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21753,a[2]=t2,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2917: chicken.compiler.support#node-class */
t4=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k21731 in k21721 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_21733(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,4)))){
C_save_and_reclaim_args((void *)trf_21733,2,t0,t1);}
a=C_alloc(29);
if(C_truep(t1)){
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_s_a_i_plus(&a,2,t2,C_fix(1)));
/* core.scm:2916: chicken.compiler.support#make-node */
t4=*((C_word*)lf[489]+1);{
C_word av2[5];
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[626];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
/* core.scm:2916: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word av2[5];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}}

/* k21747 in k21751 in k21721 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21749(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21749,c,av);}
t2=((C_word*)t0)[2];
f_21733(t2,C_i_memq(C_i_car(t1),((C_word*)t0)[3]));}

/* k21751 in k21721 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21753(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_21753,c,av);}
a=C_alloc(4);
t2=C_eqp(lf[526],t1);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21749,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2918: chicken.compiler.support#node-parameters */
t4=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=((C_word*)t0)[2];
f_21733(t3,C_SCHEME_FALSE);}}

/* k21760 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21762(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,4)))){
C_save_and_reclaim((void *)f_21762,c,av);}
a=C_alloc(32);
t2=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[2])[1],C_fix(8));
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t4=C_a_i_list1(&a,1,t1);
/* core.scm:2929: chicken.compiler.support#make-node */
t5=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=t4;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21803(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(28,c,4)))){
C_save_and_reclaim((void *)f_21803,c,av);}
a=C_alloc(28);
t5=((C_word*)((C_word*)t0)[2])[1];
t6=C_i_car(t5);
t7=(*a=C_CLOSURE_TYPE|22,a[1]=(C_word)f_21810,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[2],a[12]=t1,a[13]=((C_word*)t0)[12],a[14]=t3,a[15]=((C_word*)t0)[13],a[16]=t6,a[17]=t2,a[18]=t4,a[19]=((C_word*)t0)[14],a[20]=((C_word*)t0)[15],a[21]=((C_word*)t0)[16],a[22]=((C_word*)t0)[17],tmp=(C_word)a,a+=23,tmp);
if(C_truep(t4)){
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21938,a[2]=t7,a[3]=((C_word*)t0)[15],a[4]=t4,tmp=(C_word)a,a+=5,tmp);
/* core.scm:2949: chicken.compiler.support#db-get */
t9=*((C_word*)lf[540]+1);{
C_word *av2=av;
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[15];
av2[3]=t4;
av2[4]=lf[579];
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}
else{
t8=t7;{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_SCHEME_FALSE;
f_21810(2,av2);}}}

/* k21808 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21810(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,c,2)))){
C_save_and_reclaim((void *)f_21810,c,av);}
a=C_alloc(33);
t2=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_21813,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=t1,a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],tmp=(C_word)a,a+=22,tmp);
t3=C_i_car(((C_word*)t0)[21]);
t4=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_21908,a[2]=t1,a[3]=((C_word*)t0)[17],a[4]=((C_word*)t0)[22],a[5]=t2,a[6]=t3,a[7]=((C_word*)t0)[16],tmp=(C_word)a,a+=8,tmp);
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21929,a[2]=t4,tmp=(C_word)a,a+=3,tmp);
t6=C_eqp(lf[686],t1);
if(C_truep(t6)){
/* core.scm:2957: chicken.base#butlast */
t7=*((C_word*)lf[689]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t5;
av2[2]=((C_word*)t0)[17];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}
else{
/* core.scm:2956: ##sys#fast-reverse */
t7=*((C_word*)lf[688]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t7;
av2[1]=t4;
av2[2]=((C_word*)t0)[17];
((C_proc)(void*)(*((C_word*)t7+1)))(3,av2);}}}

/* k21811 in k21808 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21813(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,5)))){
C_save_and_reclaim((void *)f_21813,c,av);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|22,a[1]=(C_word)f_21816,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=t1,a[21]=((C_word*)t0)[20],a[22]=((C_word*)t0)[21],tmp=(C_word)a,a+=23,tmp);
t3=C_eqp(((C_word*)t0)[19],lf[686]);
if(C_truep(t3)){
/* core.scm:2965: chicken.compiler.support#debugging */
t4=*((C_word*)lf[596]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[643];
av2[3]=lf[687];
av2[4]=((C_word*)t0)[18];
av2[5]=((C_word*)t0)[16];
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_21816(2,av2);}}}

/* k21814 in k21811 in k21808 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21816(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,5)))){
C_save_and_reclaim((void *)f_21816,c,av);}
a=C_alloc(23);
t2=(*a=C_CLOSURE_TYPE|22,a[1]=(C_word)f_21819,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],a[22]=((C_word*)t0)[22],tmp=(C_word)a,a+=23,tmp);
t3=(C_truep(((C_word*)t0)[15])?((C_word*)t0)[18]:C_SCHEME_FALSE);
if(C_truep(t3)){
/* core.scm:2967: chicken.compiler.support#bomb */
t4=*((C_word*)lf[533]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[685];
av2[3]=((C_word*)t0)[16];
av2[4]=((C_word*)((C_word*)t0)[8])[1];
av2[5]=((C_word*)t0)[18];
((C_proc)(void*)(*((C_word*)t4+1)))(6,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_21819(2,av2);}}}

/* k21817 in k21814 in k21811 in k21808 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_21819(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(63,c,4)))){
C_save_and_reclaim((void *)f_21819,c,av);}
a=C_alloc(63);
t2=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_21822,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],tmp=(C_word)a,a+=15,tmp);
t3=((C_word*)((C_word*)t0)[11])[1];
t4=C_i_cadr(t3);
t5=((C_word*)((C_word*)t0)[4])[1];
t6=C_s_a_i_plus(&a,2,t5,C_fix(1));
t7=(C_truep(((C_word*)t0)[15])?((C_word*)t0)[15]:C_i_memq(((C_word*)t0)[16],lf[68]));
t8=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_21859,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[10],a[4]=((C_word*)t0)[8],a[5]=((C_word*)t0)[16],a[6]=t4,a[7]=((C_word*)t0)[17],a[8]=((C_word*)t0)[14],a[9]=((C_word*)t0)[18],a[10]=t6,a[11]=t7,a[12]=((C_word*)t0)[19],a[13]=((C_word*)t0)[20],a[14]=((C_word*)t0)[15],a[15]=t2,a[16]=((C_word*)t0)[21],a[17]=((C_word*)t0)[22],a[18]=((C_word*)t0)[2],tmp=(C_word)a,a+=19,tmp);
/* core.scm:2982: chicken.compiler.support#db-get */
t9=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=((C_word*)t0)[22];
av2[3]=((C_word*)t0)[16];
av2[4]=lf[613];
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* k21820 in k21817 in k21814 in k21811 in k21808 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_21822(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_21822,c,av);}
a=C_alloc(8);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=C_mutate(((C_word *)((C_word*)t0)[4])+1,((C_word*)t0)[5]);
t4=C_mutate(((C_word *)((C_word*)t0)[6])+1,((C_word*)t0)[7]);
t5=C_mutate(((C_word *)((C_word*)t0)[8])+1,((C_word*)t0)[9]);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_21830,a[2]=((C_word*)t0)[10],a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[12],tmp=(C_word)a,a+=5,tmp);
/* core.scm:2996: lset-adjoin/eq? */
f_7102(t6,((C_word*)t0)[13],C_a_i_list(&a,1,((C_word*)t0)[14]));}

/* k21828 in k21820 in k21817 in k21814 in k21811 in k21808 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_21830(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_21830,c,av);}
a=C_alloc(3);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=((C_word*)((C_word*)t0)[3])[1];
t4=C_i_car(t3);
t5=C_a_i_list1(&a,1,t4);
/* core.scm:2997: chicken.compiler.support#make-node */
t6=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[4];
av2[2]=lf[564];
av2[3]=t5;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}

/* k21857 in k21817 in k21814 in k21811 in k21808 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_21859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,5)))){
C_save_and_reclaim((void *)f_21859,c,av);}
a=C_alloc(22);
t2=(C_truep(t1)?t1:C_fix(0));
t3=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_21866,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t2,a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],tmp=(C_word)a,a+=19,tmp);
if(C_truep(C_i_not(((C_word*)t0)[9]))){
if(C_truep(C_i_greaterp(((C_word*)((C_word*)t0)[18])[1],C_fix(0)))){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_21885,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* core.scm:2986: chicken.compiler.support#debugging */
t5=*((C_word*)lf[596]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[643];
av2[3]=lf[684];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)((C_word*)t0)[18])[1];
((C_proc)(void*)(*((C_word*)t5+1)))(6,av2);}}
else{
t4=t3;
f_21866(t4,C_SCHEME_FALSE);}}
else{
t4=t3;
f_21866(t4,C_SCHEME_FALSE);}}

/* k21864 in k21857 in k21817 in k21814 in k21811 in k21808 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_fcall f_21866(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,4)))){
C_save_and_reclaim_args((void *)trf_21866,2,t0,t1);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|18,a[1]=(C_word)f_21870,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=t1,a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],tmp=(C_word)a,a+=19,tmp);
if(C_truep(((C_word*)t0)[15])){
t3=t2;{
C_word av2[2];
av2[0]=t3;
av2[1]=((C_word*)t0)[15];
f_21870(2,av2);}}
else{
/* core.scm:2988: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word av2[5];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[18];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[608];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k21868 in k21864 in k21857 in k21817 in k21814 in k21811 in k21808 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_21870(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,4)))){
C_save_and_reclaim((void *)f_21870,c,av);}
a=C_alloc(18);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=((C_word*)((C_word*)t0)[3])[1];
t4=((C_word*)((C_word*)t0)[4])[1];
t5=C_a_i_record(&a,17,lf[649],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],t2,t3,t4,((C_word*)t0)[11],((C_word*)t0)[12],((C_word*)t0)[13],t1,((C_word*)t0)[14],((C_word*)t0)[15],((C_word*)t0)[16]);
/* core.scm:2968: chicken.internal#hash-table-set! */
t6=*((C_word*)lf[346]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[17];
av2[2]=((C_word*)t0)[18];
av2[3]=((C_word*)t0)[5];
av2[4]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}

/* k21883 in k21857 in k21817 in k21814 in k21811 in k21808 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_21885(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_21885,c,av);}
t2=((C_word*)t0)[2];
f_21866(t2,C_SCHEME_TRUE);}

/* k21906 in k21808 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21908(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_21908,c,av);}
t2=C_eqp(lf[686],((C_word*)t0)[2]);
if(C_truep(t2)){
t3=C_i_length(((C_word*)t0)[3]);
/* core.scm:2954: walk */
t4=((C_word*)((C_word*)t0)[4])[1];
f_21487(t4,((C_word*)t0)[5],((C_word*)t0)[6],t1,C_fixnum_difference(t3,C_fix(1)),((C_word*)t0)[7],C_SCHEME_END_OF_LIST);}
else{
/* core.scm:2954: walk */
t3=((C_word*)((C_word*)t0)[4])[1];
f_21487(t3,((C_word*)t0)[5],((C_word*)t0)[6],t1,C_i_length(((C_word*)t0)[3]),((C_word*)t0)[7],C_SCHEME_END_OF_LIST);}}

/* k21927 in k21808 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21929(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_21929,c,av);}
/* core.scm:2956: ##sys#fast-reverse */
t2=*((C_word*)lf[688]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k21936 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21938(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_21938,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21944,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2950: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[556];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k21942 in k21936 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21944(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_21944,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[553];
f_21810(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_21969,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:2951: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[625];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k21967 in k21942 in k21936 in a21802 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_21969(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_21969,c,av);}
if(C_truep(C_i_not(t1))){
t2=C_i_not(((C_word*)t0)[2]);
if(C_truep(t2)){
if(C_truep(t2)){
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[686];
f_21810(2,av2);}}
else{
/* core.scm:2953: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[552];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}
else{
if(C_truep(C_i_nullp(((C_word*)t0)[2]))){
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=lf[686];
f_21810(2,av2);}}
else{
/* core.scm:2953: chicken.compiler.support#db-get */
t3=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[552];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}}
else{
/* core.scm:2953: chicken.compiler.support#db-get */
t2=*((C_word*)lf[540]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)t0)[5];
av2[4]=lf[552];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}}

/* k21999 in k22033 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22001(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,2)))){
C_save_and_reclaim((void *)f_22001,c,av);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22005,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t3=C_i_cadr(((C_word*)t0)[4]);
t4=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22013,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=t2,a[5]=t3,a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],tmp=(C_word)a,a+=9,tmp);
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22025,a[2]=t4,a[3]=((C_word*)t0)[10],tmp=(C_word)a,a+=4,tmp);
/* core.scm:3008: ##sys#fast-reverse */
t6=*((C_word*)lf[688]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)((C_word*)t0)[11])[1];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}

/* k22003 in k21999 in k22033 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22005(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22005,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:3004: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[690];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22011 in k21999 in k22033 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22013(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,3)))){
C_save_and_reclaim((void *)f_22013,c,av);}
a=C_alloc(8);
t2=C_fixnum_plus(((C_word*)t0)[2],C_fix(1));
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22021,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t1,a[6]=t2,a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
/* core.scm:3009: scheme#append */
t4=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[7];
av2[3]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k22019 in k22011 in k21999 in k22033 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22021(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_22021,c,av);}
/* core.scm:3007: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_21487(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],t1);}

/* k22023 in k21999 in k22033 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22025(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_22025,c,av);}
/* core.scm:3008: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k22033 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22035(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(47,c,6)))){
C_save_and_reclaim((void *)f_22035,c,av);}
a=C_alloc(47);
t2=C_eqp(lf[619],t1);
t3=(C_truep(t2)?C_a_i_list1(&a,1,((C_word*)t0)[2]):C_SCHEME_END_OF_LIST);
t4=((C_word*)((C_word*)t0)[3])[1];
t5=C_mutate(((C_word *)((C_word*)t0)[3])+1,C_s_a_i_plus(&a,2,t4,C_fix(1)));
t6=C_a_i_list1(&a,1,C_fix(1));
t7=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_22001,a[2]=((C_word*)t0)[4],a[3]=t6,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=t3,a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
/* core.scm:3006: walk */
t8=((C_word*)((C_word*)t0)[7])[1];
f_21487(t8,t7,((C_word*)t0)[12],((C_word*)t0)[10],((C_word*)t0)[6],((C_word*)t0)[8],((C_word*)t0)[9]);}

/* k22060 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22062(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,6)))){
C_save_and_reclaim((void *)f_22062,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22066,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:3018: walk */
t3=((C_word*)((C_word*)t0)[4])[1];
f_21487(t3,t2,C_i_cadr(((C_word*)t0)[5]),((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}

/* k22064 in k22060 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22066(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_22066,c,av);}
a=C_alloc(6);
t2=C_a_i_list2(&a,2,((C_word*)t0)[2],t1);
/* core.scm:3015: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[636];
av2[3]=((C_word*)((C_word*)t0)[4])[1];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22083 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22085(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,3)))){
C_save_and_reclaim((void *)f_22085,c,av);}
a=C_alloc(15);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22089,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
/* core.scm:3023: g5077 */
t3=t2;
f_22089(t3,((C_word*)t0)[8],t1);}
else{
t2=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_22119,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[8],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=((C_word*)t0)[14],a[14]=((C_word*)t0)[4],tmp=(C_word)a,a+=15,tmp);
/* core.scm:3029: chicken.compiler.support#node-class */
t3=*((C_word*)lf[98]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* g5077 in k22083 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22089(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,6)))){
C_save_and_reclaim_args((void *)trf_22089,3,t0,t1,t2);}
a=C_alloc(7);
t3=C_fixnum_plus(t2,C_fix(1));
t4=C_fixnum_difference(((C_word*)t0)[2],t3);
t5=C_a_i_list1(&a,1,t4);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22105,a[2]=t1,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* core.scm:3027: walk */
t7=((C_word*)((C_word*)t0)[3])[1];
f_21487(t7,t6,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[2],((C_word*)t0)[6],((C_word*)t0)[7]);}

/* k22103 in g5077 in k22083 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22105(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_22105,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:3025: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[691];
av2[3]=((C_word*)t0)[3];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22117 in k22083 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22119(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,3)))){
C_save_and_reclaim((void *)f_22119,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_22203,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=t1,a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
/* core.scm:3030: chicken.compiler.support#variable-visible? */
t3=*((C_word*)lf[574]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[2];
av2[3]=*((C_word*)lf[25]+1);
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k22123 in k22201 in k22117 in k22083 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22125(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,2)))){
C_save_and_reclaim((void *)f_22125,c,av);}
a=C_alloc(14);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_22128,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],tmp=(C_word)a,a+=14,tmp);
if(C_truep(t1)){
t3=t2;
f_22128(t3,t1);}
else{
t3=C_i_cdr(((C_word*)((C_word*)t0)[14])[1]);
if(C_truep(C_i_pairp(t3))){
t4=((C_word*)((C_word*)t0)[14])[1];
t5=C_i_cadr(t4);
t6=t2;
f_22128(t6,(C_truep(t5)?t5:C_eqp(lf[478],((C_word*)t0)[15])));}
else{
t4=t2;
f_22128(t4,C_eqp(lf[478],((C_word*)t0)[15]));}}}

/* k22126 in k22123 in k22201 in k22117 in k22083 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_22128(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(43,0,2)))){
C_save_and_reclaim_args((void *)trf_22128,2,t0,t1);}
a=C_alloc(43);
t2=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_22131,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],tmp=(C_word)a,a+=14,tmp);
if(C_truep(((C_word*)t0)[2])){
t3=((C_word*)((C_word*)t0)[13])[1];
t4=C_mutate(((C_word *)((C_word*)t0)[13])+1,C_s_a_i_plus(&a,2,t3,C_fix(1)));
t5=t2;
f_22131(t5,t4);}
else{
t3=t2;
f_22131(t3,C_SCHEME_UNDEFINED);}}

/* k22129 in k22126 in k22123 in k22201 in k22117 in k22083 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_22131(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_22131,2,t0,t1);}
a=C_alloc(12);
t2=(C_truep(((C_word*)t0)[2])?lf[692]:lf[693]);
t3=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_22158,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t2,a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
if(C_truep(((C_word*)t0)[3])){
/* core.scm:3039: blockvar-literal */
t4=((C_word*)((C_word*)t0)[12])[1];
f_22805(t4,t3,((C_word*)t0)[4]);}
else{
/* core.scm:3040: literal */
t4=((C_word*)((C_word*)t0)[13])[1];
f_22748(t4,t3,((C_word*)t0)[4]);}}

/* k22148 in k22156 in k22129 in k22126 in k22123 in k22201 in k22117 in k22083 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_22150(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_22150,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:3036: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22156 in k22129 in k22126 in k22123 in k22201 in k22117 in k22083 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_22158(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,6)))){
C_save_and_reclaim((void *)f_22158,c,av);}
a=C_alloc(14);
t2=C_a_i_list3(&a,3,t1,((C_word*)t0)[2],((C_word*)t0)[3]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22150,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:3043: walk */
t4=((C_word*)((C_word*)t0)[6])[1];
f_21487(t4,t3,C_i_car(((C_word*)t0)[7]),((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11]);}

/* k22197 in k22201 in k22117 in k22083 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22199(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22199,c,av);}
/* core.scm:3032: chicken.compiler.support#immediate? */
t2=*((C_word*)lf[630]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=C_i_car(t1);
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k22201 in k22117 in k22083 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22203(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_22203,c,av);}
a=C_alloc(19);
t2=C_i_not(t1);
t3=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_22125,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
t4=C_eqp(((C_word*)t0)[14],lf[116]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22199,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* core.scm:3032: chicken.compiler.support#node-parameters */
t6=*((C_word*)lf[527]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=((C_word*)t0)[15];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=t3;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_22125(2,av2);}}}

/* k22216 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22218(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,0,3)))){
C_save_and_reclaim_args((void *)trf_22218,2,t0,t1);}
a=C_alloc(19);
t2=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_22222,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=t1,a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
/* core.scm:3049: lset-adjoin/eq? */
f_7102(t2,((C_word*)((C_word*)t0)[2])[1],C_a_i_list(&a,1,((C_word*)t0)[15]));}

/* k22220 in k22216 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22222(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,2)))){
C_save_and_reclaim((void *)f_22222,c,av);}
a=C_alloc(18);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_22225,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=((C_word*)t0)[14],tmp=(C_word)a,a+=14,tmp);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22266,a[2]=((C_word*)t0)[15],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t5=C_i_length(((C_word*)((C_word*)t0)[5])[1]);
if(C_truep(C_fixnum_greater_or_equal_p(t5,C_fix(3)))){
t6=((C_word*)((C_word*)t0)[5])[1];
t7=t4;
f_22266(t7,C_eqp(((C_word*)t0)[10],C_i_caddr(t6)));}
else{
t6=t4;
f_22266(t6,C_SCHEME_FALSE);}}

/* k22223 in k22220 in k22216 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22225(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,0,2)))){
C_save_and_reclaim_args((void *)trf_22225,2,t0,t1);}
a=C_alloc(18);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_22228,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
t3=(C_truep(*((C_word*)lf[24]+1))?((C_word*)t0)[11]:C_SCHEME_FALSE);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22255,a[2]=((C_word*)t0)[12],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[13],a[5]=t2,a[6]=((C_word*)t0)[11],tmp=(C_word)a,a+=7,tmp);
/* core.scm:3054: chicken.compiler.support#source-info->line */
t5=*((C_word*)lf[683]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=C_a_i_cons(&a,2,C_SCHEME_FALSE,((C_word*)((C_word*)t0)[4])[1]);
t5=C_mutate(((C_word *)((C_word*)t0)[4])+1,t4);
t6=t2;
f_22228(t6,t5);}}

/* k22226 in k22223 in k22220 in k22216 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22228(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,6)))){
C_save_and_reclaim_args((void *)trf_22228,2,t0,t1);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22235,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:3060: mapwalk */
t3=((C_word*)((C_word*)t0)[5])[1];
f_22697(t3,t2,((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10]);}

/* k22233 in k22226 in k22223 in k22220 in k22216 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_22235(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22235,c,av);}
/* core.scm:3060: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)((C_word*)t0)[4])[1];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k22253 in k22223 in k22220 in k22216 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22255(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_22255,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22259,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:3055: chicken.compiler.support#source-info->name */
t3=*((C_word*)lf[682]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22257 in k22253 in k22223 in k22220 in k22216 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_22259(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(47,c,1)))){
C_save_and_reclaim((void *)f_22259,c,av);}
a=C_alloc(47);
t2=C_a_i_list4(&a,4,((C_word*)((C_word*)t0)[2])[1],lf[681],((C_word*)t0)[3],t1);
t3=C_a_i_cons(&a,2,((C_word*)((C_word*)t0)[2])[1],((C_word*)((C_word*)t0)[4])[1]);
t4=C_mutate(((C_word *)((C_word*)t0)[4])+1,t3);
t5=C_a_i_cons(&a,2,t2,((C_word*)((C_word*)t0)[5])[1]);
t6=C_mutate(((C_word *)((C_word*)t0)[5])+1,t5);
t7=((C_word*)((C_word*)t0)[2])[1];
t8=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_s_a_i_plus(&a,2,t7,C_fix(1)));
t9=((C_word*)t0)[6];
f_22228(t9,t8);}

/* k22264 in k22220 in k22216 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22266(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,0,1)))){
C_save_and_reclaim_args((void *)trf_22266,2,t0,t1);}
a=C_alloc(29);
if(C_truep(t1)){
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_s_a_i_plus(&a,2,t2,C_fix(1)));
t4=((C_word*)t0)[3];
f_22225(t4,t3);}
else{
t2=((C_word*)t0)[3];
f_22225(t2,C_SCHEME_UNDEFINED);}}

/* k22301 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22303(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,6)))){
C_save_and_reclaim_args((void *)trf_22303,2,t0,t1);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22310,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:3064: mapwalk */
t3=((C_word*)((C_word*)t0)[5])[1];
f_22697(t3,t2,((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10]);}

/* k22308 in k22301 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22310(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22310,c,av);}
/* core.scm:3064: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)((C_word*)t0)[4])[1];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22330(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_22330,2,t0,t1);}
a=C_alloc(8);
if(C_truep(t1)){
/* core.scm:3069: immediate-literal */
f_22849(((C_word*)t0)[3],((C_word*)t0)[4]);}
else{
if(C_truep(C_i_numberp(((C_word*)t0)[4]))){
t2=C_eqp(lf[380],*((C_word*)lf[379]+1));
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22351,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_integerp(((C_word*)t0)[4]))){
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22398,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* core.scm:3072: chicken.compiler.support#big-fixnum? */
t5=*((C_word*)lf[698]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=t3;
f_22351(t4,C_SCHEME_FALSE);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22409,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* core.scm:3079: literal */
t4=((C_word*)((C_word*)t0)[5])[1];
f_22748(t4,t3,((C_word*)t0)[4]);}}
else{
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22415,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
/* core.scm:3080: chicken.compiler.support#immediate? */
t3=*((C_word*)lf[630]+1);{
C_word av2[3];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}}

/* k22349 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22351(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_22351,2,t0,t1);}
a=C_alloc(9);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22354,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22365,a[2]=t2,a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:3074: chicken.base#open-output-string */
t4=*((C_word*)lf[131]+1);{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* core.scm:3078: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word av2[4];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[697];
av2[3]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k22352 in k22349 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22354(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_22354,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22361,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:3077: scheme#inexact->exact */
t3=*((C_word*)lf[694]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22359 in k22352 in k22349 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22361(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22361,c,av);}
/* core.scm:3077: immediate-literal */
f_22849(((C_word*)t0)[3],t1);}

/* k22363 in k22349 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22365(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22365,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22371,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:3074: ##sys#print */
t4=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[696];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k22369 in k22363 in k22349 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22371(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22371,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22374,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:3074: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22372 in k22369 in k22363 in k22349 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_22374(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_22374,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22377,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
/* core.scm:3074: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[695];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22375 in k22372 in k22369 in k22363 in k22349 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_22377(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_22377,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22380,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22387,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:3076: scheme#inexact->exact */
t4=*((C_word*)lf[694]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k22378 in k22375 in k22372 in k22369 in k22363 in k22349 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_22380(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_22380,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22383,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:3074: chicken.base#get-output-string */
t3=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22381 in k22378 in k22375 in k22372 in k22369 in k22363 in k22349 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_22383(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_22383,c,av);}
/* core.scm:3073: chicken.base#warning */
t2=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k22385 in k22375 in k22372 in k22369 in k22363 in k22349 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_22387(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22387,c,av);}
/* core.scm:3074: ##sys#print */
t2=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k22396 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22398(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_22398,c,av);}
t2=((C_word*)t0)[2];
f_22351(t2,C_i_not(t1));}

/* k22407 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22409(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_22409,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:3079: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[679];
av2[3]=t2;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22413 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22415(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_22415,c,av);}
a=C_alloc(3);
if(C_truep(t1)){
/* core.scm:3080: immediate-literal */
f_22849(((C_word*)t0)[3],((C_word*)t0)[4]);}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22429,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* core.scm:3081: literal */
t3=((C_word*)((C_word*)t0)[5])[1];
f_22748(t3,t2,((C_word*)t0)[4]);}}

/* k22427 in k22413 in k22328 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22429(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_22429,c,av);}
a=C_alloc(3);
t2=C_a_i_list1(&a,1,t1);
/* core.scm:3081: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[679];
av2[3]=t2;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k22437 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22439(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_22439,c,av);}
t2=((C_word*)t0)[2];
f_22330(t2,C_i_not(t1));}

/* k22449 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22451(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,6)))){
C_save_and_reclaim((void *)f_22451,c,av);}
a=C_alloc(16);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=((C_word*)((C_word*)t0)[3])[1];
t4=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_22454,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t3,a[5]=t2,a[6]=t1,a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],a[10]=((C_word*)t0)[7],a[11]=((C_word*)t0)[8],a[12]=((C_word*)t0)[9],a[13]=((C_word*)t0)[10],a[14]=((C_word*)t0)[11],a[15]=((C_word*)t0)[12],tmp=(C_word)a,a+=16,tmp);
/* core.scm:3087: walk */
t5=((C_word*)((C_word*)t0)[7])[1];
f_21487(t5,t4,C_i_cadr(((C_word*)t0)[8]),((C_word*)t0)[9],((C_word*)t0)[10],((C_word*)t0)[11],((C_word*)t0)[12]);}

/* k22452 in k22449 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22454(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,6)))){
C_save_and_reclaim((void *)f_22454,c,av);}
a=C_alloc(13);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=((C_word*)((C_word*)t0)[3])[1];
t4=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22457,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[6],a[7]=t1,a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=t2,a[12]=t3,tmp=(C_word)a,a+=13,tmp);
/* core.scm:3090: walk */
t5=((C_word*)((C_word*)t0)[10])[1];
f_21487(t5,t4,C_i_caddr(((C_word*)t0)[11]),((C_word*)t0)[12],((C_word*)t0)[13],((C_word*)t0)[14],((C_word*)t0)[15]);}

/* k22455 in k22452 in k22449 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22457(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(71,c,3)))){
C_save_and_reclaim((void *)f_22457,c,av);}
a=C_alloc(71);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_22488,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
t3=C_s_a_i_minus(&a,2,((C_word*)((C_word*)t0)[3])[1],((C_word*)t0)[12]);
t4=C_s_a_i_minus(&a,2,((C_word*)t0)[12],((C_word*)t0)[2]);
/* core.scm:3091: scheme#max */
t5=*((C_word*)lf[699]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=t2;
av2[2]=t3;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* k22474 in k22486 in k22455 in k22452 in k22449 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_22476(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(38,c,4)))){
C_save_and_reclaim((void *)f_22476,c,av);}
a=C_alloc(38);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],t1);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,t2);
t4=C_a_i_list3(&a,3,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6]);
/* core.scm:3093: chicken.compiler.support#make-node */
t5=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[7];
av2[2]=((C_word*)t0)[8];
av2[3]=((C_word*)((C_word*)t0)[9])[1];
av2[4]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}

/* k22486 in k22455 in k22452 in k22449 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22488(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(97,c,3)))){
C_save_and_reclaim((void *)f_22488,c,av);}
a=C_alloc(97);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],t1);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,t2);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22476,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[11],tmp=(C_word)a,a+=10,tmp);
t5=C_s_a_i_minus(&a,2,((C_word*)((C_word*)t0)[5])[1],((C_word*)t0)[12]);
t6=C_s_a_i_minus(&a,2,((C_word*)t0)[12],((C_word*)t0)[4]);
/* core.scm:3092: scheme#max */
t7=*((C_word*)lf[699]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t4;
av2[2]=t5;
av2[3]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k22515 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22517(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,5)))){
C_save_and_reclaim((void *)f_22517,c,av);}
a=C_alloc(18);
t2=((C_word*)((C_word*)t0)[2])[1];
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22528,a[2]=t1,a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t4=((C_word*)((C_word*)t0)[5])[1];
t5=C_i_car(t4);
t6=C_i_cdr(((C_word*)t0)[6]);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22538,a[2]=((C_word*)t0)[2],a[3]=t2,a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[11],a[9]=t8,tmp=(C_word)a,a+=10,tmp));
t10=((C_word*)t8)[1];
f_22538(t10,t3,t5,t6,C_fix(0));}

/* k22526 in k22515 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22528(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,4)))){
C_save_and_reclaim((void *)f_22528,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
/* core.scm:3098: chicken.compiler.support#make-node */
t3=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
av2[2]=((C_word*)t0)[4];
av2[3]=((C_word*)((C_word*)t0)[5])[1];
av2[4]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* loop in k22515 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22538(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,0,6)))){
C_save_and_reclaim_args((void *)trf_22538,5,t0,t1,t2,t3,t4);}
a=C_alloc(14);
t5=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
if(C_truep(C_i_zerop(t2))){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22547,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[2],a[4]=t1,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
/* core.scm:3106: walk */
t7=((C_word*)((C_word*)t0)[4])[1];
f_21487(t7,t6,C_i_car(t3),((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}
else{
t6=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_22569,a[2]=t1,a[3]=t2,a[4]=t3,a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[3],a[8]=t4,a[9]=((C_word*)t0)[4],a[10]=((C_word*)t0)[5],a[11]=((C_word*)t0)[6],a[12]=((C_word*)t0)[7],a[13]=((C_word*)t0)[8],tmp=(C_word)a,a+=14,tmp);
/* core.scm:3109: walk */
t7=((C_word*)((C_word*)t0)[4])[1];
f_21487(t7,t6,C_i_car(t3),((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}}

/* k22545 in loop in k22515 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22547(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(35,c,3)))){
C_save_and_reclaim((void *)f_22547,c,av);}
a=C_alloc(35);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22558,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,tmp=(C_word)a,a+=6,tmp);
t3=C_s_a_i_minus(&a,2,((C_word*)((C_word*)t0)[3])[1],((C_word*)t0)[2]);
/* core.scm:3107: scheme#max */
t4=*((C_word*)lf[699]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k22556 in k22545 in loop in k22515 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22558(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,1)))){
C_save_and_reclaim((void *)f_22558,c,av);}
a=C_alloc(32);
t2=C_s_a_i_plus(&a,2,((C_word*)t0)[2],t1);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,t2);
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_list1(&a,1,((C_word*)t0)[5]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k22567 in loop in k22515 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22569(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,6)))){
C_save_and_reclaim((void *)f_22569,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22572,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* core.scm:3110: walk */
t3=((C_word*)((C_word*)t0)[9])[1];
f_21487(t3,t2,C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[10],((C_word*)t0)[11],((C_word*)t0)[12],((C_word*)t0)[13]);}

/* k22570 in k22567 in loop in k22515 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22572(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(69,c,3)))){
C_save_and_reclaim((void *)f_22572,c,av);}
a=C_alloc(69);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22579,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t3=C_s_a_i_minus(&a,2,((C_word*)t0)[4],C_fix(1));
t4=C_i_cddr(((C_word*)t0)[5]);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22589,a[2]=((C_word*)t0)[6],a[3]=t2,a[4]=t3,a[5]=t4,tmp=(C_word)a,a+=6,tmp);
t6=C_s_a_i_minus(&a,2,((C_word*)((C_word*)t0)[7])[1],((C_word*)t0)[8]);
/* core.scm:3113: scheme#max */
t7=*((C_word*)lf[699]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t5;
av2[2]=t6;
av2[3]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k22577 in k22570 in k22567 in loop in k22515 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_22579(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_22579,c,av);}
a=C_alloc(6);
/* core.scm:3111: cons* */
f_6707(((C_word*)t0)[2],((C_word*)t0)[3],C_a_i_list(&a,2,((C_word*)t0)[4],t1));}

/* k22587 in k22570 in k22567 in loop in k22515 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_22589(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22589,c,av);}
/* core.scm:3113: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_22538(t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],t1);}

/* k22628 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22630(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22630,c,av);}
/* core.scm:3122: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)((C_word*)t0)[4])[1];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* mapwalk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22697(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6){
C_word tmp;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,0,3)))){
C_save_and_reclaim_args((void *)trf_22697,7,t0,t1,t2,t3,t4,t5,t6);}
a=C_alloc(20);
t7=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t8=t7;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=((C_word*)t9)[1];
t11=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22702,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t4,a[5]=t5,a[6]=t6,tmp=(C_word)a,a+=7,tmp);
t12=C_i_check_list_2(t2,lf[10]);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22714,a[2]=t9,a[3]=t14,a[4]=t11,a[5]=t10,tmp=(C_word)a,a+=6,tmp));
t16=((C_word*)t14)[1];
f_22714(t16,t1,t2);}

/* g5175 in mapwalk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22702(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,6)))){
C_save_and_reclaim_args((void *)trf_22702,3,t0,t1,t2);}
/* core.scm:3125: walk */
t3=((C_word*)((C_word*)t0)[2])[1];
f_21487(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6]);}

/* map-loop5169 in mapwalk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22714(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_22714,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22739,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:3125: g5175 */
t4=((C_word*)t0)[4];
f_22702(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k22737 in map-loop5169 in mapwalk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22739(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_22739,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_22714(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22748(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_22748,3,t0,t1,t2);}
a=C_alloc(10);
t3=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22755,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
/* core.scm:3128: chicken.compiler.support#immediate? */
t4=*((C_word*)lf[630]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k22753 in literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22755(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(35,c,3)))){
C_save_and_reclaim((void *)f_22755,c,av);}
a=C_alloc(35);
if(C_truep(t1)){
/* core.scm:3128: immediate-literal */
f_22849(((C_word*)t0)[3],((C_word*)t0)[4]);}
else{
t2=(C_truep(C_blockp(((C_word*)t0)[4]))?C_lambdainfop(((C_word*)t0)[4]):C_SCHEME_FALSE);
if(C_truep(t2)){
t3=((C_word*)((C_word*)t0)[5])[1];
t4=C_a_i_cons(&a,2,((C_word*)t0)[4],((C_word*)((C_word*)t0)[6])[1]);
t5=C_mutate(((C_word *)((C_word*)t0)[6])+1,t4);
t6=((C_word*)((C_word*)t0)[5])[1];
t7=C_mutate(((C_word *)((C_word*)t0)[5])+1,C_s_a_i_plus(&a,2,t6,C_fix(1)));
t8=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t8;
av2[1]=C_a_i_vector1(&a,1,t3);
((C_proc)(void*)(*((C_word*)t8+1)))(2,av2);}}
else{
t3=((C_word*)((C_word*)t0)[7])[1];
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7526,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
t5=(
  f_7526(t4,C_fix(0),t3)
);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22780,a[2]=((C_word*)t0)[8],tmp=(C_word)a,a+=3,tmp);
/* core.scm:3128: g5205 */
t7=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t7;
av2[1]=(
/* core.scm:3128: g5205 */
  f_22780(t6,t5)
);
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}
else{
/* core.scm:3137: new-literal */
t6=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t6;
av2[1]=(
/* core.scm:3137: new-literal */
  f_22796(C_a_i(&a,32),((C_word*)((C_word*)t0)[9])[1],((C_word*)t0)[4])
);
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}}

/* g5205 in k22753 in literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static C_word C_fcall f_22780(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_stack_overflow_check;{}
return(C_fixnum_difference(((C_word*)((C_word*)t0)[2])[1],C_fixnum_plus(t1,C_fix(1))));}

/* new-literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static C_word C_fcall f_22796(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_stack_overflow_check;{}
t2=((C_word*)((C_word*)t0)[2])[1];
t3=C_a_i_cons(&a,2,t1,((C_word*)((C_word*)t0)[3])[1]);
t4=C_mutate(((C_word *)((C_word*)t0)[3])+1,t3);
t5=((C_word*)((C_word*)t0)[2])[1];
t6=C_mutate(((C_word *)((C_word*)t0)[2])+1,C_s_a_i_plus(&a,2,t5,C_fix(1)));
return(t2);}

/* blockvar-literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22805(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,0,4)))){
C_save_and_reclaim_args((void *)trf_22805,3,t0,t1,t2);}
a=C_alloc(15);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_22809,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22833,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t5=((C_word*)((C_word*)t0)[4])[1];
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7074,a[2]=t7,a[3]=t4,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_7074(t9,t3,C_fix(0),t5);}

/* k22807 in blockvar-literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22809(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_22809,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22813,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:3146: g5221 */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
/* core.scm:3146: g5221 */
  f_22813(t2,t1)
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22831,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:3152: chicken.compiler.support#make-block-variable-literal */
t3=*((C_word*)lf[700]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}}

/* g5221 in k22807 in blockvar-literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static C_word C_fcall f_22813(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_stack_overflow_check;{}
return(C_fixnum_difference(((C_word*)((C_word*)t0)[2])[1],C_fixnum_plus(t1,C_fix(1))));}

/* k22829 in k22807 in blockvar-literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22831(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,1)))){
C_save_and_reclaim((void *)f_22831,c,av);}
a=C_alloc(32);
/* core.scm:3152: new-literal */
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(
/* core.scm:3152: new-literal */
  f_22796(C_a_i(&a,32),((C_word*)((C_word*)t0)[3])[1],t1)
);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a22832 in blockvar-literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22833(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_22833,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_22840,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:3148: chicken.compiler.support#block-variable-literal? */
t4=*((C_word*)lf[702]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k22838 in a22832 in blockvar-literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22840(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_22840,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_22847,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:3149: chicken.compiler.support#block-variable-literal-name */
t3=*((C_word*)lf[701]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k22845 in k22838 in a22832 in blockvar-literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22847(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_22847,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_eqp(((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* immediate-literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_22849(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_22849,2,t1,t2);}
a=C_alloc(9);
t3=*((C_word*)lf[703]+1);
t4=C_eqp(*((C_word*)lf[703]+1),t2);
if(C_truep(t4)){
/* core.scm:3156: chicken.compiler.support#make-node */
t5=*((C_word*)lf[489]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t1;
av2[2]=lf[478];
av2[3]=C_SCHEME_END_OF_LIST;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_22866,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
if(C_truep(C_fixnump(t2))){
t6=C_a_i_list(&a,2,lf[705],t2);
/* core.scm:3157: chicken.compiler.support#make-node */
t7=*((C_word*)lf[489]+1);{
C_word av2[5];
av2[0]=t7;
av2[1]=t1;
av2[2]=lf[704];
av2[3]=t6;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
if(C_truep(C_booleanp(t2))){
t6=C_a_i_list(&a,2,lf[706],t2);
/* core.scm:3157: chicken.compiler.support#make-node */
t7=*((C_word*)lf[489]+1);{
C_word av2[5];
av2[0]=t7;
av2[1]=t1;
av2[2]=lf[704];
av2[3]=t6;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
if(C_truep(C_charp(t2))){
t6=t5;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_a_i_list(&a,2,lf[707],t2);
f_22866(2,av2);}}
else{
if(C_truep(C_i_nullp(t2))){
/* core.scm:3157: chicken.compiler.support#make-node */
t6=*((C_word*)lf[489]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[704];
av2[3]=lf[708];
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
if(C_truep(C_eofp(t2))){
/* core.scm:3157: chicken.compiler.support#make-node */
t6=*((C_word*)lf[489]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[704];
av2[3]=lf[709];
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
if(C_truep(C_bwpp(t2))){
/* core.scm:3157: chicken.compiler.support#make-node */
t6=*((C_word*)lf[489]+1);{
C_word av2[5];
av2[0]=t6;
av2[1]=t1;
av2[2]=lf[704];
av2[3]=lf[710];
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
/* core.scm:3165: chicken.compiler.support#bomb */
t6=*((C_word*)lf[533]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=lf[711];
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}}}}}}}

/* k22864 in immediate-literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22866(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_22866,c,av);}
/* core.scm:3157: chicken.compiler.support#make-node */
t2=*((C_word*)lf[489]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[704];
av2[3]=t1;
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k22913 in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22915(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,6)))){
C_save_and_reclaim((void *)f_22915,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22918,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],tmp=(C_word)a,a+=10,tmp);
/* core.scm:3169: walk */
t3=((C_word*)((C_word*)t0)[10])[1];
f_21487(t3,t2,((C_word*)t0)[11],C_SCHEME_END_OF_LIST,C_fix(0),C_SCHEME_FALSE,C_SCHEME_END_OF_LIST);}

/* k22916 in k22913 in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22918(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_22918,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_22921,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
t3=((C_word*)((C_word*)t0)[9])[1];
if(C_truep(C_i_positivep(t3))){
/* core.scm:3171: chicken.compiler.support#debugging */
t4=*((C_word*)lf[596]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[643];
av2[3]=lf[714];
av2[4]=((C_word*)((C_word*)t0)[9])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_22921(2,av2);}}}

/* k22919 in k22916 in k22913 in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22921(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_22921,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_22924,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t3=((C_word*)((C_word*)t0)[9])[1];
if(C_truep(C_i_positivep(t3))){
/* core.scm:3173: chicken.compiler.support#debugging */
t4=*((C_word*)lf[596]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[643];
av2[3]=lf[713];
av2[4]=((C_word*)((C_word*)t0)[9])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_22924(2,av2);}}}

/* k22922 in k22919 in k22916 in k22913 in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22924(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_22924,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_22927,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
t3=((C_word*)((C_word*)t0)[8])[1];
if(C_truep(C_i_positivep(t3))){
/* core.scm:3175: chicken.compiler.support#debugging */
t4=*((C_word*)lf[596]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t2;
av2[2]=lf[643];
av2[3]=lf[712];
av2[4]=((C_word*)((C_word*)t0)[8])[1];
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}
else{
t4=t2;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_22927(2,av2);}}}

/* k22925 in k22922 in k22919 in k22916 in k22913 in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22927(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_22927,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22934,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:3177: ##sys#fast-reverse */
t3=*((C_word*)lf[688]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[7])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22932 in k22925 in k22922 in k22919 in k22916 in k22913 in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22934(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_22934,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22938,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:3178: ##sys#fast-reverse */
t3=*((C_word*)lf[688]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[6])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22936 in k22932 in k22925 in k22922 in k22919 in k22916 in k22913 in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22938(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_22938,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_22942,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=t1,a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:3180: scheme#reverse */
t3=*((C_word*)lf[261]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[6])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k22940 in k22936 in k22932 in k22925 in k22922 in k22919 in k22916 in k22913 in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_22942(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_22942,c,av);}
/* core.scm:3176: scheme#values */{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=((C_word*)t0)[5];
av2[5]=((C_word*)t0)[6];
av2[6]=t1;
C_values(7,av2);}}

/* k6225 */
static void C_ccall f_6227(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6227,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6230,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_eval_toplevel(2,av2);}}

/* k6228 in k6225 */
static void C_ccall f_6230(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6230,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6233,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_extras_toplevel(2,av2);}}

/* k6231 in k6228 in k6225 */
static void C_ccall f_6233(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6233,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6236,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_expand_toplevel(2,av2);}}

/* k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6236(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6236,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6239,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_data_2dstructures_toplevel(2,av2);}}

/* k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6239(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6239,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6242,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_scrutinizer_toplevel(2,av2);}}

/* k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6242(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6242,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6245,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_support_toplevel(2,av2);}}

/* k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6245(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(19,c,2)))){
C_save_and_reclaim((void *)f_6245,c,av);}
a=C_alloc(19);
t2=C_a_i_provide(&a,1,lf[0]);
t3=C_a_i_provide(&a,1,lf[1]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6248,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t4;
C_file_toplevel(2,av2);}}

/* k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6248(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6248,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6251,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_internal_toplevel(2,av2);}}

/* k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6251(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_6251,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6254,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_pathname_toplevel(2,av2);}}

/* k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6254(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word t57;
C_word t58;
C_word t59;
C_word t60;
C_word t61;
C_word t62;
C_word t63;
C_word t64;
C_word t65;
C_word t66;
C_word t67;
C_word t68;
C_word t69;
C_word t70;
C_word t71;
C_word t72;
C_word t73;
C_word t74;
C_word t75;
C_word t76;
C_word t77;
C_word t78;
C_word t79;
C_word t80;
C_word t81;
C_word t82;
C_word t83;
C_word t84;
C_word t85;
C_word t86;
C_word t87;
C_word t88;
C_word t89;
C_word t90;
C_word t91;
C_word t92;
C_word t93;
C_word t94;
C_word t95;
C_word t96;
C_word t97;
C_word t98;
C_word t99;
C_word t100;
C_word t101;
C_word t102;
C_word t103;
C_word t104;
C_word t105;
C_word t106;
C_word t107;
C_word t108;
C_word t109;
C_word t110;
C_word t111;
C_word t112;
C_word t113;
C_word t114;
C_word t115;
C_word t116;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(88,c,9)))){
C_save_and_reclaim((void *)f_6254,c,av);}
a=C_alloc(88);
t2=C_mutate(&lf[2] /* (set! chicken.compiler.core#every ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_6643,tmp=(C_word)a,a+=2,tmp));
t3=C_mutate(&lf[3] /* (set! chicken.compiler.core#cons* ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_6707,tmp=(C_word)a,a+=2,tmp));
t4=C_mutate(&lf[4] /* (set! chicken.compiler.core#concatenate ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_6735,tmp=(C_word)a,a+=2,tmp));
t5=C_mutate(&lf[6] /* (set! chicken.compiler.core#delete ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_6763,tmp=(C_word)a,a+=2,tmp));
t6=C_mutate(&lf[7] /* (set! chicken.compiler.core#filter ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_6883,tmp=(C_word)a,a+=2,tmp));
t7=C_mutate(&lf[9] /* (set! chicken.compiler.core#unzip1 ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_6992,tmp=(C_word)a,a+=2,tmp));
t8=C_mutate(&lf[11] /* (set! chicken.compiler.core#lset-adjoin/eq? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7102,tmp=(C_word)a,a+=2,tmp));
t9=C_mutate(&lf[12] /* (set! chicken.compiler.core#lset-difference/eq? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7143,tmp=(C_word)a,a+=2,tmp));
t10=C_mutate(&lf[13] /* (set! chicken.compiler.core#lset-union/eq? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7188,tmp=(C_word)a,a+=2,tmp));
t11=C_mutate(&lf[15] /* (set! chicken.compiler.core#lset-intersection/eq? ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7267,tmp=(C_word)a,a+=2,tmp));
t12=C_mutate(&lf[16] /* (set! chicken.compiler.core#posq ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7486,tmp=(C_word)a,a+=2,tmp));
t13=C_set_block_item(lf[17] /* chicken.compiler.core#unit-name */,0,C_SCHEME_FALSE);
t14=C_set_block_item(lf[18] /* chicken.compiler.core#standard-bindings */,0,C_SCHEME_END_OF_LIST);
t15=C_set_block_item(lf[19] /* chicken.compiler.core#extended-bindings */,0,C_SCHEME_END_OF_LIST);
t16=C_set_block_item(lf[20] /* chicken.compiler.core#insert-timer-checks */,0,C_SCHEME_TRUE);
t17=C_set_block_item(lf[21] /* chicken.compiler.core#used-units */,0,C_SCHEME_END_OF_LIST);
t18=C_set_block_item(lf[22] /* chicken.compiler.core#foreign-declarations */,0,C_SCHEME_END_OF_LIST);
t19=C_set_block_item(lf[23] /* chicken.compiler.core#emit-trace-info */,0,C_SCHEME_FALSE);
t20=C_set_block_item(lf[24] /* chicken.compiler.core#emit-debug-info */,0,C_SCHEME_FALSE);
t21=C_set_block_item(lf[25] /* chicken.compiler.core#block-compilation */,0,C_SCHEME_FALSE);
t22=C_set_block_item(lf[26] /* chicken.compiler.core#line-number-database-size */,0,C_fix(997));
t23=C_set_block_item(lf[27] /* chicken.compiler.core#target-heap-size */,0,C_SCHEME_FALSE);
t24=C_set_block_item(lf[28] /* chicken.compiler.core#target-stack-size */,0,C_SCHEME_FALSE);
t25=C_set_block_item(lf[29] /* chicken.compiler.core#optimize-leaf-routines */,0,C_SCHEME_FALSE);
t26=C_set_block_item(lf[30] /* chicken.compiler.core#emit-profile */,0,C_SCHEME_FALSE);
t27=C_set_block_item(lf[31] /* chicken.compiler.core#no-bound-checks */,0,C_SCHEME_FALSE);
t28=C_set_block_item(lf[32] /* chicken.compiler.core#no-argc-checks */,0,C_SCHEME_FALSE);
t29=C_set_block_item(lf[33] /* chicken.compiler.core#no-procedure-checks */,0,C_SCHEME_FALSE);
t30=C_set_block_item(lf[34] /* chicken.compiler.core#no-global-procedure-checks */,0,C_SCHEME_FALSE);
t31=lf[35] /* chicken.compiler.core#safe-globals-flag */ =C_SCHEME_FALSE;;
t32=C_set_block_item(lf[36] /* chicken.compiler.core#explicit-use-flag */,0,C_SCHEME_FALSE);
t33=C_set_block_item(lf[37] /* chicken.compiler.core#disable-stack-overflow-checking */,0,C_SCHEME_FALSE);
t34=C_set_block_item(lf[38] /* chicken.compiler.core#external-protos-first */,0,C_SCHEME_FALSE);
t35=C_set_block_item(lf[39] /* chicken.compiler.core#inline-max-size */,0,C_fix(20));
t36=C_set_block_item(lf[40] /* chicken.compiler.core#unroll-limit */,0,C_fix(1));
t37=C_set_block_item(lf[41] /* chicken.compiler.core#emit-closure-info */,0,C_SCHEME_TRUE);
t38=C_set_block_item(lf[42] /* chicken.compiler.core#undefine-shadowed-macros */,0,C_SCHEME_TRUE);
t39=C_set_block_item(lf[43] /* chicken.compiler.core#profiled-procedures */,0,C_SCHEME_FALSE);
t40=C_set_block_item(lf[44] /* chicken.compiler.core#import-libraries */,0,C_SCHEME_END_OF_LIST);
t41=C_set_block_item(lf[45] /* chicken.compiler.core#all-import-libraries */,0,C_SCHEME_FALSE);
t42=C_set_block_item(lf[46] /* chicken.compiler.core#preserve-unchanged-import-libraries */,0,C_SCHEME_TRUE);
t43=C_set_block_item(lf[47] /* chicken.compiler.core#compile-module-registration */,0,C_SCHEME_FALSE);
t44=C_set_block_item(lf[48] /* chicken.compiler.core#standalone-executable */,0,C_SCHEME_TRUE);
t45=C_set_block_item(lf[49] /* chicken.compiler.core#local-definitions */,0,C_SCHEME_FALSE);
t46=C_set_block_item(lf[50] /* chicken.compiler.core#inline-locally */,0,C_SCHEME_FALSE);
t47=C_set_block_item(lf[51] /* chicken.compiler.core#enable-inline-files */,0,C_SCHEME_FALSE);
t48=C_set_block_item(lf[52] /* chicken.compiler.core#compiler-syntax-enabled */,0,C_SCHEME_TRUE);
t49=C_set_block_item(lf[53] /* chicken.compiler.core#bootstrap-mode */,0,C_SCHEME_FALSE);
t50=C_set_block_item(lf[54] /* chicken.compiler.core#strict-variable-types */,0,C_SCHEME_FALSE);
t51=C_set_block_item(lf[55] /* chicken.compiler.core#enable-specialization */,0,C_SCHEME_FALSE);
t52=C_set_block_item(lf[56] /* chicken.compiler.core#static-extensions */,0,C_SCHEME_FALSE);
t53=C_set_block_item(lf[57] /* chicken.compiler.core#emit-link-file */,0,C_SCHEME_FALSE);
t54=C_set_block_item(lf[58] /* chicken.compiler.core#types-output-file */,0,C_SCHEME_FALSE);
t55=C_set_block_item(lf[59] /* chicken.compiler.core#verbose-mode */,0,C_SCHEME_FALSE);
t56=lf[60] /* chicken.compiler.core#original-program-size */ =C_SCHEME_FALSE;;
t57=lf[61] /* chicken.compiler.core#current-program-size */ =C_fix(0);;
t58=lf[62] /* chicken.compiler.core#current-analysis-database-size */ =C_fix(3001);;
t59=C_set_block_item(lf[63] /* chicken.compiler.core#line-number-database-2 */,0,C_SCHEME_FALSE);
t60=C_set_block_item(lf[64] /* chicken.compiler.core#immutable-constants */,0,C_SCHEME_END_OF_LIST);
t61=C_set_block_item(lf[65] /* chicken.compiler.core#inline-table */,0,C_SCHEME_FALSE);
t62=C_set_block_item(lf[66] /* chicken.compiler.core#constant-table */,0,C_SCHEME_FALSE);
t63=C_set_block_item(lf[67] /* chicken.compiler.core#inline-substitutions-enabled */,0,C_SCHEME_FALSE);
t64=lf[68] /* chicken.compiler.core#direct-call-ids */ =C_SCHEME_END_OF_LIST;;
t65=C_set_block_item(lf[69] /* chicken.compiler.core#first-analysis */,0,C_SCHEME_TRUE);
t66=lf[70] /* chicken.compiler.core#foreign-variables */ =C_SCHEME_END_OF_LIST;;
t67=C_set_block_item(lf[71] /* chicken.compiler.core#foreign-lambda-stubs */,0,C_SCHEME_END_OF_LIST);
t68=C_set_block_item(lf[72] /* chicken.compiler.core#external-variables */,0,C_SCHEME_END_OF_LIST);
t69=lf[73] /* chicken.compiler.core#external-to-pointer */ =C_SCHEME_END_OF_LIST;;
t70=lf[74] /* chicken.compiler.core#location-pointer-map */ =C_SCHEME_END_OF_LIST;;
t71=lf[75] /* chicken.compiler.core#pending-canonicalizations */ =C_SCHEME_END_OF_LIST;;
t72=lf[76] /* chicken.compiler.core#defconstant-bindings */ =C_SCHEME_END_OF_LIST;;
t73=lf[77] /* chicken.compiler.core#callback-names */ =C_SCHEME_END_OF_LIST;;
t74=lf[78] /* chicken.compiler.core#toplevel-scope */ =C_SCHEME_TRUE;;
t75=lf[79] /* chicken.compiler.core#toplevel-lambda-id */ =C_SCHEME_FALSE;;
t76=C_set_block_item(lf[80] /* chicken.compiler.core#required-extensions */,0,C_SCHEME_END_OF_LIST);
t77=C_set_block_item(lf[81] /* chicken.compiler.core#linked-libraries */,0,C_SCHEME_END_OF_LIST);
t78=C_set_block_item(lf[82] /* chicken.compiler.core#used-libraries */,0,C_SCHEME_END_OF_LIST);
t79=C_mutate(&lf[83] /* (set! chicken.compiler.core#unlikely-variables ...) */,lf[84]);
t80=C_set_block_item(lf[85] /* chicken.compiler.core#default-extended-bindings */,0,C_SCHEME_END_OF_LIST);
t81=C_set_block_item(lf[86] /* chicken.compiler.core#default-standard-bindings */,0,C_SCHEME_END_OF_LIST);
t82=C_set_block_item(lf[87] /* chicken.compiler.core#internal-bindings */,0,C_SCHEME_END_OF_LIST);
t83=C_mutate((C_word*)lf[88]+1 /* (set! chicken.compiler.core#initialize-compiler ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7622,tmp=(C_word)a,a+=2,tmp));
t84=C_mutate((C_word*)lf[94]+1 /* (set! chicken.compiler.core#compute-database-statistics ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7664,tmp=(C_word)a,a+=2,tmp));
t85=C_mutate((C_word*)lf[102]+1 /* (set! chicken.compiler.core#canonicalize-expression ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7772,tmp=(C_word)a,a+=2,tmp));
t86=C_mutate((C_word*)lf[488]+1 /* (set! chicken.compiler.core#build-toplevel-procedure ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15598,tmp=(C_word)a,a+=2,tmp));
t87=C_mutate((C_word*)lf[492]+1 /* (set! chicken.compiler.core#foreign-stub-id ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15621,tmp=(C_word)a,a+=2,tmp));
t88=C_mutate((C_word*)lf[495]+1 /* (set! chicken.compiler.core#foreign-stub-return-type ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15630,tmp=(C_word)a,a+=2,tmp));
t89=C_mutate((C_word*)lf[497]+1 /* (set! chicken.compiler.core#foreign-stub-name ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15639,tmp=(C_word)a,a+=2,tmp));
t90=C_mutate((C_word*)lf[499]+1 /* (set! chicken.compiler.core#foreign-stub-argument-types ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15648,tmp=(C_word)a,a+=2,tmp));
t91=C_mutate((C_word*)lf[501]+1 /* (set! chicken.compiler.core#foreign-stub-argument-names ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15657,tmp=(C_word)a,a+=2,tmp));
t92=C_mutate((C_word*)lf[503]+1 /* (set! chicken.compiler.core#foreign-stub-body ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15666,tmp=(C_word)a,a+=2,tmp));
t93=C_mutate((C_word*)lf[505]+1 /* (set! chicken.compiler.core#foreign-stub-cps ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15675,tmp=(C_word)a,a+=2,tmp));
t94=C_mutate((C_word*)lf[507]+1 /* (set! chicken.compiler.core#foreign-stub-callback ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15684,tmp=(C_word)a,a+=2,tmp));
t95=C_mutate(&lf[318] /* (set! chicken.compiler.core#create-foreign-stub ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_15693,tmp=(C_word)a,a+=2,tmp));
t96=C_mutate(&lf[311] /* (set! chicken.compiler.core#expand-foreign-lambda ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_16082,tmp=(C_word)a,a+=2,tmp));
t97=C_mutate(&lf[314] /* (set! chicken.compiler.core#expand-foreign-lambda* ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_16119,tmp=(C_word)a,a+=2,tmp));
t98=C_mutate((C_word*)lf[522]+1 /* (set! chicken.compiler.core#perform-cps-conversion ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_16385,tmp=(C_word)a,a+=2,tmp));
t99=C_mutate((C_word*)lf[536]+1 /* (set! chicken.compiler.core#analyze-expression ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_17299,tmp=(C_word)a,a+=2,tmp));
t100=C_mutate((C_word*)lf[607]+1 /* (set! chicken.compiler.core#perform-closure-conversion ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_19355,tmp=(C_word)a,a+=2,tmp));
t101=C_mutate((C_word*)lf[648]+1 /* (set! chicken.compiler.core#lambda-literal-id ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21232,tmp=(C_word)a,a+=2,tmp));
t102=C_mutate((C_word*)lf[651]+1 /* (set! chicken.compiler.core#lambda-literal-external ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21241,tmp=(C_word)a,a+=2,tmp));
t103=C_mutate((C_word*)lf[653]+1 /* (set! chicken.compiler.core#lambda-literal-argument-count ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21259,tmp=(C_word)a,a+=2,tmp));
t104=C_mutate((C_word*)lf[655]+1 /* (set! chicken.compiler.core#lambda-literal-rest-argument ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21268,tmp=(C_word)a,a+=2,tmp));
t105=C_mutate((C_word*)lf[657]+1 /* (set! chicken.compiler.core#lambda-literal-temporaries ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21277,tmp=(C_word)a,a+=2,tmp));
t106=C_mutate((C_word*)lf[659]+1 /* (set! chicken.compiler.core#lambda-literal-float-temporaries ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21286,tmp=(C_word)a,a+=2,tmp));
t107=C_mutate((C_word*)lf[661]+1 /* (set! chicken.compiler.core#lambda-literal-callee-signatures ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21295,tmp=(C_word)a,a+=2,tmp));
t108=C_mutate((C_word*)lf[663]+1 /* (set! chicken.compiler.core#lambda-literal-allocated ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21304,tmp=(C_word)a,a+=2,tmp));
t109=C_mutate((C_word*)lf[665]+1 /* (set! chicken.compiler.core#lambda-literal-closure-size ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21322,tmp=(C_word)a,a+=2,tmp));
t110=C_mutate((C_word*)lf[667]+1 /* (set! chicken.compiler.core#lambda-literal-looping ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21331,tmp=(C_word)a,a+=2,tmp));
t111=C_mutate((C_word*)lf[669]+1 /* (set! chicken.compiler.core#lambda-literal-customizable ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21340,tmp=(C_word)a,a+=2,tmp));
t112=C_mutate((C_word*)lf[671]+1 /* (set! chicken.compiler.core#lambda-literal-rest-argument-mode ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21349,tmp=(C_word)a,a+=2,tmp));
t113=C_mutate((C_word*)lf[673]+1 /* (set! chicken.compiler.core#lambda-literal-body ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21358,tmp=(C_word)a,a+=2,tmp));
t114=C_mutate((C_word*)lf[675]+1 /* (set! chicken.compiler.core#lambda-literal-direct ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21367,tmp=(C_word)a,a+=2,tmp));
t115=C_mutate((C_word*)lf[677]+1 /* (set! chicken.compiler.core#prepare-for-code-generation ...) */,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_21376,tmp=(C_word)a,a+=2,tmp));
t116=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t116;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t116+1)))(2,av2);}}

/* loop in a12869 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_6440(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,4)))){
C_save_and_reclaim_args((void *)trf_6440,5,t0,t1,t2,t3,t4);}
a=C_alloc(4);
if(C_truep(C_fixnum_less_or_equal_p(t2,C_fix(0)))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6454,a[2]=t1,a[3]=t4,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:67: scheme#reverse */
t6=*((C_word*)lf[261]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=C_fixnum_difference(t2,C_fix(1));
t6=C_i_car(t4);
t7=C_a_i_cons(&a,2,t6,t3);
/* mini-srfi-1.scm:68: loop */
t9=t1;
t10=t5;
t11=t7;
t12=C_u_i_cdr(t4);
t1=t9;
t2=t10;
t3=t11;
t4=t12;
goto loop;}}

/* k6452 in loop in a12869 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_6454(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6454,c,av);}
/* mini-srfi-1.scm:67: scheme#values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
C_values(4,av2);}}

/* chicken.compiler.core#every in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6643(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_6643,3,t1,t2,t3);}
a=C_alloc(6);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6649,a[2]=t5,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t7=((C_word*)t5)[1];
f_6649(t7,t1,t3);}

/* loop in chicken.compiler.core#every in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6649(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_6649,3,t0,t1,t2);}
a=C_alloc(5);
t3=C_i_nullp(t2);
if(C_truep(t3)){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6671,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:82: pred */
t5=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}}

/* k6669 in loop in chicken.compiler.core#every in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6671(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6671,c,av);}
if(C_truep(C_i_not(t1))){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* mini-srfi-1.scm:83: loop */
t2=((C_word*)((C_word*)t0)[3])[1];
f_6649(t2,((C_word*)t0)[2],C_u_i_cdr(((C_word*)t0)[4]));}}

/* loop in foldl545 in foldl529 in chicken.compiler.core#lset-union/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static C_word C_fcall f_6683(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_nullp(t1))){
return(C_SCHEME_FALSE);}
else{
t2=(
/* mini-srfi-1.scm:88: pred */
  f_7247(((C_word*)t0)[2],C_i_car(t1))
);
if(C_truep(t2)){
return(t2);}
else{
t4=C_u_i_cdr(t1);
t1=t4;
goto loop;}}}

/* chicken.compiler.core#cons* in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6707(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_6707,3,t1,t2,t3);}
a=C_alloc(5);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6713,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_6713(t7,t1,t2,t3);}

/* loop in chicken.compiler.core#cons* in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6713(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,3)))){
C_save_and_reclaim_args((void *)trf_6713,4,t0,t1,t2,t3);}
a=C_alloc(4);
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6727,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:95: loop */
t6=t4;
t7=C_i_car(t3);
t8=C_u_i_cdr(t3);
t1=t6;
t2=t7;
t3=t8;
goto loop;}}

/* k6725 in loop in chicken.compiler.core#cons* in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6727(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_6727,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* chicken.compiler.core#concatenate in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6735(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_6735,2,t1,t2);}
a=C_alloc(5);
t3=C_SCHEME_UNDEFINED;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_set_block_item(t4,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6741,a[2]=t4,tmp=(C_word)a,a+=3,tmp));
t6=((C_word*)t4)[1];
f_6741(t6,t1,t2);}

/* loop in chicken.compiler.core#concatenate in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6741(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_6741,3,t0,t1,t2);}
a=C_alloc(4);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_car(t2);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6759,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:101: loop */
t6=t4;
t7=C_u_i_cdr(t2);
t1=t6;
t2=t7;
goto loop;}}

/* k6757 in loop in chicken.compiler.core#concatenate in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6759(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6759,c,av);}
/* mini-srfi-1.scm:101: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* chicken.compiler.core#delete in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6763(C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_6763,4,t1,t2,t3,t4);}
a=C_alloc(7);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6769,a[2]=t6,a[3]=t4,a[4]=t2,tmp=(C_word)a,a+=5,tmp));
t8=((C_word*)t6)[1];
f_6769(t8,t1,t3);}

/* loop in chicken.compiler.core#delete in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6769(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,3)))){
C_save_and_reclaim_args((void *)trf_6769,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6782,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:106: test */
t4=((C_word*)t0)[3];{
C_word av2[4];
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[4];
av2[3]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k6780 in loop in chicken.compiler.core#delete in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6782(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_6782,c,av);}
a=C_alloc(4);
if(C_truep(t1)){
/* mini-srfi-1.scm:107: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_6769(t2,((C_word*)t0)[3],C_u_i_cdr(((C_word*)t0)[4]));}
else{
t2=C_u_i_car(((C_word*)t0)[4]);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6796,a[2]=((C_word*)t0)[3],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:109: loop */
t4=((C_word*)((C_word*)t0)[2])[1];
f_6769(t4,t3,C_u_i_cdr(((C_word*)t0)[4]));}}

/* k6794 in k6780 in loop in chicken.compiler.core#delete in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6796(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_6796,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* loop in k19795 in a19775 in k19764 in a19758 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6844(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,4)))){
C_save_and_reclaim_args((void *)trf_6844,3,t0,t1,t2);}
a=C_alloc(10);
if(C_truep(C_i_nullp(t2))){
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=C_i_car(t2);
t4=C_u_i_cdr(t2);
t5=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_6858,a[2]=t4,a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6871,a[2]=((C_word*)t0)[2],a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:123: delete */
f_6763(t6,t3,t4,((C_word*)t0)[3]);}}

/* k6856 in loop in k19795 in a19775 in k19764 in a19758 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_6858(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_6858,c,av);}
a=C_alloc(3);
t2=C_i_equalp(((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?((C_word*)t0)[4]:C_a_i_cons(&a,2,((C_word*)t0)[5],t1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k6869 in loop in k19795 in a19775 in k19764 in a19758 in k19421 in k19391 in k19388 in k19385 in gather in chicken.compiler.core#perform-closure-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_6871(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_6871,c,av);}
/* mini-srfi-1.scm:123: loop */
t2=((C_word*)((C_word*)t0)[2])[1];
f_6844(t2,((C_word*)t0)[3],t1);}

/* chicken.compiler.core#filter in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6883(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_6883,3,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_check_list_2(t3,lf[8]);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6892,a[2]=t2,a[3]=t6,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_6892(t8,t1,t3);}

/* foldr401 in chicken.compiler.core#filter in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6892(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_6892,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6900,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6921,a[2]=t3,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t7=t5;
t8=C_slot(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* g406 in foldr401 in chicken.compiler.core#filter in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6900(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_6900,4,t0,t1,t2,t3);}
a=C_alloc(5);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6907,a[2]=t1,a[3]=t2,a[4]=t3,tmp=(C_word)a,a+=5,tmp);
/* mini-srfi-1.scm:131: pred */
t5=((C_word*)t0)[2];{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k6905 in g406 in foldr401 in chicken.compiler.core#filter in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6907(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_6907,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=(C_truep(t1)?C_a_i_cons(&a,2,((C_word*)t0)[3],((C_word*)t0)[4]):((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k6919 in foldr401 in chicken.compiler.core#filter in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_6921(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6921,c,av);}
/* mini-srfi-1.scm:131: g406 */
t2=((C_word*)t0)[2];
f_6900(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* foldr419 in globalize-all in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_fcall f_6936(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(8,0,4)))){
C_save_and_reclaim_args((void *)trf_6936,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6944,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t4=C_slot(t2,C_fix(0));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_6970,a[2]=t3,a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t7=t5;
t8=C_slot(t2,C_fix(1));
t1=t7;
t2=t8;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* g424 in foldr419 in globalize-all in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_6944(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_6944,4,t0,t1,t2,t3);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_6948,a[2]=t3,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* mini-srfi-1.scm:135: pred */
t5=((C_word*)((C_word*)t0)[2])[1];
f_13703(t5,t4,t2);}

/* k6946 in g424 in foldr419 in globalize-all in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_6948(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,2)))){
C_save_and_reclaim((void *)f_6948,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6952,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:135: g434 */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(
/* mini-srfi-1.scm:135: g434 */
  f_6952(C_a_i(&a,3),t2,t1)
);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t2=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* g434 in k6946 in g424 in foldr419 in globalize-all in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static C_word C_fcall f_6952(C_word *a,C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_stack_overflow_check;{}
return(C_a_i_cons(&a,2,t1,((C_word*)t0)[2]));}

/* k6968 in foldr419 in globalize-all in g2486 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_6970(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_6970,c,av);}
/* mini-srfi-1.scm:134: g424 */
t2=((C_word*)t0)[2];
f_6944(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* chicken.compiler.core#unzip1 in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_6992(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,0,3)))){
C_save_and_reclaim_args((void *)trf_6992,2,t1,t2);}
a=C_alloc(12);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_check_list_2(t2,lf[10]);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7009,a[2]=t5,a[3]=t9,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_7009(t11,t1,t2);}

/* map-loop447 in chicken.compiler.core#unzip1 in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7009(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,2)))){
C_save_and_reclaim_args((void *)trf_7009,3,t0,t1,t2);}
a=C_alloc(3);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=C_a_i_cons(&a,2,t4,C_SCHEME_END_OF_LIST);
t6=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t5);
t7=C_mutate(((C_word *)((C_word*)t0)[2])+1,t5);
t9=t1;
t10=C_slot(t2,C_fix(1));
t1=t9;
t2=t10;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* loop in k16805 in k16483 in k16474 in k16471 in k16468 in k16465 in walk in chicken.compiler.core#perform-cps-conversion in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static C_word C_fcall f_7049(C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_stack_overflow_check;
loop:{}
t2=C_i_cdr(t1);
if(C_truep(C_i_nullp(t2))){
return(C_u_i_car(t1));}
else{
t4=C_u_i_cdr(t1);
t1=t4;
goto loop;}}

/* loop in blockvar-literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7074(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_7074,4,t0,t1,t2,t3);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7087,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* mini-srfi-1.scm:154: pred */
t5=((C_word*)t0)[3];
f_22833(t5,t4,C_i_car(t3));}}

/* k7085 in loop in blockvar-literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7087(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7087,c,av);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* mini-srfi-1.scm:155: loop */
t2=((C_word*)((C_word*)t0)[4])[1];
f_7074(t2,((C_word*)t0)[2],C_fixnum_plus(((C_word*)t0)[3],C_fix(1)),C_u_i_cdr(((C_word*)t0)[5]));}}

/* chicken.compiler.core#lset-adjoin/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7102(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_7102,3,t1,t2,t3);}
a=C_alloc(5);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7108,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_7108(t7,t1,t3,t2);}

/* loop in chicken.compiler.core#lset-adjoin/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7108(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_7108,4,t0,t1,t2,t3);}
a=C_alloc(3);
if(C_truep(C_i_nullp(t2))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=C_i_car(t2);
if(C_truep(C_i_memq(t4,t3))){
/* mini-srfi-1.scm:160: loop */
t9=t1;
t10=C_u_i_cdr(t2);
t11=t3;
t1=t9;
t2=t10;
t3=t11;
goto loop;}
else{
t5=C_u_i_cdr(t2);
t6=C_u_i_car(t2);
t7=C_a_i_cons(&a,2,t6,t3);
/* mini-srfi-1.scm:161: loop */
t9=t1;
t10=t5;
t11=t7;
t1=t9;
t2=t10;
t3=t11;
goto loop;}}}

/* chicken.compiler.core#lset-difference/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7143(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_7143,3,t1,t2,t3);}
a=C_alloc(5);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7149,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_7149(t7,t1,t3,t2);}

/* foldl507 in chicken.compiler.core#lset-difference/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7149(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_7149,4,t0,t1,t2,t3);}
a=C_alloc(8);
if(C_truep(C_i_pairp(t2))){
t4=C_slot(t2,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7182,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t6=C_slot(t2,C_fix(0));
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7171,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:166: filter */
f_6883(t5,t7,t3);}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* a7170 in foldl507 in chicken.compiler.core#lset-difference/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7171(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7171,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_not(C_i_memq(t2,((C_word*)t0)[2]));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k7180 in foldl507 in chicken.compiler.core#lset-difference/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7182,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7149(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* chicken.compiler.core#lset-union/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7188(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_7188,3,t1,t2,t3);}
a=C_alloc(5);
t4=C_SCHEME_UNDEFINED;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=C_set_block_item(t5,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7194,a[2]=t5,tmp=(C_word)a,a+=3,tmp));
t7=((C_word*)t5)[1];
f_7194(t7,t1,t3,t2);}

/* foldl529 in chicken.compiler.core#lset-union/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7194(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,4)))){
C_save_and_reclaim_args((void *)trf_7194,4,t0,t1,t2,t3);}
a=C_alloc(10);
if(C_truep(C_i_pairp(t2))){
t4=C_slot(t2,C_fix(1));
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7261,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t4,tmp=(C_word)a,a+=5,tmp);
t6=C_slot(t2,C_fix(0));
t7=C_i_check_list_2(t6,lf[14]);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7219,a[2]=t9,tmp=(C_word)a,a+=3,tmp));
t11=((C_word*)t9)[1];
f_7219(t11,t5,t6,t3);}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* foldl545 in foldl529 in chicken.compiler.core#lset-union/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7219(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(9,0,3)))){
C_save_and_reclaim_args((void *)trf_7219,4,t0,t1,t2,t3);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t4=C_slot(t2,C_fix(1));
t5=C_slot(t2,C_fix(0));
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7247,a[2]=t5,tmp=(C_word)a,a+=3,tmp);
t7=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6683,a[2]=t6,tmp=(C_word)a,a+=3,tmp);
t8=(
  f_6683(t7,t3)
);
if(C_truep(t8)){
t11=t1;
t12=t4;
t13=t3;
t1=t11;
t2=t12;
t3=t13;
goto loop;}
else{
t9=C_a_i_cons(&a,2,t5,t3);
t11=t1;
t12=t4;
t13=t9;
t1=t11;
t2=t12;
t3=t13;
goto loop;}}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* a7246 in foldl545 in foldl529 in chicken.compiler.core#lset-union/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static C_word C_fcall f_7247(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_stack_overflow_check;{}
return(C_eqp(t1,((C_word*)t0)[2]));}

/* k7259 in foldl529 in chicken.compiler.core#lset-union/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7261(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7261,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7194(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* chicken.compiler.core#lset-intersection/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7267(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_7267,3,t1,t2,t3);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7273,a[2]=t3,tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:182: filter */
f_6883(t1,t4,t2);}

/* a7272 in chicken.compiler.core#lset-intersection/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7273(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_7273,c,av);}
a=C_alloc(3);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7279,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* mini-srfi-1.scm:183: every */
f_6643(t1,t3,((C_word*)t0)[2]);}

/* a7278 in a7272 in chicken.compiler.core#lset-intersection/eq? in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7279(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7279,c,av);}
t3=t1;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_memq(((C_word*)t0)[2],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* chicken.compiler.core#posq in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7486(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,3)))){
C_save_and_reclaim_args((void *)trf_7486,3,t1,t2,t3);}
a=C_alloc(3);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7492,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=(
  f_7492(t4,C_fix(0),t3)
);
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* loop in chicken.compiler.core#posq in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static C_word C_fcall f_7492(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_nullp(t2))){
return(C_SCHEME_FALSE);}
else{
t3=C_i_car(t2);
t4=C_eqp(t3,((C_word*)t0)[2]);
if(C_truep(t4)){
return(t1);}
else{
t6=C_fixnum_plus(t1,C_fix(1));
t7=C_u_i_cdr(t2);
t1=t6;
t2=t7;
goto loop;}}}

/* loop in k22753 in literal in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static C_word C_fcall f_7526(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_stack_overflow_check;
loop:{}
if(C_truep(C_i_nullp(t2))){
return(C_SCHEME_FALSE);}
else{
t3=C_i_car(t2);
if(C_truep(C_i_eqvp(t3,((C_word*)t0)[2]))){
return(t1);}
else{
t5=C_fixnum_plus(t1,C_fix(1));
t6=C_u_i_cdr(t2);
t1=t5;
t2=t6;
goto loop;}}}

/* chicken.compiler.core#initialize-compiler in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7622(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_7622,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7626,a[2]=t1,tmp=(C_word)a,a+=3,tmp);
if(C_truep(*((C_word*)lf[63]+1))){
/* core.scm:466: scheme#vector-fill! */
t3=*((C_word*)lf[92]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=*((C_word*)lf[63]+1);
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7662,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:467: scheme#make-vector */
t4=*((C_word*)lf[93]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=*((C_word*)lf[26]+1);
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k7624 in chicken.compiler.core#initialize-compiler in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7626(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_7626,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7629,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(*((C_word*)lf[65]+1))){
/* core.scm:469: scheme#vector-fill! */
t3=*((C_word*)lf[92]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=*((C_word*)lf[65]+1);
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7655,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:470: scheme#make-vector */
t4=*((C_word*)lf[93]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_fix(301);
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k7627 in k7624 in chicken.compiler.core#initialize-compiler in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7629(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_7629,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7632,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
if(C_truep(*((C_word*)lf[66]+1))){
/* core.scm:472: scheme#vector-fill! */
t3=*((C_word*)lf[92]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=*((C_word*)lf[66]+1);
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7648,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:473: scheme#make-vector */
t4=*((C_word*)lf[93]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_fix(301);
av2[3]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k7630 in k7627 in k7624 in chicken.compiler.core#initialize-compiler in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7632(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_7632,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7635,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:474: chicken.compiler.support#reset-profile-info-vector-name! */
t3=*((C_word*)lf[91]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k7633 in k7630 in k7627 in k7624 in chicken.compiler.core#initialize-compiler in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7635(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_7635,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7638,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:475: chicken.compiler.support#clear-real-name-table! */
t3=*((C_word*)lf[90]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k7636 in k7633 in k7630 in k7627 in k7624 in chicken.compiler.core#initialize-compiler in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7638(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7638,c,av);}
/* core.scm:476: chicken.compiler.support#clear-foreign-type-table! */
t2=*((C_word*)lf[89]+1);{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k7646 in k7627 in k7624 in chicken.compiler.core#initialize-compiler in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7648(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7648,c,av);}
t2=C_mutate((C_word*)lf[66]+1 /* (set! chicken.compiler.core#constant-table ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
f_7632(2,av2);}}

/* k7653 in k7624 in chicken.compiler.core#initialize-compiler in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7655(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7655,c,av);}
t2=C_mutate((C_word*)lf[65]+1 /* (set! chicken.compiler.core#inline-table ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
f_7629(2,av2);}}

/* k7660 in chicken.compiler.core#initialize-compiler in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7662(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7662,c,av);}
t2=C_mutate((C_word*)lf[63]+1 /* (set! chicken.compiler.core#line-number-database-2 ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
f_7626(2,av2);}}

/* chicken.compiler.core#compute-database-statistics in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7664(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,4)))){
C_save_and_reclaim((void *)f_7664,c,av);}
a=C_alloc(25);
t3=C_fix(0);
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_fix(0);
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_fix(0);
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_fix(0);
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_fix(0);
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_7668,a[2]=t1,a[3]=t6,a[4]=t4,a[5]=t8,a[6]=t12,a[7]=t10,tmp=(C_word)a,a+=8,tmp);
t14=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7673,a[2]=t10,a[3]=t8,a[4]=t6,a[5]=t4,a[6]=t12,tmp=(C_word)a,a+=7,tmp);
/* core.scm:498: chicken.internal#hash-table-for-each */
t15=*((C_word*)lf[101]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t15;
av2[1]=t13;
av2[2]=t14;
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t15+1)))(4,av2);}}

/* k7666 in chicken.compiler.core#compute-database-statistics in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7668(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_7668,c,av);}
/* core.scm:512: scheme#values */{
C_word *av2;
if(c >= 9) {
  av2=av;
} else {
  av2=C_alloc(9);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[61];
av2[3]=lf[60];
av2[4]=((C_word*)((C_word*)t0)[3])[1];
av2[5]=((C_word*)((C_word*)t0)[4])[1];
av2[6]=((C_word*)((C_word*)t0)[5])[1];
av2[7]=((C_word*)((C_word*)t0)[6])[1];
av2[8]=((C_word*)((C_word*)t0)[7])[1];
C_values(9,av2);}}

/* a7672 in chicken.compiler.core#compute-database-statistics in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7673(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,3)))){
C_save_and_reclaim((void *)f_7673,c,av);}
a=C_alloc(13);
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_7675,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
t5=C_i_check_list_2(t3,lf[100]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7749,a[2]=t7,a[3]=t4,tmp=(C_word)a,a+=4,tmp));
t9=((C_word*)t7)[1];
f_7749(t9,t1,t3);}

/* g777 in a7672 in chicken.compiler.core#compute-database-statistics in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7675(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(62,0,2)))){
C_save_and_reclaim_args((void *)trf_7675,3,t0,t1,t2);}
a=C_alloc(62);
t3=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[2])[1],C_fix(1));
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t3);
t5=C_i_car(t2);
t6=C_eqp(t5,lf[95]);
if(C_truep(t6)){
t7=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[3])[1],C_fix(1));
t8=C_mutate(((C_word *)((C_word*)t0)[3])+1,t7);
t9=t1;{
C_word av2[2];
av2[0]=t9;
av2[1]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(2,av2);}}
else{
t7=C_eqp(t5,lf[96]);
if(C_truep(t7)){
t8=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[4])[1],C_fix(1));
t9=C_mutate(((C_word *)((C_word*)t0)[4])+1,t8);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7717,a[2]=((C_word*)t0)[5],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:507: chicken.compiler.support#node-class */
t11=*((C_word*)lf[98]+1);{
C_word av2[3];
av2[0]=t11;
av2[1]=t10;
av2[2]=C_u_i_cdr(t2);
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t8=C_eqp(t5,lf[99]);
if(C_truep(t8)){
t9=C_i_length(C_u_i_cdr(t2));
t10=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[6])[1],t9);
t11=C_mutate(((C_word *)((C_word*)t0)[6])+1,t10);
t12=t1;{
C_word av2[2];
av2[0]=t12;
av2[1]=t11;
((C_proc)(void*)(*((C_word*)t12+1)))(2,av2);}}
else{
t9=C_SCHEME_UNDEFINED;
t10=t1;{
C_word av2[2];
av2[0]=t10;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}}}}

/* k7715 in g777 in a7672 in chicken.compiler.core#compute-database-statistics in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7717(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(29,c,1)))){
C_save_and_reclaim((void *)f_7717,c,av);}
a=C_alloc(29);
t2=C_eqp(lf[97],t1);
if(C_truep(t2)){
t3=C_s_a_i_plus(&a,2,((C_word*)((C_word*)t0)[2])[1],C_fix(1));
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t3);
t5=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* for-each-loop776 in a7672 in chicken.compiler.core#compute-database-statistics in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7749(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_7749,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7759,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:500: g777 */
t4=((C_word*)t0)[3];
f_7675(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k7757 in for-each-loop776 in a7672 in chicken.compiler.core#compute-database-statistics in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7759(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_7759,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7749(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7772(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(73,c,9)))){
C_save_and_reclaim((void *)f_7772,c,av);}
a=C_alloc(73);
t3=C_SCHEME_END_OF_LIST;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_SCHEME_END_OF_LIST;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_SCHEME_UNDEFINED;
t8=(*a=C_VECTOR_TYPE|1,a[1]=t7,tmp=(C_word)a,a+=2,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_SCHEME_UNDEFINED;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_SCHEME_UNDEFINED;
t16=(*a=C_VECTOR_TYPE|1,a[1]=t15,tmp=(C_word)a,a+=2,tmp);
t17=C_SCHEME_UNDEFINED;
t18=(*a=C_VECTOR_TYPE|1,a[1]=t17,tmp=(C_word)a,a+=2,tmp);
t19=C_SCHEME_UNDEFINED;
t20=(*a=C_VECTOR_TYPE|1,a[1]=t19,tmp=(C_word)a,a+=2,tmp);
t21=C_SCHEME_UNDEFINED;
t22=(*a=C_VECTOR_TYPE|1,a[1]=t21,tmp=(C_word)a,a+=2,tmp);
t23=C_SCHEME_UNDEFINED;
t24=(*a=C_VECTOR_TYPE|1,a[1]=t23,tmp=(C_word)a,a+=2,tmp);
t25=C_SCHEME_UNDEFINED;
t26=(*a=C_VECTOR_TYPE|1,a[1]=t25,tmp=(C_word)a,a+=2,tmp);
t27=C_set_block_item(t8,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7775,a[2]=t8,tmp=(C_word)a,a+=3,tmp));
t28=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7810,a[2]=t8,tmp=(C_word)a,a+=3,tmp));
t29=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7844,a[2]=t10,tmp=(C_word)a,a+=3,tmp));
t30=C_set_block_item(t14,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7857,tmp=(C_word)a,a+=2,tmp));
t31=C_set_block_item(t16,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7884,a[2]=t14,tmp=(C_word)a,a+=3,tmp));
t32=C_set_block_item(t18,0,(*a=C_CLOSURE_TYPE|1,a[1]=(C_word)f_7913,tmp=(C_word)a,a+=2,tmp));
t33=C_set_block_item(t20,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7979,a[2]=t10,tmp=(C_word)a,a+=3,tmp));
t34=C_set_block_item(t22,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8022,a[2]=t24,a[3]=t6,a[4]=t10,tmp=(C_word)a,a+=5,tmp));
t35=C_set_block_item(t24,0,(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_8330,a[2]=t22,a[3]=t24,a[4]=t16,a[5]=t18,a[6]=t6,a[7]=t10,a[8]=t4,a[9]=t20,a[10]=t26,a[11]=t12,a[12]=t14,tmp=(C_word)a,a+=13,tmp));
t36=C_set_block_item(t26,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13577,a[2]=t24,tmp=(C_word)a,a+=3,tmp));
t37=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13629,a[2]=t24,a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_memq(lf[160],*((C_word*)lf[486]+1)))){
t38=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13660,a[2]=t37,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1527: scheme#newline */
t39=*((C_word*)lf[487]+1);{
C_word *av2=av;
av2[0]=t39;
av2[1]=t38;
((C_proc)(void*)(*((C_word*)t39+1)))(2,av2);}}
else{
t38=t37;{
C_word *av2=av;
av2[0]=t38;
av2[1]=C_SCHEME_UNDEFINED;
f_13629(2,av2);}}}

/* find-id in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7775(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_7775,4,t0,t1,t2,t3);}
a=C_alloc(6);
if(C_truep(C_i_nullp(t3))){
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
t4=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7788,a[2]=t1,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=t2,tmp=(C_word)a,a+=6,tmp);
t5=C_i_caar(t3);
t6=C_eqp(t2,t5);
if(C_truep(t6)){
t7=C_u_i_car(t3);
t8=t4;
f_7788(t8,C_i_symbolp(C_u_i_cdr(t7)));}
else{
t7=t4;
f_7788(t7,C_SCHEME_FALSE);}}}

/* k7786 in find-id in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7788(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,3)))){
C_save_and_reclaim_args((void *)trf_7788,2,t0,t1);}
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=C_u_i_cdr(C_u_i_car(((C_word*)t0)[3]));
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* core.scm:529: find-id */
t2=((C_word*)((C_word*)t0)[4])[1];
f_7775(t2,((C_word*)t0)[2],((C_word*)t0)[5],C_u_i_cdr(((C_word*)t0)[3]));}}

/* lookup in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7810(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_7810,3,t0,t1,t2);}
a=C_alloc(9);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7814,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7842,a[2]=((C_word*)t0)[2],a[3]=t3,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:532: ##sys#current-environment */
t5=*((C_word*)lf[107]+1);{
C_word av2[2];
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k7812 in lookup in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7814(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_7814,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7822,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7828,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
/* core.scm:532: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}}

/* a7821 in k7812 in lookup in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7822(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7822,c,av);}
/* core.scm:533: ##sys#get */
t2=*((C_word*)lf[103]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=t1;
av2[2]=((C_word*)t0)[2];
av2[3]=lf[104];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* a7827 in k7812 in lookup in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7828(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand((c-2)*C_SIZEOF_PAIR +5,c,3)))){
C_save_and_reclaim((void*)f_7828,c,av);}
a=C_alloc((c-2)*C_SIZEOF_PAIR+5);
t2=C_build_rest(&a,c,2,av);
C_word t3;
C_word t4;
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7835,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=t3;
av2[2]=*((C_word*)lf[106]+1);
av2[3]=t2;
C_apply(4,av2);}}

/* k7833 in a7827 in k7812 in lookup in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7835(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7835,c,av);}
if(C_truep(t1)){{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=*((C_word*)lf[105]+1);
av2[3]=((C_word*)t0)[3];
C_apply(4,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k7840 in lookup in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7842,c,av);}
/* core.scm:532: find-id */
t2=((C_word*)((C_word*)t0)[2])[1];
f_7775(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1);}

/* macro-alias in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7844(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_7844,3,t0,t1,t2);}
a=C_alloc(5);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7848,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:537: chicken.base#gensym */
t4=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k7846 in macro-alias in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7848(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_7848,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7851,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7855,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:538: lookup */
t4=((C_word*)((C_word*)t0)[3])[1];
f_7810(t4,t3,((C_word*)t0)[4]);}

/* k7849 in k7846 in macro-alias in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7851(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7851,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k7853 in k7846 in macro-alias in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7855(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_7855,c,av);}
/* core.scm:538: ##sys#put! */
t2=*((C_word*)lf[108]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[104];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* handle-expansion-result in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7857(C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,4)))){
C_save_and_reclaim_args((void *)trf_7857,2,t1,t2);}
a=C_alloc(3);
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7859,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* f_7859 in handle-expansion-result in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_7859,c,av);}
a=C_alloc(10);
t4=C_eqp(t2,t3);
t5=C_i_not(t4);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7866,a[2]=t1,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
if(C_truep(t5)){
t7=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7869,a[2]=t6,a[3]=t3,a[4]=t1,a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* core.scm:544: chicken.syntax#get-line-number */
t8=*((C_word*)lf[111]+1);{
C_word *av2=av;
av2[0]=t8;
av2[1]=t7;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t7=t1;{
C_word *av2=av;
av2[0]=t7;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k7864 */
static void C_ccall f_7866(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7866,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k7867 */
static void C_ccall f_7869(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7869,c,av);}
if(C_truep(t1)){
if(C_truep(t1)){
/* core.scm:545: ##sys#update-line-number-database! */
t2=*((C_word*)lf[110]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}
else{
if(C_truep(((C_word*)t0)[5])){
/* core.scm:545: ##sys#update-line-number-database! */
t2=*((C_word*)lf[110]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[5];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}}

/* canonicalize-body/ln in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7884(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4){
C_word tmp;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_7884,5,t0,t1,t2,t3,t4);}
a=C_alloc(5);
t5=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7888,a[2]=t3,a[3]=t4,a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* core.scm:550: handle-expansion-result */
f_7857(t5,t2);}

/* k7886 in canonicalize-body/ln in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7888(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,4)))){
C_save_and_reclaim((void *)f_7888,c,av);}
a=C_alloc(16);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7893,a[2]=t5,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7898,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_7908,a[2]=t3,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* core.scm:549: ##sys#dynamic-wind */
t9=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[4];
av2[2]=t6;
av2[3]=t7;
av2[4]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* a7892 in k7886 in canonicalize-body/ln in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7893(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7893,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,*((C_word*)lf[112]+1));
t3=C_mutate((C_word*)lf[112]+1 /* (set! chicken.syntax#expansion-result-hook ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a7897 in k7886 in canonicalize-body/ln in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7898(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_7898,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_7906,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:551: ##sys#current-environment */
t3=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k7904 in a7897 in k7886 in canonicalize-body/ln in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7906(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_7906,c,av);}
/* core.scm:551: ##sys#canonicalize-body */
t2=*((C_word*)lf[113]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* a7907 in k7886 in canonicalize-body/ln in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7908(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_7908,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,*((C_word*)lf[112]+1));
t3=C_mutate((C_word*)lf[112]+1 /* (set! chicken.syntax#expansion-result-hook ...) */,((C_word*)((C_word*)t0)[3])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* set-real-names! in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7913(C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,4)))){
C_save_and_reclaim_args((void *)trf_7913,3,t1,t2,t3);}
a=C_alloc(5);
t4=C_i_check_list_2(t2,lf[100]);
t5=C_i_check_list_2(t3,lf[100]);
t6=C_SCHEME_UNDEFINED;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=C_set_block_item(t7,0,(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_7930,a[2]=t7,tmp=(C_word)a,a+=3,tmp));
t9=((C_word*)t7)[1];
f_7930(t9,t1,t2,t3);}

/* for-each-loop868 in set-real-names! in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7930(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,3)))){
C_save_and_reclaim_args((void *)trf_7930,4,t0,t1,t2,t3);}
a=C_alloc(6);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_7940,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,a[5]=t3,tmp=(C_word)a,a+=6,tmp);
/* core.scm:554: chicken.compiler.support#set-real-name! */
t7=*((C_word*)lf[115]+1);{
C_word av2[4];
av2[0]=t7;
av2[1]=t6;
av2[2]=C_slot(t2,C_fix(0));
av2[3]=C_slot(t3,C_fix(0));
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}
else{
t6=C_SCHEME_UNDEFINED;
t7=t1;{
C_word av2[2];
av2[0]=t7;
av2[1]=t6;
((C_proc)(void*)(*((C_word*)t7+1)))(2,av2);}}}

/* k7938 in for-each-loop868 in set-real-names! in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_7940(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_7940,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_7930(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)),C_slot(((C_word*)t0)[5],C_fix(1)));}

/* unquotify in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_7979(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,2)))){
C_save_and_reclaim_args((void *)trf_7979,3,t0,t1,t2);}
a=C_alloc(4);
if(C_truep(C_i_listp(t2))){
t3=C_eqp(C_fix(2),C_u_i_length(t2));
if(C_truep(t3)){
t4=C_i_car(t2);
if(C_truep(C_i_symbolp(t4))){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8011,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:565: lookup */
t6=((C_word*)((C_word*)t0)[2])[1];
f_7810(t6,t5,C_u_i_car(t2));}
else{
t5=t1;{
C_word av2[2];
av2[0]=t5;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}
else{
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k8009 in unquotify in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8011(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8011,c,av);}
t2=C_eqp(lf[116],t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=(C_truep(t2)?C_i_cadr(((C_word*)t0)[3]):((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_8022(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7){
C_word tmp;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,0,2)))){
C_save_and_reclaim_args((void *)trf_8022,8,t0,t1,t2,t3,t4,t5,t6,t7);}
a=C_alloc(16);
t8=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_8026,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t6,a[9]=t7,a[10]=((C_word*)t0)[3],a[11]=((C_word*)t0)[4],tmp=(C_word)a,a+=12,tmp);
if(C_truep(C_i_memq(t2,lf[83]))){
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8218,a[2]=t8,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:572: chicken.base#open-output-string */
t10=*((C_word*)lf[131]+1);{
C_word av2[2];
av2[0]=t10;
av2[1]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(2,av2);}}
else{
t9=t8;{
C_word av2[2];
av2[0]=t9;
av2[1]=C_SCHEME_UNDEFINED;
f_8026(2,av2);}}}

/* k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8026(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_8026,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8029,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* core.scm:573: lookup */
t3=((C_word*)((C_word*)t0)[11])[1];
f_7810(t3,t2,((C_word*)t0)[3]);}

/* k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8029(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_8029,c,av);}
a=C_alloc(11);
t2=C_i_symbolp(t1);
if(C_truep(C_i_not(t2))){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8041,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[2],a[8]=t1,a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* core.scm:576: chicken.internal#hash-table-ref */
t4=*((C_word*)lf[133]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=*((C_word*)lf[66]+1);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8041(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_8041,c,av);}
a=C_alloc(11);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8045,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:575: g923 */
t3=t2;
f_8045(t3,((C_word*)t0)[7],t1);}
else{
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8055,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* core.scm:578: chicken.internal#hash-table-ref */
t3=*((C_word*)lf[133]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=*((C_word*)lf[65]+1);
av2[3]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}

/* g923 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_8045(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,8)))){
C_save_and_reclaim_args((void *)trf_8045,3,t0,t1,t2);}
/* core.scm:577: walk */
t3=((C_word*)((C_word*)t0)[2])[1];
f_8330(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],C_SCHEME_FALSE,C_SCHEME_FALSE);}

/* k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8055(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_8055,c,av);}
a=C_alloc(7);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8059,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:575: g927 */
t3=t2;
f_8059(t3,((C_word*)t0)[7],t1);}
else{
t2=C_i_assq(((C_word*)t0)[8],lf[70]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8073,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:575: g931 */
t4=t3;
f_8073(t4,((C_word*)t0)[7],t2);}
else{
t3=C_i_assq(((C_word*)t0)[8],lf[74]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8112,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],tmp=(C_word)a,a+=7,tmp);
/* core.scm:575: g941 */
t5=t4;
f_8112(t5,((C_word*)t0)[7],t3);}
else{
t4=C_i_memq(((C_word*)t0)[8],((C_word*)t0)[3]);
if(C_truep(C_i_not(t4))){
t5=C_a_i_cons(&a,2,((C_word*)t0)[6],((C_word*)t0)[9]);
/* core.scm:600: ##sys#alias-global-hook */
t6=*((C_word*)lf[122]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t6;
av2[1]=((C_word*)t0)[7];
av2[2]=((C_word*)t0)[8];
av2[3]=C_SCHEME_FALSE;
av2[4]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(5,av2);}}
else{
t5=C_i_assq(((C_word*)t0)[8],((C_word*)((C_word*)t0)[10])[1]);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8164,a[2]=((C_word*)t0)[8],tmp=(C_word)a,a+=3,tmp);
/* core.scm:575: g951 */
t7=t6;
f_8164(t7,((C_word*)t0)[7],t5);}
else{
t6=((C_word*)t0)[7];{
C_word *av2=av;
av2[0]=t6;
av2[1]=((C_word*)t0)[8];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}}}}}

/* g927 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_8059(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,0,8)))){
C_save_and_reclaim_args((void *)trf_8059,3,t0,t1,t2);}
/* core.scm:579: walk */
t3=((C_word*)((C_word*)t0)[2])[1];
f_8330(t3,t1,t2,((C_word*)t0)[3],((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],C_SCHEME_FALSE,C_SCHEME_FALSE);}

/* g931 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_8073(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_8073,3,t0,t1,t2);}
a=C_alloc(10);
t3=C_i_cadr(t2);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_8080,a[2]=t2,a[3]=t3,a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],tmp=(C_word)a,a+=10,tmp);
/* core.scm:583: chicken.compiler.support#final-foreign-type */
t5=*((C_word*)lf[120]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k8078 in g931 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8080(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,3)))){
C_save_and_reclaim((void *)f_8080,c,av);}
a=C_alloc(24);
t2=C_i_caddr(((C_word*)t0)[2]);
t3=C_a_i_list(&a,2,t2,((C_word*)t0)[3]);
t4=C_a_i_list(&a,2,lf[117],t3);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_8090,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],tmp=(C_word)a,a+=8,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8094,a[2]=t5,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:587: chicken.compiler.support#finish-foreign-result */
t7=*((C_word*)lf[119]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=t1;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k8088 in k8078 in g931 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8090(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_8090,c,av);}
/* core.scm:585: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],C_SCHEME_FALSE,C_SCHEME_FALSE);}

/* k8092 in k8078 in g931 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8094(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_8094,c,av);}
/* core.scm:586: chicken.compiler.support#foreign-type-convert-result */
t2=*((C_word*)lf[118]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* g941 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_8112(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,0,2)))){
C_save_and_reclaim_args((void *)trf_8112,3,t0,t1,t2);}
a=C_alloc(10);
t3=C_i_caddr(t2);
t4=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_8119,a[2]=t3,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=t1,a[6]=((C_word*)t0)[3],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],tmp=(C_word)a,a+=10,tmp);
/* core.scm:593: chicken.compiler.support#final-foreign-type */
t5=*((C_word*)lf[120]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=t3;
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}

/* k8117 in g941 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8119(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,3)))){
C_save_and_reclaim((void *)f_8119,c,av);}
a=C_alloc(24);
t2=C_a_i_list(&a,1,((C_word*)t0)[2]);
t3=C_i_cadr(((C_word*)t0)[3]);
t4=C_a_i_list(&a,3,lf[121],t2,t3);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_8129,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],tmp=(C_word)a,a+=8,tmp);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8133,a[2]=t5,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:597: chicken.compiler.support#finish-foreign-result */
t7=*((C_word*)lf[119]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=t1;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k8127 in k8117 in g941 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8129(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_8129,c,av);}
/* core.scm:595: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],C_SCHEME_FALSE,C_SCHEME_FALSE);}

/* k8131 in k8117 in g941 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8133(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_8133,c,av);}
/* core.scm:596: chicken.compiler.support#foreign-type-convert-result */
t2=*((C_word*)lf[118]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* g951 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_8164(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_8164,3,t0,t1,t2);}
a=C_alloc(8);
t3=C_i_cdr(t2);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8175,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
if(C_truep(t3)){
t5=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8182,a[2]=t4,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* core.scm:606: chicken.base#open-output-string */
t6=*((C_word*)lf[131]+1);{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t5=t4;{
C_word av2[2];
av2[0]=t5;
av2[1]=lf[132];
f_8175(2,av2);}}}

/* k8173 in g951 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8175(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_8175,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8179,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:607: chicken.compiler.support#get-real-name */
t3=*((C_word*)lf[125]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k8177 in k8173 in g951 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8179(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_8179,c,av);}
/* core.scm:604: chicken.compiler.support#quit-compiling */
t2=*((C_word*)lf[123]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[124];
av2[3]=((C_word*)t0)[3];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k8180 in g951 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8182(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_8182,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8188,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:606: ##sys#write-char-0 */
t4=*((C_word*)lf[130]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_make_character(40);
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k8186 in k8180 in g951 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8188(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_8188,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8191,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:606: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8189 in k8186 in k8180 in g951 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8191(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_8191,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8194,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:606: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[129];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8192 in k8189 in k8186 in k8180 in g951 in k8053 in k8039 in k8027 in k8024 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8194(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8194,c,av);}
/* core.scm:606: chicken.base#get-output-string */
t2=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k8216 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8218(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_8218,c,av);}
a=C_alloc(5);
t2=C_i_check_port_2(t1,C_fix(2),C_SCHEME_TRUE,lf[126]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8224,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:572: ##sys#print */
t4=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[136];
av2[3]=C_SCHEME_FALSE;
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k8222 in k8216 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8224(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_8224,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8227,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:572: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_TRUE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8225 in k8222 in k8216 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8227(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_8227,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8230,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:572: ##sys#print */
t3=*((C_word*)lf[128]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[135];
av2[3]=C_SCHEME_FALSE;
av2[4]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8228 in k8225 in k8222 in k8216 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8230(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_8230,c,av);}
a=C_alloc(3);
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8233,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:572: chicken.base#get-output-string */
t3=*((C_word*)lf[127]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k8231 in k8228 in k8225 in k8222 in k8216 in resolve-variable in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8233(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8233,c,av);}
/* core.scm:571: chicken.base#warning */
t2=*((C_word*)lf[134]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k8237 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_8239(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,3)))){
C_save_and_reclaim((void *)f_8239,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8242,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:614: ##sys#compiled-module-registration */
t3=*((C_word*)lf[233]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k8240 in k8237 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_8242(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,2)))){
C_save_and_reclaim((void *)f_8242,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8245,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8314,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:616: chicken.file#file-exists? */
t4=*((C_word*)lf[254]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k8243 in k8240 in k8237 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_8245(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,6)))){
C_save_and_reclaim((void *)f_8245,c,av);}
a=C_alloc(5);
t2=C_i_equalp(((C_word*)t0)[2],t1);
t3=(C_truep(t2)?*((C_word*)lf[46]+1):C_SCHEME_FALSE);
if(C_truep(t3)){
if(C_truep(*((C_word*)lf[59]+1))){
/* core.scm:620: chicken.base#print */
t4=*((C_word*)lf[238]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t4;
av2[1]=((C_word*)t0)[3];
av2[2]=lf[239];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[240];
av2[5]=((C_word*)t0)[5];
av2[6]=lf[241];
((C_proc)(void*)(*((C_word*)t4+1)))(7,av2);}}
else{
t4=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
f_10865(2,av2);}}}
else{
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8260,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
if(C_truep(*((C_word*)lf[59]+1))){
/* core.scm:624: chicken.base#print */
t5=*((C_word*)lf[238]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=lf[249];
av2[3]=((C_word*)t0)[4];
av2[4]=lf[250];
av2[5]=((C_word*)t0)[5];
av2[6]=lf[251];
((C_proc)(void*)(*((C_word*)t5+1)))(7,av2);}}
else{
t5=t4;{
C_word *av2=av;
av2[0]=t5;
av2[1]=C_SCHEME_UNDEFINED;
f_8260(2,av2);}}}}

/* k8258 in k8243 in k8240 in k8237 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_8260(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,3)))){
C_save_and_reclaim((void *)f_8260,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8265,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:626: scheme#with-output-to-file */
t3=*((C_word*)lf[248]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[4];
av2[2]=((C_word*)t0)[3];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* a8264 in k8258 in k8243 in k8240 in k8237 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in ... */
static void C_ccall f_8265(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,2)))){
C_save_and_reclaim((void *)f_8265,c,av);}
a=C_alloc(8);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8269,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8305,a[2]=t2,a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:629: chicken.platform#chicken-version */
t4=*((C_word*)lf[247]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k8267 in a8264 in k8258 in k8243 in k8240 in k8237 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in ... */
static void C_ccall f_8269(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_8269,c,av);}
a=C_alloc(9);
t2=*((C_word*)lf[242]+1);
t3=C_i_check_list_2(((C_word*)t0)[2],lf[100]);
t4=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8275,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t5=C_SCHEME_UNDEFINED;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=C_set_block_item(t6,0,(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8280,a[2]=t6,a[3]=t2,tmp=(C_word)a,a+=4,tmp));
t8=((C_word*)t6)[1];
f_8280(t8,t4,((C_word*)t0)[2]);}

/* k8273 in k8267 in a8264 in k8258 in k8243 in k8240 in k8237 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in ... */
static void C_ccall f_8275(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8275,c,av);}
/* core.scm:631: chicken.base#print */
t2=*((C_word*)lf[238]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[243];
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* for-each-loop983 in k8267 in a8264 in k8258 in k8243 in k8240 in k8237 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in ... */
static void C_fcall f_8280(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,0,2)))){
C_save_and_reclaim_args((void *)trf_8280,3,t0,t1,t2);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8290,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:630: g984 */
t4=((C_word*)t0)[3];{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_SCHEME_UNDEFINED;
t4=t1;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k8288 in for-each-loop983 in k8267 in a8264 in k8258 in k8243 in k8240 in k8237 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in ... */
static void C_ccall f_8290(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8290,c,av);}
t2=((C_word*)((C_word*)t0)[2])[1];
f_8280(t2,((C_word*)t0)[3],C_slot(((C_word*)t0)[4],C_fix(1)));}

/* k8303 in a8264 in k8258 in k8243 in k8240 in k8237 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in ... */
static void C_ccall f_8305(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,6)))){
C_save_and_reclaim((void *)f_8305,c,av);}
/* core.scm:628: chicken.base#print */
t2=*((C_word*)lf[238]+1);{
C_word *av2;
if(c >= 7) {
  av2=av;
} else {
  av2=C_alloc(7);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[244];
av2[3]=((C_word*)t0)[3];
av2[4]=lf[245];
av2[5]=t1;
av2[6]=lf[246];
((C_proc)(void*)(*((C_word*)t2+1)))(7,av2);}}

/* k8312 in k8240 in k8237 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_8314(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_8314,c,av);}
if(C_truep(t1)){
/* core.scm:617: scheme#call-with-input-file */
t2=*((C_word*)lf[252]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=*((C_word*)lf[253]+1);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_FALSE;
f_8245(2,av2);}}}

/* k8322 in k10705 in k10702 in k10699 in k10696 in k10693 in k10690 in k10681 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_8324(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_8324,c,av);}
/* ##sys#string-append */
t2=*((C_word*)lf[255]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=lf[256];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_8330(C_word t0,C_word t1,C_word t2,C_word t3,C_word t4,C_word t5,C_word t6,C_word t7,C_word t8){
C_word tmp;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,0,2)))){
C_save_and_reclaim_args((void *)trf_8330,9,t0,t1,t2,t3,t4,t5,t6,t7,t8);}
a=C_alloc(21);
t9=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_8337,a[2]=t1,a[3]=t2,a[4]=((C_word*)t0)[2],a[5]=t3,a[6]=t4,a[7]=t5,a[8]=t6,a[9]=t7,a[10]=((C_word*)t0)[3],a[11]=t8,a[12]=((C_word*)t0)[4],a[13]=((C_word*)t0)[5],a[14]=((C_word*)t0)[6],a[15]=((C_word*)t0)[7],a[16]=((C_word*)t0)[8],a[17]=((C_word*)t0)[9],a[18]=((C_word*)t0)[10],a[19]=((C_word*)t0)[11],a[20]=((C_word*)t0)[12],tmp=(C_word)a,a+=21,tmp);
/* core.scm:634: chicken.keyword#keyword? */
t10=*((C_word*)lf[485]+1);{
C_word av2[3];
av2[0]=t10;
av2[1]=t9;
av2[2]=t2;
((C_proc)(void*)(*((C_word*)t10+1)))(3,av2);}}

/* k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8337(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,7)))){
C_save_and_reclaim((void *)f_8337,c,av);}
a=C_alloc(21);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,2,lf[116],((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
if(C_truep(C_i_symbolp(((C_word*)t0)[3]))){
/* core.scm:635: resolve-variable */
t2=((C_word*)((C_word*)t0)[4])[1];
f_8022(t2,((C_word*)t0)[2],((C_word*)t0)[3],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}
else{
t2=C_i_pairp(((C_word*)t0)[3]);
if(C_truep(C_i_not(t2))){
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8361,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:637: chicken.compiler.support#constant? */
t4=*((C_word*)lf[139]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_i_car(((C_word*)t0)[3]);
if(C_truep(C_i_symbolp(t3))){
t4=(*a=C_CLOSURE_TYPE|20,a[1]=(C_word)f_8376,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[4],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],tmp=(C_word)a,a+=21,tmp);
/* core.scm:641: chicken.syntax#get-line-number */
t5=*((C_word*)lf[111]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=C_i_listp(((C_word*)t0)[3]);
if(C_truep(C_i_not(t4))){
/* core.scm:1508: ##sys#syntax-error/context */
t5=*((C_word*)lf[137]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[483];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t5=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_13523,a[2]=((C_word*)t0)[18],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[11],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[6],a[11]=((C_word*)t0)[7],tmp=(C_word)a,a+=12,tmp);
/* core.scm:1510: chicken.compiler.support#constant? */
t6=*((C_word*)lf[139]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=C_u_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}}}}}}

/* k8359 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8361(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_8361,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,2,lf[116],((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
/* core.scm:639: ##sys#syntax-error/context */
t2=*((C_word*)lf[137]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=lf[138];
av2[3]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}}

/* k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8376(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,3)))){
C_save_and_reclaim((void *)f_8376,c,av);}
a=C_alloc(22);
t2=(C_truep(t1)?t1:((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_8382,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=t2,a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[2],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],tmp=(C_word)a,a+=22,tmp);
/* core.scm:642: chicken.compiler.support#emit-syntax-trace-info */
t4=*((C_word*)lf[482]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
av2[3]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}

/* k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8382(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(27,c,3)))){
C_save_and_reclaim((void *)f_8382,c,av);}
a=C_alloc(27);
t2=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_8385,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],tmp=(C_word)a,a+=22,tmp);
if(C_truep(C_i_listp(((C_word*)t0)[2]))){
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_SCHEME_UNDEFINED;
f_8385(2,av2);}}
else{
if(C_truep(((C_word*)t0)[9])){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13490,a[2]=t2,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[9],tmp=(C_word)a,a+=5,tmp);
/* core.scm:645: chicken.base#open-output-string */
t4=*((C_word*)lf[131]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* core.scm:646: ##sys#syntax-error/context */
t3=*((C_word*)lf[137]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=lf[481];
av2[3]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}}}

/* k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8385(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,2)))){
C_save_and_reclaim((void *)f_8385,c,av);}
a=C_alloc(22);
t2=C_mutate((C_word*)lf[140]+1 /* (set! ##sys#syntax-error-culprit ...) */,((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_8389,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],tmp=(C_word)a,a+=22,tmp);
/* core.scm:648: lookup */
t4=((C_word*)((C_word*)t0)[16])[1];
f_7810(t4,t3,C_u_i_car(((C_word*)t0)[2]));}

/* k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8389(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,2)))){
C_save_and_reclaim((void *)f_8389,c,av);}
a=C_alloc(22);
t2=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_8392,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=t1,a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],a[16]=((C_word*)t0)[15],a[17]=((C_word*)t0)[16],a[18]=((C_word*)t0)[17],a[19]=((C_word*)t0)[18],a[20]=((C_word*)t0)[19],a[21]=((C_word*)t0)[20],tmp=(C_word)a,a+=22,tmp);
/* core.scm:651: handle-expansion-result */
f_7857(t2,((C_word*)t0)[9]);}

/* k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8392(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(37,c,4)))){
C_save_and_reclaim((void *)f_8392,c,av);}
a=C_alloc(37);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_8395,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],tmp=(C_word)a,a+=22,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13457,a[2]=t5,a[3]=t3,tmp=(C_word)a,a+=4,tmp);
t8=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_13462,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t9=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13472,a[2]=t3,a[3]=t5,tmp=(C_word)a,a+=4,tmp);
/* core.scm:650: ##sys#dynamic-wind */
t10=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t10;
av2[1]=t6;
av2[2]=t7;
av2[3]=t8;
av2[4]=t9;
((C_proc)(void*)(*((C_word*)t10+1)))(5,av2);}}

/* k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8395(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,8)))){
C_save_and_reclaim((void *)f_8395,c,av);}
a=C_alloc(22);
t2=C_eqp(((C_word*)t0)[2],t1);
if(C_truep(C_i_not(t2))){
/* core.scm:654: walk */
t3=((C_word*)((C_word*)t0)[3])[1];
f_8330(t3,((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10]);}
else{
t3=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_8407,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[4],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],a[16]=((C_word*)t0)[16],a[17]=((C_word*)t0)[17],a[18]=((C_word*)t0)[18],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],tmp=(C_word)a,a+=22,tmp);
/* core.scm:656: chicken.internal#hash-table-ref */
t4=*((C_word*)lf[133]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=*((C_word*)lf[65]+1);
av2[3]=((C_word*)t0)[11];
((C_proc)(void*)(*((C_word*)t4+1)))(4,av2);}}}

/* k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8407(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,8)))){
C_save_and_reclaim((void *)f_8407,c,av);}
a=C_alloc(22);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8411,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
/* core.scm:653: g1052 */
t3=t2;
f_8411(t3,((C_word*)t0)[9],t1);}
else{
t2=C_eqp(((C_word*)t0)[10],lf[141]);
if(C_truep(t2)){
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_8439,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],tmp=(C_word)a,a+=8,tmp);
/* core.scm:665: walk */
t4=((C_word*)((C_word*)t0)[3])[1];
f_8330(t4,t3,C_i_cadr(((C_word*)t0)[2]),((C_word*)t0)[4],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}
else{
t3=C_eqp(((C_word*)t0)[10],lf[144]);
t4=(C_truep(t3)?t3:C_eqp(((C_word*)t0)[10],lf[145]));
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8485,a[2]=((C_word*)t0)[9],tmp=(C_word)a,a+=3,tmp);
/* core.scm:672: chicken.syntax#strip-syntax */
t6=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t6;
av2[1]=t5;
av2[2]=C_i_cadr(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=C_eqp(((C_word*)t0)[10],lf[147]);
if(C_truep(t5)){
if(C_truep(*((C_word*)lf[148]+1))){
t6=((C_word*)t0)[9];{
C_word *av2=av;
av2[0]=t6;
av2[1]=lf[149];
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
/* core.scm:677: walk */
t6=((C_word*)((C_word*)t0)[3])[1];
f_8330(t6,((C_word*)t0)[9],C_i_cadr(((C_word*)t0)[2]),((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[11]);}}
else{
t6=C_eqp(((C_word*)t0)[10],lf[150]);
if(C_truep(t6)){
t7=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8518,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[11],tmp=(C_word)a,a+=11,tmp);
/* core.scm:681: chicken.syntax#strip-syntax */
t8=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t8;
av2[1]=t7;
av2[2]=C_i_cadr(((C_word*)t0)[2]);
((C_proc)(void*)(*((C_word*)t8+1)))(3,av2);}}
else{
t7=C_eqp(((C_word*)t0)[10],lf[151]);
if(C_truep(t7)){
t8=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_8543,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[12],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[13],tmp=(C_word)a,a+=10,tmp);
/* core.scm:686: resolve-variable */
t9=((C_word*)((C_word*)t0)[12])[1];
f_8022(t9,t8,C_i_cadr(((C_word*)t0)[2]),((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[13]);}
else{
t8=C_eqp(((C_word*)t0)[10],lf[155]);
if(C_truep(t8)){
t9=(C_truep(((C_word*)t0)[8])?((C_word*)t0)[8]:C_i_cadr(((C_word*)t0)[2]));
t10=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_8626,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[11],a[9]=((C_word*)t0)[2],a[10]=t9,a[11]=((C_word*)t0)[9],tmp=(C_word)a,a+=12,tmp);
/* core.scm:700: walk */
t11=((C_word*)((C_word*)t0)[3])[1];
f_8330(t11,t10,C_i_caddr(((C_word*)t0)[2]),((C_word*)t0)[4],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[11]);}
else{
t9=C_eqp(((C_word*)t0)[10],lf[156]);
if(C_truep(t9)){
t10=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8710,a[2]=((C_word*)t0)[9],tmp=(C_word)a,a+=3,tmp);
/* core.scm:707: scheme#cadadr */
t11=*((C_word*)lf[161]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t11;
av2[1]=t10;
av2[2]=((C_word*)t0)[2];
((C_proc)(void*)(*((C_word*)t11+1)))(3,av2);}}
else{
t10=C_eqp(((C_word*)t0)[10],lf[162]);
t11=(*a=C_CLOSURE_TYPE|21,a[1]=(C_word)f_8741,a[2]=((C_word*)t0)[9],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],a[11]=((C_word*)t0)[13],a[12]=((C_word*)t0)[14],a[13]=((C_word*)t0)[15],a[14]=((C_word*)t0)[12],a[15]=((C_word*)t0)[16],a[16]=((C_word*)t0)[17],a[17]=((C_word*)t0)[18],a[18]=((C_word*)t0)[11],a[19]=((C_word*)t0)[19],a[20]=((C_word*)t0)[20],a[21]=((C_word*)t0)[21],tmp=(C_word)a,a+=22,tmp);
if(C_truep(t10)){
t12=t11;
f_8741(t12,t10);}
else{
t12=C_eqp(((C_word*)t0)[10],lf[477]);
t13=t11;
f_8741(t13,(C_truep(t12)?t12:C_eqp(((C_word*)t0)[10],lf[478])));}}}}}}}}}}

/* g1052 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_8411(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,0,8)))){
C_save_and_reclaim_args((void *)trf_8411,3,t0,t1,t2);}
a=C_alloc(3);
t3=C_i_cdr(((C_word*)t0)[2]);
t4=C_a_i_cons(&a,2,t2,t3);
/* core.scm:658: walk */
t5=((C_word*)((C_word*)t0)[3])[1];
f_8330(t5,t1,t4,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* k8437 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8439(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,8)))){
C_save_and_reclaim((void *)f_8439,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8443,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* core.scm:666: walk */
t3=((C_word*)((C_word*)t0)[4])[1];
f_8330(t3,t2,C_i_caddr(((C_word*)t0)[3]),((C_word*)t0)[5],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[6],((C_word*)t0)[7],C_SCHEME_FALSE);}

/* k8441 in k8437 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_8443(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(17,c,8)))){
C_save_and_reclaim((void *)f_8443,c,av);}
a=C_alloc(17);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8447,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
t3=C_i_cdddr(((C_word*)t0)[4]);
if(C_truep(C_i_nullp(t3))){
t4=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_list(&a,4,lf[142],((C_word*)t0)[3],t1,lf[143]);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}
else{
/* core.scm:669: walk */
t4=((C_word*)((C_word*)t0)[5])[1];
f_8330(t4,t2,C_i_cadddr(((C_word*)t0)[4]),((C_word*)t0)[6],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}}

/* k8445 in k8441 in k8437 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_8447(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_8447,c,av);}
a=C_alloc(12);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,4,lf[142],((C_word*)t0)[3],((C_word*)t0)[4],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8483 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8485(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_8485,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,2,lf[116],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8516 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8518(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,8)))){
C_save_and_reclaim((void *)f_8518,c,av);}
a=C_alloc(5);
t2=C_i_caddr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8526,a[2]=((C_word*)t0)[3],a[3]=t1,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:683: walk */
t4=((C_word*)((C_word*)t0)[4])[1];
f_8330(t4,t3,C_i_cadddr(((C_word*)t0)[2]),((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10]);}

/* k8524 in k8516 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_8526(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_8526,c,av);}
a=C_alloc(12);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,4,lf[150],((C_word*)t0)[3],((C_word*)t0)[4],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8541 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8543(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,7)))){
C_save_and_reclaim((void *)f_8543,c,av);}
a=C_alloc(6);
t2=C_i_caddr(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8549,a[2]=t2,a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[2],tmp=(C_word)a,a+=6,tmp);
/* core.scm:688: resolve-variable */
t4=((C_word*)((C_word*)t0)[4])[1];
f_8022(t4,t3,t2,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9]);}

/* k8547 in k8541 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_8549(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,4)))){
C_save_and_reclaim((void *)f_8549,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8552,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:689: ##sys#get */
t3=*((C_word*)lf[103]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[4];
av2[3]=lf[153];
av2[4]=C_SCHEME_END_OF_LIST;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8550 in k8547 in k8541 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_8552(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_8552,c,av);}
a=C_alloc(18);
t2=C_SCHEME_UNDEFINED;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8553,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
t5=C_set_block_item(t3,0,t4);
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8585,a[2]=((C_word*)t0)[4],tmp=(C_word)a,a+=3,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8589,a[2]=t6,a[3]=((C_word*)t0)[5],tmp=(C_word)a,a+=4,tmp);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8593,a[2]=t7,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:694: resolve-alias */
t9=((C_word*)t3)[1];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t9;
av2[1]=t8;
av2[2]=C_i_cdddr(((C_word*)t0)[6]);
((C_proc)(void*)(*((C_word*)t9+1)))(3,av2);}}

/* resolve-alias1077 in k8550 in k8547 in k8541 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_8553(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8553,c,av);}
a=C_alloc(5);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8567,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,tmp=(C_word)a,a+=5,tmp);
/* core.scm:691: resolve-alias */
t4=((C_word*)((C_word*)t0)[2])[1];{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
av2[2]=C_u_i_car(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=C_eqp(t2,((C_word*)t0)[3]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=(C_truep(t3)?((C_word*)t0)[4]:t2);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}}

/* k8565 in resolve-alias1077 in k8550 in k8547 in k8541 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_8567(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_8567,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8571,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:691: resolve-alias */
t3=((C_word*)((C_word*)t0)[3])[1];{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=C_u_i_cdr(((C_word*)t0)[4]);
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k8569 in k8565 in resolve-alias1077 in k8550 in k8547 in k8541 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_8571(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_8571,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8583 in k8550 in k8547 in k8541 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_8585(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8585,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[152];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8587 in k8550 in k8547 in k8541 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_8589(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_8589,c,av);}
/* core.scm:694: ##sys#put! */
t2=*((C_word*)lf[108]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=lf[153];
av2[4]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k8591 in k8550 in k8547 in k8541 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_8593(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_8593,c,av);}
/* core.scm:694: ##sys#append */
t2=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k8624 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8626(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(27,c,3)))){
C_save_and_reclaim((void *)f_8626,c,av);}
a=C_alloc(27);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8631,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t7=C_i_cdddr(((C_word*)t0)[9]);
t8=C_i_check_list_2(t7,lf[10]);
t9=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8660,a[2]=t1,a[3]=((C_word*)t0)[10],a[4]=((C_word*)t0)[11],tmp=(C_word)a,a+=5,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8662,a[2]=t4,a[3]=t11,a[4]=t6,a[5]=t5,tmp=(C_word)a,a+=6,tmp));
t13=((C_word*)t11)[1];
f_8662(t13,t9,t7);}

/* g1101 in k8624 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_8631(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,0,2)))){
C_save_and_reclaim_args((void *)trf_8631,3,t0,t1,t2);}
a=C_alloc(11);
t3=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8639,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=t2,a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[4],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[7],a[10]=((C_word*)t0)[8],tmp=(C_word)a,a+=11,tmp);
/* core.scm:702: chicken.syntax#strip-syntax */
t4=*((C_word*)lf[146]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_car(t2);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k8637 in g1101 in k8624 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_8639(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,8)))){
C_save_and_reclaim((void *)f_8639,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8643,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:703: walk */
t3=((C_word*)((C_word*)t0)[3])[1];
f_8330(t3,t2,C_i_cadr(((C_word*)t0)[4]),((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10]);}

/* k8641 in k8637 in g1101 in k8624 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_8643(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_8643,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list2(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8658 in k8624 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_8660(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_8660,c,av);}
a=C_alloc(9);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_cons(&a,2,((C_word*)t0)[3],t2);
t4=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_a_i_cons(&a,2,lf[155],t3);
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* map-loop1095 in k8624 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_8662(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_8662,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8687,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:701: g1101 */
t4=((C_word*)t0)[4];
f_8631(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k8685 in map-loop1095 in k8624 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_8687(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_8687,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_8662(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k8708 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_ccall f_8710(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_8710,c,av);}
a=C_alloc(4);
t2=C_i_assoc(t1,*((C_word*)lf[64]+1));
if(C_truep(t2)){
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_i_cdr(t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}
else{
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8722,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:710: chicken.base#gensym */
t4=*((C_word*)lf[109]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=lf[160];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}}

/* k8720 in k8708 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_8722(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,3)))){
C_save_and_reclaim((void *)f_8722,c,av);}
a=C_alloc(10);
t2=*((C_word*)lf[64]+1);
t3=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t4=C_a_i_cons(&a,2,t3,*((C_word*)lf[64]+1));
t5=C_mutate((C_word*)lf[64]+1 /* (set! chicken.compiler.core#immutable-constants ...) */,t4);
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8729,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:712: chicken.compiler.support#mark-variable */
t7=*((C_word*)lf[158]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t7;
av2[1]=t6;
av2[2]=t1;
av2[3]=lf[159];
((C_proc)(void*)(*((C_word*)t7+1)))(4,av2);}}

/* k8727 in k8720 in k8708 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_8729(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_8729,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8732,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:713: chicken.compiler.support#hide-variable */
t3=*((C_word*)lf[157]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k8730 in k8727 in k8720 in k8708 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_8732(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8732,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall f_8741(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word t16;
C_word t17;
C_word t18;
C_word t19;
C_word t20;
C_word t21;
C_word t22;
C_word t23;
C_word t24;
C_word t25;
C_word t26;
C_word t27;
C_word t28;
C_word t29;
C_word t30;
C_word t31;
C_word t32;
C_word t33;
C_word t34;
C_word t35;
C_word t36;
C_word t37;
C_word t38;
C_word t39;
C_word t40;
C_word t41;
C_word t42;
C_word t43;
C_word t44;
C_word t45;
C_word t46;
C_word t47;
C_word t48;
C_word t49;
C_word t50;
C_word t51;
C_word t52;
C_word t53;
C_word t54;
C_word t55;
C_word t56;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,0,8)))){
C_save_and_reclaim_args((void *)trf_8741,2,t0,t1);}
a=C_alloc(33);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=C_eqp(((C_word*)t0)[4],lf[163]);
if(C_truep(t2)){
t3=C_i_cadr(((C_word*)t0)[3]);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8754,a[2]=((C_word*)t0)[2],a[3]=t3,tmp=(C_word)a,a+=4,tmp);
/* core.scm:720: lset-adjoin/eq? */
f_7102(t4,*((C_word*)lf[21]+1),C_a_i_list(&a,1,t3));}
else{
t3=C_eqp(((C_word*)t0)[4],lf[117]);
if(C_truep(t3)){
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8774,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:725: scheme#caadr */
t5=*((C_word*)lf[164]+1);{
C_word av2[3];
av2[0]=t5;
av2[1]=t4;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t5+1)))(3,av2);}}
else{
t4=C_eqp(((C_word*)t0)[4],lf[121]);
if(C_truep(t4)){
t5=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_8795,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
/* core.scm:729: chicken.syntax#strip-syntax */
t6=*((C_word*)lf[146]+1);{
C_word av2[3];
av2[0]=t6;
av2[1]=t5;
av2[2]=C_i_cadr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t6+1)))(3,av2);}}
else{
t5=C_eqp(((C_word*)t0)[4],lf[165]);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8816,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:733: chicken.load#load-extension */
t7=*((C_word*)lf[167]+1);{
C_word av2[5];
av2[0]=t7;
av2[1]=t6;
av2[2]=C_i_cadr(((C_word*)t0)[3]);
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t7+1)))(5,av2);}}
else{
t6=C_eqp(((C_word*)t0)[4],lf[168]);
if(C_truep(t6)){
t7=C_i_cadr(((C_word*)t0)[3]);
t8=C_u_i_cdr(((C_word*)t0)[3]);
t9=C_i_pairp(C_u_i_cdr(t8));
t10=(C_truep(t9)?C_i_caddr(((C_word*)t0)[3]):C_SCHEME_FALSE);
t11=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8835,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=t7,a[10]=t10,tmp=(C_word)a,a+=11,tmp);
t12=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8855,a[2]=t11,a[3]=t7,tmp=(C_word)a,a+=4,tmp);
/* core.scm:739: chicken.load#core-library? */
t13=*((C_word*)lf[172]+1);{
C_word av2[3];
av2[0]=t13;
av2[1]=t12;
av2[2]=t7;
((C_proc)(void*)(*((C_word*)t13+1)))(3,av2);}}
else{
t7=C_eqp(((C_word*)t0)[4],lf[173]);
if(C_truep(t7)){
t8=C_i_cadr(((C_word*)t0)[3]);
t9=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_8880,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[9],a[6]=t8,a[7]=((C_word*)t0)[2],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[12],a[11]=((C_word*)t0)[3],a[12]=((C_word*)t0)[13],tmp=(C_word)a,a+=13,tmp);
/* core.scm:750: unzip1 */
f_6992(t9,t8);}
else{
t8=C_eqp(((C_word*)t0)[4],lf[176]);
if(C_truep(t8)){
t9=C_i_cadr(((C_word*)t0)[3]);
t10=C_u_i_cdr(((C_word*)t0)[3]);
t11=C_u_i_cdr(t10);
t12=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t13=t12;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=((C_word*)t14)[1];
t16=C_i_check_list_2(t9,lf[10]);
t17=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9108,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=t11,a[10]=t9,tmp=(C_word)a,a+=11,tmp);
t18=C_SCHEME_UNDEFINED;
t19=(*a=C_VECTOR_TYPE|1,a[1]=t18,tmp=(C_word)a,a+=2,tmp);
t20=C_set_block_item(t19,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9180,a[2]=t14,a[3]=t19,a[4]=t15,tmp=(C_word)a,a+=5,tmp));
t21=((C_word*)t19)[1];
f_9180(t21,t17,t9);}
else{
t9=C_eqp(((C_word*)t0)[4],lf[179]);
if(C_truep(t9)){
t10=C_i_cadr(((C_word*)t0)[3]);
t11=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9224,a[2]=((C_word*)t0)[3],a[3]=t10,a[4]=((C_word*)t0)[10],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* core.scm:781: unzip1 */
f_6992(t11,t10);}
else{
t10=C_eqp(((C_word*)t0)[4],lf[180]);
if(C_truep(t10)){
t11=C_i_caddr(((C_word*)t0)[3]);
t12=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t13=t12;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=((C_word*)t14)[1];
t16=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_9498,a[2]=t11,a[3]=((C_word*)t0)[14],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[11],tmp=(C_word)a,a+=9,tmp);
t17=C_u_i_cdr(((C_word*)t0)[3]);
t18=C_u_i_car(t17);
t19=C_i_check_list_2(t18,lf[10]);
t20=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9514,a[2]=((C_word*)t0)[15],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[2],tmp=(C_word)a,a+=11,tmp);
t21=C_SCHEME_UNDEFINED;
t22=(*a=C_VECTOR_TYPE|1,a[1]=t21,tmp=(C_word)a,a+=2,tmp);
t23=C_set_block_item(t22,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9542,a[2]=t14,a[3]=t22,a[4]=t16,a[5]=t15,tmp=(C_word)a,a+=6,tmp));
t24=((C_word*)t22)[1];
f_9542(t24,t20,t18);}
else{
t11=C_eqp(((C_word*)t0)[4],lf[97]);
if(C_truep(t11)){
t12=C_i_cadr(((C_word*)t0)[3]);
t13=t12;
t14=(*a=C_VECTOR_TYPE|1,a[1]=t13,tmp=(C_word)a,a+=2,tmp);
t15=C_u_i_cdr(((C_word*)t0)[3]);
t16=C_u_i_cdr(t15);
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_9588,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[13],a[7]=((C_word*)t0)[15],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[12],a[10]=t17,a[11]=((C_word*)t0)[3],a[12]=((C_word*)t0)[2],a[13]=t14,tmp=(C_word)a,a+=14,tmp);
t19=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9800,a[2]=t14,a[3]=t17,a[4]=t18,tmp=(C_word)a,a+=5,tmp);
/* core.scm:813: ##sys#extended-lambda-list? */
t20=*((C_word*)lf[194]+1);{
C_word av2[3];
av2[0]=t20;
av2[1]=t19;
av2[2]=((C_word*)t14)[1];
((C_proc)(void*)(*((C_word*)t20+1)))(3,av2);}}
else{
t12=C_eqp(((C_word*)t0)[4],lf[195]);
if(C_truep(t12)){
t13=*((C_word*)lf[107]+1);
t14=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_9827,a[2]=t13,a[3]=((C_word*)t0)[11],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[12],a[10]=((C_word*)t0)[3],a[11]=((C_word*)t0)[2],tmp=(C_word)a,a+=12,tmp);
t15=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t16=t15;
t17=(*a=C_VECTOR_TYPE|1,a[1]=t16,tmp=(C_word)a,a+=2,tmp);
t18=((C_word*)t17)[1];
t19=C_i_cadr(((C_word*)t0)[3]);
t20=C_i_check_list_2(t19,lf[10]);
t21=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_9917,a[2]=t14,tmp=(C_word)a,a+=3,tmp);
t22=C_SCHEME_UNDEFINED;
t23=(*a=C_VECTOR_TYPE|1,a[1]=t22,tmp=(C_word)a,a+=2,tmp);
t24=C_set_block_item(t23,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9923,a[2]=t17,a[3]=t23,a[4]=t18,tmp=(C_word)a,a+=5,tmp));
t25=((C_word*)t23)[1];
f_9923(t25,t21,t19);}
else{
t13=C_eqp(((C_word*)t0)[4],lf[198]);
if(C_truep(t13)){
t14=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t15=t14;
t16=(*a=C_VECTOR_TYPE|1,a[1]=t15,tmp=(C_word)a,a+=2,tmp);
t17=((C_word*)t16)[1];
t18=C_i_cadr(((C_word*)t0)[3]);
t19=C_i_check_list_2(t18,lf[10]);
t20=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9996,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[12],a[9]=((C_word*)t0)[3],a[10]=((C_word*)t0)[2],tmp=(C_word)a,a+=11,tmp);
t21=C_SCHEME_UNDEFINED;
t22=(*a=C_VECTOR_TYPE|1,a[1]=t21,tmp=(C_word)a,a+=2,tmp);
t23=C_set_block_item(t22,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10093,a[2]=t16,a[3]=t22,a[4]=t17,tmp=(C_word)a,a+=5,tmp));
t24=((C_word*)t22)[1];
f_10093(t24,t20,t18);}
else{
t14=C_eqp(((C_word*)t0)[4],lf[199]);
if(C_truep(t14)){
t15=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10134,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[16],a[10]=((C_word*)t0)[3],tmp=(C_word)a,a+=11,tmp);
t16=C_u_i_car(((C_word*)t0)[3]);
t17=C_i_cadr(((C_word*)t0)[3]);
t18=C_i_pairp(t17);
t19=(C_truep(t18)?lf[209]:lf[210]);
t20=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10227,a[2]=t15,a[3]=t16,a[4]=((C_word*)t0)[3],a[5]=t19,tmp=(C_word)a,a+=6,tmp);
/* core.scm:904: ##sys#current-environment */
t21=*((C_word*)lf[107]+1);{
C_word av2[2];
av2[0]=t21;
av2[1]=t20;
((C_proc)(void*)(*((C_word*)t21+1)))(2,av2);}}
else{
t15=C_eqp(((C_word*)t0)[4],lf[212]);
if(C_truep(t15)){
t16=C_i_cadr(((C_word*)t0)[3]);
t17=C_i_caddr(((C_word*)t0)[3]);
t18=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10249,a[2]=t17,a[3]=t16,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[2],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[17],tmp=(C_word)a,a+=12,tmp);
/* core.scm:927: lookup */
t19=((C_word*)((C_word*)t0)[16])[1];
f_7810(t19,t18,t16);}
else{
t16=C_eqp(((C_word*)t0)[4],lf[216]);
if(C_truep(t16)){
t17=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t18=t17;
t19=(*a=C_VECTOR_TYPE|1,a[1]=t18,tmp=(C_word)a,a+=2,tmp);
t20=((C_word*)t19)[1];
t21=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_10329,a[2]=((C_word*)t0)[16],tmp=(C_word)a,a+=3,tmp);
t22=C_i_cadr(((C_word*)t0)[3]);
t23=C_i_check_list_2(t22,lf[10]);
t24=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_10386,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[18],a[9]=((C_word*)t0)[12],a[10]=((C_word*)t0)[3],a[11]=((C_word*)t0)[2],tmp=(C_word)a,a+=12,tmp);
t25=C_SCHEME_UNDEFINED;
t26=(*a=C_VECTOR_TYPE|1,a[1]=t25,tmp=(C_word)a,a+=2,tmp);
t27=C_set_block_item(t26,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_10501,a[2]=t19,a[3]=t26,a[4]=t21,a[5]=t20,tmp=(C_word)a,a+=6,tmp));
t28=((C_word*)t26)[1];
f_10501(t28,t24,t22);}
else{
t17=C_eqp(((C_word*)t0)[4],lf[220]);
if(C_truep(t17)){
t18=C_i_cadr(((C_word*)t0)[3]);
t19=C_i_caddr(((C_word*)t0)[3]);
t20=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_10552,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[18],a[9]=((C_word*)t0)[3],a[10]=((C_word*)t0)[12],tmp=(C_word)a,a+=11,tmp);
/* core.scm:992: ##sys#include-forms-from-file */
t21=*((C_word*)lf[222]+1);{
C_word av2[5];
av2[0]=t21;
av2[1]=((C_word*)t0)[2];
av2[2]=t18;
av2[3]=t19;
av2[4]=t20;
((C_proc)(void*)(*((C_word*)t21+1)))(5,av2);}}
else{
t18=C_eqp(((C_word*)t0)[4],lf[223]);
if(C_truep(t18)){
t19=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t20=t19;
t21=(*a=C_VECTOR_TYPE|1,a[1]=t20,tmp=(C_word)a,a+=2,tmp);
t22=((C_word*)t21)[1];
t23=C_i_cadr(((C_word*)t0)[3]);
t24=C_i_check_list_2(t23,lf[10]);
t25=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10626,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[2],tmp=(C_word)a,a+=10,tmp);
t26=C_SCHEME_UNDEFINED;
t27=(*a=C_VECTOR_TYPE|1,a[1]=t26,tmp=(C_word)a,a+=2,tmp);
t28=C_set_block_item(t27,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_10642,a[2]=t21,a[3]=t27,a[4]=t22,tmp=(C_word)a,a+=5,tmp));
t29=((C_word*)t27)[1];
f_10642(t29,t25,t23);}
else{
t19=C_eqp(((C_word*)t0)[4],lf[227]);
if(C_truep(t19)){
t20=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_10683,a[2]=((C_word*)t0)[17],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[18],a[9]=((C_word*)t0)[3],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1015: chicken.syntax#strip-syntax */
t21=*((C_word*)lf[146]+1);{
C_word av2[3];
av2[0]=t21;
av2[1]=t20;
av2[2]=C_i_cadr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t21+1)))(3,av2);}}
else{
t20=C_eqp(((C_word*)t0)[4],lf[276]);
if(C_truep(t20)){
t21=C_i_cadr(((C_word*)t0)[3]);
t22=C_u_i_cdr(((C_word*)t0)[3]);
t23=C_u_i_cdr(t22);
t24=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t25=t24;
t26=(*a=C_VECTOR_TYPE|1,a[1]=t25,tmp=(C_word)a,a+=2,tmp);
t27=((C_word*)t26)[1];
t28=C_i_check_list_2(t21,lf[10]);
t29=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_11259,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[13],a[5]=t21,a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[6],a[9]=((C_word*)t0)[12],a[10]=t23,a[11]=((C_word*)t0)[3],tmp=(C_word)a,a+=12,tmp);
t30=C_SCHEME_UNDEFINED;
t31=(*a=C_VECTOR_TYPE|1,a[1]=t30,tmp=(C_word)a,a+=2,tmp);
t32=C_set_block_item(t31,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11324,a[2]=t26,a[3]=t31,a[4]=t27,tmp=(C_word)a,a+=5,tmp));
t33=((C_word*)t31)[1];
f_11324(t33,t29,t21);}
else{
t21=C_eqp(((C_word*)t0)[4],lf[277]);
if(C_truep(t21)){
t22=C_i_cadr(((C_word*)t0)[3]);
t23=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11368,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[18],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:1115: lookup */
t24=((C_word*)((C_word*)t0)[16])[1];
f_7810(t24,t23,t22);}
else{
t22=C_eqp(((C_word*)t0)[4],lf[177]);
if(C_truep(t22)){
t23=C_i_cadr(((C_word*)t0)[3]);
t24=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11414,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[2],a[7]=t23,a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1127: lookup */
t25=((C_word*)((C_word*)t0)[16])[1];
f_7810(t25,t24,t23);}
else{
t23=C_eqp(((C_word*)t0)[4],lf[188]);
if(C_truep(t23)){
t24=C_i_cadr(((C_word*)t0)[3]);
t25=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t26=t25;
t27=(*a=C_VECTOR_TYPE|1,a[1]=t26,tmp=(C_word)a,a+=2,tmp);
t28=((C_word*)t27)[1];
t29=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11783,a[2]=((C_word*)t0)[19],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[18],tmp=(C_word)a,a+=8,tmp);
t30=C_u_i_cdr(((C_word*)t0)[3]);
t31=C_u_i_cdr(t30);
t32=C_i_check_list_2(t31,lf[10]);
t33=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_11799,a[2]=((C_word*)t0)[10],a[3]=t24,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
t34=C_SCHEME_UNDEFINED;
t35=(*a=C_VECTOR_TYPE|1,a[1]=t34,tmp=(C_word)a,a+=2,tmp);
t36=C_set_block_item(t35,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11801,a[2]=t27,a[3]=t35,a[4]=t29,a[5]=t28,tmp=(C_word)a,a+=6,tmp));
t37=((C_word*)t35)[1];
f_11801(t37,t33,t31);}
else{
t24=C_eqp(((C_word*)t0)[4],lf[302]);
if(C_truep(t24)){
t25=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11850,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[20],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],tmp=(C_word)a,a+=8,tmp);
/* core.scm:1192: unquotify */
t26=((C_word*)((C_word*)t0)[19])[1];
f_7979(t26,t25,C_i_cadr(((C_word*)t0)[3]));}
else{
t25=C_eqp(((C_word*)t0)[4],lf[303]);
if(C_truep(t25)){
t26=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t27=t26;
t28=(*a=C_VECTOR_TYPE|1,a[1]=t27,tmp=(C_word)a,a+=2,tmp);
t29=((C_word*)t28)[1];
t30=C_i_cadr(((C_word*)t0)[3]);
t31=C_i_check_list_2(t30,lf[10]);
t32=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_11888,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[20],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],tmp=(C_word)a,a+=8,tmp);
t33=C_SCHEME_UNDEFINED;
t34=(*a=C_VECTOR_TYPE|1,a[1]=t33,tmp=(C_word)a,a+=2,tmp);
t35=C_set_block_item(t34,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_11898,a[2]=t28,a[3]=t34,a[4]=((C_word*)t0)[19],a[5]=t29,tmp=(C_word)a,a+=6,tmp));
t36=((C_word*)t34)[1];
f_11898(t36,t32,t30);}
else{
t26=C_eqp(((C_word*)t0)[4],lf[282]);
if(C_truep(t26)){
t27=C_i_cadr(((C_word*)t0)[3]);
t28=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_11947,a[2]=((C_word*)t0)[2],a[3]=t27,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1200: walk */
t29=((C_word*)((C_word*)t0)[5])[1];
f_8330(t29,t28,C_i_caddr(((C_word*)t0)[3]),((C_word*)t0)[6],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[9],((C_word*)t0)[10],C_SCHEME_FALSE);}
else{
t27=C_eqp(((C_word*)t0)[4],lf[285]);
if(C_truep(t27)){
t28=C_i_cadr(((C_word*)t0)[3]);
t29=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_11968,a[2]=((C_word*)t0)[2],a[3]=t28,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[3],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1205: walk */
t30=((C_word*)((C_word*)t0)[5])[1];
f_8330(t30,t29,C_i_caddr(((C_word*)t0)[3]),((C_word*)t0)[6],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[9],((C_word*)t0)[10],C_SCHEME_FALSE);}
else{
t28=C_eqp(((C_word*)t0)[4],lf[304]);
t29=(C_truep(t28)?t28:C_eqp(((C_word*)t0)[4],lf[305]));
if(C_truep(t29)){
t30=C_i_cadr(((C_word*)t0)[3]);
t31=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_11995,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=t30,a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[18],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1210: ##sys#eval/meta */
t32=*((C_word*)lf[197]+1);{
C_word av2[3];
av2[0]=t32;
av2[1]=t31;
av2[2]=t30;
((C_proc)(void*)(*((C_word*)t32+1)))(3,av2);}}
else{
t30=C_eqp(((C_word*)t0)[4],lf[306]);
t31=(C_truep(t30)?t30:C_eqp(((C_word*)t0)[4],lf[307]));
if(C_truep(t31)){
t32=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12010,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:1214: ##sys#eval/meta */
t33=*((C_word*)lf[197]+1);{
C_word av2[3];
av2[0]=t33;
av2[1]=t32;
av2[2]=C_i_cadr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t33+1)))(3,av2);}}
else{
t32=C_eqp(((C_word*)t0)[4],lf[190]);
if(C_truep(t32)){
if(C_truep(C_i_pairp(C_u_i_cdr(((C_word*)t0)[3])))){
t33=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12033,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
t34=C_u_i_cdr(((C_word*)t0)[3]);
t35=C_SCHEME_UNDEFINED;
t36=(*a=C_VECTOR_TYPE|1,a[1]=t35,tmp=(C_word)a,a+=2,tmp);
t37=C_set_block_item(t36,0,(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12037,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[7],a[5]=((C_word*)t0)[8],a[6]=((C_word*)t0)[9],a[7]=((C_word*)t0)[10],a[8]=((C_word*)t0)[18],a[9]=t36,tmp=(C_word)a,a+=10,tmp));
t38=((C_word*)t36)[1];
f_12037(t38,t33,t34);}
else{
t33=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t33;
av2[1]=lf[309];
((C_proc)(void*)(*((C_word*)t33+1)))(2,av2);}}}
else{
t33=C_eqp(((C_word*)t0)[4],lf[310]);
if(C_truep(t33)){
t34=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12081,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1229: expand-foreign-lambda */
f_16082(t34,((C_word*)t0)[3],C_SCHEME_FALSE);}
else{
t34=C_eqp(((C_word*)t0)[4],lf[312]);
if(C_truep(t34)){
t35=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12094,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1232: expand-foreign-lambda */
f_16082(t35,((C_word*)t0)[3],C_SCHEME_TRUE);}
else{
t35=C_eqp(((C_word*)t0)[4],lf[313]);
if(C_truep(t35)){
t36=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12107,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1235: expand-foreign-lambda* */
f_16119(t36,((C_word*)t0)[3],C_SCHEME_FALSE);}
else{
t36=C_eqp(((C_word*)t0)[4],lf[315]);
if(C_truep(t36)){
t37=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12120,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1238: expand-foreign-lambda* */
f_16119(t37,((C_word*)t0)[3],C_SCHEME_TRUE);}
else{
t37=C_eqp(((C_word*)t0)[4],lf[316]);
if(C_truep(t37)){
t38=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12133,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],tmp=(C_word)a,a+=9,tmp);
t39=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_16236,a[2]=((C_word*)t0)[3],a[3]=t38,tmp=(C_word)a,a+=4,tmp);
t40=C_i_cddr(((C_word*)t0)[3]);
if(C_truep(C_i_pairp(t40))){
t41=C_i_caddr(((C_word*)t0)[3]);
t42=t39;
f_16236(t42,C_i_not(C_i_stringp(t41)));}
else{
t41=t39;
f_16236(t41,C_SCHEME_FALSE);}}
else{
t38=C_eqp(((C_word*)t0)[4],lf[321]);
if(C_truep(t38)){
t39=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12142,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:1244: chicken.syntax#strip-syntax */
t40=*((C_word*)lf[146]+1);{
C_word av2[3];
av2[0]=t40;
av2[1]=t39;
av2[2]=C_i_cadr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t40+1)))(3,av2);}}
else{
t39=C_eqp(((C_word*)t0)[4],lf[323]);
if(C_truep(t39)){
t40=C_i_cadr(((C_word*)t0)[3]);
t41=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_12189,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[18],a[11]=t40,tmp=(C_word)a,a+=12,tmp);
/* core.scm:1256: chicken.syntax#strip-syntax */
t42=*((C_word*)lf[146]+1);{
C_word av2[3];
av2[0]=t42;
av2[1]=t41;
av2[2]=C_i_caddr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t42+1)))(3,av2);}}
else{
t40=C_eqp(((C_word*)t0)[4],lf[331]);
if(C_truep(t40)){
t41=C_i_cadr(((C_word*)t0)[3]);
t42=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12311,a[2]=((C_word*)t0)[3],a[3]=t41,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[18],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1289: chicken.syntax#get-line-number */
t43=*((C_word*)lf[111]+1);{
C_word av2[3];
av2[0]=t43;
av2[1]=t42;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t43+1)))(3,av2);}}
else{
t41=C_eqp(((C_word*)t0)[4],lf[340]);
if(C_truep(t41)){
t42=C_i_cadr(((C_word*)t0)[3]);
t43=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_12398,a[2]=((C_word*)t0)[3],a[3]=t42,a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[2],tmp=(C_word)a,a+=11,tmp);
/* core.scm:1309: chicken.syntax#strip-syntax */
t44=*((C_word*)lf[146]+1);{
C_word av2[3];
av2[0]=t44;
av2[1]=t43;
av2[2]=C_i_caddr(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t44+1)))(3,av2);}}
else{
t42=C_eqp(((C_word*)t0)[4],lf[344]);
if(C_truep(t42)){
t43=C_i_cadr(((C_word*)t0)[3]);
t44=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12593,a[2]=((C_word*)t0)[2],a[3]=t43,a[4]=((C_word*)t0)[18],a[5]=((C_word*)t0)[3],tmp=(C_word)a,a+=6,tmp);
/* core.scm:1337: scheme#cdaddr */
t45=*((C_word*)lf[350]+1);{
C_word av2[3];
av2[0]=t45;
av2[1]=t44;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t45+1)))(3,av2);}}
else{
t43=C_eqp(((C_word*)t0)[4],lf[351]);
if(C_truep(t43)){
t44=C_i_cadr(((C_word*)t0)[3]);
t45=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_12605,a[2]=((C_word*)t0)[3],a[3]=t44,a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[18],tmp=(C_word)a,a+=9,tmp);
/* core.scm:1349: chicken.syntax#get-line-number */
t46=*((C_word*)lf[111]+1);{
C_word av2[3];
av2[0]=t46;
av2[1]=t45;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t46+1)))(3,av2);}}
else{
t44=C_eqp(((C_word*)t0)[4],lf[366]);
if(C_truep(t44)){
t45=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t46=t45;
t47=(*a=C_VECTOR_TYPE|1,a[1]=t46,tmp=(C_word)a,a+=2,tmp);
t48=((C_word*)t47)[1];
t49=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_12804,a[2]=((C_word*)t0)[6],a[3]=((C_word*)t0)[16],tmp=(C_word)a,a+=4,tmp);
t50=C_u_i_cdr(((C_word*)t0)[3]);
t51=C_i_check_list_2(t50,lf[10]);
t52=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_12825,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[10],tmp=(C_word)a,a+=7,tmp);
t53=C_SCHEME_UNDEFINED;
t54=(*a=C_VECTOR_TYPE|1,a[1]=t53,tmp=(C_word)a,a+=2,tmp);
t55=C_set_block_item(t54,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_12827,a[2]=t47,a[3]=t54,a[4]=t49,a[5]=t48,tmp=(C_word)a,a+=6,tmp));
t56=((C_word*)t54)[1];
f_12827(t56,t52,t50);}
else{
t45=C_eqp(((C_word*)t0)[4],lf[449]);
if(C_truep(t45)){
t46=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_12870,a[2]=((C_word*)t0)[3],tmp=(C_word)a,a+=3,tmp);
t47=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_12880,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[21],a[7]=((C_word*)t0)[20],a[8]=((C_word*)t0)[3],a[9]=((C_word*)t0)[7],tmp=(C_word)a,a+=10,tmp);
/* core.scm:1393: ##sys#call-with-values */{
C_word av2[4];
av2[0]=0;
av2[1]=((C_word*)t0)[2];
av2[2]=t46;
av2[3]=t47;
C_call_with_values(4,av2);}}
else{
t46=C_eqp(((C_word*)t0)[4],lf[473]);
if(C_truep(t46)){
t47=C_i_cadr(((C_word*)t0)[3]);
if(C_truep(C_i_symbolp(t47))){
t48=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13261,a[2]=((C_word*)t0)[5],a[3]=((C_word*)t0)[6],a[4]=((C_word*)t0)[9],a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[2],a[7]=t47,tmp=(C_word)a,a+=8,tmp);
/* core.scm:1477: lookup */
t49=((C_word*)((C_word*)t0)[16])[1];
f_7810(t49,t48,t47);}
else{
t48=C_a_i_list(&a,2,lf[145],lf[474]);
t49=C_a_i_list(&a,5,lf[475],t47,C_fix(0),C_SCHEME_FALSE,t48);
/* core.scm:1490: walk */
t50=((C_word*)((C_word*)t0)[5])[1];
f_8330(t50,((C_word*)t0)[2],t49,((C_word*)t0)[6],C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[9],((C_word*)t0)[10],C_SCHEME_FALSE);}}
else{
t47=C_a_i_cons(&a,2,((C_word*)t0)[4],*((C_word*)lf[476]+1));
t48=t47;
t49=(*a=C_VECTOR_TYPE|1,a[1]=t48,tmp=(C_word)a,a+=2,tmp);
t50=C_SCHEME_FALSE;
t51=(*a=C_VECTOR_TYPE|1,a[1]=t50,tmp=(C_word)a,a+=2,tmp);
t52=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_13278,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[10],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
t53=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13307,a[2]=t51,a[3]=t49,tmp=(C_word)a,a+=4,tmp);
t54=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_13312,a[2]=((C_word*)t0)[20],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[9],a[6]=((C_word*)t0)[10],a[7]=((C_word*)t0)[18],tmp=(C_word)a,a+=8,tmp);
t55=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_13318,a[2]=t49,a[3]=t51,tmp=(C_word)a,a+=4,tmp);
/* core.scm:1495: ##sys#dynamic-wind */
t56=*((C_word*)lf[114]+1);{
C_word av2[5];
av2[0]=t56;
av2[1]=t52;
av2[2]=t53;
av2[3]=t54;
av2[4]=t55;
((C_proc)(void*)(*((C_word*)t56+1)))(5,av2);}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}

/* k8752 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_8754(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_8754,c,av);}
a=C_alloc(6);
t2=C_mutate((C_word*)lf[21]+1 /* (set! chicken.compiler.core#used-units ...) */,t1);
t3=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list(&a,2,lf[163],((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k8772 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_8774(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_8774,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8778,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8782,a[2]=t2,tmp=(C_word)a,a+=3,tmp);
/* core.scm:725: scheme#cadadr */
t4=*((C_word*)lf[161]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k8776 in k8772 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_8778(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,1)))){
C_save_and_reclaim((void *)f_8778,c,av);}
a=C_alloc(12);
t2=C_a_i_list(&a,2,((C_word*)t0)[2],t1);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=C_a_i_list(&a,2,lf[117],t2);
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k8780 in k8772 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_8782(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,2)))){
C_save_and_reclaim((void *)f_8782,c,av);}
/* core.scm:725: chicken.syntax#strip-syntax */
t2=*((C_word*)lf[146]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(3,av2);}}

/* k8793 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_8795(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,8)))){
C_save_and_reclaim((void *)f_8795,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8799,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:730: walk */
t3=((C_word*)((C_word*)t0)[3])[1];
f_8330(t3,t2,C_i_caddr(((C_word*)t0)[4]),((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],C_SCHEME_FALSE);}

/* k8797 in k8793 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_8799(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_8799,c,av);}
a=C_alloc(9);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,3,lf[121],((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8814 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_8816(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8816,c,av);}
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=lf[166];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8833 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_8835(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,0,4)))){
C_save_and_reclaim_args((void *)trf_8835,2,t0,t1);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8842,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],tmp=(C_word)a,a+=9,tmp);
t3=C_i_memq(((C_word*)t0)[9],*((C_word*)lf[81]+1));
t4=(C_truep(t3)?t3:*((C_word*)lf[56]+1));
if(C_truep(t4)){
/* core.scm:741: ##sys#process-require */
t5=*((C_word*)lf[169]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[10];
av2[4]=lf[170];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}
else{
/* core.scm:741: ##sys#process-require */
t5=*((C_word*)lf[169]+1);{
C_word av2[5];
av2[0]=t5;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
av2[3]=((C_word*)t0)[10];
av2[4]=lf[171];
((C_proc)(void*)(*((C_word*)t5+1)))(5,av2);}}}

/* k8840 in k8833 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_8842(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_8842,c,av);}
/* core.scm:741: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* k8853 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_8855(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,3)))){
C_save_and_reclaim((void *)f_8855,c,av);}
a=C_alloc(6);
if(C_truep(t1)){
t2=((C_word*)t0)[2];
f_8835(t2,C_SCHEME_UNDEFINED);}
else{
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_8859,a[2]=((C_word*)t0)[2],tmp=(C_word)a,a+=3,tmp);
/* core.scm:740: lset-adjoin/eq? */
f_7102(t2,*((C_word*)lf[80]+1),C_a_i_list(&a,1,((C_word*)t0)[3]));}}

/* k8857 in k8853 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_8859(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8859,c,av);}
t2=C_mutate((C_word*)lf[80]+1 /* (set! chicken.compiler.core#required-extensions ...) */,t1);
t3=((C_word*)t0)[2];
f_8835(t3,t2);}

/* k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_8880(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,3)))){
C_save_and_reclaim((void *)f_8880,c,av);}
a=C_alloc(26);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_check_list_2(t1,lf[10]);
t7=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_8889,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=t1,tmp=(C_word)a,a+=14,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9035,a[2]=t4,a[3]=t9,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_9035(t11,t7,t1);}

/* k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_8889(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(20,c,2)))){
C_save_and_reclaim((void *)f_8889,c,av);}
a=C_alloc(20);
t2=(*a=C_CLOSURE_TYPE|14,a[1]=(C_word)f_8892,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],tmp=(C_word)a,a+=15,tmp);
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9033,a[2]=t2,a[3]=((C_word*)t0)[13],a[4]=t1,tmp=(C_word)a,a+=5,tmp);
/* core.scm:752: ##sys#current-environment */
t4=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_8892(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_8892,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_8895,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
/* core.scm:753: chicken.syntax#get-line-number */
t3=*((C_word*)lf[111]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[12];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_8895(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(14,c,3)))){
C_save_and_reclaim((void *)f_8895,c,av);}
a=C_alloc(14);
t2=(C_truep(t1)?t1:((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|13,a[1]=(C_word)f_8901,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=t2,a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],a[12]=((C_word*)t0)[12],a[13]=((C_word*)t0)[13],tmp=(C_word)a,a+=14,tmp);
/* core.scm:754: set-real-names! */
f_7913(t3,((C_word*)t0)[6],((C_word*)t0)[15]);}

/* k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_8901(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,4)))){
C_save_and_reclaim((void *)f_8901,c,av);}
a=C_alloc(32);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8909,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],tmp=(C_word)a,a+=6,tmp);
t7=C_i_check_list_2(((C_word*)t0)[6],lf[10]);
t8=C_i_check_list_2(((C_word*)t0)[7],lf[10]);
t9=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_8932,a[2]=((C_word*)t0)[8],a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[10],a[6]=((C_word*)t0)[11],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[5],a[9]=((C_word*)t0)[6],a[10]=((C_word*)t0)[3],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],tmp=(C_word)a,a+=13,tmp);
t10=C_SCHEME_UNDEFINED;
t11=(*a=C_VECTOR_TYPE|1,a[1]=t10,tmp=(C_word)a,a+=2,tmp);
t12=C_set_block_item(t11,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8983,a[2]=t4,a[3]=t11,a[4]=t6,a[5]=t5,tmp=(C_word)a,a+=6,tmp));
t13=((C_word*)t11)[1];
f_8983(t13,t9,((C_word*)t0)[6],((C_word*)t0)[7]);}

/* g1201 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_8909(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,8)))){
C_save_and_reclaim_args((void *)trf_8909,4,t0,t1,t2,t3);}
a=C_alloc(4);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8917,a[2]=t1,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:757: walk */
t5=((C_word*)((C_word*)t0)[2])[1];
f_8330(t5,t4,C_i_cadr(t3),((C_word*)t0)[3],C_u_i_car(t3),C_SCHEME_TRUE,((C_word*)t0)[4],((C_word*)t0)[5],C_SCHEME_FALSE);}

/* k8915 in g1201 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_8917(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,1)))){
C_save_and_reclaim((void *)f_8917,c,av);}
a=C_alloc(6);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list2(&a,2,((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k8930 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_8932(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(28,c,4)))){
C_save_and_reclaim((void *)f_8932,c,av);}
a=C_alloc(28);
t2=*((C_word*)lf[107]+1);
t3=((C_word*)t0)[2];
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_SCHEME_TRUE;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8936,a[2]=((C_word*)t0)[3],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8938,a[2]=t4,a[3]=t6,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t9=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_8955,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[11],a[10]=((C_word*)t0)[12],tmp=(C_word)a,a+=11,tmp);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8973,a[2]=t4,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:759: ##sys#dynamic-wind */
t11=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t11;
av2[1]=t7;
av2[2]=t8;
av2[3]=t9;
av2[4]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(5,av2);}}

/* k8934 in k8930 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_8936(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,1)))){
C_save_and_reclaim((void *)f_8936,c,av);}
a=C_alloc(9);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_list(&a,3,lf[174],((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* a8937 in k8930 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_8938(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_8938,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_8942,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)((C_word*)t0)[3])[1])){
/* core.scm:759: ##sys#current-environment1227 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
f_8942(2,av2);}}}

/* k8940 in a8937 in k8930 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_8942(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_8942,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_8946,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* core.scm:759: ##sys#current-environment1227 */
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k8944 in k8940 in a8937 in k8930 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_8946(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_8946,c,av);}
a=C_alloc(4);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_8949,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:759: ##sys#current-environment1227 */
t4=((C_word*)t0)[5];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k8947 in k8944 in k8940 in a8937 in k8930 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_8949(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8949,c,av);}
t2=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_FALSE);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a8954 in k8930 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_8955(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(10,c,4)))){
C_save_and_reclaim((void *)f_8955,c,av);}
a=C_alloc(10);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_8963,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
/* core.scm:760: canonicalize-body/ln */
t3=((C_word*)((C_word*)t0)[9])[1];
f_7884(t3,t2,((C_word*)t0)[6],C_i_cddr(((C_word*)t0)[10]),*((C_word*)lf[52]+1));}

/* k8961 in a8954 in k8930 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_8963(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_8963,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_8967,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],tmp=(C_word)a,a+=9,tmp);
/* core.scm:762: scheme#append */
t3=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[8];
av2[3]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k8965 in k8961 in a8954 in k8930 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_8967(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_8967,c,av);}
/* core.scm:760: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* a8972 in k8930 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_8973(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_8973,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8977,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:759: ##sys#current-environment1227 */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k8975 in a8972 in k8930 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_8977(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_8977,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_8980,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:759: ##sys#current-environment1227 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k8978 in k8975 in a8972 in k8930 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_8980(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_8980,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* map-loop1195 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_fcall f_8983(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_8983,4,t0,t1,t2,t3);}
a=C_alloc(7);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9012,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,a[6]=t3,tmp=(C_word)a,a+=7,tmp);
/* core.scm:756: g1201 */
t7=((C_word*)t0)[4];
f_8909(t7,t6,C_slot(t2,C_fix(0)),C_slot(t3,C_fix(0)));}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* k9010 in map-loop1195 in k8899 in k8893 in k8890 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_9012(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,3)))){
C_save_and_reclaim((void *)f_9012,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_8983(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)),C_slot(((C_word*)t0)[6],C_fix(1)));}

/* k9031 in k8887 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9033(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9033,c,av);}
/* core.scm:752: ##sys#extend-se */
t2=*((C_word*)lf[175]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* map-loop1161 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_9035(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_9035,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9060,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:751: g1167 */
t4=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9058 in map-loop1161 in k8878 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9060(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_9060,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_9035(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k9106 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_9108(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(26,c,3)))){
C_save_and_reclaim((void *)f_9108,c,av);}
a=C_alloc(26);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9112,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9132,a[2]=((C_word*)t0)[9],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9146,a[2]=t5,a[3]=t9,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_9146(t11,t7,((C_word*)t0)[10]);}

/* k9110 in k9106 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9112(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,8)))){
C_save_and_reclaim((void *)f_9112,c,av);}
a=C_alloc(6);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_cons(&a,2,lf[173],t2);
/* core.scm:768: walk */
t4=((C_word*)((C_word*)t0)[3])[1];
f_8330(t4,((C_word*)t0)[4],t3,((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],C_SCHEME_FALSE);}

/* k9130 in k9106 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9132(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_9132,c,av);}
a=C_alloc(9);
t2=C_a_i_cons(&a,2,C_SCHEME_END_OF_LIST,((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,lf[173],t2);
t4=C_a_i_list(&a,1,t3);
/* core.scm:769: ##sys#append */
t5=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* map-loop1276 in k9106 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_9146(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(12,0,2)))){
C_save_and_reclaim_args((void *)trf_9146,3,t0,t1,t2);}
a=C_alloc(12);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=C_i_cadr(t3);
t6=C_a_i_list(&a,3,lf[177],t4,t5);
t7=C_a_i_cons(&a,2,t6,C_SCHEME_END_OF_LIST);
t8=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t7);
t9=C_mutate(((C_word *)((C_word*)t0)[2])+1,t7);
t11=t1;
t12=C_slot(t2,C_fix(1));
t1=t11;
t2=t12;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* map-loop1249 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_9180(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_9180,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=C_a_i_list2(&a,2,t4,lf[178]);
t6=C_a_i_cons(&a,2,t5,C_SCHEME_END_OF_LIST);
t7=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t6);
t8=C_mutate(((C_word *)((C_word*)t0)[2])+1,t6);
t10=t1;
t11=C_slot(t2,C_fix(1));
t1=t10;
t2=t11;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9222 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_9224(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(24,c,3)))){
C_save_and_reclaim((void *)f_9224,c,av);}
a=C_alloc(24);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=C_i_check_list_2(t1,lf[10]);
t7=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_9233,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9453,a[2]=t4,a[3]=t9,a[4]=t5,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_9453(t11,t7,t1);}

/* k9231 in k9222 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9233(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(25,c,3)))){
C_save_and_reclaim((void *)f_9233,c,av);}
a=C_alloc(25);
t2=C_i_cddr(((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=C_i_check_list_2(((C_word*)t0)[3],lf[10]);
t8=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_9262,a[2]=((C_word*)t0)[4],a[3]=((C_word*)t0)[5],a[4]=t1,a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=t2,a[12]=((C_word*)t0)[3],tmp=(C_word)a,a+=13,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9419,a[2]=t5,a[3]=t10,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t12=((C_word*)t10)[1];
f_9419(t12,t8,((C_word*)t0)[3]);}

/* k9260 in k9231 in k9222 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9262(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(30,c,4)))){
C_save_and_reclaim((void *)f_9262,c,av);}
a=C_alloc(30);
t2=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t3=t2;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=((C_word*)t4)[1];
t6=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9275,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t7=C_i_check_list_2(((C_word*)t0)[4],lf[10]);
t8=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_9293,a[2]=t1,a[3]=((C_word*)t0)[5],a[4]=((C_word*)t0)[6],a[5]=((C_word*)t0)[7],a[6]=((C_word*)t0)[8],a[7]=((C_word*)t0)[9],a[8]=((C_word*)t0)[10],a[9]=((C_word*)t0)[3],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[2],a[12]=((C_word*)t0)[4],tmp=(C_word)a,a+=13,tmp);
t9=C_SCHEME_UNDEFINED;
t10=(*a=C_VECTOR_TYPE|1,a[1]=t9,tmp=(C_word)a,a+=2,tmp);
t11=C_set_block_item(t10,0,(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9371,a[2]=t6,a[3]=t4,a[4]=t10,a[5]=t5,tmp=(C_word)a,a+=6,tmp));
t12=((C_word*)t10)[1];
f_9371(t12,t8,((C_word*)t0)[4],((C_word*)t0)[12]);}

/* g1372 in k9260 in k9231 in k9222 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static C_word C_fcall f_9275(C_word *a,C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_stack_overflow_check;{}
t3=C_i_cadr(t2);
t4=C_a_i_list(&a,4,lf[180],((C_word*)t0)[2],((C_word*)t0)[3],t3);
return(C_a_i_list2(&a,2,t1,t4));}

/* k9291 in k9260 in k9231 in k9222 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_9293(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(27,c,4)))){
C_save_and_reclaim((void *)f_9293,c,av);}
a=C_alloc(27);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9297,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
t3=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t4=t3;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=((C_word*)t5)[1];
t7=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9309,a[2]=((C_word*)t0)[10],a[3]=t2,tmp=(C_word)a,a+=4,tmp);
t8=C_SCHEME_UNDEFINED;
t9=(*a=C_VECTOR_TYPE|1,a[1]=t8,tmp=(C_word)a,a+=2,tmp);
t10=C_set_block_item(t9,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9323,a[2]=t5,a[3]=t9,a[4]=t6,tmp=(C_word)a,a+=5,tmp));
t11=((C_word*)t9)[1];
f_9323(t11,t7,((C_word*)t0)[11],((C_word*)t0)[12]);}

/* k9295 in k9291 in k9260 in k9231 in k9222 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_9297(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,8)))){
C_save_and_reclaim((void *)f_9297,c,av);}
a=C_alloc(15);
t2=C_a_i_cons(&a,2,((C_word*)t0)[2],t1);
t3=C_a_i_cons(&a,2,lf[173],t2);
t4=C_a_i_list(&a,3,lf[173],((C_word*)t0)[3],t3);
/* core.scm:784: walk */
t5=((C_word*)((C_word*)t0)[4])[1];
f_8330(t5,((C_word*)t0)[5],t4,((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10],C_SCHEME_FALSE);}

/* k9307 in k9291 in k9260 in k9231 in k9222 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_9309(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,3)))){
C_save_and_reclaim((void *)f_9309,c,av);}
a=C_alloc(9);
t2=C_a_i_cons(&a,2,C_SCHEME_END_OF_LIST,((C_word*)t0)[2]);
t3=C_a_i_cons(&a,2,lf[173],t2);
t4=C_a_i_list(&a,1,t3);
/* core.scm:785: ##sys#append */
t5=*((C_word*)lf[154]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t5;
av2[1]=((C_word*)t0)[3];
av2[2]=t1;
av2[3]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}

/* map-loop1402 in k9291 in k9260 in k9231 in k9222 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_fcall f_9323(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word t15;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(12,0,3)))){
C_save_and_reclaim_args((void *)trf_9323,4,t0,t1,t2,t3);}
a=C_alloc(12);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=C_slot(t2,C_fix(0));
t7=C_slot(t3,C_fix(0));
t8=C_a_i_list(&a,3,lf[177],t6,t7);
t9=C_a_i_cons(&a,2,t8,C_SCHEME_END_OF_LIST);
t10=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t9);
t11=C_mutate(((C_word *)((C_word*)t0)[2])+1,t9);
t13=t1;
t14=C_slot(t2,C_fix(1));
t15=C_slot(t3,C_fix(1));
t1=t13;
t2=t14;
t3=t15;
goto loop;}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* map-loop1366 in k9260 in k9231 in k9222 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_fcall f_9371(C_word t0,C_word t1,C_word t2,C_word t3){
C_word tmp;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(21,0,3)))){
C_save_and_reclaim_args((void *)trf_9371,4,t0,t1,t2,t3);}
a=C_alloc(21);
t4=C_i_pairp(t2);
t5=(C_truep(t4)?C_i_pairp(t3):C_SCHEME_FALSE);
if(C_truep(t5)){
t6=(
/* core.scm:790: g1372 */
  f_9275(C_a_i(&a,18),((C_word*)t0)[2],C_slot(t2,C_fix(0)),C_slot(t3,C_fix(0)))
);
t7=C_a_i_cons(&a,2,t6,C_SCHEME_END_OF_LIST);
t8=C_i_setslot(((C_word*)((C_word*)t0)[3])[1],C_fix(1),t7);
t9=C_mutate(((C_word *)((C_word*)t0)[3])+1,t7);
t11=t1;
t12=C_slot(t2,C_fix(1));
t13=C_slot(t3,C_fix(1));
t1=t11;
t2=t12;
t3=t13;
goto loop;}
else{
t6=t1;{
C_word av2[2];
av2[0]=t6;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}}

/* map-loop1339 in k9231 in k9222 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_fcall f_9419(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
loop:
if(C_unlikely(!C_demand(C_calculate_demand(9,0,2)))){
C_save_and_reclaim_args((void *)trf_9419,3,t0,t1,t2);}
a=C_alloc(9);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=C_a_i_list2(&a,2,t4,lf[181]);
t6=C_a_i_cons(&a,2,t5,C_SCHEME_END_OF_LIST);
t7=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t6);
t8=C_mutate(((C_word *)((C_word*)t0)[2])+1,t6);
t10=t1;
t11=C_slot(t2,C_fix(1));
t1=t10;
t2=t11;
goto loop;}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* map-loop1309 in k9222 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_fcall f_9453(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_9453,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9478,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:782: g1315 */
t4=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9476 in map-loop1309 in k9222 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9478(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_9478,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_9453(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* g1446 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_9498(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,0,7)))){
C_save_and_reclaim_args((void *)trf_9498,3,t0,t1,t2);}
a=C_alloc(4);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9506,a[2]=t1,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:803: resolve-variable */
t4=((C_word*)((C_word*)t0)[3])[1];
f_8022(t4,t3,t2,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8]);}

/* k9504 in g1446 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9506(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,1)))){
C_save_and_reclaim((void *)f_9506,c,av);}
a=C_alloc(3);
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_a_i_cons(&a,2,t1,((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}

/* k9512 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_9514(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,3)))){
C_save_and_reclaim((void *)f_9514,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9517,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
/* core.scm:807: scheme#append */
t3=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=t1;
av2[3]=((C_word*)((C_word*)t0)[2])[1];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k9515 in k9512 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9517(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,4)))){
C_save_and_reclaim((void *)f_9517,c,av);}
a=C_alloc(23);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9522,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t7=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_9527,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],tmp=(C_word)a,a+=9,tmp);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9537,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* core.scm:806: ##sys#dynamic-wind */
t9=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[10];
av2[2]=t6;
av2[3]=t7;
av2[4]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* a9521 in k9515 in k9512 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9522(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9522,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a9526 in k9515 in k9512 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9527(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_9527,c,av);}
/* core.scm:808: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,t1,C_i_cadddr(((C_word*)t0)[3]),((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* a9536 in k9515 in k9512 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9537(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9537,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* map-loop1440 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_9542(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_9542,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9567,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:802: g1446 */
t4=((C_word*)t0)[4];
f_9498(t4,t3,C_slot(t2,C_fix(0)));}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[5],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9565 in map-loop1440 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9567(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_9567,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_9542(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_9588(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,5)))){
C_save_and_reclaim((void *)f_9588,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_9593,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],a[11]=((C_word*)t0)[11],tmp=(C_word)a,a+=12,tmp);
/* core.scm:818: ##sys#decompose-lambda-list */
t3=*((C_word*)lf[191]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[12];
av2[2]=((C_word*)((C_word*)t0)[13])[1];
av2[3]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9593(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4=av[4];
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word t12;
C_word t13;
C_word t14;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(28,c,3)))){
C_save_and_reclaim((void *)f_9593,c,av);}
a=C_alloc(28);
t5=C_a_i_cons(&a,2,C_SCHEME_UNDEFINED,C_SCHEME_END_OF_LIST);
t6=t5;
t7=(*a=C_VECTOR_TYPE|1,a[1]=t6,tmp=(C_word)a,a+=2,tmp);
t8=((C_word*)t7)[1];
t9=C_i_check_list_2(t2,lf[10]);
t10=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_9603,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=t2,a[9]=t4,a[10]=t3,a[11]=((C_word*)t0)[7],a[12]=((C_word*)t0)[8],a[13]=((C_word*)t0)[9],a[14]=((C_word*)t0)[10],a[15]=((C_word*)t0)[11],tmp=(C_word)a,a+=16,tmp);
t11=C_SCHEME_UNDEFINED;
t12=(*a=C_VECTOR_TYPE|1,a[1]=t11,tmp=(C_word)a,a+=2,tmp);
t13=C_set_block_item(t12,0,(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9765,a[2]=t7,a[3]=t12,a[4]=t8,tmp=(C_word)a,a+=5,tmp));
t14=((C_word*)t12)[1];
f_9765(t14,t10,t2);}

/* k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9603(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_9603,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_9606,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],a[13]=((C_word*)t0)[12],a[14]=((C_word*)t0)[13],a[15]=((C_word*)t0)[14],tmp=(C_word)a,a+=16,tmp);
/* core.scm:822: chicken.syntax#get-line-number */
t3=*((C_word*)lf[111]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[15];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_9606(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(21,c,2)))){
C_save_and_reclaim((void *)f_9606,c,av);}
a=C_alloc(21);
t2=(C_truep(t1)?t1:((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|15,a[1]=(C_word)f_9612,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],a[10]=((C_word*)t0)[11],a[11]=((C_word*)t0)[12],a[12]=((C_word*)t0)[13],a[13]=t2,a[14]=((C_word*)t0)[14],a[15]=((C_word*)t0)[15],tmp=(C_word)a,a+=16,tmp);
t4=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9763,a[2]=t3,a[3]=((C_word*)t0)[9],a[4]=((C_word*)t0)[8],tmp=(C_word)a,a+=5,tmp);
/* core.scm:823: ##sys#current-environment */
t5=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}

/* k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_9612(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word t10;
C_word t11;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(34,c,4)))){
C_save_and_reclaim((void *)f_9612,c,av);}
a=C_alloc(34);
t2=*((C_word*)lf[107]+1);
t3=t1;
t4=(*a=C_VECTOR_TYPE|1,a[1]=t3,tmp=(C_word)a,a+=2,tmp);
t5=C_SCHEME_TRUE;
t6=(*a=C_VECTOR_TYPE|1,a[1]=t5,tmp=(C_word)a,a+=2,tmp);
t7=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9615,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=((C_word*)t0)[8],a[9]=((C_word*)t0)[9],a[10]=((C_word*)t0)[10],tmp=(C_word)a,a+=11,tmp);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9690,a[2]=t4,a[3]=t6,a[4]=t2,tmp=(C_word)a,a+=5,tmp);
t9=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9707,a[2]=((C_word*)t0)[11],a[3]=((C_word*)t0)[12],a[4]=((C_word*)t0)[2],a[5]=((C_word*)t0)[13],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[4],a[8]=((C_word*)t0)[14],a[9]=((C_word*)t0)[15],tmp=(C_word)a,a+=10,tmp);
t10=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9751,a[2]=t4,a[3]=t2,tmp=(C_word)a,a+=4,tmp);
/* core.scm:824: ##sys#dynamic-wind */
t11=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t11;
av2[1]=t7;
av2[2]=t8;
av2[3]=t9;
av2[4]=t10;
((C_proc)(void*)(*((C_word*)t11+1)))(5,av2);}}

/* k9613 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_9615(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(15,c,4)))){
C_save_and_reclaim((void *)f_9615,c,av);}
a=C_alloc(15);
t2=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9618,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],tmp=(C_word)a,a+=10,tmp);
if(C_truep(((C_word*)t0)[9])){
t3=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9688,a[2]=t2,a[3]=((C_word*)t0)[7],a[4]=((C_word*)t0)[10],tmp=(C_word)a,a+=5,tmp);
/* core.scm:839: posq */
f_7486(t3,((C_word*)t0)[9],((C_word*)t0)[8]);}
else{
/* core.scm:837: chicken.compiler.support#build-lambda-list */
t3=*((C_word*)lf[187]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[7];
av2[3]=((C_word*)t0)[10];
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}

/* k9616 in k9613 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_9618(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(18,c,3)))){
C_save_and_reclaim((void *)f_9618,c,av);}
a=C_alloc(18);
t2=C_a_i_list(&a,3,lf[97],t1,((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_9624,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=t2,a[5]=t1,a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[5],a[8]=((C_word*)t0)[6],tmp=(C_word)a,a+=9,tmp);
/* core.scm:841: set-real-names! */
f_7913(t3,((C_word*)t0)[8],((C_word*)t0)[9]);}

/* k9622 in k9616 in k9613 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_9624(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_9624,c,av);}
a=C_alloc(12);
t2=C_i_not(((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9633,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[2],a[7]=((C_word*)t0)[7],tmp=(C_word)a,a+=8,tmp);
if(C_truep(t2)){
t4=t3;
f_9633(t4,t2);}
else{
if(C_truep(((C_word*)t0)[8])){
t4=t3;
f_9633(t4,((C_word*)t0)[8]);}
else{
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9677,a[2]=t3,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:844: ##sys#current-environment */
t5=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t5;
av2[1]=t4;
((C_proc)(void*)(*((C_word*)t5+1)))(2,av2);}}}}

/* k9631 in k9622 in k9616 in k9613 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_fcall f_9633(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,3)))){
C_save_and_reclaim_args((void *)trf_9633,2,t0,t1);}
a=C_alloc(8);
if(C_truep(t1)){
t2=((C_word*)t0)[2];{
C_word av2[2];
av2[0]=t2;
av2[1]=((C_word*)t0)[3];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}
else{
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9639,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[3],tmp=(C_word)a,a+=8,tmp);
if(C_truep(*((C_word*)lf[30]+1))){
t3=C_eqp(*((C_word*)lf[43]+1),lf[183]);
if(C_truep(t3)){
t4=t2;{
C_word av2[2];
av2[0]=t4;
av2[1]=t3;
f_9639(2,av2);}}
else{
t4=C_eqp(*((C_word*)lf[43]+1),lf[184]);
if(C_truep(t4)){
/* core.scm:850: chicken.compiler.support#variable-mark */
t5=*((C_word*)lf[185]+1);{
C_word av2[4];
av2[0]=t5;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=lf[186];
((C_proc)(void*)(*((C_word*)t5+1)))(4,av2);}}
else{
t5=t2;{
C_word av2[2];
av2[0]=t5;
av2[1]=C_SCHEME_FALSE;
f_9639(2,av2);}}}}
else{
t3=t2;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_SCHEME_FALSE;
f_9639(2,av2);}}}}

/* k9637 in k9631 in k9622 in k9616 in k9613 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_9639(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_9639,c,av);}
a=C_alloc(5);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9646,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],tmp=(C_word)a,a+=5,tmp);
if(C_truep(C_i_memq(((C_word*)t0)[5],((C_word*)t0)[6]))){
/* core.scm:851: chicken.compiler.support#expand-profile-lambda */
t3=*((C_word*)lf[182]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
/* core.scm:854: ##sys#alias-global-hook */
t3=*((C_word*)lf[122]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[5];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}}
else{
t2=((C_word*)t0)[2];{
C_word *av2=av;
av2[0]=t2;
av2[1]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t2+1)))(2,av2);}}}

/* k9644 in k9637 in k9631 in k9622 in k9616 in k9613 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in ... */
static void C_ccall f_9646(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9646,c,av);}
/* core.scm:851: chicken.compiler.support#expand-profile-lambda */
t2=*((C_word*)lf[182]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* k9675 in k9622 in k9616 in k9613 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_9677(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9677,c,av);}
t2=((C_word*)t0)[2];
f_9633(t2,C_i_assq(((C_word*)t0)[3],t1));}

/* k9686 in k9613 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_9688(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9688,c,av);}
/* core.scm:837: chicken.compiler.support#build-lambda-list */
t2=*((C_word*)lf[187]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=((C_word*)t0)[4];
av2[4]=C_i_list_ref(((C_word*)t0)[3],t1);
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* a9689 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_9690(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_9690,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9694,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)((C_word*)t0)[3])[1])){
/* core.scm:824: ##sys#current-environment1519 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
f_9694(2,av2);}}}

/* k9692 in a9689 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_9694(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_9694,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9698,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* core.scm:824: ##sys#current-environment1519 */
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k9696 in k9692 in a9689 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_9698(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_9698,c,av);}
a=C_alloc(4);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9701,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:824: ##sys#current-environment1519 */
t4=((C_word*)t0)[5];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k9699 in k9696 in k9692 in a9689 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_ccall f_9701(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9701,c,av);}
t2=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_FALSE);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a9706 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_9707(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_9707,c,av);}
a=C_alloc(9);
t2=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_9711,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=((C_word*)t0)[6],a[7]=((C_word*)t0)[7],a[8]=t1,tmp=(C_word)a,a+=9,tmp);
/* core.scm:825: canonicalize-body/ln */
t3=((C_word*)((C_word*)t0)[8])[1];
f_7884(t3,t2,((C_word*)t0)[5],((C_word*)((C_word*)t0)[9])[1],*((C_word*)lf[52]+1));}

/* k9709 in a9706 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_9711(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(22,c,4)))){
C_save_and_reclaim((void *)f_9711,c,av);}
a=C_alloc(22);
t2=C_SCHEME_END_OF_LIST;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_FALSE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9716,a[2]=t5,a[3]=((C_word*)t0)[2],a[4]=t3,tmp=(C_word)a,a+=5,tmp);
t7=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9721,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=t1,tmp=(C_word)a,a+=8,tmp);
t8=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9746,a[2]=t3,a[3]=((C_word*)t0)[2],a[4]=t5,tmp=(C_word)a,a+=5,tmp);
/* core.scm:827: ##sys#dynamic-wind */
t9=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[8];
av2[2]=t6;
av2[3]=t7;
av2[4]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* a9715 in k9709 in a9706 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_9716(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9716,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a9720 in k9709 in a9706 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_9721(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(32,c,2)))){
C_save_and_reclaim((void *)f_9721,c,av);}
a=C_alloc(32);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9729,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
if(C_truep(*((C_word*)lf[24]+1))){
t3=C_a_i_list(&a,2,lf[145],((C_word*)t0)[3]);
t4=C_a_i_list(&a,3,lf[188],lf[189],t3);
t5=t2;
f_9729(t5,C_a_i_list(&a,3,lf[190],t4,((C_word*)t0)[7]));}
else{
t3=t2;
f_9729(t3,((C_word*)t0)[7]);}}

/* k9727 in a9720 in k9709 in a9706 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in ... */
static void C_fcall f_9729(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,0,3)))){
C_save_and_reclaim_args((void *)trf_9729,2,t0,t1);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9733,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],tmp=(C_word)a,a+=7,tmp);
/* core.scm:834: scheme#append */
t3=*((C_word*)lf[5]+1);{
C_word av2[4];
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[6];
av2[3]=((C_word*)t0)[7];
((C_proc)(void*)(*((C_word*)t3+1)))(4,av2);}}

/* k9731 in k9727 in a9720 in k9709 in a9706 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in ... */
static void C_ccall f_9733(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_9733,c,av);}
/* core.scm:828: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],((C_word*)t0)[4],t1,C_SCHEME_FALSE,C_SCHEME_FALSE,((C_word*)t0)[5],((C_word*)t0)[6],C_SCHEME_FALSE);}

/* a9745 in k9709 in a9706 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_9746(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9746,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)((C_word*)t0)[3])[1]);
t3=C_mutate(((C_word *)((C_word*)t0)[3])+1,((C_word*)((C_word*)t0)[4])[1]);
t4=t1;{
C_word *av2=av;
av2[0]=t4;
av2[1]=C_SCHEME_UNDEFINED;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* a9750 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in ... */
static void C_ccall f_9751(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_9751,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9755,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:824: ##sys#current-environment1519 */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k9753 in a9750 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in ... */
static void C_ccall f_9755(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_9755,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9758,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:824: ##sys#current-environment1519 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k9756 in k9753 in a9750 in k9610 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in ... */
static void C_ccall f_9758(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9758,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k9761 in k9604 in k9601 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_9763(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,4)))){
C_save_and_reclaim((void *)f_9763,c,av);}
/* core.scm:823: ##sys#extend-se */
t2=*((C_word*)lf[175]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=((C_word*)t0)[3];
av2[4]=((C_word*)t0)[4];
((C_proc)(void*)(*((C_word*)t2+1)))(5,av2);}}

/* map-loop1488 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_fcall f_9765(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,0,2)))){
C_save_and_reclaim_args((void *)trf_9765,3,t0,t1,t2);}
a=C_alloc(6);
if(C_truep(C_i_pairp(t2))){
t3=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9790,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=t2,tmp=(C_word)a,a+=6,tmp);
/* core.scm:821: g1494 */
t4=*((C_word*)lf[109]+1);{
C_word av2[3];
av2[0]=t4;
av2[1]=t3;
av2[2]=C_slot(t2,C_fix(0));
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9788 in map-loop1488 in a9592 in k9586 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_9790(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void *)f_9790,c,av);}
a=C_alloc(3);
t2=C_a_i_cons(&a,2,t1,C_SCHEME_END_OF_LIST);
t3=C_i_setslot(((C_word*)((C_word*)t0)[2])[1],C_fix(1),t2);
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=((C_word*)((C_word*)t0)[3])[1];
f_9765(t5,((C_word*)t0)[4],C_slot(((C_word*)t0)[5],C_fix(1)));}

/* k9798 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_9800(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,c,4)))){
C_save_and_reclaim((void *)f_9800,c,av);}
a=C_alloc(8);
if(C_truep(t1)){
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9805,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9815,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],tmp=(C_word)a,a+=4,tmp);
/* core.scm:814: ##sys#call-with-values */{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=0;
av2[1]=((C_word*)t0)[4];
av2[2]=t2;
av2[3]=t3;
C_call_with_values(4,av2);}}
else{
t2=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t2;
av2[1]=C_SCHEME_UNDEFINED;
f_9588(2,av2);}}}

/* a9804 in k9798 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9805(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_9805,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9813,a[2]=t1,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:817: ##sys#current-environment */
t3=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k9811 in a9804 in k9798 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9813(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,5)))){
C_save_and_reclaim((void *)f_9813,c,av);}
/* core.scm:816: ##sys#expand-extended-lambda-list */
t2=*((C_word*)lf[192]+1);{
C_word *av2;
if(c >= 6) {
  av2=av;
} else {
  av2=C_alloc(6);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)((C_word*)t0)[3])[1];
av2[3]=((C_word*)((C_word*)t0)[4])[1];
av2[4]=*((C_word*)lf[193]+1);
av2[5]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(6,av2);}}

/* a9814 in k9798 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9815(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2=av[2];
C_word t3=av[3];
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9815,c,av);}
t4=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t5=C_mutate(((C_word *)((C_word*)t0)[3])+1,t3);
t6=t1;{
C_word *av2=av;
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}

/* k9825 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_9827(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word t7;
C_word t8;
C_word t9;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(23,c,4)))){
C_save_and_reclaim((void *)f_9827,c,av);}
a=C_alloc(23);
t2=t1;
t3=(*a=C_VECTOR_TYPE|1,a[1]=t2,tmp=(C_word)a,a+=2,tmp);
t4=C_SCHEME_TRUE;
t5=(*a=C_VECTOR_TYPE|1,a[1]=t4,tmp=(C_word)a,a+=2,tmp);
t6=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9832,a[2]=t3,a[3]=t5,a[4]=((C_word*)t0)[2],tmp=(C_word)a,a+=5,tmp);
t7=(*a=C_CLOSURE_TYPE|9,a[1]=(C_word)f_9849,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=((C_word*)t0)[9],a[9]=((C_word*)t0)[10],tmp=(C_word)a,a+=10,tmp);
t8=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9869,a[2]=t3,a[3]=((C_word*)t0)[2],tmp=(C_word)a,a+=4,tmp);
/* core.scm:859: ##sys#dynamic-wind */
t9=*((C_word*)lf[114]+1);{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t9;
av2[1]=((C_word*)t0)[11];
av2[2]=t6;
av2[3]=t7;
av2[4]=t8;
((C_proc)(void*)(*((C_word*)t9+1)))(5,av2);}}

/* a9831 in k9825 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9832(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(6,c,4)))){
C_save_and_reclaim((void *)f_9832,c,av);}
a=C_alloc(6);
t2=(*a=C_CLOSURE_TYPE|5,a[1]=(C_word)f_9836,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],tmp=(C_word)a,a+=6,tmp);
if(C_truep(((C_word*)((C_word*)t0)[3])[1])){
/* core.scm:859: ##sys#current-environment1571 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_TRUE;
av2[4]=C_SCHEME_FALSE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}
else{
t3=t2;{
C_word *av2=av;
av2[0]=t3;
av2[1]=((C_word*)((C_word*)t0)[2])[1];
f_9836(2,av2);}}}

/* k9834 in a9831 in k9825 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9836(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(7,c,2)))){
C_save_and_reclaim((void *)f_9836,c,av);}
a=C_alloc(7);
t2=(*a=C_CLOSURE_TYPE|6,a[1]=(C_word)f_9840,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=((C_word*)t0)[4],a[5]=((C_word*)t0)[5],a[6]=t1,tmp=(C_word)a,a+=7,tmp);
/* core.scm:859: ##sys#current-environment1571 */
t3=((C_word*)t0)[5];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k9838 in k9834 in a9831 in k9825 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_9840(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,4)))){
C_save_and_reclaim((void *)f_9840,c,av);}
a=C_alloc(4);
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,t1);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9843,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:859: ##sys#current-environment1571 */
t4=((C_word*)t0)[5];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=((C_word*)t0)[6];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t4+1)))(5,av2);}}

/* k9841 in k9838 in k9834 in a9831 in k9825 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in ... */
static void C_ccall f_9843(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9843,c,av);}
t2=C_set_block_item(((C_word*)t0)[2],0,C_SCHEME_FALSE);
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* a9848 in k9825 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9849(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(11,c,2)))){
C_save_and_reclaim((void *)f_9849,c,av);}
a=C_alloc(11);
t2=(*a=C_CLOSURE_TYPE|10,a[1]=(C_word)f_9853,a[2]=((C_word*)t0)[2],a[3]=((C_word*)t0)[3],a[4]=t1,a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],tmp=(C_word)a,a+=11,tmp);
/* core.scm:871: chicken.syntax#get-line-number */
t3=*((C_word*)lf[111]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[9];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* k9851 in a9848 in k9825 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9853(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(9,c,4)))){
C_save_and_reclaim((void *)f_9853,c,av);}
a=C_alloc(9);
t2=(C_truep(t1)?t1:((C_word*)t0)[2]);
t3=(*a=C_CLOSURE_TYPE|8,a[1]=(C_word)f_9863,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],a[4]=((C_word*)t0)[5],a[5]=((C_word*)t0)[6],a[6]=((C_word*)t0)[7],a[7]=((C_word*)t0)[8],a[8]=t2,tmp=(C_word)a,a+=9,tmp);
/* core.scm:873: canonicalize-body/ln */
t4=((C_word*)((C_word*)t0)[9])[1];
f_7884(t4,t3,t2,C_i_cddr(((C_word*)t0)[10]),*((C_word*)lf[52]+1));}

/* k9861 in k9851 in a9848 in k9825 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_9863(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,8)))){
C_save_and_reclaim((void *)f_9863,c,av);}
/* core.scm:872: walk */
t2=((C_word*)((C_word*)t0)[2])[1];
f_8330(t2,((C_word*)t0)[3],t1,((C_word*)t0)[4],((C_word*)t0)[5],((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],C_SCHEME_FALSE);}

/* a9868 in k9825 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9869(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,2)))){
C_save_and_reclaim((void *)f_9869,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9873,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:859: ##sys#current-environment1571 */
t3=((C_word*)t0)[3];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k9871 in a9868 in k9825 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9873(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(5,c,4)))){
C_save_and_reclaim((void *)f_9873,c,av);}
a=C_alloc(5);
t2=(*a=C_CLOSURE_TYPE|4,a[1]=(C_word)f_9876,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],tmp=(C_word)a,a+=5,tmp);
/* core.scm:859: ##sys#current-environment1571 */
t3=((C_word*)t0)[4];{
C_word *av2;
if(c >= 5) {
  av2=av;
} else {
  av2=C_alloc(5);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)((C_word*)t0)[2])[1];
av2[3]=C_SCHEME_FALSE;
av2[4]=C_SCHEME_TRUE;
((C_proc)(void*)(*((C_word*)t3+1)))(5,av2);}}

/* k9874 in k9871 in a9868 in k9825 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in ... */
static void C_ccall f_9876(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,1)))){
C_save_and_reclaim((void *)f_9876,c,av);}
t2=C_mutate(((C_word *)((C_word*)t0)[2])+1,((C_word*)t0)[3]);
t3=((C_word*)t0)[4];{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k9892 in map-loop1580 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9894(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_9894,c,av);}
a=C_alloc(12);
t2=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9898,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],tmp=(C_word)a,a+=8,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9902,a[2]=t2,a[3]=((C_word*)t0)[7],tmp=(C_word)a,a+=4,tmp);
/* core.scm:867: ##sys#eval/meta */
t4=*((C_word*)lf[197]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t4;
av2[1]=t3;
av2[2]=C_i_cadr(((C_word*)t0)[7]);
((C_proc)(void*)(*((C_word*)t4+1)))(3,av2);}}

/* k9896 in k9892 in map-loop1580 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9898(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_9898,c,av);}
a=C_alloc(12);
t2=C_a_i_list3(&a,3,((C_word*)t0)[2],((C_word*)t0)[3],t1);
t3=C_a_i_cons(&a,2,t2,C_SCHEME_END_OF_LIST);
t4=C_i_setslot(((C_word*)((C_word*)t0)[4])[1],C_fix(1),t3);
t5=C_mutate(((C_word *)((C_word*)t0)[4])+1,t3);
t6=((C_word*)((C_word*)t0)[5])[1];
f_9923(t6,((C_word*)t0)[6],C_slot(((C_word*)t0)[7],C_fix(1)));}

/* k9900 in k9892 in map-loop1580 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in ... */
static void C_ccall f_9902(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9902,c,av);}
/* core.scm:866: ##sys#ensure-transformer */
t2=*((C_word*)lf[196]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_u_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k9915 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_9917(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(4,c,2)))){
C_save_and_reclaim((void *)f_9917,c,av);}
a=C_alloc(4);
t2=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_9921,a[2]=((C_word*)t0)[2],a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:870: ##sys#current-environment */
t3=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t3;
av2[1]=t2;
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}

/* k9919 in k9915 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9921(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9921,c,av);}
/* core.scm:861: scheme#append */
t2=*((C_word*)lf[5]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=((C_word*)t0)[3];
av2[3]=t1;
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* map-loop1580 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_fcall f_9923(C_word t0,C_word t1,C_word t2){
C_word tmp;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(8,0,2)))){
C_save_and_reclaim_args((void *)trf_9923,3,t0,t1,t2);}
a=C_alloc(8);
if(C_truep(C_i_pairp(t2))){
t3=C_slot(t2,C_fix(0));
t4=C_i_car(t3);
t5=(*a=C_CLOSURE_TYPE|7,a[1]=(C_word)f_9894,a[2]=t4,a[3]=((C_word*)t0)[2],a[4]=((C_word*)t0)[3],a[5]=t1,a[6]=t2,a[7]=t3,tmp=(C_word)a,a+=8,tmp);
/* core.scm:865: ##sys#current-environment */
t6=*((C_word*)lf[107]+1);{
C_word av2[2];
av2[0]=t6;
av2[1]=t5;
((C_proc)(void*)(*((C_word*)t6+1)))(2,av2);}}
else{
t3=t1;{
C_word av2[2];
av2[0]=t3;
av2[1]=C_slot(((C_word*)t0)[4],C_fix(1));
((C_proc)(void*)(*((C_word*)t3+1)))(2,av2);}}}

/* k9975 in map-loop1619 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9977(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word t6;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(12,c,2)))){
C_save_and_reclaim((void *)f_9977,c,av);}
a=C_alloc(12);
t2=C_a_i_list3(&a,3,((C_word*)t0)[2],C_SCHEME_FALSE,t1);
t3=C_a_i_cons(&a,2,t2,C_SCHEME_END_OF_LIST);
t4=C_i_setslot(((C_word*)((C_word*)t0)[3])[1],C_fix(1),t3);
t5=C_mutate(((C_word *)((C_word*)t0)[3])+1,t3);
t6=((C_word*)((C_word*)t0)[4])[1];
f_10093(t6,((C_word*)t0)[5],C_slot(((C_word*)t0)[6],C_fix(1)));}

/* k9979 in map-loop1619 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9981(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(0,c,3)))){
C_save_and_reclaim((void *)f_9981,c,av);}
/* core.scm:882: ##sys#ensure-transformer */
t2=*((C_word*)lf[196]+1);{
C_word *av2;
if(c >= 4) {
  av2=av;
} else {
  av2=C_alloc(4);
}
av2[0]=t2;
av2[1]=((C_word*)t0)[2];
av2[2]=t1;
av2[3]=C_u_i_car(((C_word*)t0)[3]);
((C_proc)(void*)(*((C_word*)t2+1)))(4,av2);}}

/* k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 in ... */
static void C_ccall f_9996(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word t4;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(16,c,2)))){
C_save_and_reclaim((void *)f_9996,c,av);}
a=C_alloc(16);
t2=(*a=C_CLOSURE_TYPE|11,a[1]=(C_word)f_9999,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],tmp=(C_word)a,a+=12,tmp);
t3=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_10091,a[2]=t2,a[3]=t1,tmp=(C_word)a,a+=4,tmp);
/* core.scm:886: ##sys#current-environment */
t4=*((C_word*)lf[107]+1);{
C_word *av2=av;
av2[0]=t4;
av2[1]=t3;
((C_proc)(void*)(*((C_word*)t4+1)))(2,av2);}}

/* k9997 in k9994 in k8739 in k8405 in k8393 in k8390 in k8387 in k8383 in k8380 in k8374 in k8335 in walk in chicken.compiler.core#canonicalize-expression in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in ... */
static void C_ccall f_9999(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(13,c,2)))){
C_save_and_reclaim((void *)f_9999,c,av);}
a=C_alloc(13);
t2=(*a=C_CLOSURE_TYPE|12,a[1]=(C_word)f_10002,a[2]=((C_word*)t0)[2],a[3]=t1,a[4]=((C_word*)t0)[3],a[5]=((C_word*)t0)[4],a[6]=((C_word*)t0)[5],a[7]=((C_word*)t0)[6],a[8]=((C_word*)t0)[7],a[9]=((C_word*)t0)[8],a[10]=((C_word*)t0)[9],a[11]=((C_word*)t0)[10],a[12]=((C_word*)t0)[11],tmp=(C_word)a,a+=13,tmp);
/* core.scm:887: chicken.syntax#get-line-number */
t3=*((C_word*)lf[111]+1);{
C_word *av2;
if(c >= 3) {
  av2=av;
} else {
  av2=C_alloc(3);
}
av2[0]=t3;
av2[1]=t2;
av2[2]=((C_word*)t0)[10];
((C_proc)(void*)(*((C_word*)t3+1)))(3,av2);}}

/* toplevel */
static C_TLS int toplevel_initialized=0;

void C_ccall C_compiler_toplevel(C_word c,C_word *av){
C_word tmp;
C_word t0=av[0];
C_word t1=av[1];
C_word t2;
C_word t3;
C_word *a;
if(toplevel_initialized) {C_kontinue(t1,C_SCHEME_UNDEFINED);}
else C_toplevel_entry(C_text("compiler"));
C_check_nursery_minimum(C_calculate_demand(3,c,2));
if(C_unlikely(!C_demand(C_calculate_demand(3,c,2)))){
C_save_and_reclaim((void*)C_compiler_toplevel,c,av);}
toplevel_initialized=1;
if(C_unlikely(!C_demand_2(4406))){
C_save(t1);
C_rereclaim2(4406*sizeof(C_word),1);
t1=C_restore;}
a=C_alloc(3);
C_initialize_lf(lf,716);
lf[0]=C_h_intern(&lf[0],8, C_text("compiler"));
lf[1]=C_h_intern(&lf[1],22, C_text("chicken.compiler.core#"));
lf[5]=C_h_intern(&lf[5],13, C_text("scheme#append"));
lf[8]=C_h_intern(&lf[8],5, C_text("foldr"));
lf[10]=C_h_intern(&lf[10],3, C_text("map"));
lf[14]=C_h_intern(&lf[14],5, C_text("foldl"));
lf[17]=C_h_intern(&lf[17],31, C_text("chicken.compiler.core#unit-name"));
lf[18]=C_h_intern(&lf[18],39, C_text("chicken.compiler.core#standard-bindings"));
lf[19]=C_h_intern(&lf[19],39, C_text("chicken.compiler.core#extended-bindings"));
lf[20]=C_h_intern(&lf[20],41, C_text("chicken.compiler.core#insert-timer-checks"));
lf[21]=C_h_intern(&lf[21],32, C_text("chicken.compiler.core#used-units"));
lf[22]=C_h_intern(&lf[22],42, C_text("chicken.compiler.core#foreign-declarations"));
lf[23]=C_h_intern(&lf[23],37, C_text("chicken.compiler.core#emit-trace-info"));
lf[24]=C_h_intern(&lf[24],37, C_text("chicken.compiler.core#emit-debug-info"));
lf[25]=C_h_intern(&lf[25],39, C_text("chicken.compiler.core#block-compilation"));
lf[26]=C_h_intern(&lf[26],47, C_text("chicken.compiler.core#line-number-database-size"));
lf[27]=C_h_intern(&lf[27],38, C_text("chicken.compiler.core#target-heap-size"));
lf[28]=C_h_intern(&lf[28],39, C_text("chicken.compiler.core#target-stack-size"));
lf[29]=C_h_intern(&lf[29],44, C_text("chicken.compiler.core#optimize-leaf-routines"));
lf[30]=C_h_intern(&lf[30],34, C_text("chicken.compiler.core#emit-profile"));
lf[31]=C_h_intern(&lf[31],37, C_text("chicken.compiler.core#no-bound-checks"));
lf[32]=C_h_intern(&lf[32],36, C_text("chicken.compiler.core#no-argc-checks"));
lf[33]=C_h_intern(&lf[33],41, C_text("chicken.compiler.core#no-procedure-checks"));
lf[34]=C_h_intern(&lf[34],48, C_text("chicken.compiler.core#no-global-procedure-checks"));
lf[36]=C_h_intern(&lf[36],39, C_text("chicken.compiler.core#explicit-use-flag"));
lf[37]=C_h_intern(&lf[37],53, C_text("chicken.compiler.core#disable-stack-overflow-checking"));
lf[38]=C_h_intern(&lf[38],43, C_text("chicken.compiler.core#external-protos-first"));
lf[39]=C_h_intern(&lf[39],37, C_text("chicken.compiler.core#inline-max-size"));
lf[40]=C_h_intern(&lf[40],34, C_text("chicken.compiler.core#unroll-limit"));
lf[41]=C_h_intern(&lf[41],39, C_text("chicken.compiler.core#emit-closure-info"));
lf[42]=C_h_intern(&lf[42],46, C_text("chicken.compiler.core#undefine-shadowed-macros"));
lf[43]=C_h_intern(&lf[43],41, C_text("chicken.compiler.core#profiled-procedures"));
lf[44]=C_h_intern(&lf[44],38, C_text("chicken.compiler.core#import-libraries"));
lf[45]=C_h_intern(&lf[45],42, C_text("chicken.compiler.core#all-import-libraries"));
lf[46]=C_h_intern(&lf[46],57, C_text("chicken.compiler.core#preserve-unchanged-import-libraries"));
lf[47]=C_h_intern(&lf[47],49, C_text("chicken.compiler.core#compile-module-registration"));
lf[48]=C_h_intern(&lf[48],43, C_text("chicken.compiler.core#standalone-executable"));
lf[49]=C_h_intern(&lf[49],39, C_text("chicken.compiler.core#local-definitions"));
lf[50]=C_h_intern(&lf[50],36, C_text("chicken.compiler.core#inline-locally"));
lf[51]=C_h_intern(&lf[51],41, C_text("chicken.compiler.core#enable-inline-files"));
lf[52]=C_h_intern(&lf[52],45, C_text("chicken.compiler.core#compiler-syntax-enabled"));
lf[53]=C_h_intern(&lf[53],36, C_text("chicken.compiler.core#bootstrap-mode"));
lf[54]=C_h_intern(&lf[54],43, C_text("chicken.compiler.core#strict-variable-types"));
lf[55]=C_h_intern(&lf[55],43, C_text("chicken.compiler.core#enable-specialization"));
lf[56]=C_h_intern(&lf[56],39, C_text("chicken.compiler.core#static-extensions"));
lf[57]=C_h_intern(&lf[57],36, C_text("chicken.compiler.core#emit-link-file"));
lf[58]=C_h_intern(&lf[58],39, C_text("chicken.compiler.core#types-output-file"));
lf[59]=C_h_intern(&lf[59],34, C_text("chicken.compiler.core#verbose-mode"));
lf[63]=C_h_intern(&lf[63],44, C_text("chicken.compiler.core#line-number-database-2"));
lf[64]=C_h_intern(&lf[64],41, C_text("chicken.compiler.core#immutable-constants"));
lf[65]=C_h_intern(&lf[65],34, C_text("chicken.compiler.core#inline-table"));
lf[66]=C_h_intern(&lf[66],36, C_text("chicken.compiler.core#constant-table"));
lf[67]=C_h_intern(&lf[67],50, C_text("chicken.compiler.core#inline-substitutions-enabled"));
lf[69]=C_h_intern(&lf[69],36, C_text("chicken.compiler.core#first-analysis"));
lf[71]=C_h_intern(&lf[71],42, C_text("chicken.compiler.core#foreign-lambda-stubs"));
lf[72]=C_h_intern(&lf[72],40, C_text("chicken.compiler.core#external-variables"));
lf[80]=C_h_intern(&lf[80],41, C_text("chicken.compiler.core#required-extensions"));
lf[81]=C_h_intern(&lf[81],38, C_text("chicken.compiler.core#linked-libraries"));
lf[82]=C_h_intern(&lf[82],36, C_text("chicken.compiler.core#used-libraries"));
lf[84]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\007\001unquote\376\003\000\000\002\376\001\000\000\020\001unquote-splicing\376\377\016"));
lf[85]=C_h_intern(&lf[85],47, C_text("chicken.compiler.core#default-extended-bindings"));
lf[86]=C_h_intern(&lf[86],47, C_text("chicken.compiler.core#default-standard-bindings"));
lf[87]=C_h_intern(&lf[87],39, C_text("chicken.compiler.core#internal-bindings"));
lf[88]=C_h_intern(&lf[88],41, C_text("chicken.compiler.core#initialize-compiler"));
lf[89]=C_h_intern(&lf[89],50, C_text("chicken.compiler.support#clear-foreign-type-table!"));
lf[90]=C_h_intern(&lf[90],47, C_text("chicken.compiler.support#clear-real-name-table!"));
lf[91]=C_h_intern(&lf[91],56, C_text("chicken.compiler.support#reset-profile-info-vector-name!"));
lf[92]=C_h_intern(&lf[92],19, C_text("scheme#vector-fill!"));
lf[93]=C_h_intern(&lf[93],18, C_text("scheme#make-vector"));
lf[94]=C_h_intern(&lf[94],49, C_text("chicken.compiler.core#compute-database-statistics"));
lf[95]=C_h_intern(&lf[95],6, C_text("global"));
lf[96]=C_h_intern(&lf[96],5, C_text("value"));
lf[97]=C_h_intern(&lf[97],13, C_text("##core#lambda"));
lf[98]=C_h_intern(&lf[98],35, C_text("chicken.compiler.support#node-class"));
lf[99]=C_h_intern(&lf[99],10, C_text("call-sites"));
lf[100]=C_h_intern(&lf[100],8, C_text("for-each"));
lf[101]=C_h_intern(&lf[101],36, C_text("chicken.internal#hash-table-for-each"));
lf[102]=C_h_intern(&lf[102],45, C_text("chicken.compiler.core#canonicalize-expression"));
lf[103]=C_h_intern(&lf[103],9, C_text("##sys#get"));
lf[104]=C_h_intern(&lf[104],18, C_text("##core#macro-alias"));
lf[105]=C_h_intern(&lf[105],13, C_text("scheme#values"));
lf[106]=C_h_intern(&lf[106],14, C_text("scheme#symbol\077"));
lf[107]=C_h_intern(&lf[107],25, C_text("##sys#current-environment"));
lf[108]=C_h_intern(&lf[108],10, C_text("##sys#put!"));
lf[109]=C_h_intern(&lf[109],19, C_text("chicken.base#gensym"));
lf[110]=C_h_intern(&lf[110],34, C_text("##sys#update-line-number-database!"));
lf[111]=C_h_intern(&lf[111],30, C_text("chicken.syntax#get-line-number"));
lf[112]=C_h_intern(&lf[112],36, C_text("chicken.syntax#expansion-result-hook"));
lf[113]=C_h_intern(&lf[113],23, C_text("##sys#canonicalize-body"));
lf[114]=C_h_intern(&lf[114],18, C_text("##sys#dynamic-wind"));
lf[115]=C_h_intern(&lf[115],39, C_text("chicken.compiler.support#set-real-name!"));
lf[116]=C_h_intern(&lf[116],5, C_text("quote"));
lf[117]=C_h_intern(&lf[117],17, C_text("##core#inline_ref"));
lf[118]=C_h_intern(&lf[118],52, C_text("chicken.compiler.support#foreign-type-convert-result"));
lf[119]=C_h_intern(&lf[119],46, C_text("chicken.compiler.support#finish-foreign-result"));
lf[120]=C_h_intern(&lf[120],43, C_text("chicken.compiler.support#final-foreign-type"));
lf[121]=C_h_intern(&lf[121],21, C_text("##core#inline_loc_ref"));
lf[122]=C_h_intern(&lf[122],23, C_text("##sys#alias-global-hook"));
lf[123]=C_h_intern(&lf[123],39, C_text("chicken.compiler.support#quit-compiling"));
lf[124]=C_decode_literal(C_heaptop,C_text("\376B\000\0008~acyclical reference in LETREC binding for variable `~a\047"));
lf[125]=C_h_intern(&lf[125],38, C_text("chicken.compiler.support#get-real-name"));
lf[126]=C_h_intern(&lf[126],6, C_text("format"));
lf[127]=C_h_intern(&lf[127],30, C_text("chicken.base#get-output-string"));
lf[128]=C_h_intern(&lf[128],11, C_text("##sys#print"));
lf[129]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004) - "));
lf[130]=C_h_intern(&lf[130],18, C_text("##sys#write-char-0"));
lf[131]=C_h_intern(&lf[131],31, C_text("chicken.base#open-output-string"));
lf[132]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[133]=C_h_intern(&lf[133],31, C_text("chicken.internal#hash-table-ref"));
lf[134]=C_h_intern(&lf[134],20, C_text("chicken.base#warning"));
lf[135]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025\047 possibly unintended"));
lf[136]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027reference to variable `"));
lf[137]=C_h_intern(&lf[137],26, C_text("##sys#syntax-error/context"));
lf[138]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023illegal atomic form"));
lf[139]=C_h_intern(&lf[139],34, C_text("chicken.compiler.support#constant\077"));
lf[140]=C_h_intern(&lf[140],26, C_text("##sys#syntax-error-culprit"));
lf[141]=C_h_intern(&lf[141],9, C_text("##core#if"));
lf[142]=C_h_intern(&lf[142],2, C_text("if"));
lf[143]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[144]=C_h_intern(&lf[144],13, C_text("##core#syntax"));
lf[145]=C_h_intern(&lf[145],12, C_text("##core#quote"));
lf[146]=C_h_intern(&lf[146],27, C_text("chicken.syntax#strip-syntax"));
lf[147]=C_h_intern(&lf[147],12, C_text("##core#check"));
lf[148]=C_h_intern(&lf[148],31, C_text("chicken.compiler.support#unsafe"));
lf[149]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\005\001quote\376\003\000\000\002\376\377\006\001\376\377\016"));
lf[150]=C_h_intern(&lf[150],10, C_text("##core#the"));
lf[151]=C_h_intern(&lf[151],27, C_text("##core#local-specialization"));
lf[152]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[153]=C_h_intern(&lf[153],32, C_text("##compiler#local-specializations"));
lf[154]=C_h_intern(&lf[154],12, C_text("##sys#append"));
lf[155]=C_h_intern(&lf[155],15, C_text("##core#typecase"));
lf[156]=C_h_intern(&lf[156],16, C_text("##core#immutable"));
lf[157]=C_h_intern(&lf[157],38, C_text("chicken.compiler.support#hide-variable"));
lf[158]=C_h_intern(&lf[158],38, C_text("chicken.compiler.support#mark-variable"));
lf[159]=C_h_intern(&lf[159],23, C_text("##compiler#always-bound"));
lf[160]=C_h_intern(&lf[160],1, C_text("c"));
lf[161]=C_h_intern(&lf[161],13, C_text("scheme#cadadr"));
lf[162]=C_h_intern(&lf[162],14, C_text("##core#provide"));
lf[163]=C_h_intern(&lf[163],15, C_text("##core#callunit"));
lf[164]=C_h_intern(&lf[164],12, C_text("scheme#caadr"));
lf[165]=C_h_intern(&lf[165],25, C_text("##core#require-for-syntax"));
lf[166]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[167]=C_h_intern(&lf[167],27, C_text("chicken.load#load-extension"));
lf[168]=C_h_intern(&lf[168],14, C_text("##core#require"));
lf[169]=C_h_intern(&lf[169],21, C_text("##sys#process-require"));
lf[170]=C_h_intern(&lf[170],6, C_text("static"));
lf[171]=C_h_intern(&lf[171],7, C_text("dynamic"));
lf[172]=C_h_intern(&lf[172],26, C_text("chicken.load#core-library\077"));
lf[173]=C_h_intern(&lf[173],10, C_text("##core#let"));
lf[174]=C_h_intern(&lf[174],3, C_text("let"));
lf[175]=C_h_intern(&lf[175],15, C_text("##sys#extend-se"));
lf[176]=C_h_intern(&lf[176],14, C_text("##core#letrec\052"));
lf[177]=C_h_intern(&lf[177],11, C_text("##core#set!"));
lf[178]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[179]=C_h_intern(&lf[179],13, C_text("##core#letrec"));
lf[180]=C_h_intern(&lf[180],26, C_text("##core#with-forbidden-refs"));
lf[181]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[182]=C_h_intern(&lf[182],46, C_text("chicken.compiler.support#expand-profile-lambda"));
lf[183]=C_h_intern(&lf[183],3, C_text("all"));
lf[184]=C_h_intern(&lf[184],4, C_text("some"));
lf[185]=C_h_intern(&lf[185],38, C_text("chicken.compiler.support#variable-mark"));
lf[186]=C_h_intern(&lf[186],18, C_text("##compiler#profile"));
lf[187]=C_h_intern(&lf[187],42, C_text("chicken.compiler.support#build-lambda-list"));
lf[188]=C_h_intern(&lf[188],18, C_text("##core#debug-event"));
lf[189]=C_h_intern(&lf[189],13, C_text("C_DEBUG_ENTRY"));
lf[190]=C_h_intern(&lf[190],12, C_text("##core#begin"));
lf[191]=C_h_intern(&lf[191],27, C_text("##sys#decompose-lambda-list"));
lf[192]=C_h_intern(&lf[192],33, C_text("##sys#expand-extended-lambda-list"));
lf[193]=C_h_intern(&lf[193],11, C_text("##sys#error"));
lf[194]=C_h_intern(&lf[194],27, C_text("##sys#extended-lambda-list\077"));
lf[195]=C_h_intern(&lf[195],17, C_text("##core#let-syntax"));
lf[196]=C_h_intern(&lf[196],24, C_text("##sys#ensure-transformer"));
lf[197]=C_h_intern(&lf[197],15, C_text("##sys#eval/meta"));
lf[198]=C_h_intern(&lf[198],20, C_text("##core#letrec-syntax"));
lf[199]=C_h_intern(&lf[199],20, C_text("##core#define-syntax"));
lf[200]=C_h_intern(&lf[200],27, C_text("##sys#enable-runtime-macros"));
lf[201]=C_h_intern(&lf[201],30, C_text("##sys#extend-macro-environment"));
lf[202]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[203]=C_h_intern(&lf[203],28, C_text("##sys#register-syntax-export"));
lf[204]=C_h_intern(&lf[204],20, C_text("##sys#current-module"));
lf[205]=C_h_intern(&lf[205],18, C_text("##sys#put/restore!"));
lf[206]=C_h_intern(&lf[206],14, C_text("##sys#override"));
lf[207]=C_h_intern(&lf[207],6, C_text("syntax"));
lf[208]=C_h_intern(&lf[208],12, C_text("scheme#cdadr"));
lf[209]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001_\376\003\000\000\002\376\003\000\000\002\376\001\000\000\010\001variable\376\001\000\000\013\001lambda-list\376\000\000\000\002\376\001\000\000\001\001_\376\377\001\000\000\000\001"));
lf[210]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001_\376\003\000\000\002\376\001\000\000\010\001variable\376\003\000\000\002\376\001\000\000\001\001_\376\377\016"));
lf[211]=C_h_intern(&lf[211],18, C_text("##sys#check-syntax"));
lf[212]=C_h_intern(&lf[212],29, C_text("##core#define-compiler-syntax"));
lf[213]=C_h_intern(&lf[213],26, C_text("##compiler#compiler-syntax"));
lf[214]=C_h_intern(&lf[214],10, C_text("##sys#cons"));
lf[215]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[216]=C_h_intern(&lf[216],26, C_text("##core#let-compiler-syntax"));
lf[217]=C_h_intern(&lf[217],19, C_text("let-compiler-syntax"));
lf[218]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001symbol\376\000\000\000\003\376\001\000\000\001\001_\376\377\001\000\000\000\000\376\377\001\000\000\000\001"));
lf[219]=C_h_intern(&lf[219],19, C_text("scheme#dynamic-wind"));
lf[220]=C_h_intern(&lf[220],14, C_text("##core#include"));
lf[221]=C_h_intern(&lf[221],29, C_text("##sys#current-source-filename"));
lf[222]=C_h_intern(&lf[222],29, C_text("##sys#include-forms-from-file"));
lf[223]=C_h_intern(&lf[223],23, C_text("##core#let-module-alias"));
lf[224]=C_h_intern(&lf[224],25, C_text("##sys#with-module-aliases"));
lf[225]=C_h_intern(&lf[225],7, C_text("functor"));
lf[226]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\006\001symbol\376\003\000\000\002\376\001\000\000\006\001symbol\376\377\016"));
lf[227]=C_h_intern(&lf[227],13, C_text("##core#module"));
lf[228]=C_h_intern(&lf[228],23, C_text("##sys#macro-environment"));
lf[229]=C_h_intern(&lf[229],30, C_text("##sys#module-alias-environment"));
lf[230]=C_h_intern(&lf[230],31, C_text("##sys#initial-macro-environment"));
lf[231]=C_h_intern(&lf[231],48, C_text("chicken.compiler.support#canonicalize-begin-body"));
lf[232]=C_h_intern(&lf[232],3, C_text("yes"));
lf[233]=C_h_intern(&lf[233],34, C_text("##sys#compiled-module-registration"));
lf[234]=C_h_intern(&lf[234],30, C_text("##sys#current-meta-environment"));
lf[235]=C_h_intern(&lf[235],28, C_text("##sys#meta-macro-environment"));
lf[236]=C_h_intern(&lf[236],35, C_text("chicken.internal#module-requirement"));
lf[237]=C_h_intern(&lf[237],13, C_text("scheme#equal\077"));
lf[238]=C_h_intern(&lf[238],18, C_text("chicken.base#print"));
lf[239]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037not generating import library `"));
lf[240]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016\047 for module `"));
lf[241]=C_decode_literal(C_heaptop,C_text("\376B\000\000 \047 because imports did not change"));
lf[242]=C_h_intern(&lf[242],33, C_text("chicken.pretty-print#pretty-print"));
lf[243]=C_decode_literal(C_heaptop,C_text("\376B\000\000\017\012;; END OF FILE"));
lf[244]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005;;;; "));
lf[245]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030 - GENERATED BY CHICKEN "));
lf[246]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020 -\052- Scheme -\052-\012"));
lf[247]=C_h_intern(&lf[247],32, C_text("chicken.platform#chicken-version"));
lf[248]=C_h_intern(&lf[248],26, C_text("scheme#with-output-to-file"));
lf[249]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033generating import library `"));
lf[250]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016\047 for module `"));
lf[251]=C_decode_literal(C_heaptop,C_text("\376B\000\000\005\047 ..."));
lf[252]=C_h_intern(&lf[252],27, C_text("scheme#call-with-input-file"));
lf[253]=C_h_intern(&lf[253],41, C_text("chicken.compiler.support#read-expressions"));
lf[254]=C_h_intern(&lf[254],25, C_text("chicken.file#file-exists\077"));
lf[255]=C_h_intern(&lf[255],19, C_text("##sys#string-append"));
lf[256]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013.import.scm"));
lf[257]=C_h_intern(&lf[257],21, C_text("scheme#symbol->string"));
lf[258]=C_h_intern(&lf[258],17, C_text("chicken.base#exit"));
lf[259]=C_h_intern(&lf[259],37, C_text("chicken.condition#print-error-message"));
lf[260]=C_h_intern(&lf[260],20, C_text("##sys#standard-error"));
lf[261]=C_h_intern(&lf[261],14, C_text("scheme#reverse"));
lf[262]=C_decode_literal(C_heaptop,C_text("\376B\000\000\022a foreign variable"));
lf[263]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023an inlined function"));
lf[264]=C_decode_literal(C_heaptop,C_text("\376B\000\000\012a constant"));
lf[265]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023a type abbreviation"));
lf[266]=C_h_intern(&lf[266],28, C_text("##compiler#type-abbreviation"));
lf[267]=C_h_intern(&lf[267],21, C_text("##sys#finalize-module"));
lf[268]=C_h_intern(&lf[268],40, C_text("chicken.condition#with-exception-handler"));
lf[269]=C_h_intern(&lf[269],37, C_text("scheme#call-with-current-continuation"));
lf[270]=C_h_intern(&lf[270],27, C_text("##sys#with-property-restore"));
lf[271]=C_h_intern(&lf[271],23, C_text("##sys#syntax-error-hook"));
lf[272]=C_h_intern(&lf[272],6, C_text("module"));
lf[273]=C_decode_literal(C_heaptop,C_text("\376B\000\000\031modules may not be nested"));
lf[274]=C_h_intern(&lf[274],21, C_text("##sys#register-module"));
lf[275]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025invalid export syntax"));
lf[276]=C_h_intern(&lf[276],18, C_text("##core#loop-lambda"));
lf[277]=C_h_intern(&lf[277],33, C_text("##core#ensure-toplevel-definition"));
lf[278]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[279]=C_decode_literal(C_heaptop,C_text("\376B\000\0005~atoplevel definition of `~s\047 in non-toplevel context"));
lf[280]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004) - "));
lf[281]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[282]=C_h_intern(&lf[282],20, C_text("##core#inline_update"));
lf[283]=C_h_intern(&lf[283],43, C_text("chicken.compiler.support#foreign-type-check"));
lf[284]=C_h_intern(&lf[284],54, C_text("chicken.compiler.support#foreign-type-convert-argument"));
lf[285]=C_h_intern(&lf[285],24, C_text("##core#inline_loc_update"));
lf[286]=C_h_intern(&lf[286],4, C_text("set!"));
lf[287]=C_h_intern(&lf[287],30, C_text("##sys#unregister-syntax-export"));
lf[288]=C_h_intern(&lf[288],21, C_text("##sys#undefine-macro!"));
lf[289]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026assignment to syntax `"));
lf[290]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004) - "));
lf[291]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[292]=C_decode_literal(C_heaptop,C_text("\376B\000\000&assignment to imported value binding `"));
lf[293]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004) - "));
lf[294]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[295]=C_h_intern(&lf[295],12, C_text("##sys#macro\077"));
lf[296]=C_h_intern(&lf[296],21, C_text("C_DEBUG_GLOBAL_ASSIGN"));
lf[297]=C_h_intern(&lf[297],36, C_text("##compiler#always-bound-to-procedure"));
lf[298]=C_decode_literal(C_heaptop,C_text("\376B\000\000\025\047 possibly unintended"));
lf[299]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030assignment to variable `"));
lf[300]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004) - "));
lf[301]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[302]=C_h_intern(&lf[302],13, C_text("##core#inline"));
lf[303]=C_h_intern(&lf[303],22, C_text("##core#inline_allocate"));
lf[304]=C_h_intern(&lf[304],21, C_text("##core#compiletimetoo"));
lf[305]=C_h_intern(&lf[305],25, C_text("##core#elaborationtimetoo"));
lf[306]=C_h_intern(&lf[306],22, C_text("##core#compiletimeonly"));
lf[307]=C_h_intern(&lf[307],26, C_text("##core#elaborationtimeonly"));
lf[308]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[309]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[310]=C_h_intern(&lf[310],21, C_text("##core#foreign-lambda"));
lf[312]=C_h_intern(&lf[312],26, C_text("##core#foreign-safe-lambda"));
lf[313]=C_h_intern(&lf[313],22, C_text("##core#foreign-lambda\052"));
lf[315]=C_h_intern(&lf[315],27, C_text("##core#foreign-safe-lambda\052"));
lf[316]=C_h_intern(&lf[316],24, C_text("##core#foreign-primitive"));
lf[317]=C_h_intern(&lf[317],4, C_text("void"));
lf[319]=C_h_intern(&lf[319],33, C_text("chicken.string#string-intersperse"));
lf[320]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[321]=C_h_intern(&lf[321],30, C_text("##core#define-foreign-variable"));
lf[322]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[323]=C_h_intern(&lf[323],26, C_text("##core#define-foreign-type"));
lf[324]=C_h_intern(&lf[324],12, C_text("##sys#values"));
lf[325]=C_h_intern(&lf[325],21, C_text("##sys#register-export"));
lf[326]=C_h_intern(&lf[326],47, C_text("chicken.compiler.support#register-foreign-type!"));
lf[327]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[328]=C_decode_literal(C_heaptop,C_text("\376B\000\0009~adefinition of foreign type `~s\047 in non-toplevel context"));
lf[329]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004) - "));
lf[330]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[331]=C_h_intern(&lf[331],31, C_text("##core#define-external-variable"));
lf[332]=C_h_intern(&lf[332],9, C_text("c-pointer"));
lf[333]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[334]=C_h_intern(&lf[334],20, C_text("scheme#string-append"));
lf[335]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001&"));
lf[336]=C_decode_literal(C_heaptop,C_text("\376B\000\000>~aexternal variable definition of `~s\047 in non-toplevel context"));
lf[337]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004) - "));
lf[338]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[339]=C_h_intern(&lf[339],41, C_text("chicken.compiler.support#make-random-name"));
lf[340]=C_h_intern(&lf[340],19, C_text("##core#let-location"));
lf[341]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020C_a_i_bytevector"));
lf[342]=C_h_intern(&lf[342],37, C_text("chicken.compiler.support#bytes->words"));
lf[343]=C_h_intern(&lf[343],62, C_text("chicken.compiler.support#estimate-foreign-result-location-size"));
lf[344]=C_h_intern(&lf[344],20, C_text("##core#define-inline"));
lf[345]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[346]=C_h_intern(&lf[346],32, C_text("chicken.internal#hash-table-set!"));
lf[347]=C_decode_literal(C_heaptop,C_text("\376B\000\0003~ainline definition of `~s\047 in non-toplevel context"));
lf[348]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004) - "));
lf[349]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[350]=C_h_intern(&lf[350],13, C_text("scheme#cdaddr"));
lf[351]=C_h_intern(&lf[351],22, C_text("##core#define-constant"));
lf[352]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[353]=C_h_intern(&lf[353],6, C_text("define"));
lf[354]=C_h_intern(&lf[354],19, C_text("##compiler#constant"));
lf[355]=C_decode_literal(C_heaptop,C_text("\376B\000\000\010constant"));
lf[356]=C_decode_literal(C_heaptop,C_text("\376B\000\0004~ainvalid compile-time value for named constant `~S\047"));
lf[357]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004) - "));
lf[358]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[359]=C_h_intern(&lf[359],39, C_text("chicken.compiler.support#basic-literal\077"));
lf[360]=C_h_intern(&lf[360],45, C_text("chicken.compiler.support#collapsable-literal\077"));
lf[361]=C_decode_literal(C_heaptop,C_text("\376B\000\0005~aconstant definition of `~s\047 in non-toplevel context"));
lf[362]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004) - "));
lf[363]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[364]=C_decode_literal(C_heaptop,C_text("\376B\000\000:error in constant evaluation of ~S for named constant `~S\047"));
lf[365]=C_h_intern(&lf[365],11, C_text("scheme#eval"));
lf[366]=C_h_intern(&lf[366],14, C_text("##core#declare"));
lf[367]=C_h_intern(&lf[367],27, C_text("chicken.syntax#syntax-error"));
lf[368]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023invalid declaration"));
lf[369]=C_h_intern(&lf[369],12, C_text("##sys#notice"));
lf[370]=C_decode_literal(C_heaptop,C_text("\376B\000\0001ignoring declaration for locally bound variable `"));
lf[371]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[372]=C_h_intern(&lf[372],4, C_text("uses"));
lf[373]=C_h_intern(&lf[373],4, C_text("unit"));
lf[374]=C_decode_literal(C_heaptop,C_text("\376B\000\0003unit was already given a name (new name is ignored)"));
lf[375]=C_h_intern(&lf[375],17, C_text("standard-bindings"));
lf[376]=C_h_intern(&lf[376],17, C_text("extended-bindings"));
lf[377]=C_h_intern(&lf[377],18, C_text("usual-integrations"));
lf[378]=C_h_intern(&lf[378],11, C_text("number-type"));
lf[379]=C_h_intern(&lf[379],36, C_text("chicken.compiler.support#number-type"));
lf[380]=C_h_intern(&lf[380],6, C_text("fixnum"));
lf[381]=C_h_intern(&lf[381],17, C_text("fixnum-arithmetic"));
lf[382]=C_h_intern(&lf[382],7, C_text("generic"));
lf[383]=C_h_intern(&lf[383],6, C_text("unsafe"));
lf[384]=C_h_intern(&lf[384],4, C_text("safe"));
lf[385]=C_h_intern(&lf[385],15, C_text("no-bound-checks"));
lf[386]=C_h_intern(&lf[386],14, C_text("no-argc-checks"));
lf[387]=C_h_intern(&lf[387],19, C_text("no-procedure-checks"));
lf[388]=C_h_intern(&lf[388],18, C_text("disable-interrupts"));
lf[389]=C_h_intern(&lf[389],12, C_text("always-bound"));
lf[390]=C_h_intern(&lf[390],12, C_text("safe-globals"));
lf[391]=C_h_intern(&lf[391],38, C_text("no-procedure-checks-for-usual-bindings"));
lf[392]=C_h_intern(&lf[392],41, C_text("no-procedure-checks-for-toplevel-bindings"));
lf[393]=C_h_intern(&lf[393],18, C_text("bound-to-procedure"));
lf[394]=C_h_intern(&lf[394],15, C_text("foreign-declare"));
lf[395]=C_h_intern(&lf[395],7, C_text("declare"));
lf[396]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023invalid declaration"));
lf[397]=C_h_intern(&lf[397],14, C_text("scheme#string\077"));
lf[398]=C_h_intern(&lf[398],5, C_text("block"));
lf[399]=C_h_intern(&lf[399],8, C_text("separate"));
lf[400]=C_h_intern(&lf[400],20, C_text("keep-shadowed-macros"));
lf[401]=C_h_intern(&lf[401],6, C_text("unused"));
lf[402]=C_h_intern(&lf[402],17, C_text("##compiler#unused"));
lf[403]=C_h_intern(&lf[403],22, C_text("enforce-argument-types"));
lf[404]=C_h_intern(&lf[404],18, C_text("##compiler#enforce"));
lf[405]=C_h_intern(&lf[405],3, C_text("not"));
lf[406]=C_h_intern(&lf[406],6, C_text("inline"));
lf[407]=C_h_intern(&lf[407],17, C_text("##compiler#inline"));
lf[408]=C_h_intern(&lf[408],2, C_text("no"));
lf[409]=C_h_intern(&lf[409],13, C_text("inline-global"));
lf[410]=C_h_intern(&lf[410],24, C_text("##compiler#inline-global"));
lf[411]=C_decode_literal(C_heaptop,C_text("\376B\000\000!unsupported declaration specifier"));
lf[412]=C_h_intern(&lf[412],14, C_text("compile-syntax"));
lf[413]=C_h_intern(&lf[413],12, C_text("block-global"));
lf[414]=C_h_intern(&lf[414],4, C_text("hide"));
lf[415]=C_h_intern(&lf[415],6, C_text("export"));
lf[416]=C_h_intern(&lf[416],40, C_text("chicken.compiler.support#export-variable"));
lf[417]=C_h_intern(&lf[417],30, C_text("emit-external-prototypes-first"));
lf[418]=C_h_intern(&lf[418],16, C_text("##compiler#local"));
lf[419]=C_h_intern(&lf[419],12, C_text("inline-limit"));
lf[420]=C_decode_literal(C_heaptop,C_text("\376B\000\000.invalid argument to `inline-limit\047 declaration"));
lf[421]=C_h_intern(&lf[421],12, C_text("unroll-limit"));
lf[422]=C_decode_literal(C_heaptop,C_text("\376B\000\000.invalid argument to `unroll-limit\047 declaration"));
lf[423]=C_h_intern(&lf[423],4, C_text("pure"));
lf[424]=C_h_intern(&lf[424],15, C_text("##compiler#pure"));
lf[425]=C_decode_literal(C_heaptop,C_text("\376B\000\000+invalid arguments to `pure\047 declaration: ~S"));
lf[426]=C_h_intern(&lf[426],19, C_text("emit-import-library"));
lf[427]=C_decode_literal(C_heaptop,C_text("\376B\000\000\013.import.scm"));
lf[428]=C_decode_literal(C_heaptop,C_text("\376B\000\000\052invalid `import-library\047 specification: ~S"));
lf[429]=C_h_intern(&lf[429],15, C_text("emit-types-file"));
lf[430]=C_decode_literal(C_heaptop,C_text("\376B\000\000)invalid `emit-types-file\047 declaration: ~S"));
lf[431]=C_h_intern(&lf[431],7, C_text("profile"));
lf[432]=C_h_intern(&lf[432],5, C_text("local"));
lf[433]=C_h_intern(&lf[433],4, C_text("type"));
lf[434]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030illegal type declaration"));
lf[435]=C_h_intern(&lf[435],42, C_text("chicken.compiler.scrutinizer#validate-type"));
lf[436]=C_h_intern(&lf[436],52, C_text("chicken.compiler.scrutinizer#install-specializations"));
lf[437]=C_h_intern(&lf[437],20, C_text("##compiler#predicate"));
lf[438]=C_h_intern(&lf[438],22, C_text("##compiler#type-source"));
lf[439]=C_h_intern(&lf[439],15, C_text("##compiler#type"));
lf[440]=C_h_intern(&lf[440],9, C_text("procedure"));
lf[441]=C_decode_literal(C_heaptop,C_text("\376B\000\000\032illegal `type\047 declaration"));
lf[442]=C_h_intern(&lf[442],9, C_text("predicate"));
lf[443]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037illegal `predicate\047 declaration"));
lf[444]=C_decode_literal(C_heaptop,C_text("\376B\000\000\037illegal `type\047 declaration item"));
lf[445]=C_h_intern(&lf[445],10, C_text("specialize"));
lf[446]=C_h_intern(&lf[446],12, C_text("strict-types"));
lf[447]=C_decode_literal(C_heaptop,C_text("\376B\000\000\035unknown declaration specifier"));
lf[448]=C_decode_literal(C_heaptop,C_text("\376B\000\000!invalid declaration specification"));
lf[449]=C_h_intern(&lf[449],31, C_text("##core#foreign-callback-wrapper"));
lf[450]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\005\001const\376\003\000\000\002\376\001\000\000\020\001nonnull-c-string\376\377\016"));
lf[451]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\005\001const\376\003\000\000\002\376\001\000\000\031\001nonnull-unsigned-c-string\376\377\016"));
lf[452]=C_h_intern(&lf[452],25, C_text("nonnull-unsigned-c-string"));
lf[453]=C_h_intern(&lf[453],16, C_text("nonnull-c-string"));
lf[454]=C_h_intern(&lf[454],19, C_text("##sys#make-c-string"));
lf[455]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\005\001const\376\003\000\000\002\376\001\000\000\011\001c-string\052\376\377\016"));
lf[456]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\005\001const\376\003\000\000\002\376\001\000\000\022\001unsigned-c-string\052\376\377\016"));
lf[457]=C_h_intern(&lf[457],18, C_text("unsigned-c-string\052"));
lf[458]=C_h_intern(&lf[458],9, C_text("c-string\052"));
lf[459]=C_h_intern(&lf[459],13, C_text("c-string-list"));
lf[460]=C_h_intern(&lf[460],14, C_text("c-string-list\052"));
lf[461]=C_decode_literal(C_heaptop,C_text("\376B\000\000/not a valid result type for callback procedures"));
lf[462]=C_h_intern(&lf[462],8, C_text("c-string"));
lf[463]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\005\001const\376\003\000\000\002\376\001\000\000\021\001unsigned-c-string\376\377\016"));
lf[464]=C_h_intern(&lf[464],17, C_text("unsigned-c-string"));
lf[465]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\005\001const\376\003\000\000\002\376\001\000\000\010\001c-string\376\377\016"));
lf[466]=C_h_intern(&lf[466],1, C_text("r"));
lf[467]=C_h_intern(&lf[467],3, C_text("and"));
lf[468]=C_decode_literal(C_heaptop,C_text("\376B\000\000Anon-matching or invalid argument list to foreign callback-wrapper"));
lf[469]=C_decode_literal(C_heaptop,C_text("\376B\000\000>~aname `~S\047 of external definition is not a valid C identifier"));
lf[470]=C_decode_literal(C_heaptop,C_text("\376B\000\000\004) - "));
lf[471]=C_decode_literal(C_heaptop,C_text("\376B\000\000\000"));
lf[472]=C_h_intern(&lf[472],44, C_text("chicken.compiler.support#valid-c-identifier\077"));
lf[473]=C_h_intern(&lf[473],15, C_text("##core#location"));
lf[474]=C_h_intern(&lf[474],8, C_text("location"));
lf[475]=C_h_intern(&lf[475],19, C_text("##sys#make-locative"));
lf[476]=C_h_intern(&lf[476],20, C_text("##sys#syntax-context"));
lf[477]=C_h_intern(&lf[477],16, C_text("##core#primitive"));
lf[478]=C_h_intern(&lf[478],16, C_text("##core#undefined"));
lf[479]=C_h_intern(&lf[479],21, C_text("chicken.syntax#expand"));
lf[480]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030) - malformed expression"));
lf[481]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024malformed expression"));
lf[482]=C_h_intern(&lf[482],47, C_text("chicken.compiler.support#emit-syntax-trace-info"));
lf[483]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024malformed expression"));
lf[484]=C_decode_literal(C_heaptop,C_text("\376B\000\000\034literal in operator position"));
lf[485]=C_h_intern(&lf[485],24, C_text("chicken.keyword#keyword\077"));
lf[486]=C_h_intern(&lf[486],42, C_text("chicken.compiler.support#debugging-chicken"));
lf[487]=C_h_intern(&lf[487],14, C_text("scheme#newline"));
lf[488]=C_h_intern(&lf[488],46, C_text("chicken.compiler.core#build-toplevel-procedure"));
lf[489]=C_h_intern(&lf[489],34, C_text("chicken.compiler.support#make-node"));
lf[490]=C_h_intern(&lf[490],6, C_text("lambda"));
lf[491]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\377\016\376\377\016"));
lf[492]=C_h_intern(&lf[492],37, C_text("chicken.compiler.core#foreign-stub-id"));
lf[493]=C_h_intern(&lf[493],34, C_text("chicken.compiler.core#foreign-stub"));
lf[494]=C_h_intern(&lf[494],15, C_text("foreign-stub-id"));
lf[495]=C_h_intern(&lf[495],46, C_text("chicken.compiler.core#foreign-stub-return-type"));
lf[496]=C_h_intern(&lf[496],24, C_text("foreign-stub-return-type"));
lf[497]=C_h_intern(&lf[497],39, C_text("chicken.compiler.core#foreign-stub-name"));
lf[498]=C_h_intern(&lf[498],17, C_text("foreign-stub-name"));
lf[499]=C_h_intern(&lf[499],49, C_text("chicken.compiler.core#foreign-stub-argument-types"));
lf[500]=C_h_intern(&lf[500],27, C_text("foreign-stub-argument-types"));
lf[501]=C_h_intern(&lf[501],49, C_text("chicken.compiler.core#foreign-stub-argument-names"));
lf[502]=C_h_intern(&lf[502],27, C_text("foreign-stub-argument-names"));
lf[503]=C_h_intern(&lf[503],39, C_text("chicken.compiler.core#foreign-stub-body"));
lf[504]=C_h_intern(&lf[504],17, C_text("foreign-stub-body"));
lf[505]=C_h_intern(&lf[505],38, C_text("chicken.compiler.core#foreign-stub-cps"));
lf[506]=C_h_intern(&lf[506],16, C_text("foreign-stub-cps"));
lf[507]=C_h_intern(&lf[507],43, C_text("chicken.compiler.core#foreign-stub-callback"));
lf[508]=C_h_intern(&lf[508],21, C_text("foreign-stub-callback"));
lf[509]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\003\000\000\002\376\001\000\000\010\001##sys#gc\376\003\000\000\002\376\377\006\000\376\377\016\376\377\016"));
lf[510]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[511]=C_decode_literal(C_heaptop,C_text("\376B\000\000\020C_a_i_bytevector"));
lf[512]=C_h_intern(&lf[512],21, C_text("scheme#string->symbol"));
lf[513]=C_h_intern(&lf[513],53, C_text("chicken.compiler.support#estimate-foreign-result-size"));
lf[514]=C_h_intern(&lf[514],4, C_text("stub"));
lf[515]=C_h_intern(&lf[515],1, C_text("a"));
lf[516]=C_h_intern(&lf[516],19, C_text("chicken.string#conc"));
lf[517]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\052"));
lf[518]=C_h_intern(&lf[518],5, C_text("const"));
lf[519]=C_h_intern(&lf[519],6, C_text("struct"));
lf[520]=C_decode_literal(C_heaptop,C_text("\376B\000\000-name `~s\047 of foreign procedure has wrong type"));
lf[521]=C_decode_literal(C_heaptop,C_text("\376B\000\000\001\012"));
lf[522]=C_h_intern(&lf[522],44, C_text("chicken.compiler.core#perform-cps-conversion"));
lf[523]=C_h_intern(&lf[523],11, C_text("##core#call"));
lf[524]=C_h_intern(&lf[524],32, C_text("chicken.compiler.support#varnode"));
lf[525]=C_h_intern(&lf[525],1, C_text("k"));
lf[526]=C_h_intern(&lf[526],15, C_text("##core#variable"));
lf[527]=C_h_intern(&lf[527],40, C_text("chicken.compiler.support#node-parameters"));
lf[528]=C_h_intern(&lf[528],2, C_text("f_"));
lf[529]=C_h_intern(&lf[529],1, C_text("t"));
lf[530]=C_h_intern(&lf[530],44, C_text("chicken.compiler.support#node-subexpressions"));
lf[531]=C_h_intern(&lf[531],56, C_text("chicken.compiler.support#register-foreign-callback-stub!"));
lf[532]=C_h_intern(&lf[532],17, C_text("##core#the/result"));
lf[533]=C_h_intern(&lf[533],29, C_text("chicken.compiler.support#bomb"));
lf[534]=C_decode_literal(C_heaptop,C_text("\376B\000\000\016bad node (cps)"));
lf[535]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\005\001quote\376\003\000\000\002\376\001\000\000\017\001##core#variable\376\003\000\000\002\376\001\000\000\020\001##core#undefined\376\377\016"));
lf[536]=C_h_intern(&lf[536],40, C_text("chicken.compiler.core#analyze-expression"));
lf[537]=C_h_intern(&lf[537],15, C_text("##core#rest-cdr"));
lf[538]=C_h_intern(&lf[538],32, C_text("chicken.compiler.support#db-put!"));
lf[539]=C_h_intern(&lf[539],8, C_text("captured"));
lf[540]=C_h_intern(&lf[540],31, C_text("chicken.compiler.support#db-get"));
lf[541]=C_h_intern(&lf[541],14, C_text("##core#recurse"));
lf[542]=C_h_intern(&lf[542],33, C_text("chicken.compiler.support#collect!"));
lf[543]=C_decode_literal(C_heaptop,C_text("\376B\000\000;known procedure called with wrong number of arguments: `~A\047"));
lf[544]=C_h_intern(&lf[544],34, C_text("chicken.compiler.support#real-name"));
lf[545]=C_h_intern(&lf[545],37, C_text("chicken.compiler.support#llist-match\077"));
lf[546]=C_h_intern(&lf[546],7, C_text("unknown"));
lf[547]=C_h_intern(&lf[547],4, C_text("home"));
lf[548]=C_h_intern(&lf[548],20, C_text("##core#direct_lambda"));
lf[549]=C_h_intern(&lf[549],6, C_text("simple"));
lf[550]=C_h_intern(&lf[550],44, C_text("chicken.compiler.support#simple-lambda-node\077"));
lf[551]=C_h_intern(&lf[551],8, C_text("rest-cdr"));
lf[552]=C_h_intern(&lf[552],14, C_text("rest-parameter"));
lf[553]=C_h_intern(&lf[553],4, C_text("list"));
lf[554]=C_h_intern(&lf[554],12, C_text("contained-in"));
lf[555]=C_h_intern(&lf[555],8, C_text("contains"));
lf[556]=C_h_intern(&lf[556],8, C_text("assigned"));
lf[557]=C_h_intern(&lf[557],16, C_text("assigned-locally"));
lf[558]=C_h_intern(&lf[558],16, C_text("potential-values"));
lf[559]=C_h_intern(&lf[559],8, C_text("standard"));
lf[560]=C_decode_literal(C_heaptop,C_text("\376B\000\000 redefinition of standard binding"));
lf[561]=C_h_intern(&lf[561],8, C_text("extended"));
lf[562]=C_decode_literal(C_heaptop,C_text("\376B\000\000 redefinition of extended binding"));
lf[563]=C_h_intern(&lf[563],20, C_text("##compiler#intrinsic"));
lf[564]=C_h_intern(&lf[564],11, C_text("##core#proc"));
lf[565]=C_h_intern(&lf[565],17, C_text("derived-rest-vars"));
lf[566]=C_h_intern(&lf[566],10, C_text("rest-null\077"));
lf[567]=C_h_intern(&lf[567],9, C_text("undefined"));
lf[568]=C_h_intern(&lf[568],17, C_text("##core#rest-null\077"));
lf[569]=C_h_intern(&lf[569],22, C_text("chicken.base#alist-ref"));
lf[570]=C_h_intern(&lf[570],5, C_text("depth"));
lf[571]=C_h_intern(&lf[571],4, C_text("rvar"));
lf[572]=C_h_intern(&lf[572],35, C_text("chicken.compiler.support#db-get-all"));
lf[573]=C_h_intern(&lf[573],11, C_text("local-value"));
lf[574]=C_h_intern(&lf[574],42, C_text("chicken.compiler.support#variable-visible\077"));
lf[575]=C_h_intern(&lf[575],8, C_text("test-var"));
lf[576]=C_h_intern(&lf[576],35, C_text("chicken.compiler.support#match-node"));
lf[577]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\013\001##core#cond\376\003\000\000\002\376\377\016\376\003\000\000\002\376\003\000\000\002\376\001\000\000\017\001##core#variable\376\003\000\000\002\376\003\000\000\002\376\001\000\000\010\001tes"
"t-var\376\377\016\376\377\016\376\003\000\000\002\376\003\000\000\002\376\001\000\000\005\001quote\376\003\000\000\002\376\003\000\000\002\376\377\016\376\377\016\376\377\016\376\003\000\000\002\376\003\000\000\002\376\001\000\000\017\001##core#rest-c"
"dr\376\003\000\000\002\376\003\000\000\002\376\001\000\000\004\001rvar\376\003\000\000\002\376\001\000\000\005\001depth\376\377\016\376\377\016\376\377\016"));
lf[578]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\010\001test-var\376\003\000\000\002\376\001\000\000\004\001rvar\376\003\000\000\002\376\001\000\000\005\001depth\376\377\016"));
lf[579]=C_h_intern(&lf[579],10, C_text("references"));
lf[580]=C_h_intern(&lf[580],10, C_text("replacable"));
lf[581]=C_h_intern(&lf[581],9, C_text("replacing"));
lf[582]=C_h_intern(&lf[582],9, C_text("removable"));
lf[583]=C_h_intern(&lf[583],35, C_text("chicken.compiler.support#intrinsic\077"));
lf[584]=C_h_intern(&lf[584],19, C_text("##core#always-bound"));
lf[585]=C_h_intern(&lf[585],53, C_text("chicken.compiler.support#expression-has-side-effects\077"));
lf[586]=C_h_intern(&lf[586],21, C_text("has-unused-parameters"));
lf[587]=C_h_intern(&lf[587],15, C_text("consed-rest-arg"));
lf[588]=C_h_intern(&lf[588],13, C_text("explicit-rest"));
lf[589]=C_h_intern(&lf[589],19, C_text("chicken.base#rassoc"));
lf[590]=C_h_intern(&lf[590],10, C_text("scheme#eq\077"));
lf[591]=C_h_intern(&lf[591],11, C_text("collapsable"));
lf[592]=C_h_intern(&lf[592],12, C_text("contractable"));
lf[593]=C_h_intern(&lf[593],9, C_text("inlinable"));
lf[594]=C_h_intern(&lf[594],44, C_text("chicken.compiler.support#scan-free-variables"));
lf[595]=C_h_intern(&lf[595],11, C_text("hidden-refs"));
lf[596]=C_h_intern(&lf[596],34, C_text("chicken.compiler.support#debugging"));
lf[597]=C_h_intern(&lf[597],1, C_text("i"));
lf[598]=C_decode_literal(C_heaptop,C_text("\376B\000\000>global inlining candidate was assigned and will not be inlined"));
lf[599]=C_h_intern(&lf[599],30, C_text("chicken.compiler.support#node\077"));
lf[600]=C_h_intern(&lf[600],5, C_text("boxed"));
lf[601]=C_decode_literal(C_heaptop,C_text("\376B\000\000(\047 is only locally visible and never used"));
lf[602]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021global variable `"));
lf[603]=C_h_intern(&lf[603],41, C_text("chicken.compiler.support#variable-hidden\077"));
lf[604]=C_h_intern(&lf[604],1, C_text("p"));
lf[605]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033analysis gathering phase..."));
lf[606]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033analysis traversal phase..."));
lf[607]=C_h_intern(&lf[607],48, C_text("chicken.compiler.core#perform-closure-conversion"));
lf[608]=C_h_intern(&lf[608],12, C_text("customizable"));
lf[609]=C_decode_literal(C_heaptop,C_text("\376B\000\000\033let-node has invalid format"));
lf[610]=C_h_intern(&lf[610],45, C_text("chicken.compiler.support#node-parameters-set!"));
lf[611]=C_h_intern(&lf[611],8, C_text("toplevel"));
lf[612]=C_h_intern(&lf[612],18, C_text("captured-variables"));
lf[613]=C_h_intern(&lf[613],12, C_text("closure-size"));
lf[614]=C_h_intern(&lf[614],12, C_text("##core#unbox"));
lf[615]=C_h_intern(&lf[615],54, C_text("chicken.compiler.support#replace-rest-op-with-list-ops"));
lf[616]=C_decode_literal(C_heaptop,C_text("\376B\000\000;Saw rest op for captured variable.  This should not happen!"));
lf[617]=C_h_intern(&lf[617],10, C_text("##core#ref"));
lf[618]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\001\001i\376\377\016"));
lf[619]=C_h_intern(&lf[619],10, C_text("##core#box"));
lf[620]=C_h_intern(&lf[620],14, C_text("##core#closure"));
lf[621]=C_h_intern(&lf[621],30, C_text("chicken.compiler.support#qnode"));
lf[622]=C_h_intern(&lf[622],22, C_text("##sys#make-lambda-info"));
lf[623]=C_h_intern(&lf[623],1, C_text("\077"));
lf[624]=C_h_intern(&lf[624],23, C_text("chicken.string#->string"));
lf[625]=C_h_intern(&lf[625],10, C_text("boxed-rest"));
lf[626]=C_h_intern(&lf[626],18, C_text("##core#updatebox_i"));
lf[627]=C_h_intern(&lf[627],16, C_text("##core#updatebox"));
lf[628]=C_h_intern(&lf[628],15, C_text("##core#update_i"));
lf[629]=C_h_intern(&lf[629],13, C_text("##core#update"));
lf[630]=C_h_intern(&lf[630],35, C_text("chicken.compiler.support#immediate\077"));
lf[631]=C_decode_literal(C_heaptop,C_text("\376B\000\000\023bad node (closure2)"));
lf[632]=C_h_intern(&lf[632],13, C_text("##core#switch"));
lf[633]=C_h_intern(&lf[633],11, C_text("##core#cond"));
lf[634]=C_h_intern(&lf[634],18, C_text("##core#direct_call"));
lf[635]=C_h_intern(&lf[635],13, C_text("##core#return"));
lf[636]=C_h_intern(&lf[636],16, C_text("##core#let_float"));
lf[637]=C_h_intern(&lf[637],16, C_text("##core#box_float"));
lf[638]=C_h_intern(&lf[638],18, C_text("##core#unbox_float"));
lf[639]=C_h_intern(&lf[639],15, C_text("##core#rest-car"));
lf[640]=C_h_intern(&lf[640],18, C_text("##core#rest-length"));
lf[641]=C_h_intern(&lf[641],12, C_text("##core#float"));
lf[642]=C_h_intern(&lf[642],21, C_text("##core#float-variable"));
lf[643]=C_h_intern(&lf[643],1, C_text("o"));
lf[644]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026calls to known targets"));
lf[645]=C_decode_literal(C_heaptop,C_text("\376B\000\000\052closure conversion transformation phase..."));
lf[646]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027customizable procedures"));
lf[647]=C_decode_literal(C_heaptop,C_text("\376B\000\000%closure conversion gathering phase..."));
lf[648]=C_h_intern(&lf[648],39, C_text("chicken.compiler.core#lambda-literal-id"));
lf[649]=C_h_intern(&lf[649],36, C_text("chicken.compiler.core#lambda-literal"));
lf[650]=C_h_intern(&lf[650],17, C_text("lambda-literal-id"));
lf[651]=C_h_intern(&lf[651],45, C_text("chicken.compiler.core#lambda-literal-external"));
lf[652]=C_h_intern(&lf[652],23, C_text("lambda-literal-external"));
lf[653]=C_h_intern(&lf[653],51, C_text("chicken.compiler.core#lambda-literal-argument-count"));
lf[654]=C_h_intern(&lf[654],29, C_text("lambda-literal-argument-count"));
lf[655]=C_h_intern(&lf[655],50, C_text("chicken.compiler.core#lambda-literal-rest-argument"));
lf[656]=C_h_intern(&lf[656],28, C_text("lambda-literal-rest-argument"));
lf[657]=C_h_intern(&lf[657],48, C_text("chicken.compiler.core#lambda-literal-temporaries"));
lf[658]=C_h_intern(&lf[658],26, C_text("lambda-literal-temporaries"));
lf[659]=C_h_intern(&lf[659],54, C_text("chicken.compiler.core#lambda-literal-float-temporaries"));
lf[660]=C_h_intern(&lf[660],32, C_text("lambda-literal-float-temporaries"));
lf[661]=C_h_intern(&lf[661],54, C_text("chicken.compiler.core#lambda-literal-callee-signatures"));
lf[662]=C_h_intern(&lf[662],32, C_text("lambda-literal-callee-signatures"));
lf[663]=C_h_intern(&lf[663],46, C_text("chicken.compiler.core#lambda-literal-allocated"));
lf[664]=C_h_intern(&lf[664],24, C_text("lambda-literal-allocated"));
lf[665]=C_h_intern(&lf[665],49, C_text("chicken.compiler.core#lambda-literal-closure-size"));
lf[666]=C_h_intern(&lf[666],27, C_text("lambda-literal-closure-size"));
lf[667]=C_h_intern(&lf[667],44, C_text("chicken.compiler.core#lambda-literal-looping"));
lf[668]=C_h_intern(&lf[668],22, C_text("lambda-literal-looping"));
lf[669]=C_h_intern(&lf[669],49, C_text("chicken.compiler.core#lambda-literal-customizable"));
lf[670]=C_h_intern(&lf[670],27, C_text("lambda-literal-customizable"));
lf[671]=C_h_intern(&lf[671],55, C_text("chicken.compiler.core#lambda-literal-rest-argument-mode"));
lf[672]=C_h_intern(&lf[672],33, C_text("lambda-literal-rest-argument-mode"));
lf[673]=C_h_intern(&lf[673],41, C_text("chicken.compiler.core#lambda-literal-body"));
lf[674]=C_h_intern(&lf[674],19, C_text("lambda-literal-body"));
lf[675]=C_h_intern(&lf[675],43, C_text("chicken.compiler.core#lambda-literal-direct"));
lf[676]=C_h_intern(&lf[676],21, C_text("lambda-literal-direct"));
lf[677]=C_h_intern(&lf[677],49, C_text("chicken.compiler.core#prepare-for-code-generation"));
lf[678]=C_h_intern(&lf[678],12, C_text("##core#local"));
lf[679]=C_h_intern(&lf[679],14, C_text("##core#literal"));
lf[680]=C_h_intern(&lf[680],13, C_text("##core#global"));
lf[681]=C_h_intern(&lf[681],12, C_text("C_DEBUG_CALL"));
lf[682]=C_h_intern(&lf[682],42, C_text("chicken.compiler.support#source-info->name"));
lf[683]=C_h_intern(&lf[683],42, C_text("chicken.compiler.support#source-info->line"));
lf[684]=C_decode_literal(C_heaptop,C_text("\376B\000\000!identified direct recursive calls"));
lf[685]=C_decode_literal(C_heaptop,C_text("\376B\000\000\021bad direct lambda"));
lf[686]=C_h_intern(&lf[686],4, C_text("none"));
lf[687]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024unused rest argument"));
lf[688]=C_h_intern(&lf[688],18, C_text("##sys#fast-reverse"));
lf[689]=C_h_intern(&lf[689],20, C_text("chicken.base#butlast"));
lf[690]=C_h_intern(&lf[690],11, C_text("##core#bind"));
lf[691]=C_h_intern(&lf[691],15, C_text("##core#setlocal"));
lf[692]=C_h_intern(&lf[692],18, C_text("##core#setglobal_i"));
lf[693]=C_h_intern(&lf[693],16, C_text("##core#setglobal"));
lf[694]=C_h_intern(&lf[694],21, C_text("scheme#inexact->exact"));
lf[695]=C_decode_literal(C_heaptop,C_text("\376B\000\000\014\047 to fixnum "));
lf[696]=C_decode_literal(C_heaptop,C_text("\376B\000\000 coerced inexact literal number `"));
lf[697]=C_decode_literal(C_heaptop,C_text("\376B\000\000,cannot coerce inexact literal `~S\047 to fixnum"));
lf[698]=C_h_intern(&lf[698],36, C_text("chicken.compiler.support#big-fixnum\077"));
lf[699]=C_h_intern(&lf[699],10, C_text("scheme#max"));
lf[700]=C_h_intern(&lf[700],52, C_text("chicken.compiler.support#make-block-variable-literal"));
lf[701]=C_h_intern(&lf[701],52, C_text("chicken.compiler.support#block-variable-literal-name"));
lf[702]=C_h_intern(&lf[702],48, C_text("chicken.compiler.support#block-variable-literal\077"));
lf[703]=C_h_intern(&lf[703],21, C_text("##sys#undefined-value"));
lf[704]=C_h_intern(&lf[704],16, C_text("##core#immediate"));
lf[705]=C_h_intern(&lf[705],3, C_text("fix"));
lf[706]=C_h_intern(&lf[706],4, C_text("bool"));
lf[707]=C_h_intern(&lf[707],4, C_text("char"));
lf[708]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001nil\376\377\016"));
lf[709]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001eof\376\377\016"));
lf[710]=C_decode_literal(C_heaptop,C_text("\376\003\000\000\002\376\001\000\000\003\001bwp\376\377\016"));
lf[711]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027bad immediate (prepare)"));
lf[712]=C_decode_literal(C_heaptop,C_text("\376B\000\000\027fast global assignments"));
lf[713]=C_decode_literal(C_heaptop,C_text("\376B\000\000\026fast global references"));
lf[714]=C_decode_literal(C_heaptop,C_text("\376B\000\000\030fast box initializations"));
lf[715]=C_decode_literal(C_heaptop,C_text("\376B\000\000\024preparation phase..."));
C_register_lf2(lf,716,create_ptable());{}
t2=(*a=C_CLOSURE_TYPE|2,a[1]=(C_word)f_6227,a[2]=t1,tmp=(C_word)a,a+=3,tmp);{
C_word *av2=av;
av2[0]=C_SCHEME_UNDEFINED;
av2[1]=t2;
C_library_toplevel(2,av2);}}

/* va26246 in k21504 in k21495 in k21492 in k21489 in walk in k21378 in chicken.compiler.core#prepare-for-code-generation in k6252 in k6249 in k6246 in k6243 in k6240 in k6237 in k6234 in k6231 in k6228 in k6225 */
static void C_fcall va26246(C_word t0,C_word t1){
C_word tmp;
C_word t2;
C_word t3;
C_word t4;
C_word t5;
C_word *a;
if(C_unlikely(!C_demand(C_calculate_demand(33,0,6)))){
C_save_and_reclaim_args((void *)trva26246,2,t0,t1);}
a=C_alloc(33);
t2=C_s_a_i_plus(&a,2,t1,C_fix(1));
t3=C_mutate(((C_word *)((C_word*)t0)[2])+1,t2);
t4=(*a=C_CLOSURE_TYPE|3,a[1]=(C_word)f_21682,a[2]=((C_word*)t0)[3],a[3]=((C_word*)t0)[4],tmp=(C_word)a,a+=4,tmp);
/* core.scm:2907: mapwalk */
t5=((C_word*)((C_word*)t0)[5])[1];
f_22697(t5,t4,((C_word*)t0)[6],((C_word*)t0)[7],((C_word*)t0)[8],((C_word*)t0)[9],((C_word*)t0)[10]);}

#ifdef C_ENABLE_PTABLES
static C_PTABLE_ENTRY ptable[1494] = {
{C_text("f24688:core_2escm"),(void*)f24688},
{C_text("f25357:core_2escm"),(void*)f25357},
{C_text("f_10002:core_2escm"),(void*)f_10002},
{C_text("f_10006:core_2escm"),(void*)f_10006},
{C_text("f_10025:core_2escm"),(void*)f_10025},
{C_text("f_10029:core_2escm"),(void*)f_10029},
{C_text("f_10033:core_2escm"),(void*)f_10033},
{C_text("f_10036:core_2escm"),(void*)f_10036},
{C_text("f_10042:core_2escm"),(void*)f_10042},
{C_text("f_10050:core_2escm"),(void*)f_10050},
{C_text("f_10056:core_2escm"),(void*)f_10056},
{C_text("f_10060:core_2escm"),(void*)f_10060},
{C_text("f_10063:core_2escm"),(void*)f_10063},
{C_text("f_10066:core_2escm"),(void*)f_10066},
{C_text("f_10091:core_2escm"),(void*)f_10091},
{C_text("f_10093:core_2escm"),(void*)f_10093},
{C_text("f_10134:core_2escm"),(void*)f_10134},
{C_text("f_10137:core_2escm"),(void*)f_10137},
{C_text("f_10140:core_2escm"),(void*)f_10140},
{C_text("f_10143:core_2escm"),(void*)f_10143},
{C_text("f_10146:core_2escm"),(void*)f_10146},
{C_text("f_10149:core_2escm"),(void*)f_10149},
{C_text("f_10152:core_2escm"),(void*)f_10152},
{C_text("f_10174:core_2escm"),(void*)f_10174},
{C_text("f_10178:core_2escm"),(void*)f_10178},
{C_text("f_10182:core_2escm"),(void*)f_10182},
{C_text("f_10196:core_2escm"),(void*)f_10196},
{C_text("f_10227:core_2escm"),(void*)f_10227},
{C_text("f_10249:core_2escm"),(void*)f_10249},
{C_text("f_10252:core_2escm"),(void*)f_10252},
{C_text("f_10255:core_2escm"),(void*)f_10255},
{C_text("f_10303:core_2escm"),(void*)f_10303},
{C_text("f_10307:core_2escm"),(void*)f_10307},
{C_text("f_10311:core_2escm"),(void*)f_10311},
{C_text("f_10319:core_2escm"),(void*)f_10319},
{C_text("f_10329:core_2escm"),(void*)f_10329},
{C_text("f_10333:core_2escm"),(void*)f_10333},
{C_text("f_10336:core_2escm"),(void*)f_10336},
{C_text("f_10343:core_2escm"),(void*)f_10343},
{C_text("f_10347:core_2escm"),(void*)f_10347},
{C_text("f_10357:core_2escm"),(void*)f_10357},
{C_text("f_10361:core_2escm"),(void*)f_10361},
{C_text("f_10365:core_2escm"),(void*)f_10365},
{C_text("f_10386:core_2escm"),(void*)f_10386},
{C_text("f_10389:core_2escm"),(void*)f_10389},
{C_text("f_10397:core_2escm"),(void*)f_10397},
{C_text("f_10419:core_2escm"),(void*)f_10419},
{C_text("f_10429:core_2escm"),(void*)f_10429},
{C_text("f_10442:core_2escm"),(void*)f_10442},
{C_text("f_10450:core_2escm"),(void*)f_10450},
{C_text("f_10456:core_2escm"),(void*)f_10456},
{C_text("f_10478:core_2escm"),(void*)f_10478},
{C_text("f_10488:core_2escm"),(void*)f_10488},
{C_text("f_10501:core_2escm"),(void*)f_10501},
{C_text("f_10526:core_2escm"),(void*)f_10526},
{C_text("f_10552:core_2escm"),(void*)f_10552},
{C_text("f_10556:core_2escm"),(void*)f_10556},
{C_text("f_10561:core_2escm"),(void*)f_10561},
{C_text("f_10566:core_2escm"),(void*)f_10566},
{C_text("f_10572:core_2escm"),(void*)f_10572},
{C_text("f_10585:core_2escm"),(void*)f_10585},
{C_text("f_10614:core_2escm"),(void*)f_10614},
{C_text("f_10626:core_2escm"),(void*)f_10626},
{C_text("f_10628:core_2escm"),(void*)f_10628},
{C_text("f_10642:core_2escm"),(void*)f_10642},
{C_text("f_10667:core_2escm"),(void*)f_10667},
{C_text("f_10683:core_2escm"),(void*)f_10683},
{C_text("f_10692:core_2escm"),(void*)f_10692},
{C_text("f_10695:core_2escm"),(void*)f_10695},
{C_text("f_10698:core_2escm"),(void*)f_10698},
{C_text("f_10701:core_2escm"),(void*)f_10701},
{C_text("f_10704:core_2escm"),(void*)f_10704},
{C_text("f_10707:core_2escm"),(void*)f_10707},
{C_text("f_10710:core_2escm"),(void*)f_10710},
{C_text("f_10717:core_2escm"),(void*)f_10717},
{C_text("f_10725:core_2escm"),(void*)f_10725},
{C_text("f_10731:core_2escm"),(void*)f_10731},
{C_text("f_10734:core_2escm"),(void*)f_10734},
{C_text("f_10737:core_2escm"),(void*)f_10737},
{C_text("f_10742:core_2escm"),(void*)f_10742},
{C_text("f_10746:core_2escm"),(void*)f_10746},
{C_text("f_10749:core_2escm"),(void*)f_10749},
{C_text("f_10753:core_2escm"),(void*)f_10753},
{C_text("f_10757:core_2escm"),(void*)f_10757},
{C_text("f_10760:core_2escm"),(void*)f_10760},
{C_text("f_10763:core_2escm"),(void*)f_10763},
{C_text("f_10772:core_2escm"),(void*)f_10772},
{C_text("f_10777:core_2escm"),(void*)f_10777},
{C_text("f_10784:core_2escm"),(void*)f_10784},
{C_text("f_10792:core_2escm"),(void*)f_10792},
{C_text("f_10817:core_2escm"),(void*)f_10817},
{C_text("f_10830:core_2escm"),(void*)f_10830},
{C_text("f_10834:core_2escm"),(void*)f_10834},
{C_text("f_10837:core_2escm"),(void*)f_10837},
{C_text("f_10840:core_2escm"),(void*)f_10840},
{C_text("f_10843:core_2escm"),(void*)f_10843},
{C_text("f_10862:core_2escm"),(void*)f_10862},
{C_text("f_10865:core_2escm"),(void*)f_10865},
{C_text("f_10875:core_2escm"),(void*)f_10875},
{C_text("f_10877:core_2escm"),(void*)f_10877},
{C_text("f_10888:core_2escm"),(void*)f_10888},
{C_text("f_10902:core_2escm"),(void*)f_10902},
{C_text("f_10906:core_2escm"),(void*)f_10906},
{C_text("f_10909:core_2escm"),(void*)f_10909},
{C_text("f_10912:core_2escm"),(void*)f_10912},
{C_text("f_10915:core_2escm"),(void*)f_10915},
{C_text("f_10919:core_2escm"),(void*)f_10919},
{C_text("f_10923:core_2escm"),(void*)f_10923},
{C_text("f_10927:core_2escm"),(void*)f_10927},
{C_text("f_10931:core_2escm"),(void*)f_10931},
{C_text("f_10934:core_2escm"),(void*)f_10934},
{C_text("f_10937:core_2escm"),(void*)f_10937},
{C_text("f_10940:core_2escm"),(void*)f_10940},
{C_text("f_10943:core_2escm"),(void*)f_10943},
{C_text("f_10958:core_2escm"),(void*)f_10958},
{C_text("f_10964:core_2escm"),(void*)f_10964},
{C_text("f_10974:core_2escm"),(void*)f_10974},
{C_text("f_10984:core_2escm"),(void*)f_10984},
{C_text("f_10989:core_2escm"),(void*)f_10989},
{C_text("f_10995:core_2escm"),(void*)f_10995},
{C_text("f_11001:core_2escm"),(void*)f_11001},
{C_text("f_11005:core_2escm"),(void*)f_11005},
{C_text("f_11010:core_2escm"),(void*)f_11010},
{C_text("f_11012:core_2escm"),(void*)f_11012},
{C_text("f_11016:core_2escm"),(void*)f_11016},
{C_text("f_11021:core_2escm"),(void*)f_11021},
{C_text("f_11034:core_2escm"),(void*)f_11034},
{C_text("f_11040:core_2escm"),(void*)f_11040},
{C_text("f_11046:core_2escm"),(void*)f_11046},
{C_text("f_11047:core_2escm"),(void*)f_11047},
{C_text("f_11053:core_2escm"),(void*)f_11053},
{C_text("f_11064:core_2escm"),(void*)f_11064},
{C_text("f_11079:core_2escm"),(void*)f_11079},
{C_text("f_11083:core_2escm"),(void*)f_11083},
{C_text("f_11087:core_2escm"),(void*)f_11087},
{C_text("f_11090:core_2escm"),(void*)f_11090},
{C_text("f_11093:core_2escm"),(void*)f_11093},
{C_text("f_11096:core_2escm"),(void*)f_11096},
{C_text("f_11099:core_2escm"),(void*)f_11099},
{C_text("f_11102:core_2escm"),(void*)f_11102},
{C_text("f_11105:core_2escm"),(void*)f_11105},
{C_text("f_11108:core_2escm"),(void*)f_11108},
{C_text("f_11115:core_2escm"),(void*)f_11115},
{C_text("f_11125:core_2escm"),(void*)f_11125},
{C_text("f_11129:core_2escm"),(void*)f_11129},
{C_text("f_11142:core_2escm"),(void*)f_11142},
{C_text("f_11153:core_2escm"),(void*)f_11153},
{C_text("f_11178:core_2escm"),(void*)f_11178},
{C_text("f_11186:core_2escm"),(void*)f_11186},
{C_text("f_11211:core_2escm"),(void*)f_11211},
{C_text("f_11259:core_2escm"),(void*)f_11259},
{C_text("f_11262:core_2escm"),(void*)f_11262},
{C_text("f_11265:core_2escm"),(void*)f_11265},
{C_text("f_11271:core_2escm"),(void*)f_11271},
{C_text("f_11274:core_2escm"),(void*)f_11274},
{C_text("f_11279:core_2escm"),(void*)f_11279},
{C_text("f_11283:core_2escm"),(void*)f_11283},
{C_text("f_11287:core_2escm"),(void*)f_11287},
{C_text("f_11290:core_2escm"),(void*)f_11290},
{C_text("f_11296:core_2escm"),(void*)f_11296},
{C_text("f_11304:core_2escm"),(void*)f_11304},
{C_text("f_11308:core_2escm"),(void*)f_11308},
{C_text("f_11310:core_2escm"),(void*)f_11310},
{C_text("f_11314:core_2escm"),(void*)f_11314},
{C_text("f_11317:core_2escm"),(void*)f_11317},
{C_text("f_11322:core_2escm"),(void*)f_11322},
{C_text("f_11324:core_2escm"),(void*)f_11324},
{C_text("f_11349:core_2escm"),(void*)f_11349},
{C_text("f_11368:core_2escm"),(void*)f_11368},
{C_text("f_11371:core_2escm"),(void*)f_11371},
{C_text("f_11374:core_2escm"),(void*)f_11374},
{C_text("f_11377:core_2escm"),(void*)f_11377},
{C_text("f_11384:core_2escm"),(void*)f_11384},
{C_text("f_11387:core_2escm"),(void*)f_11387},
{C_text("f_11393:core_2escm"),(void*)f_11393},
{C_text("f_11396:core_2escm"),(void*)f_11396},
{C_text("f_11399:core_2escm"),(void*)f_11399},
{C_text("f_11414:core_2escm"),(void*)f_11414},
{C_text("f_11417:core_2escm"),(void*)f_11417},
{C_text("f_11423:core_2escm"),(void*)f_11423},
{C_text("f_11430:core_2escm"),(void*)f_11430},
{C_text("f_11437:core_2escm"),(void*)f_11437},
{C_text("f_11460:core_2escm"),(void*)f_11460},
{C_text("f_11472:core_2escm"),(void*)f_11472},
{C_text("f_11482:core_2escm"),(void*)f_11482},
{C_text("f_11489:core_2escm"),(void*)f_11489},
{C_text("f_11516:core_2escm"),(void*)f_11516},
{C_text("f_11524:core_2escm"),(void*)f_11524},
{C_text("f_11530:core_2escm"),(void*)f_11530},
{C_text("f_11537:core_2escm"),(void*)f_11537},
{C_text("f_11548:core_2escm"),(void*)f_11548},
{C_text("f_11551:core_2escm"),(void*)f_11551},
{C_text("f_11554:core_2escm"),(void*)f_11554},
{C_text("f_11560:core_2escm"),(void*)f_11560},
{C_text("f_11563:core_2escm"),(void*)f_11563},
{C_text("f_11569:core_2escm"),(void*)f_11569},
{C_text("f_11576:core_2escm"),(void*)f_11576},
{C_text("f_11580:core_2escm"),(void*)f_11580},
{C_text("f_11586:core_2escm"),(void*)f_11586},
{C_text("f_11589:core_2escm"),(void*)f_11589},
{C_text("f_11592:core_2escm"),(void*)f_11592},
{C_text("f_11595:core_2escm"),(void*)f_11595},
{C_text("f_11598:core_2escm"),(void*)f_11598},
{C_text("f_11602:core_2escm"),(void*)f_11602},
{C_text("f_11605:core_2escm"),(void*)f_11605},
{C_text("f_11611:core_2escm"),(void*)f_11611},
{C_text("f_11614:core_2escm"),(void*)f_11614},
{C_text("f_11617:core_2escm"),(void*)f_11617},
{C_text("f_11633:core_2escm"),(void*)f_11633},
{C_text("f_11639:core_2escm"),(void*)f_11639},
{C_text("f_11642:core_2escm"),(void*)f_11642},
{C_text("f_11645:core_2escm"),(void*)f_11645},
{C_text("f_11648:core_2escm"),(void*)f_11648},
{C_text("f_11651:core_2escm"),(void*)f_11651},
{C_text("f_11655:core_2escm"),(void*)f_11655},
{C_text("f_11658:core_2escm"),(void*)f_11658},
{C_text("f_11664:core_2escm"),(void*)f_11664},
{C_text("f_11667:core_2escm"),(void*)f_11667},
{C_text("f_11670:core_2escm"),(void*)f_11670},
{C_text("f_11677:core_2escm"),(void*)f_11677},
{C_text("f_11681:core_2escm"),(void*)f_11681},
{C_text("f_11704:core_2escm"),(void*)f_11704},
{C_text("f_11717:core_2escm"),(void*)f_11717},
{C_text("f_11723:core_2escm"),(void*)f_11723},
{C_text("f_11726:core_2escm"),(void*)f_11726},
{C_text("f_11729:core_2escm"),(void*)f_11729},
{C_text("f_11732:core_2escm"),(void*)f_11732},
{C_text("f_11735:core_2escm"),(void*)f_11735},
{C_text("f_11739:core_2escm"),(void*)f_11739},
{C_text("f_11742:core_2escm"),(void*)f_11742},
{C_text("f_11748:core_2escm"),(void*)f_11748},
{C_text("f_11751:core_2escm"),(void*)f_11751},
{C_text("f_11754:core_2escm"),(void*)f_11754},
{C_text("f_11783:core_2escm"),(void*)f_11783},
{C_text("f_11791:core_2escm"),(void*)f_11791},
{C_text("f_11799:core_2escm"),(void*)f_11799},
{C_text("f_11801:core_2escm"),(void*)f_11801},
{C_text("f_11826:core_2escm"),(void*)f_11826},
{C_text("f_11850:core_2escm"),(void*)f_11850},
{C_text("f_11854:core_2escm"),(void*)f_11854},
{C_text("f_11888:core_2escm"),(void*)f_11888},
{C_text("f_11892:core_2escm"),(void*)f_11892},
{C_text("f_11898:core_2escm"),(void*)f_11898},
{C_text("f_11923:core_2escm"),(void*)f_11923},
{C_text("f_11947:core_2escm"),(void*)f_11947},
{C_text("f_11968:core_2escm"),(void*)f_11968},
{C_text("f_11972:core_2escm"),(void*)f_11972},
{C_text("f_11995:core_2escm"),(void*)f_11995},
{C_text("f_12010:core_2escm"),(void*)f_12010},
{C_text("f_12033:core_2escm"),(void*)f_12033},
{C_text("f_12037:core_2escm"),(void*)f_12037},
{C_text("f_12055:core_2escm"),(void*)f_12055},
{C_text("f_12062:core_2escm"),(void*)f_12062},
{C_text("f_12066:core_2escm"),(void*)f_12066},
{C_text("f_12081:core_2escm"),(void*)f_12081},
{C_text("f_12094:core_2escm"),(void*)f_12094},
{C_text("f_12107:core_2escm"),(void*)f_12107},
{C_text("f_12120:core_2escm"),(void*)f_12120},
{C_text("f_12133:core_2escm"),(void*)f_12133},
{C_text("f_12142:core_2escm"),(void*)f_12142},
{C_text("f_12145:core_2escm"),(void*)f_12145},
{C_text("f_12148:core_2escm"),(void*)f_12148},
{C_text("f_12189:core_2escm"),(void*)f_12189},
{C_text("f_12195:core_2escm"),(void*)f_12195},
{C_text("f_12204:core_2escm"),(void*)f_12204},
{C_text("f_12207:core_2escm"),(void*)f_12207},
{C_text("f_12210:core_2escm"),(void*)f_12210},
{C_text("f_12213:core_2escm"),(void*)f_12213},
{C_text("f_12216:core_2escm"),(void*)f_12216},
{C_text("f_12219:core_2escm"),(void*)f_12219},
{C_text("f_12222:core_2escm"),(void*)f_12222},
{C_text("f_12225:core_2escm"),(void*)f_12225},
{C_text("f_12228:core_2escm"),(void*)f_12228},
{C_text("f_12243:core_2escm"),(void*)f_12243},
{C_text("f_12263:core_2escm"),(void*)f_12263},
{C_text("f_12267:core_2escm"),(void*)f_12267},
{C_text("f_12270:core_2escm"),(void*)f_12270},
{C_text("f_12277:core_2escm"),(void*)f_12277},
{C_text("f_12280:core_2escm"),(void*)f_12280},
{C_text("f_12286:core_2escm"),(void*)f_12286},
{C_text("f_12289:core_2escm"),(void*)f_12289},
{C_text("f_12292:core_2escm"),(void*)f_12292},
{C_text("f_12311:core_2escm"),(void*)f_12311},
{C_text("f_12314:core_2escm"),(void*)f_12314},
{C_text("f_12323:core_2escm"),(void*)f_12323},
{C_text("f_12326:core_2escm"),(void*)f_12326},
{C_text("f_12329:core_2escm"),(void*)f_12329},
{C_text("f_12349:core_2escm"),(void*)f_12349},
{C_text("f_12357:core_2escm"),(void*)f_12357},
{C_text("f_12368:core_2escm"),(void*)f_12368},
{C_text("f_12371:core_2escm"),(void*)f_12371},
{C_text("f_12377:core_2escm"),(void*)f_12377},
{C_text("f_12380:core_2escm"),(void*)f_12380},
{C_text("f_12383:core_2escm"),(void*)f_12383},
{C_text("f_12398:core_2escm"),(void*)f_12398},
{C_text("f_12401:core_2escm"),(void*)f_12401},
{C_text("f_12404:core_2escm"),(void*)f_12404},
{C_text("f_12410:core_2escm"),(void*)f_12410},
{C_text("f_12422:core_2escm"),(void*)f_12422},
{C_text("f_12426:core_2escm"),(void*)f_12426},
{C_text("f_12430:core_2escm"),(void*)f_12430},
{C_text("f_12433:core_2escm"),(void*)f_12433},
{C_text("f_12439:core_2escm"),(void*)f_12439},
{C_text("f_12459:core_2escm"),(void*)f_12459},
{C_text("f_12463:core_2escm"),(void*)f_12463},
{C_text("f_12488:core_2escm"),(void*)f_12488},
{C_text("f_12511:core_2escm"),(void*)f_12511},
{C_text("f_12513:core_2escm"),(void*)f_12513},
{C_text("f_12517:core_2escm"),(void*)f_12517},
{C_text("f_12520:core_2escm"),(void*)f_12520},
{C_text("f_12525:core_2escm"),(void*)f_12525},
{C_text("f_12558:core_2escm"),(void*)f_12558},
{C_text("f_12561:core_2escm"),(void*)f_12561},
{C_text("f_12564:core_2escm"),(void*)f_12564},
{C_text("f_12571:core_2escm"),(void*)f_12571},
{C_text("f_12574:core_2escm"),(void*)f_12574},
{C_text("f_12580:core_2escm"),(void*)f_12580},
{C_text("f_12583:core_2escm"),(void*)f_12583},
{C_text("f_12586:core_2escm"),(void*)f_12586},
{C_text("f_12593:core_2escm"),(void*)f_12593},
{C_text("f_12605:core_2escm"),(void*)f_12605},
{C_text("f_12611:core_2escm"),(void*)f_12611},
{C_text("f_12614:core_2escm"),(void*)f_12614},
{C_text("f_12617:core_2escm"),(void*)f_12617},
{C_text("f_12627:core_2escm"),(void*)f_12627},
{C_text("f_12630:core_2escm"),(void*)f_12630},
{C_text("f_12640:core_2escm"),(void*)f_12640},
{C_text("f_12643:core_2escm"),(void*)f_12643},
{C_text("f_12646:core_2escm"),(void*)f_12646},
{C_text("f_12649:core_2escm"),(void*)f_12649},
{C_text("f_12652:core_2escm"),(void*)f_12652},
{C_text("f_12655:core_2escm"),(void*)f_12655},
{C_text("f_12673:core_2escm"),(void*)f_12673},
{C_text("f_12676:core_2escm"),(void*)f_12676},
{C_text("f_12682:core_2escm"),(void*)f_12682},
{C_text("f_12685:core_2escm"),(void*)f_12685},
{C_text("f_12688:core_2escm"),(void*)f_12688},
{C_text("f_12706:core_2escm"),(void*)f_12706},
{C_text("f_12709:core_2escm"),(void*)f_12709},
{C_text("f_12715:core_2escm"),(void*)f_12715},
{C_text("f_12718:core_2escm"),(void*)f_12718},
{C_text("f_12721:core_2escm"),(void*)f_12721},
{C_text("f_12726:core_2escm"),(void*)f_12726},
{C_text("f_12732:core_2escm"),(void*)f_12732},
{C_text("f_12738:core_2escm"),(void*)f_12738},
{C_text("f_12744:core_2escm"),(void*)f_12744},
{C_text("f_12750:core_2escm"),(void*)f_12750},
{C_text("f_12757:core_2escm"),(void*)f_12757},
{C_text("f_12776:core_2escm"),(void*)f_12776},
{C_text("f_12782:core_2escm"),(void*)f_12782},
{C_text("f_12804:core_2escm"),(void*)f_12804},
{C_text("f_12810:core_2escm"),(void*)f_12810},
{C_text("f_12818:core_2escm"),(void*)f_12818},
{C_text("f_12825:core_2escm"),(void*)f_12825},
{C_text("f_12827:core_2escm"),(void*)f_12827},
{C_text("f_12852:core_2escm"),(void*)f_12852},
{C_text("f_12870:core_2escm"),(void*)f_12870},
{C_text("f_12880:core_2escm"),(void*)f_12880},
{C_text("f_12890:core_2escm"),(void*)f_12890},
{C_text("f_12902:core_2escm"),(void*)f_12902},
{C_text("f_12905:core_2escm"),(void*)f_12905},
{C_text("f_12912:core_2escm"),(void*)f_12912},
{C_text("f_12916:core_2escm"),(void*)f_12916},
{C_text("f_12924:core_2escm"),(void*)f_12924},
{C_text("f_12936:core_2escm"),(void*)f_12936},
{C_text("f_12940:core_2escm"),(void*)f_12940},
{C_text("f_12952:core_2escm"),(void*)f_12952},
{C_text("f_13012:core_2escm"),(void*)f_13012},
{C_text("f_13041:core_2escm"),(void*)f_13041},
{C_text("f_13065:core_2escm"),(void*)f_13065},
{C_text("f_13073:core_2escm"),(void*)f_13073},
{C_text("f_13077:core_2escm"),(void*)f_13077},
{C_text("f_13081:core_2escm"),(void*)f_13081},
{C_text("f_13122:core_2escm"),(void*)f_13122},
{C_text("f_13133:core_2escm"),(void*)f_13133},
{C_text("f_13140:core_2escm"),(void*)f_13140},
{C_text("f_13143:core_2escm"),(void*)f_13143},
{C_text("f_13149:core_2escm"),(void*)f_13149},
{C_text("f_13152:core_2escm"),(void*)f_13152},
{C_text("f_13155:core_2escm"),(void*)f_13155},
{C_text("f_13192:core_2escm"),(void*)f_13192},
{C_text("f_13218:core_2escm"),(void*)f_13218},
{C_text("f_13246:core_2escm"),(void*)f_13246},
{C_text("f_13261:core_2escm"),(void*)f_13261},
{C_text("f_13278:core_2escm"),(void*)f_13278},
{C_text("f_13284:core_2escm"),(void*)f_13284},
{C_text("f_13287:core_2escm"),(void*)f_13287},
{C_text("f_13307:core_2escm"),(void*)f_13307},
{C_text("f_13312:core_2escm"),(void*)f_13312},
{C_text("f_13318:core_2escm"),(void*)f_13318},
{C_text("f_13457:core_2escm"),(void*)f_13457},
{C_text("f_13462:core_2escm"),(void*)f_13462},
{C_text("f_13470:core_2escm"),(void*)f_13470},
{C_text("f_13472:core_2escm"),(void*)f_13472},
{C_text("f_13490:core_2escm"),(void*)f_13490},
{C_text("f_13496:core_2escm"),(void*)f_13496},
{C_text("f_13499:core_2escm"),(void*)f_13499},
{C_text("f_13502:core_2escm"),(void*)f_13502},
{C_text("f_13505:core_2escm"),(void*)f_13505},
{C_text("f_13523:core_2escm"),(void*)f_13523},
{C_text("f_13526:core_2escm"),(void*)f_13526},
{C_text("f_13529:core_2escm"),(void*)f_13529},
{C_text("f_13535:core_2escm"),(void*)f_13535},
{C_text("f_13538:core_2escm"),(void*)f_13538},
{C_text("f_13577:core_2escm"),(void*)f_13577},
{C_text("f_13582:core_2escm"),(void*)f_13582},
{C_text("f_13594:core_2escm"),(void*)f_13594},
{C_text("f_13619:core_2escm"),(void*)f_13619},
{C_text("f_13629:core_2escm"),(void*)f_13629},
{C_text("f_13640:core_2escm"),(void*)f_13640},
{C_text("f_13644:core_2escm"),(void*)f_13644},
{C_text("f_13654:core_2escm"),(void*)f_13654},
{C_text("f_13660:core_2escm"),(void*)f_13660},
{C_text("f_13668:core_2escm"),(void*)f_13668},
{C_text("f_13703:core_2escm"),(void*)f_13703},
{C_text("f_13710:core_2escm"),(void*)f_13710},
{C_text("f_13713:core_2escm"),(void*)f_13713},
{C_text("f_13720:core_2escm"),(void*)f_13720},
{C_text("f_13722:core_2escm"),(void*)f_13722},
{C_text("f_13728:core_2escm"),(void*)f_13728},
{C_text("f_13736:core_2escm"),(void*)f_13736},
{C_text("f_13742:core_2escm"),(void*)f_13742},
{C_text("f_13745:core_2escm"),(void*)f_13745},
{C_text("f_13748:core_2escm"),(void*)f_13748},
{C_text("f_13751:core_2escm"),(void*)f_13751},
{C_text("f_13756:core_2escm"),(void*)f_13756},
{C_text("f_13760:core_2escm"),(void*)f_13760},
{C_text("f_13763:core_2escm"),(void*)f_13763},
{C_text("f_13766:core_2escm"),(void*)f_13766},
{C_text("f_13772:core_2escm"),(void*)f_13772},
{C_text("f_13776:core_2escm"),(void*)f_13776},
{C_text("f_13780:core_2escm"),(void*)f_13780},
{C_text("f_13791:core_2escm"),(void*)f_13791},
{C_text("f_13794:core_2escm"),(void*)f_13794},
{C_text("f_13797:core_2escm"),(void*)f_13797},
{C_text("f_13833:core_2escm"),(void*)f_13833},
{C_text("f_13837:core_2escm"),(void*)f_13837},
{C_text("f_13858:core_2escm"),(void*)f_13858},
{C_text("f_13862:core_2escm"),(void*)f_13862},
{C_text("f_13883:core_2escm"),(void*)f_13883},
{C_text("f_13887:core_2escm"),(void*)f_13887},
{C_text("f_13891:core_2escm"),(void*)f_13891},
{C_text("f_13904:core_2escm"),(void*)f_13904},
{C_text("f_13908:core_2escm"),(void*)f_13908},
{C_text("f_13991:core_2escm"),(void*)f_13991},
{C_text("f_14001:core_2escm"),(void*)f_14001},
{C_text("f_14033:core_2escm"),(void*)f_14033},
{C_text("f_14039:core_2escm"),(void*)f_14039},
{C_text("f_14047:core_2escm"),(void*)f_14047},
{C_text("f_14055:core_2escm"),(void*)f_14055},
{C_text("f_14065:core_2escm"),(void*)f_14065},
{C_text("f_14078:core_2escm"),(void*)f_14078},
{C_text("f_14088:core_2escm"),(void*)f_14088},
{C_text("f_14115:core_2escm"),(void*)f_14115},
{C_text("f_14126:core_2escm"),(void*)f_14126},
{C_text("f_14136:core_2escm"),(void*)f_14136},
{C_text("f_14146:core_2escm"),(void*)f_14146},
{C_text("f_14159:core_2escm"),(void*)f_14159},
{C_text("f_14169:core_2escm"),(void*)f_14169},
{C_text("f_14195:core_2escm"),(void*)f_14195},
{C_text("f_14199:core_2escm"),(void*)f_14199},
{C_text("f_14237:core_2escm"),(void*)f_14237},
{C_text("f_14245:core_2escm"),(void*)f_14245},
{C_text("f_14255:core_2escm"),(void*)f_14255},
{C_text("f_14282:core_2escm"),(void*)f_14282},
{C_text("f_14290:core_2escm"),(void*)f_14290},
{C_text("f_14300:core_2escm"),(void*)f_14300},
{C_text("f_14322:core_2escm"),(void*)f_14322},
{C_text("f_14325:core_2escm"),(void*)f_14325},
{C_text("f_14342:core_2escm"),(void*)f_14342},
{C_text("f_14346:core_2escm"),(void*)f_14346},
{C_text("f_14370:core_2escm"),(void*)f_14370},
{C_text("f_14374:core_2escm"),(void*)f_14374},
{C_text("f_14402:core_2escm"),(void*)f_14402},
{C_text("f_14410:core_2escm"),(void*)f_14410},
{C_text("f_14420:core_2escm"),(void*)f_14420},
{C_text("f_14455:core_2escm"),(void*)f_14455},
{C_text("f_14459:core_2escm"),(void*)f_14459},
{C_text("f_14463:core_2escm"),(void*)f_14463},
{C_text("f_14491:core_2escm"),(void*)f_14491},
{C_text("f_14499:core_2escm"),(void*)f_14499},
{C_text("f_14509:core_2escm"),(void*)f_14509},
{C_text("f_14530:core_2escm"),(void*)f_14530},
{C_text("f_14533:core_2escm"),(void*)f_14533},
{C_text("f_14582:core_2escm"),(void*)f_14582},
{C_text("f_14597:core_2escm"),(void*)f_14597},
{C_text("f_14607:core_2escm"),(void*)f_14607},
{C_text("f_14630:core_2escm"),(void*)f_14630},
{C_text("f_14638:core_2escm"),(void*)f_14638},
{C_text("f_14648:core_2escm"),(void*)f_14648},
{C_text("f_14689:core_2escm"),(void*)f_14689},
{C_text("f_14697:core_2escm"),(void*)f_14697},
{C_text("f_14707:core_2escm"),(void*)f_14707},
{C_text("f_14731:core_2escm"),(void*)f_14731},
{C_text("f_14753:core_2escm"),(void*)f_14753},
{C_text("f_14775:core_2escm"),(void*)f_14775},
{C_text("f_14781:core_2escm"),(void*)f_14781},
{C_text("f_14789:core_2escm"),(void*)f_14789},
{C_text("f_14797:core_2escm"),(void*)f_14797},
{C_text("f_14807:core_2escm"),(void*)f_14807},
{C_text("f_14833:core_2escm"),(void*)f_14833},
{C_text("f_14852:core_2escm"),(void*)f_14852},
{C_text("f_14856:core_2escm"),(void*)f_14856},
{C_text("f_14863:core_2escm"),(void*)f_14863},
{C_text("f_14909:core_2escm"),(void*)f_14909},
{C_text("f_14915:core_2escm"),(void*)f_14915},
{C_text("f_14917:core_2escm"),(void*)f_14917},
{C_text("f_14942:core_2escm"),(void*)f_14942},
{C_text("f_14967:core_2escm"),(void*)f_14967},
{C_text("f_14970:core_2escm"),(void*)f_14970},
{C_text("f_15019:core_2escm"),(void*)f_15019},
{C_text("f_15027:core_2escm"),(void*)f_15027},
{C_text("f_15037:core_2escm"),(void*)f_15037},
{C_text("f_15073:core_2escm"),(void*)f_15073},
{C_text("f_15081:core_2escm"),(void*)f_15081},
{C_text("f_15091:core_2escm"),(void*)f_15091},
{C_text("f_15128:core_2escm"),(void*)f_15128},
{C_text("f_15136:core_2escm"),(void*)f_15136},
{C_text("f_15146:core_2escm"),(void*)f_15146},
{C_text("f_15168:core_2escm"),(void*)f_15168},
{C_text("f_15175:core_2escm"),(void*)f_15175},
{C_text("f_15182:core_2escm"),(void*)f_15182},
{C_text("f_15185:core_2escm"),(void*)f_15185},
{C_text("f_15188:core_2escm"),(void*)f_15188},
{C_text("f_15194:core_2escm"),(void*)f_15194},
{C_text("f_15204:core_2escm"),(void*)f_15204},
{C_text("f_15210:core_2escm"),(void*)f_15210},
{C_text("f_15220:core_2escm"),(void*)f_15220},
{C_text("f_15223:core_2escm"),(void*)f_15223},
{C_text("f_15226:core_2escm"),(void*)f_15226},
{C_text("f_15229:core_2escm"),(void*)f_15229},
{C_text("f_15242:core_2escm"),(void*)f_15242},
{C_text("f_15258:core_2escm"),(void*)f_15258},
{C_text("f_15290:core_2escm"),(void*)f_15290},
{C_text("f_15332:core_2escm"),(void*)f_15332},
{C_text("f_15342:core_2escm"),(void*)f_15342},
{C_text("f_15360:core_2escm"),(void*)f_15360},
{C_text("f_15367:core_2escm"),(void*)f_15367},
{C_text("f_15370:core_2escm"),(void*)f_15370},
{C_text("f_15373:core_2escm"),(void*)f_15373},
{C_text("f_15379:core_2escm"),(void*)f_15379},
{C_text("f_15389:core_2escm"),(void*)f_15389},
{C_text("f_15395:core_2escm"),(void*)f_15395},
{C_text("f_15454:core_2escm"),(void*)f_15454},
{C_text("f_15464:core_2escm"),(void*)f_15464},
{C_text("f_15598:core_2escm"),(void*)f_15598},
{C_text("f_15621:core_2escm"),(void*)f_15621},
{C_text("f_15630:core_2escm"),(void*)f_15630},
{C_text("f_15639:core_2escm"),(void*)f_15639},
{C_text("f_15648:core_2escm"),(void*)f_15648},
{C_text("f_15657:core_2escm"),(void*)f_15657},
{C_text("f_15666:core_2escm"),(void*)f_15666},
{C_text("f_15675:core_2escm"),(void*)f_15675},
{C_text("f_15684:core_2escm"),(void*)f_15684},
{C_text("f_15693:core_2escm"),(void*)f_15693},
{C_text("f_15702:core_2escm"),(void*)f_15702},
{C_text("f_15731:core_2escm"),(void*)f_15731},
{C_text("f_15735:core_2escm"),(void*)f_15735},
{C_text("f_15780:core_2escm"),(void*)f_15780},
{C_text("f_15783:core_2escm"),(void*)f_15783},
{C_text("f_15786:core_2escm"),(void*)f_15786},
{C_text("f_15789:core_2escm"),(void*)f_15789},
{C_text("f_15792:core_2escm"),(void*)f_15792},
{C_text("f_15795:core_2escm"),(void*)f_15795},
{C_text("f_15798:core_2escm"),(void*)f_15798},
{C_text("f_15808:core_2escm"),(void*)f_15808},
{C_text("f_15820:core_2escm"),(void*)f_15820},
{C_text("f_15829:core_2escm"),(void*)f_15829},
{C_text("f_15840:core_2escm"),(void*)f_15840},
{C_text("f_15852:core_2escm"),(void*)f_15852},
{C_text("f_15860:core_2escm"),(void*)f_15860},
{C_text("f_15867:core_2escm"),(void*)f_15867},
{C_text("f_15870:core_2escm"),(void*)f_15870},
{C_text("f_15881:core_2escm"),(void*)f_15881},
{C_text("f_15885:core_2escm"),(void*)f_15885},
{C_text("f_15889:core_2escm"),(void*)f_15889},
{C_text("f_15915:core_2escm"),(void*)f_15915},
{C_text("f_15944:core_2escm"),(void*)f_15944},
{C_text("f_15985:core_2escm"),(void*)f_15985},
{C_text("f_15996:core_2escm"),(void*)f_15996},
{C_text("f_16021:core_2escm"),(void*)f_16021},
{C_text("f_16040:core_2escm"),(void*)f_16040},
{C_text("f_16048:core_2escm"),(void*)f_16048},
{C_text("f_16073:core_2escm"),(void*)f_16073},
{C_text("f_16082:core_2escm"),(void*)f_16082},
{C_text("f_16089:core_2escm"),(void*)f_16089},
{C_text("f_16108:core_2escm"),(void*)f_16108},
{C_text("f_16119:core_2escm"),(void*)f_16119},
{C_text("f_16129:core_2escm"),(void*)f_16129},
{C_text("f_16143:core_2escm"),(void*)f_16143},
{C_text("f_16149:core_2escm"),(void*)f_16149},
{C_text("f_16155:core_2escm"),(void*)f_16155},
{C_text("f_16160:core_2escm"),(void*)f_16160},
{C_text("f_16194:core_2escm"),(void*)f_16194},
{C_text("f_16236:core_2escm"),(void*)f_16236},
{C_text("f_16242:core_2escm"),(void*)f_16242},
{C_text("f_16245:core_2escm"),(void*)f_16245},
{C_text("f_16259:core_2escm"),(void*)f_16259},
{C_text("f_16265:core_2escm"),(void*)f_16265},
{C_text("f_16271:core_2escm"),(void*)f_16271},
{C_text("f_16276:core_2escm"),(void*)f_16276},
{C_text("f_16310:core_2escm"),(void*)f_16310},
{C_text("f_16385:core_2escm"),(void*)f_16385},
{C_text("f_16388:core_2escm"),(void*)f_16388},
{C_text("f_16392:core_2escm"),(void*)f_16392},
{C_text("f_16399:core_2escm"),(void*)f_16399},
{C_text("f_16411:core_2escm"),(void*)f_16411},
{C_text("f_16417:core_2escm"),(void*)f_16417},
{C_text("f_16433:core_2escm"),(void*)f_16433},
{C_text("f_16439:core_2escm"),(void*)f_16439},
{C_text("f_16457:core_2escm"),(void*)f_16457},
{C_text("f_16461:core_2escm"),(void*)f_16461},
{C_text("f_16463:core_2escm"),(void*)f_16463},
{C_text("f_16467:core_2escm"),(void*)f_16467},
{C_text("f_16470:core_2escm"),(void*)f_16470},
{C_text("f_16473:core_2escm"),(void*)f_16473},
{C_text("f_16476:core_2escm"),(void*)f_16476},
{C_text("f_16485:core_2escm"),(void*)f_16485},
{C_text("f_16497:core_2escm"),(void*)f_16497},
{C_text("f_16500:core_2escm"),(void*)f_16500},
{C_text("f_16501:core_2escm"),(void*)f_16501},
{C_text("f_16517:core_2escm"),(void*)f_16517},
{C_text("f_16532:core_2escm"),(void*)f_16532},
{C_text("f_16536:core_2escm"),(void*)f_16536},
{C_text("f_16542:core_2escm"),(void*)f_16542},
{C_text("f_16554:core_2escm"),(void*)f_16554},
{C_text("f_16558:core_2escm"),(void*)f_16558},
{C_text("f_16578:core_2escm"),(void*)f_16578},
{C_text("f_16582:core_2escm"),(void*)f_16582},
{C_text("f_16591:core_2escm"),(void*)f_16591},
{C_text("f_16606:core_2escm"),(void*)f_16606},
{C_text("f_16629:core_2escm"),(void*)f_16629},
{C_text("f_16636:core_2escm"),(void*)f_16636},
{C_text("f_16660:core_2escm"),(void*)f_16660},
{C_text("f_16693:core_2escm"),(void*)f_16693},
{C_text("f_16706:core_2escm"),(void*)f_16706},
{C_text("f_16721:core_2escm"),(void*)f_16721},
{C_text("f_16737:core_2escm"),(void*)f_16737},
{C_text("f_16741:core_2escm"),(void*)f_16741},
{C_text("f_16745:core_2escm"),(void*)f_16745},
{C_text("f_16777:core_2escm"),(void*)f_16777},
{C_text("f_16783:core_2escm"),(void*)f_16783},
{C_text("f_16794:core_2escm"),(void*)f_16794},
{C_text("f_16798:core_2escm"),(void*)f_16798},
{C_text("f_16807:core_2escm"),(void*)f_16807},
{C_text("f_16847:core_2escm"),(void*)f_16847},
{C_text("f_16855:core_2escm"),(void*)f_16855},
{C_text("f_16860:core_2escm"),(void*)f_16860},
{C_text("f_16866:core_2escm"),(void*)f_16866},
{C_text("f_17009:core_2escm"),(void*)f_17009},
{C_text("f_17013:core_2escm"),(void*)f_17013},
{C_text("f_17016:core_2escm"),(void*)f_17016},
{C_text("f_17031:core_2escm"),(void*)f_17031},
{C_text("f_17035:core_2escm"),(void*)f_17035},
{C_text("f_17037:core_2escm"),(void*)f_17037},
{C_text("f_17043:core_2escm"),(void*)f_17043},
{C_text("f_17051:core_2escm"),(void*)f_17051},
{C_text("f_17055:core_2escm"),(void*)f_17055},
{C_text("f_17067:core_2escm"),(void*)f_17067},
{C_text("f_17071:core_2escm"),(void*)f_17071},
{C_text("f_17080:core_2escm"),(void*)f_17080},
{C_text("f_17090:core_2escm"),(void*)f_17090},
{C_text("f_17093:core_2escm"),(void*)f_17093},
{C_text("f_17108:core_2escm"),(void*)f_17108},
{C_text("f_17112:core_2escm"),(void*)f_17112},
{C_text("f_17124:core_2escm"),(void*)f_17124},
{C_text("f_17136:core_2escm"),(void*)f_17136},
{C_text("f_17140:core_2escm"),(void*)f_17140},
{C_text("f_17149:core_2escm"),(void*)f_17149},
{C_text("f_17155:core_2escm"),(void*)f_17155},
{C_text("f_17161:core_2escm"),(void*)f_17161},
{C_text("f_17169:core_2escm"),(void*)f_17169},
{C_text("f_17171:core_2escm"),(void*)f_17171},
{C_text("f_17177:core_2escm"),(void*)f_17177},
{C_text("f_17191:core_2escm"),(void*)f_17191},
{C_text("f_17197:core_2escm"),(void*)f_17197},
{C_text("f_17211:core_2escm"),(void*)f_17211},
{C_text("f_17218:core_2escm"),(void*)f_17218},
{C_text("f_17225:core_2escm"),(void*)f_17225},
{C_text("f_17240:core_2escm"),(void*)f_17240},
{C_text("f_17255:core_2escm"),(void*)f_17255},
{C_text("f_17267:core_2escm"),(void*)f_17267},
{C_text("f_17273:core_2escm"),(void*)f_17273},
{C_text("f_17277:core_2escm"),(void*)f_17277},
{C_text("f_17294:core_2escm"),(void*)f_17294},
{C_text("f_17299:core_2escm"),(void*)f_17299},
{C_text("f_17306:core_2escm"),(void*)f_17306},
{C_text("f_17308:core_2escm"),(void*)f_17308},
{C_text("f_17315:core_2escm"),(void*)f_17315},
{C_text("f_17319:core_2escm"),(void*)f_17319},
{C_text("f_17322:core_2escm"),(void*)f_17322},
{C_text("f_17325:core_2escm"),(void*)f_17325},
{C_text("f_17337:core_2escm"),(void*)f_17337},
{C_text("f_17352:core_2escm"),(void*)f_17352},
{C_text("f_17383:core_2escm"),(void*)f_17383},
{C_text("f_17413:core_2escm"),(void*)f_17413},
{C_text("f_17416:core_2escm"),(void*)f_17416},
{C_text("f_17434:core_2escm"),(void*)f_17434},
{C_text("f_17437:core_2escm"),(void*)f_17437},
{C_text("f_17447:core_2escm"),(void*)f_17447},
{C_text("f_17454:core_2escm"),(void*)f_17454},
{C_text("f_17482:core_2escm"),(void*)f_17482},
{C_text("f_17492:core_2escm"),(void*)f_17492},
{C_text("f_17496:core_2escm"),(void*)f_17496},
{C_text("f_17500:core_2escm"),(void*)f_17500},
{C_text("f_17504:core_2escm"),(void*)f_17504},
{C_text("f_17508:core_2escm"),(void*)f_17508},
{C_text("f_17512:core_2escm"),(void*)f_17512},
{C_text("f_17524:core_2escm"),(void*)f_17524},
{C_text("f_17529:core_2escm"),(void*)f_17529},
{C_text("f_17547:core_2escm"),(void*)f_17547},
{C_text("f_17556:core_2escm"),(void*)f_17556},
{C_text("f_17559:core_2escm"),(void*)f_17559},
{C_text("f_17562:core_2escm"),(void*)f_17562},
{C_text("f_17587:core_2escm"),(void*)f_17587},
{C_text("f_17589:core_2escm"),(void*)f_17589},
{C_text("f_17599:core_2escm"),(void*)f_17599},
{C_text("f_17603:core_2escm"),(void*)f_17603},
{C_text("f_17612:core_2escm"),(void*)f_17612},
{C_text("f_17614:core_2escm"),(void*)f_17614},
{C_text("f_17624:core_2escm"),(void*)f_17624},
{C_text("f_17656:core_2escm"),(void*)f_17656},
{C_text("f_17663:core_2escm"),(void*)f_17663},
{C_text("f_17664:core_2escm"),(void*)f_17664},
{C_text("f_17668:core_2escm"),(void*)f_17668},
{C_text("f_17677:core_2escm"),(void*)f_17677},
{C_text("f_17680:core_2escm"),(void*)f_17680},
{C_text("f_17683:core_2escm"),(void*)f_17683},
{C_text("f_17686:core_2escm"),(void*)f_17686},
{C_text("f_17689:core_2escm"),(void*)f_17689},
{C_text("f_17692:core_2escm"),(void*)f_17692},
{C_text("f_17708:core_2escm"),(void*)f_17708},
{C_text("f_17716:core_2escm"),(void*)f_17716},
{C_text("f_17734:core_2escm"),(void*)f_17734},
{C_text("f_17740:core_2escm"),(void*)f_17740},
{C_text("f_17749:core_2escm"),(void*)f_17749},
{C_text("f_17759:core_2escm"),(void*)f_17759},
{C_text("f_17773:core_2escm"),(void*)f_17773},
{C_text("f_17794:core_2escm"),(void*)f_17794},
{C_text("f_17797:core_2escm"),(void*)f_17797},
{C_text("f_17800:core_2escm"),(void*)f_17800},
{C_text("f_17803:core_2escm"),(void*)f_17803},
{C_text("f_17806:core_2escm"),(void*)f_17806},
{C_text("f_17809:core_2escm"),(void*)f_17809},
{C_text("f_17845:core_2escm"),(void*)f_17845},
{C_text("f_17851:core_2escm"),(void*)f_17851},
{C_text("f_17891:core_2escm"),(void*)f_17891},
{C_text("f_17897:core_2escm"),(void*)f_17897},
{C_text("f_17986:core_2escm"),(void*)f_17986},
{C_text("f_17988:core_2escm"),(void*)f_17988},
{C_text("f_18000:core_2escm"),(void*)f_18000},
{C_text("f_18010:core_2escm"),(void*)f_18010},
{C_text("f_18023:core_2escm"),(void*)f_18023},
{C_text("f_18027:core_2escm"),(void*)f_18027},
{C_text("f_18036:core_2escm"),(void*)f_18036},
{C_text("f_18040:core_2escm"),(void*)f_18040},
{C_text("f_18049:core_2escm"),(void*)f_18049},
{C_text("f_18056:core_2escm"),(void*)f_18056},
{C_text("f_18062:core_2escm"),(void*)f_18062},
{C_text("f_18074:core_2escm"),(void*)f_18074},
{C_text("f_18098:core_2escm"),(void*)f_18098},
{C_text("f_18102:core_2escm"),(void*)f_18102},
{C_text("f_18121:core_2escm"),(void*)f_18121},
{C_text("f_18125:core_2escm"),(void*)f_18125},
{C_text("f_18128:core_2escm"),(void*)f_18128},
{C_text("f_18131:core_2escm"),(void*)f_18131},
{C_text("f_18135:core_2escm"),(void*)f_18135},
{C_text("f_18139:core_2escm"),(void*)f_18139},
{C_text("f_18142:core_2escm"),(void*)f_18142},
{C_text("f_18159:core_2escm"),(void*)f_18159},
{C_text("f_18162:core_2escm"),(void*)f_18162},
{C_text("f_18165:core_2escm"),(void*)f_18165},
{C_text("f_18204:core_2escm"),(void*)f_18204},
{C_text("f_18207:core_2escm"),(void*)f_18207},
{C_text("f_18213:core_2escm"),(void*)f_18213},
{C_text("f_18240:core_2escm"),(void*)f_18240},
{C_text("f_18247:core_2escm"),(void*)f_18247},
{C_text("f_18253:core_2escm"),(void*)f_18253},
{C_text("f_18263:core_2escm"),(void*)f_18263},
{C_text("f_18266:core_2escm"),(void*)f_18266},
{C_text("f_18273:core_2escm"),(void*)f_18273},
{C_text("f_18277:core_2escm"),(void*)f_18277},
{C_text("f_18281:core_2escm"),(void*)f_18281},
{C_text("f_18295:core_2escm"),(void*)f_18295},
{C_text("f_18299:core_2escm"),(void*)f_18299},
{C_text("f_18303:core_2escm"),(void*)f_18303},
{C_text("f_18306:core_2escm"),(void*)f_18306},
{C_text("f_18326:core_2escm"),(void*)f_18326},
{C_text("f_18330:core_2escm"),(void*)f_18330},
{C_text("f_18333:core_2escm"),(void*)f_18333},
{C_text("f_18353:core_2escm"),(void*)f_18353},
{C_text("f_18357:core_2escm"),(void*)f_18357},
{C_text("f_18359:core_2escm"),(void*)f_18359},
{C_text("f_18380:core_2escm"),(void*)f_18380},
{C_text("f_18384:core_2escm"),(void*)f_18384},
{C_text("f_18387:core_2escm"),(void*)f_18387},
{C_text("f_18391:core_2escm"),(void*)f_18391},
{C_text("f_18397:core_2escm"),(void*)f_18397},
{C_text("f_18403:core_2escm"),(void*)f_18403},
{C_text("f_18546:core_2escm"),(void*)f_18546},
{C_text("f_18549:core_2escm"),(void*)f_18549},
{C_text("f_18552:core_2escm"),(void*)f_18552},
{C_text("f_18555:core_2escm"),(void*)f_18555},
{C_text("f_18558:core_2escm"),(void*)f_18558},
{C_text("f_18561:core_2escm"),(void*)f_18561},
{C_text("f_18564:core_2escm"),(void*)f_18564},
{C_text("f_18567:core_2escm"),(void*)f_18567},
{C_text("f_18573:core_2escm"),(void*)f_18573},
{C_text("f_18576:core_2escm"),(void*)f_18576},
{C_text("f_18594:core_2escm"),(void*)f_18594},
{C_text("f_18597:core_2escm"),(void*)f_18597},
{C_text("f_18615:core_2escm"),(void*)f_18615},
{C_text("f_18628:core_2escm"),(void*)f_18628},
{C_text("f_18652:core_2escm"),(void*)f_18652},
{C_text("f_18656:core_2escm"),(void*)f_18656},
{C_text("f_18660:core_2escm"),(void*)f_18660},
{C_text("f_18681:core_2escm"),(void*)f_18681},
{C_text("f_18687:core_2escm"),(void*)f_18687},
{C_text("f_18698:core_2escm"),(void*)f_18698},
{C_text("f_18716:core_2escm"),(void*)f_18716},
{C_text("f_18728:core_2escm"),(void*)f_18728},
{C_text("f_18750:core_2escm"),(void*)f_18750},
{C_text("f_18754:core_2escm"),(void*)f_18754},
{C_text("f_18758:core_2escm"),(void*)f_18758},
{C_text("f_18768:core_2escm"),(void*)f_18768},
{C_text("f_18772:core_2escm"),(void*)f_18772},
{C_text("f_18776:core_2escm"),(void*)f_18776},
{C_text("f_18797:core_2escm"),(void*)f_18797},
{C_text("f_18821:core_2escm"),(void*)f_18821},
{C_text("f_18831:core_2escm"),(void*)f_18831},
{C_text("f_18835:core_2escm"),(void*)f_18835},
{C_text("f_18842:core_2escm"),(void*)f_18842},
{C_text("f_18846:core_2escm"),(void*)f_18846},
{C_text("f_18855:core_2escm"),(void*)f_18855},
{C_text("f_18870:core_2escm"),(void*)f_18870},
{C_text("f_18874:core_2escm"),(void*)f_18874},
{C_text("f_18880:core_2escm"),(void*)f_18880},
{C_text("f_18893:core_2escm"),(void*)f_18893},
{C_text("f_18907:core_2escm"),(void*)f_18907},
{C_text("f_18908:core_2escm"),(void*)f_18908},
{C_text("f_18915:core_2escm"),(void*)f_18915},
{C_text("f_18918:core_2escm"),(void*)f_18918},
{C_text("f_18929:core_2escm"),(void*)f_18929},
{C_text("f_18933:core_2escm"),(void*)f_18933},
{C_text("f_18941:core_2escm"),(void*)f_18941},
{C_text("f_18951:core_2escm"),(void*)f_18951},
{C_text("f_18972:core_2escm"),(void*)f_18972},
{C_text("f_18975:core_2escm"),(void*)f_18975},
{C_text("f_18984:core_2escm"),(void*)f_18984},
{C_text("f_18997:core_2escm"),(void*)f_18997},
{C_text("f_19004:core_2escm"),(void*)f_19004},
{C_text("f_19007:core_2escm"),(void*)f_19007},
{C_text("f_19013:core_2escm"),(void*)f_19013},
{C_text("f_19045:core_2escm"),(void*)f_19045},
{C_text("f_19053:core_2escm"),(void*)f_19053},
{C_text("f_19055:core_2escm"),(void*)f_19055},
{C_text("f_19061:core_2escm"),(void*)f_19061},
{C_text("f_19073:core_2escm"),(void*)f_19073},
{C_text("f_19079:core_2escm"),(void*)f_19079},
{C_text("f_19090:core_2escm"),(void*)f_19090},
{C_text("f_19096:core_2escm"),(void*)f_19096},
{C_text("f_19100:core_2escm"),(void*)f_19100},
{C_text("f_19109:core_2escm"),(void*)f_19109},
{C_text("f_19117:core_2escm"),(void*)f_19117},
{C_text("f_19134:core_2escm"),(void*)f_19134},
{C_text("f_19141:core_2escm"),(void*)f_19141},
{C_text("f_19144:core_2escm"),(void*)f_19144},
{C_text("f_19148:core_2escm"),(void*)f_19148},
{C_text("f_19155:core_2escm"),(void*)f_19155},
{C_text("f_19161:core_2escm"),(void*)f_19161},
{C_text("f_19167:core_2escm"),(void*)f_19167},
{C_text("f_19185:core_2escm"),(void*)f_19185},
{C_text("f_19192:core_2escm"),(void*)f_19192},
{C_text("f_19198:core_2escm"),(void*)f_19198},
{C_text("f_19201:core_2escm"),(void*)f_19201},
{C_text("f_19204:core_2escm"),(void*)f_19204},
{C_text("f_19207:core_2escm"),(void*)f_19207},
{C_text("f_19241:core_2escm"),(void*)f_19241},
{C_text("f_19245:core_2escm"),(void*)f_19245},
{C_text("f_19249:core_2escm"),(void*)f_19249},
{C_text("f_19253:core_2escm"),(void*)f_19253},
{C_text("f_19259:core_2escm"),(void*)f_19259},
{C_text("f_19263:core_2escm"),(void*)f_19263},
{C_text("f_19281:core_2escm"),(void*)f_19281},
{C_text("f_19285:core_2escm"),(void*)f_19285},
{C_text("f_19293:core_2escm"),(void*)f_19293},
{C_text("f_19303:core_2escm"),(void*)f_19303},
{C_text("f_19328:core_2escm"),(void*)f_19328},
{C_text("f_19355:core_2escm"),(void*)f_19355},
{C_text("f_19358:core_2escm"),(void*)f_19358},
{C_text("f_19364:core_2escm"),(void*)f_19364},
{C_text("f_19369:core_2escm"),(void*)f_19369},
{C_text("f_19374:core_2escm"),(void*)f_19374},
{C_text("f_19381:core_2escm"),(void*)f_19381},
{C_text("f_19383:core_2escm"),(void*)f_19383},
{C_text("f_19387:core_2escm"),(void*)f_19387},
{C_text("f_19390:core_2escm"),(void*)f_19390},
{C_text("f_19393:core_2escm"),(void*)f_19393},
{C_text("f_19423:core_2escm"),(void*)f_19423},
{C_text("f_19432:core_2escm"),(void*)f_19432},
{C_text("f_19435:core_2escm"),(void*)f_19435},
{C_text("f_19445:core_2escm"),(void*)f_19445},
{C_text("f_19449:core_2escm"),(void*)f_19449},
{C_text("f_19483:core_2escm"),(void*)f_19483},
{C_text("f_19517:core_2escm"),(void*)f_19517},
{C_text("f_19525:core_2escm"),(void*)f_19525},
{C_text("f_19535:core_2escm"),(void*)f_19535},
{C_text("f_19537:core_2escm"),(void*)f_19537},
{C_text("f_19562:core_2escm"),(void*)f_19562},
{C_text("f_19593:core_2escm"),(void*)f_19593},
{C_text("f_19599:core_2escm"),(void*)f_19599},
{C_text("f_19602:core_2escm"),(void*)f_19602},
{C_text("f_19611:core_2escm"),(void*)f_19611},
{C_text("f_19614:core_2escm"),(void*)f_19614},
{C_text("f_19617:core_2escm"),(void*)f_19617},
{C_text("f_19623:core_2escm"),(void*)f_19623},
{C_text("f_19626:core_2escm"),(void*)f_19626},
{C_text("f_19629:core_2escm"),(void*)f_19629},
{C_text("f_19642:core_2escm"),(void*)f_19642},
{C_text("f_19661:core_2escm"),(void*)f_19661},
{C_text("f_19679:core_2escm"),(void*)f_19679},
{C_text("f_19697:core_2escm"),(void*)f_19697},
{C_text("f_19707:core_2escm"),(void*)f_19707},
{C_text("f_19711:core_2escm"),(void*)f_19711},
{C_text("f_19719:core_2escm"),(void*)f_19719},
{C_text("f_19723:core_2escm"),(void*)f_19723},
{C_text("f_19727:core_2escm"),(void*)f_19727},
{C_text("f_19731:core_2escm"),(void*)f_19731},
{C_text("f_19759:core_2escm"),(void*)f_19759},
{C_text("f_19766:core_2escm"),(void*)f_19766},
{C_text("f_19771:core_2escm"),(void*)f_19771},
{C_text("f_19776:core_2escm"),(void*)f_19776},
{C_text("f_19780:core_2escm"),(void*)f_19780},
{C_text("f_19783:core_2escm"),(void*)f_19783},
{C_text("f_19786:core_2escm"),(void*)f_19786},
{C_text("f_19797:core_2escm"),(void*)f_19797},
{C_text("f_19803:core_2escm"),(void*)f_19803},
{C_text("f_19817:core_2escm"),(void*)f_19817},
{C_text("f_19827:core_2escm"),(void*)f_19827},
{C_text("f_19829:core_2escm"),(void*)f_19829},
{C_text("f_19854:core_2escm"),(void*)f_19854},
{C_text("f_19914:core_2escm"),(void*)f_19914},
{C_text("f_19918:core_2escm"),(void*)f_19918},
{C_text("f_19921:core_2escm"),(void*)f_19921},
{C_text("f_19924:core_2escm"),(void*)f_19924},
{C_text("f_19933:core_2escm"),(void*)f_19933},
{C_text("f_19945:core_2escm"),(void*)f_19945},
{C_text("f_19951:core_2escm"),(void*)f_19951},
{C_text("f_19967:core_2escm"),(void*)f_19967},
{C_text("f_19970:core_2escm"),(void*)f_19970},
{C_text("f_19973:core_2escm"),(void*)f_19973},
{C_text("f_19976:core_2escm"),(void*)f_19976},
{C_text("f_19989:core_2escm"),(void*)f_19989},
{C_text("f_20002:core_2escm"),(void*)f_20002},
{C_text("f_20012:core_2escm"),(void*)f_20012},
{C_text("f_20053:core_2escm"),(void*)f_20053},
{C_text("f_20060:core_2escm"),(void*)f_20060},
{C_text("f_20064:core_2escm"),(void*)f_20064},
{C_text("f_20076:core_2escm"),(void*)f_20076},
{C_text("f_20079:core_2escm"),(void*)f_20079},
{C_text("f_20097:core_2escm"),(void*)f_20097},
{C_text("f_20101:core_2escm"),(void*)f_20101},
{C_text("f_20113:core_2escm"),(void*)f_20113},
{C_text("f_20117:core_2escm"),(void*)f_20117},
{C_text("f_20129:core_2escm"),(void*)f_20129},
{C_text("f_20140:core_2escm"),(void*)f_20140},
{C_text("f_20157:core_2escm"),(void*)f_20157},
{C_text("f_20161:core_2escm"),(void*)f_20161},
{C_text("f_20173:core_2escm"),(void*)f_20173},
{C_text("f_20182:core_2escm"),(void*)f_20182},
{C_text("f_20185:core_2escm"),(void*)f_20185},
{C_text("f_20191:core_2escm"),(void*)f_20191},
{C_text("f_20197:core_2escm"),(void*)f_20197},
{C_text("f_20203:core_2escm"),(void*)f_20203},
{C_text("f_20206:core_2escm"),(void*)f_20206},
{C_text("f_20221:core_2escm"),(void*)f_20221},
{C_text("f_20226:core_2escm"),(void*)f_20226},
{C_text("f_20234:core_2escm"),(void*)f_20234},
{C_text("f_20240:core_2escm"),(void*)f_20240},
{C_text("f_20243:core_2escm"),(void*)f_20243},
{C_text("f_20254:core_2escm"),(void*)f_20254},
{C_text("f_20258:core_2escm"),(void*)f_20258},
{C_text("f_20262:core_2escm"),(void*)f_20262},
{C_text("f_20270:core_2escm"),(void*)f_20270},
{C_text("f_20277:core_2escm"),(void*)f_20277},
{C_text("f_20283:core_2escm"),(void*)f_20283},
{C_text("f_20308:core_2escm"),(void*)f_20308},
{C_text("f_20327:core_2escm"),(void*)f_20327},
{C_text("f_20330:core_2escm"),(void*)f_20330},
{C_text("f_20340:core_2escm"),(void*)f_20340},
{C_text("f_20357:core_2escm"),(void*)f_20357},
{C_text("f_20367:core_2escm"),(void*)f_20367},
{C_text("f_20369:core_2escm"),(void*)f_20369},
{C_text("f_20395:core_2escm"),(void*)f_20395},
{C_text("f_20405:core_2escm"),(void*)f_20405},
{C_text("f_20430:core_2escm"),(void*)f_20430},
{C_text("f_20457:core_2escm"),(void*)f_20457},
{C_text("f_20462:core_2escm"),(void*)f_20462},
{C_text("f_20478:core_2escm"),(void*)f_20478},
{C_text("f_20493:core_2escm"),(void*)f_20493},
{C_text("f_20536:core_2escm"),(void*)f_20536},
{C_text("f_20542:core_2escm"),(void*)f_20542},
{C_text("f_20570:core_2escm"),(void*)f_20570},
{C_text("f_20618:core_2escm"),(void*)f_20618},
{C_text("f_20643:core_2escm"),(void*)f_20643},
{C_text("f_20652:core_2escm"),(void*)f_20652},
{C_text("f_20671:core_2escm"),(void*)f_20671},
{C_text("f_20674:core_2escm"),(void*)f_20674},
{C_text("f_20677:core_2escm"),(void*)f_20677},
{C_text("f_20680:core_2escm"),(void*)f_20680},
{C_text("f_20684:core_2escm"),(void*)f_20684},
{C_text("f_20691:core_2escm"),(void*)f_20691},
{C_text("f_20706:core_2escm"),(void*)f_20706},
{C_text("f_20710:core_2escm"),(void*)f_20710},
{C_text("f_20722:core_2escm"),(void*)f_20722},
{C_text("f_20743:core_2escm"),(void*)f_20743},
{C_text("f_20747:core_2escm"),(void*)f_20747},
{C_text("f_20758:core_2escm"),(void*)f_20758},
{C_text("f_20773:core_2escm"),(void*)f_20773},
{C_text("f_20777:core_2escm"),(void*)f_20777},
{C_text("f_20792:core_2escm"),(void*)f_20792},
{C_text("f_20825:core_2escm"),(void*)f_20825},
{C_text("f_20846:core_2escm"),(void*)f_20846},
{C_text("f_20857:core_2escm"),(void*)f_20857},
{C_text("f_20861:core_2escm"),(void*)f_20861},
{C_text("f_21100:core_2escm"),(void*)f_21100},
{C_text("f_21105:core_2escm"),(void*)f_21105},
{C_text("f_21117:core_2escm"),(void*)f_21117},
{C_text("f_21142:core_2escm"),(void*)f_21142},
{C_text("f_21151:core_2escm"),(void*)f_21151},
{C_text("f_21158:core_2escm"),(void*)f_21158},
{C_text("f_21162:core_2escm"),(void*)f_21162},
{C_text("f_21178:core_2escm"),(void*)f_21178},
{C_text("f_21189:core_2escm"),(void*)f_21189},
{C_text("f_21192:core_2escm"),(void*)f_21192},
{C_text("f_21195:core_2escm"),(void*)f_21195},
{C_text("f_21198:core_2escm"),(void*)f_21198},
{C_text("f_21201:core_2escm"),(void*)f_21201},
{C_text("f_21204:core_2escm"),(void*)f_21204},
{C_text("f_21207:core_2escm"),(void*)f_21207},
{C_text("f_21232:core_2escm"),(void*)f_21232},
{C_text("f_21241:core_2escm"),(void*)f_21241},
{C_text("f_21259:core_2escm"),(void*)f_21259},
{C_text("f_21268:core_2escm"),(void*)f_21268},
{C_text("f_21277:core_2escm"),(void*)f_21277},
{C_text("f_21286:core_2escm"),(void*)f_21286},
{C_text("f_21295:core_2escm"),(void*)f_21295},
{C_text("f_21304:core_2escm"),(void*)f_21304},
{C_text("f_21322:core_2escm"),(void*)f_21322},
{C_text("f_21331:core_2escm"),(void*)f_21331},
{C_text("f_21340:core_2escm"),(void*)f_21340},
{C_text("f_21349:core_2escm"),(void*)f_21349},
{C_text("f_21358:core_2escm"),(void*)f_21358},
{C_text("f_21367:core_2escm"),(void*)f_21367},
{C_text("f_21376:core_2escm"),(void*)f_21376},
{C_text("f_21380:core_2escm"),(void*)f_21380},
{C_text("f_21382:core_2escm"),(void*)f_21382},
{C_text("f_21386:core_2escm"),(void*)f_21386},
{C_text("f_21390:core_2escm"),(void*)f_21390},
{C_text("f_21415:core_2escm"),(void*)f_21415},
{C_text("f_21426:core_2escm"),(void*)f_21426},
{C_text("f_21431:core_2escm"),(void*)f_21431},
{C_text("f_21435:core_2escm"),(void*)f_21435},
{C_text("f_21438:core_2escm"),(void*)f_21438},
{C_text("f_21441:core_2escm"),(void*)f_21441},
{C_text("f_21452:core_2escm"),(void*)f_21452},
{C_text("f_21463:core_2escm"),(void*)f_21463},
{C_text("f_21470:core_2escm"),(void*)f_21470},
{C_text("f_21479:core_2escm"),(void*)f_21479},
{C_text("f_21487:core_2escm"),(void*)f_21487},
{C_text("f_21491:core_2escm"),(void*)f_21491},
{C_text("f_21494:core_2escm"),(void*)f_21494},
{C_text("f_21497:core_2escm"),(void*)f_21497},
{C_text("f_21506:core_2escm"),(void*)f_21506},
{C_text("f_21534:core_2escm"),(void*)f_21534},
{C_text("f_21545:core_2escm"),(void*)f_21545},
{C_text("f_21565:core_2escm"),(void*)f_21565},
{C_text("f_21569:core_2escm"),(void*)f_21569},
{C_text("f_21590:core_2escm"),(void*)f_21590},
{C_text("f_21611:core_2escm"),(void*)f_21611},
{C_text("f_21628:core_2escm"),(void*)f_21628},
{C_text("f_21632:core_2escm"),(void*)f_21632},
{C_text("f_21653:core_2escm"),(void*)f_21653},
{C_text("f_21657:core_2escm"),(void*)f_21657},
{C_text("f_21661:core_2escm"),(void*)f_21661},
{C_text("f_21682:core_2escm"),(void*)f_21682},
{C_text("f_21707:core_2escm"),(void*)f_21707},
{C_text("f_21723:core_2escm"),(void*)f_21723},
{C_text("f_21733:core_2escm"),(void*)f_21733},
{C_text("f_21749:core_2escm"),(void*)f_21749},
{C_text("f_21753:core_2escm"),(void*)f_21753},
{C_text("f_21762:core_2escm"),(void*)f_21762},
{C_text("f_21803:core_2escm"),(void*)f_21803},
{C_text("f_21810:core_2escm"),(void*)f_21810},
{C_text("f_21813:core_2escm"),(void*)f_21813},
{C_text("f_21816:core_2escm"),(void*)f_21816},
{C_text("f_21819:core_2escm"),(void*)f_21819},
{C_text("f_21822:core_2escm"),(void*)f_21822},
{C_text("f_21830:core_2escm"),(void*)f_21830},
{C_text("f_21859:core_2escm"),(void*)f_21859},
{C_text("f_21866:core_2escm"),(void*)f_21866},
{C_text("f_21870:core_2escm"),(void*)f_21870},
{C_text("f_21885:core_2escm"),(void*)f_21885},
{C_text("f_21908:core_2escm"),(void*)f_21908},
{C_text("f_21929:core_2escm"),(void*)f_21929},
{C_text("f_21938:core_2escm"),(void*)f_21938},
{C_text("f_21944:core_2escm"),(void*)f_21944},
{C_text("f_21969:core_2escm"),(void*)f_21969},
{C_text("f_22001:core_2escm"),(void*)f_22001},
{C_text("f_22005:core_2escm"),(void*)f_22005},
{C_text("f_22013:core_2escm"),(void*)f_22013},
{C_text("f_22021:core_2escm"),(void*)f_22021},
{C_text("f_22025:core_2escm"),(void*)f_22025},
{C_text("f_22035:core_2escm"),(void*)f_22035},
{C_text("f_22062:core_2escm"),(void*)f_22062},
{C_text("f_22066:core_2escm"),(void*)f_22066},
{C_text("f_22085:core_2escm"),(void*)f_22085},
{C_text("f_22089:core_2escm"),(void*)f_22089},
{C_text("f_22105:core_2escm"),(void*)f_22105},
{C_text("f_22119:core_2escm"),(void*)f_22119},
{C_text("f_22125:core_2escm"),(void*)f_22125},
{C_text("f_22128:core_2escm"),(void*)f_22128},
{C_text("f_22131:core_2escm"),(void*)f_22131},
{C_text("f_22150:core_2escm"),(void*)f_22150},
{C_text("f_22158:core_2escm"),(void*)f_22158},
{C_text("f_22199:core_2escm"),(void*)f_22199},
{C_text("f_22203:core_2escm"),(void*)f_22203},
{C_text("f_22218:core_2escm"),(void*)f_22218},
{C_text("f_22222:core_2escm"),(void*)f_22222},
{C_text("f_22225:core_2escm"),(void*)f_22225},
{C_text("f_22228:core_2escm"),(void*)f_22228},
{C_text("f_22235:core_2escm"),(void*)f_22235},
{C_text("f_22255:core_2escm"),(void*)f_22255},
{C_text("f_22259:core_2escm"),(void*)f_22259},
{C_text("f_22266:core_2escm"),(void*)f_22266},
{C_text("f_22303:core_2escm"),(void*)f_22303},
{C_text("f_22310:core_2escm"),(void*)f_22310},
{C_text("f_22330:core_2escm"),(void*)f_22330},
{C_text("f_22351:core_2escm"),(void*)f_22351},
{C_text("f_22354:core_2escm"),(void*)f_22354},
{C_text("f_22361:core_2escm"),(void*)f_22361},
{C_text("f_22365:core_2escm"),(void*)f_22365},
{C_text("f_22371:core_2escm"),(void*)f_22371},
{C_text("f_22374:core_2escm"),(void*)f_22374},
{C_text("f_22377:core_2escm"),(void*)f_22377},
{C_text("f_22380:core_2escm"),(void*)f_22380},
{C_text("f_22383:core_2escm"),(void*)f_22383},
{C_text("f_22387:core_2escm"),(void*)f_22387},
{C_text("f_22398:core_2escm"),(void*)f_22398},
{C_text("f_22409:core_2escm"),(void*)f_22409},
{C_text("f_22415:core_2escm"),(void*)f_22415},
{C_text("f_22429:core_2escm"),(void*)f_22429},
{C_text("f_22439:core_2escm"),(void*)f_22439},
{C_text("f_22451:core_2escm"),(void*)f_22451},
{C_text("f_22454:core_2escm"),(void*)f_22454},
{C_text("f_22457:core_2escm"),(void*)f_22457},
{C_text("f_22476:core_2escm"),(void*)f_22476},
{C_text("f_22488:core_2escm"),(void*)f_22488},
{C_text("f_22517:core_2escm"),(void*)f_22517},
{C_text("f_22528:core_2escm"),(void*)f_22528},
{C_text("f_22538:core_2escm"),(void*)f_22538},
{C_text("f_22547:core_2escm"),(void*)f_22547},
{C_text("f_22558:core_2escm"),(void*)f_22558},
{C_text("f_22569:core_2escm"),(void*)f_22569},
{C_text("f_22572:core_2escm"),(void*)f_22572},
{C_text("f_22579:core_2escm"),(void*)f_22579},
{C_text("f_22589:core_2escm"),(void*)f_22589},
{C_text("f_22630:core_2escm"),(void*)f_22630},
{C_text("f_22697:core_2escm"),(void*)f_22697},
{C_text("f_22702:core_2escm"),(void*)f_22702},
{C_text("f_22714:core_2escm"),(void*)f_22714},
{C_text("f_22739:core_2escm"),(void*)f_22739},
{C_text("f_22748:core_2escm"),(void*)f_22748},
{C_text("f_22755:core_2escm"),(void*)f_22755},
{C_text("f_22780:core_2escm"),(void*)f_22780},
{C_text("f_22796:core_2escm"),(void*)f_22796},
{C_text("f_22805:core_2escm"),(void*)f_22805},
{C_text("f_22809:core_2escm"),(void*)f_22809},
{C_text("f_22813:core_2escm"),(void*)f_22813},
{C_text("f_22831:core_2escm"),(void*)f_22831},
{C_text("f_22833:core_2escm"),(void*)f_22833},
{C_text("f_22840:core_2escm"),(void*)f_22840},
{C_text("f_22847:core_2escm"),(void*)f_22847},
{C_text("f_22849:core_2escm"),(void*)f_22849},
{C_text("f_22866:core_2escm"),(void*)f_22866},
{C_text("f_22915:core_2escm"),(void*)f_22915},
{C_text("f_22918:core_2escm"),(void*)f_22918},
{C_text("f_22921:core_2escm"),(void*)f_22921},
{C_text("f_22924:core_2escm"),(void*)f_22924},
{C_text("f_22927:core_2escm"),(void*)f_22927},
{C_text("f_22934:core_2escm"),(void*)f_22934},
{C_text("f_22938:core_2escm"),(void*)f_22938},
{C_text("f_22942:core_2escm"),(void*)f_22942},
{C_text("f_6227:core_2escm"),(void*)f_6227},
{C_text("f_6230:core_2escm"),(void*)f_6230},
{C_text("f_6233:core_2escm"),(void*)f_6233},
{C_text("f_6236:core_2escm"),(void*)f_6236},
{C_text("f_6239:core_2escm"),(void*)f_6239},
{C_text("f_6242:core_2escm"),(void*)f_6242},
{C_text("f_6245:core_2escm"),(void*)f_6245},
{C_text("f_6248:core_2escm"),(void*)f_6248},
{C_text("f_6251:core_2escm"),(void*)f_6251},
{C_text("f_6254:core_2escm"),(void*)f_6254},
{C_text("f_6440:core_2escm"),(void*)f_6440},
{C_text("f_6454:core_2escm"),(void*)f_6454},
{C_text("f_6643:core_2escm"),(void*)f_6643},
{C_text("f_6649:core_2escm"),(void*)f_6649},
{C_text("f_6671:core_2escm"),(void*)f_6671},
{C_text("f_6683:core_2escm"),(void*)f_6683},
{C_text("f_6707:core_2escm"),(void*)f_6707},
{C_text("f_6713:core_2escm"),(void*)f_6713},
{C_text("f_6727:core_2escm"),(void*)f_6727},
{C_text("f_6735:core_2escm"),(void*)f_6735},
{C_text("f_6741:core_2escm"),(void*)f_6741},
{C_text("f_6759:core_2escm"),(void*)f_6759},
{C_text("f_6763:core_2escm"),(void*)f_6763},
{C_text("f_6769:core_2escm"),(void*)f_6769},
{C_text("f_6782:core_2escm"),(void*)f_6782},
{C_text("f_6796:core_2escm"),(void*)f_6796},
{C_text("f_6844:core_2escm"),(void*)f_6844},
{C_text("f_6858:core_2escm"),(void*)f_6858},
{C_text("f_6871:core_2escm"),(void*)f_6871},
{C_text("f_6883:core_2escm"),(void*)f_6883},
{C_text("f_6892:core_2escm"),(void*)f_6892},
{C_text("f_6900:core_2escm"),(void*)f_6900},
{C_text("f_6907:core_2escm"),(void*)f_6907},
{C_text("f_6921:core_2escm"),(void*)f_6921},
{C_text("f_6936:core_2escm"),(void*)f_6936},
{C_text("f_6944:core_2escm"),(void*)f_6944},
{C_text("f_6948:core_2escm"),(void*)f_6948},
{C_text("f_6952:core_2escm"),(void*)f_6952},
{C_text("f_6970:core_2escm"),(void*)f_6970},
{C_text("f_6992:core_2escm"),(void*)f_6992},
{C_text("f_7009:core_2escm"),(void*)f_7009},
{C_text("f_7049:core_2escm"),(void*)f_7049},
{C_text("f_7074:core_2escm"),(void*)f_7074},
{C_text("f_7087:core_2escm"),(void*)f_7087},
{C_text("f_7102:core_2escm"),(void*)f_7102},
{C_text("f_7108:core_2escm"),(void*)f_7108},
{C_text("f_7143:core_2escm"),(void*)f_7143},
{C_text("f_7149:core_2escm"),(void*)f_7149},
{C_text("f_7171:core_2escm"),(void*)f_7171},
{C_text("f_7182:core_2escm"),(void*)f_7182},
{C_text("f_7188:core_2escm"),(void*)f_7188},
{C_text("f_7194:core_2escm"),(void*)f_7194},
{C_text("f_7219:core_2escm"),(void*)f_7219},
{C_text("f_7247:core_2escm"),(void*)f_7247},
{C_text("f_7261:core_2escm"),(void*)f_7261},
{C_text("f_7267:core_2escm"),(void*)f_7267},
{C_text("f_7273:core_2escm"),(void*)f_7273},
{C_text("f_7279:core_2escm"),(void*)f_7279},
{C_text("f_7486:core_2escm"),(void*)f_7486},
{C_text("f_7492:core_2escm"),(void*)f_7492},
{C_text("f_7526:core_2escm"),(void*)f_7526},
{C_text("f_7622:core_2escm"),(void*)f_7622},
{C_text("f_7626:core_2escm"),(void*)f_7626},
{C_text("f_7629:core_2escm"),(void*)f_7629},
{C_text("f_7632:core_2escm"),(void*)f_7632},
{C_text("f_7635:core_2escm"),(void*)f_7635},
{C_text("f_7638:core_2escm"),(void*)f_7638},
{C_text("f_7648:core_2escm"),(void*)f_7648},
{C_text("f_7655:core_2escm"),(void*)f_7655},
{C_text("f_7662:core_2escm"),(void*)f_7662},
{C_text("f_7664:core_2escm"),(void*)f_7664},
{C_text("f_7668:core_2escm"),(void*)f_7668},
{C_text("f_7673:core_2escm"),(void*)f_7673},
{C_text("f_7675:core_2escm"),(void*)f_7675},
{C_text("f_7717:core_2escm"),(void*)f_7717},
{C_text("f_7749:core_2escm"),(void*)f_7749},
{C_text("f_7759:core_2escm"),(void*)f_7759},
{C_text("f_7772:core_2escm"),(void*)f_7772},
{C_text("f_7775:core_2escm"),(void*)f_7775},
{C_text("f_7788:core_2escm"),(void*)f_7788},
{C_text("f_7810:core_2escm"),(void*)f_7810},
{C_text("f_7814:core_2escm"),(void*)f_7814},
{C_text("f_7822:core_2escm"),(void*)f_7822},
{C_text("f_7828:core_2escm"),(void*)f_7828},
{C_text("f_7835:core_2escm"),(void*)f_7835},
{C_text("f_7842:core_2escm"),(void*)f_7842},
{C_text("f_7844:core_2escm"),(void*)f_7844},
{C_text("f_7848:core_2escm"),(void*)f_7848},
{C_text("f_7851:core_2escm"),(void*)f_7851},
{C_text("f_7855:core_2escm"),(void*)f_7855},
{C_text("f_7857:core_2escm"),(void*)f_7857},
{C_text("f_7859:core_2escm"),(void*)f_7859},
{C_text("f_7866:core_2escm"),(void*)f_7866},
{C_text("f_7869:core_2escm"),(void*)f_7869},
{C_text("f_7884:core_2escm"),(void*)f_7884},
{C_text("f_7888:core_2escm"),(void*)f_7888},
{C_text("f_7893:core_2escm"),(void*)f_7893},
{C_text("f_7898:core_2escm"),(void*)f_7898},
{C_text("f_7906:core_2escm"),(void*)f_7906},
{C_text("f_7908:core_2escm"),(void*)f_7908},
{C_text("f_7913:core_2escm"),(void*)f_7913},
{C_text("f_7930:core_2escm"),(void*)f_7930},
{C_text("f_7940:core_2escm"),(void*)f_7940},
{C_text("f_7979:core_2escm"),(void*)f_7979},
{C_text("f_8011:core_2escm"),(void*)f_8011},
{C_text("f_8022:core_2escm"),(void*)f_8022},
{C_text("f_8026:core_2escm"),(void*)f_8026},
{C_text("f_8029:core_2escm"),(void*)f_8029},
{C_text("f_8041:core_2escm"),(void*)f_8041},
{C_text("f_8045:core_2escm"),(void*)f_8045},
{C_text("f_8055:core_2escm"),(void*)f_8055},
{C_text("f_8059:core_2escm"),(void*)f_8059},
{C_text("f_8073:core_2escm"),(void*)f_8073},
{C_text("f_8080:core_2escm"),(void*)f_8080},
{C_text("f_8090:core_2escm"),(void*)f_8090},
{C_text("f_8094:core_2escm"),(void*)f_8094},
{C_text("f_8112:core_2escm"),(void*)f_8112},
{C_text("f_8119:core_2escm"),(void*)f_8119},
{C_text("f_8129:core_2escm"),(void*)f_8129},
{C_text("f_8133:core_2escm"),(void*)f_8133},
{C_text("f_8164:core_2escm"),(void*)f_8164},
{C_text("f_8175:core_2escm"),(void*)f_8175},
{C_text("f_8179:core_2escm"),(void*)f_8179},
{C_text("f_8182:core_2escm"),(void*)f_8182},
{C_text("f_8188:core_2escm"),(void*)f_8188},
{C_text("f_8191:core_2escm"),(void*)f_8191},
{C_text("f_8194:core_2escm"),(void*)f_8194},
{C_text("f_8218:core_2escm"),(void*)f_8218},
{C_text("f_8224:core_2escm"),(void*)f_8224},
{C_text("f_8227:core_2escm"),(void*)f_8227},
{C_text("f_8230:core_2escm"),(void*)f_8230},
{C_text("f_8233:core_2escm"),(void*)f_8233},
{C_text("f_8239:core_2escm"),(void*)f_8239},
{C_text("f_8242:core_2escm"),(void*)f_8242},
{C_text("f_8245:core_2escm"),(void*)f_8245},
{C_text("f_8260:core_2escm"),(void*)f_8260},
{C_text("f_8265:core_2escm"),(void*)f_8265},
{C_text("f_8269:core_2escm"),(void*)f_8269},
{C_text("f_8275:core_2escm"),(void*)f_8275},
{C_text("f_8280:core_2escm"),(void*)f_8280},
{C_text("f_8290:core_2escm"),(void*)f_8290},
{C_text("f_8305:core_2escm"),(void*)f_8305},
{C_text("f_8314:core_2escm"),(void*)f_8314},
{C_text("f_8324:core_2escm"),(void*)f_8324},
{C_text("f_8330:core_2escm"),(void*)f_8330},
{C_text("f_8337:core_2escm"),(void*)f_8337},
{C_text("f_8361:core_2escm"),(void*)f_8361},
{C_text("f_8376:core_2escm"),(void*)f_8376},
{C_text("f_8382:core_2escm"),(void*)f_8382},
{C_text("f_8385:core_2escm"),(void*)f_8385},
{C_text("f_8389:core_2escm"),(void*)f_8389},
{C_text("f_8392:core_2escm"),(void*)f_8392},
{C_text("f_8395:core_2escm"),(void*)f_8395},
{C_text("f_8407:core_2escm"),(void*)f_8407},
{C_text("f_8411:core_2escm"),(void*)f_8411},
{C_text("f_8439:core_2escm"),(void*)f_8439},
{C_text("f_8443:core_2escm"),(void*)f_8443},
{C_text("f_8447:core_2escm"),(void*)f_8447},
{C_text("f_8485:core_2escm"),(void*)f_8485},
{C_text("f_8518:core_2escm"),(void*)f_8518},
{C_text("f_8526:core_2escm"),(void*)f_8526},
{C_text("f_8543:core_2escm"),(void*)f_8543},
{C_text("f_8549:core_2escm"),(void*)f_8549},
{C_text("f_8552:core_2escm"),(void*)f_8552},
{C_text("f_8553:core_2escm"),(void*)f_8553},
{C_text("f_8567:core_2escm"),(void*)f_8567},
{C_text("f_8571:core_2escm"),(void*)f_8571},
{C_text("f_8585:core_2escm"),(void*)f_8585},
{C_text("f_8589:core_2escm"),(void*)f_8589},
{C_text("f_8593:core_2escm"),(void*)f_8593},
{C_text("f_8626:core_2escm"),(void*)f_8626},
{C_text("f_8631:core_2escm"),(void*)f_8631},
{C_text("f_8639:core_2escm"),(void*)f_8639},
{C_text("f_8643:core_2escm"),(void*)f_8643},
{C_text("f_8660:core_2escm"),(void*)f_8660},
{C_text("f_8662:core_2escm"),(void*)f_8662},
{C_text("f_8687:core_2escm"),(void*)f_8687},
{C_text("f_8710:core_2escm"),(void*)f_8710},
{C_text("f_8722:core_2escm"),(void*)f_8722},
{C_text("f_8729:core_2escm"),(void*)f_8729},
{C_text("f_8732:core_2escm"),(void*)f_8732},
{C_text("f_8741:core_2escm"),(void*)f_8741},
{C_text("f_8754:core_2escm"),(void*)f_8754},
{C_text("f_8774:core_2escm"),(void*)f_8774},
{C_text("f_8778:core_2escm"),(void*)f_8778},
{C_text("f_8782:core_2escm"),(void*)f_8782},
{C_text("f_8795:core_2escm"),(void*)f_8795},
{C_text("f_8799:core_2escm"),(void*)f_8799},
{C_text("f_8816:core_2escm"),(void*)f_8816},
{C_text("f_8835:core_2escm"),(void*)f_8835},
{C_text("f_8842:core_2escm"),(void*)f_8842},
{C_text("f_8855:core_2escm"),(void*)f_8855},
{C_text("f_8859:core_2escm"),(void*)f_8859},
{C_text("f_8880:core_2escm"),(void*)f_8880},
{C_text("f_8889:core_2escm"),(void*)f_8889},
{C_text("f_8892:core_2escm"),(void*)f_8892},
{C_text("f_8895:core_2escm"),(void*)f_8895},
{C_text("f_8901:core_2escm"),(void*)f_8901},
{C_text("f_8909:core_2escm"),(void*)f_8909},
{C_text("f_8917:core_2escm"),(void*)f_8917},
{C_text("f_8932:core_2escm"),(void*)f_8932},
{C_text("f_8936:core_2escm"),(void*)f_8936},
{C_text("f_8938:core_2escm"),(void*)f_8938},
{C_text("f_8942:core_2escm"),(void*)f_8942},
{C_text("f_8946:core_2escm"),(void*)f_8946},
{C_text("f_8949:core_2escm"),(void*)f_8949},
{C_text("f_8955:core_2escm"),(void*)f_8955},
{C_text("f_8963:core_2escm"),(void*)f_8963},
{C_text("f_8967:core_2escm"),(void*)f_8967},
{C_text("f_8973:core_2escm"),(void*)f_8973},
{C_text("f_8977:core_2escm"),(void*)f_8977},
{C_text("f_8980:core_2escm"),(void*)f_8980},
{C_text("f_8983:core_2escm"),(void*)f_8983},
{C_text("f_9012:core_2escm"),(void*)f_9012},
{C_text("f_9033:core_2escm"),(void*)f_9033},
{C_text("f_9035:core_2escm"),(void*)f_9035},
{C_text("f_9060:core_2escm"),(void*)f_9060},
{C_text("f_9108:core_2escm"),(void*)f_9108},
{C_text("f_9112:core_2escm"),(void*)f_9112},
{C_text("f_9132:core_2escm"),(void*)f_9132},
{C_text("f_9146:core_2escm"),(void*)f_9146},
{C_text("f_9180:core_2escm"),(void*)f_9180},
{C_text("f_9224:core_2escm"),(void*)f_9224},
{C_text("f_9233:core_2escm"),(void*)f_9233},
{C_text("f_9262:core_2escm"),(void*)f_9262},
{C_text("f_9275:core_2escm"),(void*)f_9275},
{C_text("f_9293:core_2escm"),(void*)f_9293},
{C_text("f_9297:core_2escm"),(void*)f_9297},
{C_text("f_9309:core_2escm"),(void*)f_9309},
{C_text("f_9323:core_2escm"),(void*)f_9323},
{C_text("f_9371:core_2escm"),(void*)f_9371},
{C_text("f_9419:core_2escm"),(void*)f_9419},
{C_text("f_9453:core_2escm"),(void*)f_9453},
{C_text("f_9478:core_2escm"),(void*)f_9478},
{C_text("f_9498:core_2escm"),(void*)f_9498},
{C_text("f_9506:core_2escm"),(void*)f_9506},
{C_text("f_9514:core_2escm"),(void*)f_9514},
{C_text("f_9517:core_2escm"),(void*)f_9517},
{C_text("f_9522:core_2escm"),(void*)f_9522},
{C_text("f_9527:core_2escm"),(void*)f_9527},
{C_text("f_9537:core_2escm"),(void*)f_9537},
{C_text("f_9542:core_2escm"),(void*)f_9542},
{C_text("f_9567:core_2escm"),(void*)f_9567},
{C_text("f_9588:core_2escm"),(void*)f_9588},
{C_text("f_9593:core_2escm"),(void*)f_9593},
{C_text("f_9603:core_2escm"),(void*)f_9603},
{C_text("f_9606:core_2escm"),(void*)f_9606},
{C_text("f_9612:core_2escm"),(void*)f_9612},
{C_text("f_9615:core_2escm"),(void*)f_9615},
{C_text("f_9618:core_2escm"),(void*)f_9618},
{C_text("f_9624:core_2escm"),(void*)f_9624},
{C_text("f_9633:core_2escm"),(void*)f_9633},
{C_text("f_9639:core_2escm"),(void*)f_9639},
{C_text("f_9646:core_2escm"),(void*)f_9646},
{C_text("f_9677:core_2escm"),(void*)f_9677},
{C_text("f_9688:core_2escm"),(void*)f_9688},
{C_text("f_9690:core_2escm"),(void*)f_9690},
{C_text("f_9694:core_2escm"),(void*)f_9694},
{C_text("f_9698:core_2escm"),(void*)f_9698},
{C_text("f_9701:core_2escm"),(void*)f_9701},
{C_text("f_9707:core_2escm"),(void*)f_9707},
{C_text("f_9711:core_2escm"),(void*)f_9711},
{C_text("f_9716:core_2escm"),(void*)f_9716},
{C_text("f_9721:core_2escm"),(void*)f_9721},
{C_text("f_9729:core_2escm"),(void*)f_9729},
{C_text("f_9733:core_2escm"),(void*)f_9733},
{C_text("f_9746:core_2escm"),(void*)f_9746},
{C_text("f_9751:core_2escm"),(void*)f_9751},
{C_text("f_9755:core_2escm"),(void*)f_9755},
{C_text("f_9758:core_2escm"),(void*)f_9758},
{C_text("f_9763:core_2escm"),(void*)f_9763},
{C_text("f_9765:core_2escm"),(void*)f_9765},
{C_text("f_9790:core_2escm"),(void*)f_9790},
{C_text("f_9800:core_2escm"),(void*)f_9800},
{C_text("f_9805:core_2escm"),(void*)f_9805},
{C_text("f_9813:core_2escm"),(void*)f_9813},
{C_text("f_9815:core_2escm"),(void*)f_9815},
{C_text("f_9827:core_2escm"),(void*)f_9827},
{C_text("f_9832:core_2escm"),(void*)f_9832},
{C_text("f_9836:core_2escm"),(void*)f_9836},
{C_text("f_9840:core_2escm"),(void*)f_9840},
{C_text("f_9843:core_2escm"),(void*)f_9843},
{C_text("f_9849:core_2escm"),(void*)f_9849},
{C_text("f_9853:core_2escm"),(void*)f_9853},
{C_text("f_9863:core_2escm"),(void*)f_9863},
{C_text("f_9869:core_2escm"),(void*)f_9869},
{C_text("f_9873:core_2escm"),(void*)f_9873},
{C_text("f_9876:core_2escm"),(void*)f_9876},
{C_text("f_9894:core_2escm"),(void*)f_9894},
{C_text("f_9898:core_2escm"),(void*)f_9898},
{C_text("f_9902:core_2escm"),(void*)f_9902},
{C_text("f_9917:core_2escm"),(void*)f_9917},
{C_text("f_9921:core_2escm"),(void*)f_9921},
{C_text("f_9923:core_2escm"),(void*)f_9923},
{C_text("f_9977:core_2escm"),(void*)f_9977},
{C_text("f_9981:core_2escm"),(void*)f_9981},
{C_text("f_9996:core_2escm"),(void*)f_9996},
{C_text("f_9999:core_2escm"),(void*)f_9999},
{C_text("toplevel:core_2escm"),(void*)C_compiler_toplevel},
{C_text("va26246:core_2escm"),(void*)va26246},
{NULL,NULL}};
#endif

static C_PTABLE_ENTRY *create_ptable(void){
#ifdef C_ENABLE_PTABLES
return ptable;
#else
return NULL;
#endif
}

/*
o|hiding unexported module binding: chicken.compiler.core#d 
o|hiding unexported module binding: chicken.compiler.core#d 
o|hiding unexported module binding: chicken.compiler.core#partition 
o|hiding unexported module binding: chicken.compiler.core#span 
o|hiding unexported module binding: chicken.compiler.core#take 
o|hiding unexported module binding: chicken.compiler.core#drop 
o|hiding unexported module binding: chicken.compiler.core#split-at 
o|hiding unexported module binding: chicken.compiler.core#append-map 
o|hiding unexported module binding: chicken.compiler.core#every 
o|hiding unexported module binding: chicken.compiler.core#any 
o|hiding unexported module binding: chicken.compiler.core#cons* 
o|hiding unexported module binding: chicken.compiler.core#concatenate 
o|hiding unexported module binding: chicken.compiler.core#delete 
o|hiding unexported module binding: chicken.compiler.core#first 
o|hiding unexported module binding: chicken.compiler.core#second 
o|hiding unexported module binding: chicken.compiler.core#third 
o|hiding unexported module binding: chicken.compiler.core#fourth 
o|hiding unexported module binding: chicken.compiler.core#fifth 
o|hiding unexported module binding: chicken.compiler.core#delete-duplicates 
o|hiding unexported module binding: chicken.compiler.core#alist-cons 
o|hiding unexported module binding: chicken.compiler.core#filter 
o|hiding unexported module binding: chicken.compiler.core#filter-map 
o|hiding unexported module binding: chicken.compiler.core#remove 
o|hiding unexported module binding: chicken.compiler.core#unzip1 
o|hiding unexported module binding: chicken.compiler.core#last 
o|hiding unexported module binding: chicken.compiler.core#list-index 
o|hiding unexported module binding: chicken.compiler.core#lset-adjoin/eq? 
o|hiding unexported module binding: chicken.compiler.core#lset-difference/eq? 
o|hiding unexported module binding: chicken.compiler.core#lset-union/eq? 
o|hiding unexported module binding: chicken.compiler.core#lset-intersection/eq? 
o|hiding unexported module binding: chicken.compiler.core#list-tabulate 
o|hiding unexported module binding: chicken.compiler.core#lset<=/eq? 
o|hiding unexported module binding: chicken.compiler.core#lset=/eq? 
o|hiding unexported module binding: chicken.compiler.core#length+ 
o|hiding unexported module binding: chicken.compiler.core#find 
o|hiding unexported module binding: chicken.compiler.core#find-tail 
o|hiding unexported module binding: chicken.compiler.core#iota 
o|hiding unexported module binding: chicken.compiler.core#make-list 
o|hiding unexported module binding: chicken.compiler.core#posq 
o|hiding unexported module binding: chicken.compiler.core#posv 
o|hiding unexported module binding: chicken.compiler.core#safe-globals-flag 
o|hiding unexported module binding: chicken.compiler.core#original-program-size 
o|hiding unexported module binding: chicken.compiler.core#current-program-size 
o|hiding unexported module binding: chicken.compiler.core#current-analysis-database-size 
o|hiding unexported module binding: chicken.compiler.core#direct-call-ids 
o|hiding unexported module binding: chicken.compiler.core#foreign-variables 
o|hiding unexported module binding: chicken.compiler.core#external-to-pointer 
o|hiding unexported module binding: chicken.compiler.core#location-pointer-map 
o|hiding unexported module binding: chicken.compiler.core#pending-canonicalizations 
o|hiding unexported module binding: chicken.compiler.core#defconstant-bindings 
o|hiding unexported module binding: chicken.compiler.core#callback-names 
o|hiding unexported module binding: chicken.compiler.core#toplevel-scope 
o|hiding unexported module binding: chicken.compiler.core#toplevel-lambda-id 
o|hiding unexported module binding: chicken.compiler.core#unlikely-variables 
o|hiding unexported module binding: chicken.compiler.core#process-declaration 
o|hiding unexported module binding: chicken.compiler.core#foreign-stub 
o|hiding unexported module binding: chicken.compiler.core#make-foreign-stub 
o|hiding unexported module binding: chicken.compiler.core#foreign-stub? 
o|hiding unexported module binding: chicken.compiler.core#create-foreign-stub 
o|hiding unexported module binding: chicken.compiler.core#expand-foreign-lambda 
o|hiding unexported module binding: chicken.compiler.core#expand-foreign-lambda* 
o|hiding unexported module binding: chicken.compiler.core#expand-foreign-primitive 
o|hiding unexported module binding: chicken.compiler.core#lambda-literal 
o|hiding unexported module binding: chicken.compiler.core#make-lambda-literal 
o|hiding unexported module binding: chicken.compiler.core#lambda-literal? 
o|hiding unexported module binding: chicken.compiler.core#lambda-literal-arguments 
o|hiding unexported module binding: chicken.compiler.core#lambda-literal-directly-called 
S|applied compiler syntax:
S|  chicken.base#o		1
S|  chicken.format#sprintf		19
S|  scheme#for-each		30
S|  chicken.base#foldl		3
S|  scheme#map		42
S|  chicken.base#foldr		3
o|eliminated procedure checks: 504 
o|specializations:
o|  3 (scheme#positive? *)
o|  1 (chicken.base#sub1 *)
o|  1 (scheme#integer? *)
o|  17 (chicken.base#add1 *)
o|  2 (scheme#memq * list)
o|  3 (scheme#zero? *)
o|  2 (scheme#>= fixnum fixnum)
o|  1 (##sys#call-with-values (procedure () *) *)
o|  1 (chicken.base#current-error-port)
o|  1 (scheme#caddr (pair * (pair * pair)))
o|  4 (scheme#cadr (pair * pair))
o|  13 (scheme#cddr (pair * pair))
o|  2 (scheme#string-append string string)
o|  19 (##sys#check-output-port * * *)
o|  6 (scheme#= fixnum fixnum)
o|  3 (scheme#length list)
o|  3 (scheme#cdar (pair pair *))
o|  240 (scheme#eqv? * (or eof null fixnum char boolean symbol keyword))
o|  1 (scheme#eqv? * *)
o|  8 (##sys#check-list (or pair list) *)
o|  85 (scheme#cdr pair)
o|  30 (scheme#car pair)
o|  1 (##sys#debug-mode?)
(o e)|safe calls: 2236 
(o e)|assignments to immediate values: 41 
o|safe globals: (chicken.compiler.core#prepare-for-code-generation chicken.compiler.core#lambda-literal-direct chicken.compiler.core#lambda-literal-body chicken.compiler.core#lambda-literal-rest-argument-mode chicken.compiler.core#lambda-literal-customizable chicken.compiler.core#lambda-literal-looping chicken.compiler.core#lambda-literal-closure-size chicken.compiler.core#lambda-literal-directly-called chicken.compiler.core#lambda-literal-allocated chicken.compiler.core#lambda-literal-callee-signatures chicken.compiler.core#lambda-literal-float-temporaries chicken.compiler.core#lambda-literal-temporaries chicken.compiler.core#lambda-literal-rest-argument chicken.compiler.core#lambda-literal-argument-count chicken.compiler.core#lambda-literal-arguments chicken.compiler.core#lambda-literal-external chicken.compiler.core#lambda-literal-id chicken.compiler.core#lambda-literal? chicken.compiler.core#make-lambda-literal chicken.compiler.core#lambda-literal chicken.compiler.core#perform-closure-conversion chicken.compiler.core#analyze-expression chicken.compiler.core#perform-cps-conversion chicken.compiler.core#expand-foreign-primitive chicken.compiler.core#expand-foreign-lambda* chicken.compiler.core#expand-foreign-lambda chicken.compiler.core#create-foreign-stub chicken.compiler.core#foreign-stub-callback chicken.compiler.core#foreign-stub-cps chicken.compiler.core#foreign-stub-body chicken.compiler.core#foreign-stub-argument-names chicken.compiler.core#foreign-stub-argument-types chicken.compiler.core#foreign-stub-name chicken.compiler.core#foreign-stub-return-type chicken.compiler.core#foreign-stub-id chicken.compiler.core#foreign-stub? chicken.compiler.core#make-foreign-stub chicken.compiler.core#foreign-stub chicken.compiler.core#build-toplevel-procedure chicken.compiler.core#process-declaration chicken.compiler.core#canonicalize-expression chicken.compiler.core#compute-database-statistics chicken.compiler.core#initialize-compiler chicken.compiler.core#internal-bindings chicken.compiler.core#default-standard-bindings chicken.compiler.core#default-extended-bindings chicken.compiler.core#unlikely-variables chicken.compiler.core#used-libraries chicken.compiler.core#linked-libraries chicken.compiler.core#required-extensions chicken.compiler.core#toplevel-lambda-id chicken.compiler.core#toplevel-scope chicken.compiler.core#callback-names chicken.compiler.core#defconstant-bindings chicken.compiler.core#pending-canonicalizations chicken.compiler.core#location-pointer-map chicken.compiler.core#external-to-pointer chicken.compiler.core#external-variables chicken.compiler.core#foreign-lambda-stubs chicken.compiler.core#foreign-variables chicken.compiler.core#first-analysis chicken.compiler.core#direct-call-ids chicken.compiler.core#inline-substitutions-enabled chicken.compiler.core#constant-table chicken.compiler.core#inline-table chicken.compiler.core#immutable-constants chicken.compiler.core#line-number-database-2 chicken.compiler.core#current-analysis-database-size chicken.compiler.core#current-program-size chicken.compiler.core#original-program-size chicken.compiler.core#verbose-mode chicken.compiler.core#types-output-file chicken.compiler.core#emit-link-file chicken.compiler.core#static-extensions chicken.compiler.core#enable-specialization chicken.compiler.core#strict-variable-types chicken.compiler.core#bootstrap-mode chicken.compiler.core#compiler-syntax-enabled chicken.compiler.core#enable-inline-files chicken.compiler.core#inline-locally chicken.compiler.core#local-definitions chicken.compiler.core#standalone-executable chicken.compiler.core#compile-module-registration chicken.compiler.core#preserve-unchanged-import-libraries chicken.compiler.core#all-import-libraries chicken.compiler.core#import-libraries chicken.compiler.core#profiled-procedures chicken.compiler.core#undefine-shadowed-macros chicken.compiler.core#emit-closure-info chicken.compiler.core#unroll-limit chicken.compiler.core#inline-max-size chicken.compiler.core#external-protos-first chicken.compiler.core#disable-stack-overflow-checking chicken.compiler.core#explicit-use-flag chicken.compiler.core#safe-globals-flag chicken.compiler.core#no-global-procedure-checks chicken.compiler.core#no-procedure-checks chicken.compiler.core#no-argc-checks chicken.compiler.core#no-bound-checks chicken.compiler.core#emit-profile chicken.compiler.core#optimize-leaf-routines chicken.compiler.core#target-stack-size chicken.compiler.core#target-heap-size chicken.compiler.core#line-number-database-size chicken.compiler.core#block-compilation chicken.compiler.core#emit-debug-info chicken.compiler.core#emit-trace-info chicken.compiler.core#foreign-declarations chicken.compiler.core#used-units chicken.compiler.core#insert-timer-checks chicken.compiler.core#extended-bindings chicken.compiler.core#standard-bindings chicken.compiler.core#unit-name chicken.compiler.core#posv chicken.compiler.core#posq chicken.compiler.core#make-list chicken.compiler.core#iota chicken.compiler.core#find-tail chicken.compiler.core#find chicken.compiler.core#length+ chicken.compiler.core#lset=/eq? chicken.compiler.core#lset<=/eq? chicken.compiler.core#list-tabulate chicken.compiler.core#lset-intersection/eq? chicken.compiler.core#lset-union/eq? chicken.compiler.core#lset-difference/eq? chicken.compiler.core#lset-adjoin/eq? chicken.compiler.core#list-index chicken.compiler.core#last chicken.compiler.core#unzip1 chicken.compiler.core#remove chicken.compiler.core#filter-map chicken.compiler.core#filter chicken.compiler.core#alist-cons chicken.compiler.core#delete-duplicates chicken.compiler.core#fifth chicken.compiler.core#fourth chicken.compiler.core#third chicken.compiler.core#second chicken.compiler.core#first chicken.compiler.core#delete chicken.compiler.core#concatenate chicken.compiler.core#cons* chicken.compiler.core#any chicken.compiler.core#every chicken.compiler.core#append-map chicken.compiler.core#split-at chicken.compiler.core#drop chicken.compiler.core#take chicken.compiler.core#span chicken.compiler.core#partition chicken.compiler.core#d) 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#d 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#partition 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#span 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#drop 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#append-map 
o|inlining procedure: k6654 
o|inlining procedure: k6654 
o|inlining procedure: k6685 
o|inlining procedure: k6685 
o|merged explicitly consed rest parameter: xs350 
o|inlining procedure: k6715 
o|inlining procedure: k6715 
o|inlining procedure: k6743 
o|inlining procedure: k6743 
o|inlining procedure: k6771 
o|inlining procedure: k6771 
o|inlining procedure: k6902 
o|inlining procedure: k6902 
o|inlining procedure: k6894 
o|inlining procedure: k6894 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#remove 
o|inlining procedure: k7011 
o|contracted procedure: "(mini-srfi-1.scm:143) g453462" 
o|inlining procedure: k7011 
o|merged explicitly consed rest parameter: vals490 
o|inlining procedure: k7110 
o|inlining procedure: k7110 
o|merged explicitly consed rest parameter: lss501 
o|inlining procedure: k7151 
o|contracted procedure: "(mini-srfi-1.scm:164) g514515" 
o|inlining procedure: k7151 
o|merged explicitly consed rest parameter: lss523 
o|inlining procedure: k7196 
o|contracted procedure: "(mini-srfi-1.scm:171) g536537" 
o|inlining procedure: k7221 
o|contracted procedure: "(mini-srfi-1.scm:173) g552553" 
o|inlining procedure: k7237 
o|inlining procedure: k7237 
o|inlining procedure: k7221 
o|inlining procedure: k7196 
o|merged explicitly consed rest parameter: lss563 
o|inlining procedure: k7293 
o|inlining procedure: k7293 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#lset<=/eq? 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#lset=/eq? 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#length+ 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#find 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#find-tail 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#iota 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#make-list 
o|inlining procedure: k7494 
o|inlining procedure: k7494 
o|inlining procedure: k7684 
o|inlining procedure: k7684 
o|inlining procedure: k7704 
o|inlining procedure: k7704 
o|inlining procedure: k7720 
o|inlining procedure: k7720 
o|substituted constant variable: a7737 
o|substituted constant variable: a7739 
o|substituted constant variable: a7741 
o|inlining procedure: k7751 
o|inlining procedure: k7751 
o|inlining procedure: k7777 
o|inlining procedure: k7777 
o|inlining procedure: k7815 
o|inlining procedure: k7815 
o|inlining procedure: k7830 
o|inlining procedure: k7830 
o|inlining procedure: k7864 
o|inlining procedure: k7864 
o|inlining procedure: k7932 
o|contracted procedure: "(core.scm:554) g869877" 
o|inlining procedure: k7932 
o|removed side-effect free assignment to unused variable: write-to-string811 
o|inlining procedure: k7981 
o|inlining procedure: k7981 
o|inlining procedure: k7993 
o|inlining procedure: k7993 
o|substituted constant variable: a8018 
o|inlining procedure: k8033 
o|inlining procedure: k8033 
o|inlining procedure: k8056 
o|inlining procedure: k8056 
o|inlining procedure: "(core.scm:584) chicken.compiler.core#third" 
o|inlining procedure: "(core.scm:582) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:594) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:592) chicken.compiler.core#third" 
o|inlining procedure: k8109 
o|inlining procedure: k8109 
o|substituted constant variable: a8184 
o|substituted constant variable: a8185 
o|inlining procedure: k8161 
o|inlining procedure: k8161 
o|substituted constant variable: a8220 
o|substituted constant variable: a8221 
o|inlining procedure: k8332 
o|inlining procedure: k8332 
o|inlining procedure: k8350 
o|inlining procedure: k8350 
o|inlining procedure: k8396 
o|inlining procedure: k8396 
o|inlining procedure: k8427 
o|inlining procedure: k8445 
o|inlining procedure: k8445 
o|inlining procedure: k8427 
o|inlining procedure: k8490 
o|inlining procedure: k8490 
o|inlining procedure: k8555 
o|inlining procedure: k8555 
o|inlining procedure: k8535 
o|inlining procedure: k8535 
o|inlining procedure: k8664 
o|inlining procedure: k8664 
o|inlining procedure: k8702 
o|inlining procedure: k8702 
o|inlining procedure: k8742 
o|consed rest parameter at call site: "(core.scm:720) chicken.compiler.core#lset-adjoin/eq?" 2 
o|inlining procedure: k8742 
o|inlining procedure: k8783 
o|inlining procedure: k8783 
o|inlining procedure: k8821 
o|inlining procedure: k8844 
o|inlining procedure: k8844 
o|consed rest parameter at call site: "(core.scm:740) chicken.compiler.core#lset-adjoin/eq?" 2 
o|inlining procedure: k8821 
o|inlining procedure: k8985 
o|inlining procedure: k8985 
o|inlining procedure: k9037 
o|inlining procedure: k9037 
o|inlining procedure: k9068 
o|inlining procedure: k9148 
o|contracted procedure: "(core.scm:773) g12821291" 
o|inlining procedure: k9148 
o|inlining procedure: k9182 
o|contracted procedure: "(core.scm:770) g12551264" 
o|inlining procedure: k9182 
o|inlining procedure: k9068 
o|inlining procedure: k9325 
o|contracted procedure: "(core.scm:794) g14081418" 
o|inlining procedure: k9325 
o|inlining procedure: k9373 
o|inlining procedure: k9373 
o|inlining procedure: k9421 
o|contracted procedure: "(core.scm:786) g13451354" 
o|inlining procedure: k9421 
o|inlining procedure: k9455 
o|inlining procedure: k9455 
o|inlining procedure: k9486 
o|inlining procedure: k9544 
o|inlining procedure: k9544 
o|inlining procedure: k9486 
o|inlining procedure: k9625 
o|inlining procedure: k9625 
o|inlining procedure: k9644 
o|inlining procedure: k9644 
o|inlining procedure: k9656 
o|inlining procedure: k9656 
o|inlining procedure: k9668 
o|inlining procedure: k9668 
o|inlining procedure: k9679 
o|inlining procedure: k9679 
o|inlining procedure: k9767 
o|inlining procedure: k9767 
o|inlining procedure: k9819 
o|inlining procedure: k9925 
o|contracted procedure: "(core.scm:862) g15861595" 
o|inlining procedure: k9925 
o|inlining procedure: k9819 
o|inlining procedure: k10068 
o|inlining procedure: k10068 
o|inlining procedure: k10095 
o|contracted procedure: "(core.scm:878) g16251634" 
o|inlining procedure: k10095 
o|inlining procedure: k10126 
o|inlining procedure: k10126 
o|inlining procedure: k10275 
o|inlining procedure: k10275 
o|inlining procedure: k10294 
o|inlining procedure: k10294 
o|inlining procedure: k10320 
o|inlining procedure: k10421 
o|contracted procedure: "(core.scm:974) g17471754" 
o|inlining procedure: k10421 
o|inlining procedure: k10480 
o|contracted procedure: "(core.scm:984) g17651772" 
o|inlining procedure: k10480 
o|inlining procedure: k10503 
o|inlining procedure: k10503 
o|inlining procedure: k10320 
o|inlining procedure: k10597 
o|inlining procedure: k10644 
o|contracted procedure: "(core.scm:1007) g18041813" 
o|inlining procedure: k10644 
o|inlining procedure: k10597 
o|substituted constant variable: saved189018911909 
o|inlining procedure: k10723 
o|inlining procedure: k10794 
o|inlining procedure: k10794 
o|inlining procedure: k10826 
o|inlining procedure: k10826 
o|inlining procedure: k10723 
o|inlining procedure: k10846 
o|inlining procedure: k10846 
o|inlining procedure: k10866 
o|inlining procedure: k10866 
o|contracted procedure: "(core.scm:1077) emit-import-lib814" 
o|inlining procedure: k8246 
o|inlining procedure: k8246 
o|inlining procedure: k8282 
o|inlining procedure: k8282 
o|substituted constant variable: a8325 
o|inlining procedure: k10879 
o|inlining procedure: k10879 
o|inlining procedure: k10976 
o|inlining procedure: k11023 
o|inlining procedure: k11023 
o|inlining procedure: k11035 
o|inlining procedure: k11035 
o|merged explicitly consed rest parameter: args19331946 
o|consed rest parameter at call site: tmp25769 1 
o|inlining procedure: k10976 
o|inlining procedure: k11123 
o|inlining procedure: k11131 
o|inlining procedure: k11131 
o|inlining procedure: k11158 
o|inlining procedure: k11158 
o|inlining procedure: k11123 
o|inlining procedure: k11188 
o|inlining procedure: k11188 
o|inlining procedure: k11230 
o|propagated global variable: tmp18351837 chicken.compiler.core#unit-name 
o|propagated global variable: tmp18351837 chicken.compiler.core#unit-name 
o|inlining procedure: k11230 
o|inlining procedure: k11240 
o|inlining procedure: k11326 
o|inlining procedure: k11326 
o|inlining procedure: k11240 
o|substituted constant variable: a11389 
o|substituted constant variable: a11390 
o|inlining procedure: k11382 
o|inlining procedure: k11382 
o|inlining procedure: k11403 
o|inlining procedure: "(core.scm:1142) chicken.compiler.core#third" 
o|inlining procedure: "(core.scm:1137) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:1153) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:1147) chicken.compiler.core#third" 
o|inlining procedure: k11479 
o|inlining procedure: k11479 
o|inlining procedure: k11555 
o|substituted constant variable: a11582 
o|substituted constant variable: a11583 
o|substituted constant variable: a11607 
o|substituted constant variable: a11608 
o|inlining procedure: k11600 
o|inlining procedure: k11600 
o|inlining procedure: k11555 
o|substituted constant variable: a11635 
o|substituted constant variable: a11636 
o|substituted constant variable: a11660 
o|substituted constant variable: a11661 
o|inlining procedure: k11653 
o|inlining procedure: k11653 
o|substituted constant variable: a11719 
o|substituted constant variable: a11720 
o|substituted constant variable: a11744 
o|substituted constant variable: a11745 
o|inlining procedure: k11737 
o|inlining procedure: k11737 
o|inlining procedure: k11403 
o|inlining procedure: k11803 
o|inlining procedure: k11803 
o|inlining procedure: k11834 
o|inlining procedure: k11834 
o|inlining procedure: k11900 
o|inlining procedure: k11900 
o|inlining procedure: "(core.scm:1196) chicken.compiler.core#second" 
o|inlining procedure: k11931 
o|inlining procedure: k11931 
o|inlining procedure: k11981 
o|inlining procedure: k11981 
o|inlining procedure: k12015 
o|inlining procedure: k12043 
o|inlining procedure: k12043 
o|inlining procedure: k12015 
o|inlining procedure: k12082 
o|inlining procedure: k12082 
o|inlining procedure: k12108 
o|inlining procedure: k12108 
o|contracted procedure: "(core.scm:1241) chicken.compiler.core#expand-foreign-primitive" 
o|inlining procedure: k16278 
o|inlining procedure: k16278 
o|inlining procedure: k16312 
o|contracted procedure: "(core.scm:1902) g35803589" 
o|inlining procedure: k16312 
o|inlining procedure: k16344 
o|inlining procedure: k16344 
o|inlining procedure: k16354 
o|inlining procedure: "(core.scm:1900) chicken.compiler.core#third" 
o|inlining procedure: k16354 
o|inlining procedure: "(core.scm:1900) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:1899) chicken.compiler.core#second" 
o|inlining procedure: k12134 
o|inlining procedure: "(core.scm:1247) chicken.compiler.core#fourth" 
o|inlining procedure: "(core.scm:1245) chicken.compiler.core#third" 
o|inlining procedure: "(core.scm:1244) chicken.compiler.core#second" 
o|inlining procedure: k12134 
o|inlining procedure: k12196 
o|inlining procedure: k12245 
o|inlining procedure: "(core.scm:1281) chicken.compiler.core#second" 
o|inlining procedure: k12245 
o|inlining procedure: "(core.scm:1278) chicken.compiler.core#first" 
o|inlining procedure: k12196 
o|substituted constant variable: a12282 
o|substituted constant variable: a12283 
o|inlining procedure: k12275 
o|inlining procedure: k12275 
o|inlining procedure: "(core.scm:1256) chicken.compiler.core#third" 
o|inlining procedure: "(core.scm:1255) chicken.compiler.core#second" 
o|inlining procedure: k12300 
o|substituted constant variable: a12373 
o|substituted constant variable: a12374 
o|inlining procedure: k12366 
o|inlining procedure: k12366 
o|inlining procedure: "(core.scm:1292) chicken.compiler.core#fourth" 
o|inlining procedure: "(core.scm:1291) chicken.compiler.core#third" 
o|inlining procedure: "(core.scm:1288) chicken.compiler.core#second" 
o|inlining procedure: k12300 
o|inlining procedure: k12469 
o|inlining procedure: k12469 
o|inlining procedure: "(core.scm:1331) chicken.compiler.core#fourth" 
o|inlining procedure: "(core.scm:1312) chicken.compiler.core#fourth" 
o|inlining procedure: "(core.scm:1309) chicken.compiler.core#third" 
o|inlining procedure: "(core.scm:1308) chicken.compiler.core#second" 
o|inlining procedure: k12544 
o|substituted constant variable: a12576 
o|substituted constant variable: a12577 
o|inlining procedure: k12569 
o|inlining procedure: k12569 
o|inlining procedure: "(core.scm:1336) chicken.compiler.core#second" 
o|inlining procedure: k12544 
o|inlining procedure: k12622 
o|inlining procedure: k12622 
o|substituted constant variable: a12678 
o|substituted constant variable: a12679 
o|inlining procedure: k12671 
o|inlining procedure: k12671 
o|substituted constant variable: a12711 
o|substituted constant variable: a12712 
o|inlining procedure: k12704 
o|inlining procedure: k12704 
o|inlining procedure: k12752 
o|inlining procedure: k12752 
o|inlining procedure: "(core.scm:1350) chicken.compiler.core#third" 
o|inlining procedure: "(core.scm:1348) chicken.compiler.core#second" 
o|inlining procedure: k12787 
o|contracted procedure: "(core.scm:1388) chicken.compiler.core#process-declaration" 
o|merged explicitly consed rest parameter: maxlen2679 
o|inlining procedure: k13673 
o|inlining procedure: k13673 
o|inlining procedure: k13689 
o|inlining procedure: k13689 
o|inlining procedure: k13705 
o|inlining procedure: k13705 
o|contracted procedure: "(core.scm:1552) chicken.compiler.core#filter-map" 
o|inlining procedure: k6949 
o|inlining procedure: k6949 
o|inlining procedure: k6938 
o|inlining procedure: k6938 
o|substituted constant variable: a13738 
o|substituted constant variable: a13739 
o|inlining procedure: k13764 
o|consed rest parameter at call site: "(core.scm:1564) chicken.compiler.core#lset-union/eq?" 2 
o|consed rest parameter at call site: "(core.scm:1563) chicken.compiler.core#lset-union/eq?" 2 
o|inlining procedure: k13764 
o|inlining procedure: k13795 
o|inlining procedure: k13795 
o|consed rest parameter at call site: "(core.scm:1566) check-decl2673" 3 
o|inlining procedure: k13817 
o|inlining procedure: k13817 
o|inlining procedure: k13848 
o|inlining procedure: k13848 
o|inlining procedure: k13867 
o|consed rest parameter at call site: "(core.scm:1587) chicken.compiler.core#lset-intersection/eq?" 2 
o|consed rest parameter at call site: "(core.scm:1586) chicken.compiler.core#lset-intersection/eq?" 2 
o|inlining procedure: k13867 
o|consed rest parameter at call site: "(core.scm:1589) check-decl2673" 3 
o|inlining procedure: k13913 
o|inlining procedure: k13913 
o|inlining procedure: k13930 
o|inlining procedure: k13930 
o|inlining procedure: k13944 
o|inlining procedure: k13944 
o|inlining procedure: k13958 
o|inlining procedure: k13958 
o|inlining procedure: k13972 
o|inlining procedure: k13993 
o|contracted procedure: "(core.scm:1600) g27362743" 
o|propagated global variable: g27512752 chicken.compiler.support#mark-variable 
o|inlining procedure: k13993 
o|inlining procedure: k13972 
o|inlining procedure: k14020 
o|inlining procedure: k14057 
o|contracted procedure: "(core.scm:1606) g27862793" 
o|propagated global variable: g28012802 chicken.compiler.support#mark-variable 
o|inlining procedure: k14057 
o|inlining procedure: k14080 
o|contracted procedure: "(core.scm:1603) g27612768" 
o|propagated global variable: g27762777 chicken.compiler.support#mark-variable 
o|inlining procedure: k14080 
o|inlining procedure: k14020 
o|inlining procedure: k14107 
o|inlining procedure: k14138 
o|contracted procedure: "(core.scm:1614) g28232845" 
o|propagated global variable: g28532854 chicken.compiler.support#mark-variable 
o|inlining procedure: k14138 
o|inlining procedure: k14161 
o|contracted procedure: "(core.scm:1613) g28132830" 
o|propagated global variable: g28382839 chicken.compiler.support#mark-variable 
o|inlining procedure: k14161 
o|inlining procedure: k14107 
o|inlining procedure: k14190 
o|inlining procedure: k14190 
o|inlining procedure: k14203 
o|inlining procedure: k14203 
o|inlining procedure: k14217 
o|inlining procedure: k14217 
o|inlining procedure: k14247 
o|contracted procedure: "(core.scm:1624) g28652872" 
o|propagated global variable: g28802881 chicken.compiler.support#mark-variable 
o|inlining procedure: k14247 
o|inlining procedure: k14269 
o|inlining procedure: k14292 
o|contracted procedure: "(core.scm:1626) g28902897" 
o|propagated global variable: g29052906 chicken.compiler.support#mark-variable 
o|inlining procedure: k14292 
o|inlining procedure: k14269 
o|inlining procedure: k14326 
o|consed rest parameter at call site: "(core.scm:1636) chicken.compiler.core#lset-difference/eq?" 2 
o|inlining procedure: k14326 
o|inlining procedure: k14360 
o|inlining procedure: k14360 
o|consed rest parameter at call site: "(core.scm:1642) chicken.compiler.core#lset-difference/eq?" 2 
o|inlining procedure: k14382 
o|inlining procedure: k14412 
o|contracted procedure: "(core.scm:1647) g29212928" 
o|propagated global variable: g29362937 chicken.compiler.support#mark-variable 
o|inlining procedure: k14412 
o|inlining procedure: k14382 
o|inlining procedure: k14445 
o|inlining procedure: k14445 
o|consed rest parameter at call site: "(core.scm:1657) chicken.compiler.core#lset-difference/eq?" 2 
o|consed rest parameter at call site: "(core.scm:1656) chicken.compiler.core#lset-difference/eq?" 2 
o|inlining procedure: k14471 
o|inlining procedure: k14501 
o|contracted procedure: "(core.scm:1661) g29532960" 
o|propagated global variable: g29682969 chicken.compiler.support#mark-variable 
o|inlining procedure: k14501 
o|inlining procedure: k14471 
o|substituted constant variable: a14545 
o|consed rest parameter at call site: "(core.scm:1665) check-decl2673" 3 
o|substituted constant variable: a14551 
o|substituted constant variable: a14553 
o|substituted constant variable: a14555 
o|substituted constant variable: a14557 
o|substituted constant variable: a14559 
o|inlining procedure: "(core.scm:1631) chicken.compiler.core#second" 
o|consed rest parameter at call site: "(core.scm:1630) check-decl2673" 3 
o|inlining procedure: k14564 
o|inlining procedure: k14564 
o|inlining procedure: k14583 
o|inlining procedure: k14583 
o|inlining procedure: k14599 
o|inlining procedure: k14599 
o|inlining procedure: k14621 
o|inlining procedure: k14640 
o|inlining procedure: k14640 
o|inlining procedure: k14621 
o|inlining procedure: k14669 
o|inlining procedure: k14699 
o|contracted procedure: "(core.scm:1686) g30283035" 
o|propagated global variable: g30433044 chicken.compiler.support#mark-variable 
o|inlining procedure: k14699 
o|inlining procedure: k14669 
o|inlining procedure: k14735 
o|inlining procedure: k14735 
o|consed rest parameter at call site: "(core.scm:1690) check-decl2673" 3 
o|inlining procedure: k14745 
o|consed rest parameter at call site: "(core.scm:1698) check-decl2673" 3 
o|inlining procedure: k14745 
o|inlining procedure: k14776 
o|inlining procedure: k14799 
o|contracted procedure: "(core.scm:1708) g30583065" 
o|propagated global variable: g30733074 chicken.compiler.support#mark-variable 
o|inlining procedure: k14799 
o|inlining procedure: k14776 
o|inlining procedure: k14824 
o|inlining procedure: k14919 
o|contracted procedure: "(core.scm:1717) g30883097" 
o|inlining procedure: k14840 
o|substituted constant variable: a14857 
o|inlining procedure: k14840 
o|inlining procedure: k14881 
o|inlining procedure: k14881 
o|substituted constant variable: a14904 
o|inlining procedure: k14919 
o|inlining procedure: k14824 
o|inlining procedure: k14958 
o|inlining procedure: k14958 
o|inlining procedure: k14971 
o|inlining procedure: k14971 
o|inlining procedure: k14980 
o|inlining procedure: k14980 
o|inlining procedure: k14997 
o|inlining procedure: k15029 
o|contracted procedure: "(core.scm:1738) g31293136" 
o|propagated global variable: g31443145 chicken.compiler.support#mark-variable 
o|inlining procedure: k15029 
o|inlining procedure: k14997 
o|inlining procedure: k15059 
o|inlining procedure: k15059 
o|inlining procedure: k15083 
o|contracted procedure: "(core.scm:1745) g31603167" 
o|propagated global variable: g31753176 chicken.compiler.support#mark-variable 
o|inlining procedure: k15083 
o|inlining procedure: k15107 
o|inlining procedure: k15138 
o|contracted procedure: "(core.scm:1752) g31853192" 
o|propagated global variable: g32003201 chicken.compiler.support#mark-variable 
o|inlining procedure: k15138 
o|inlining procedure: k15107 
o|inlining procedure: k15170 
o|inlining procedure: k15170 
o|inlining procedure: k15212 
o|inlining procedure: k15269 
o|inlining procedure: k15269 
o|inlining procedure: k15212 
o|inlining procedure: k15302 
o|substituted constant variable: a15323 
o|inlining procedure: k15302 
o|inlining procedure: k15334 
o|inlining procedure: k15334 
o|inlining procedure: k15362 
o|inlining procedure: k15397 
o|inlining procedure: k15397 
o|inlining procedure: k15362 
o|inlining procedure: k15428 
o|substituted constant variable: a15437 
o|inlining procedure: k15428 
o|inlining procedure: k15354 
o|inlining procedure: k15456 
o|inlining procedure: k15456 
o|inlining procedure: k15354 
o|inlining procedure: k15483 
o|inlining procedure: k15483 
o|substituted constant variable: a15494 
o|substituted constant variable: a15496 
o|substituted constant variable: a15498 
o|substituted constant variable: a15500 
o|substituted constant variable: a15502 
o|substituted constant variable: a15504 
o|substituted constant variable: a15506 
o|substituted constant variable: a15508 
o|substituted constant variable: a15510 
o|substituted constant variable: a15512 
o|substituted constant variable: a15514 
o|substituted constant variable: a15516 
o|substituted constant variable: a15518 
o|substituted constant variable: a15520 
o|substituted constant variable: a15522 
o|substituted constant variable: a15527 
o|substituted constant variable: a15529 
o|substituted constant variable: a15531 
o|substituted constant variable: a15533 
o|substituted constant variable: a15535 
o|substituted constant variable: a15537 
o|substituted constant variable: a15539 
o|substituted constant variable: a15541 
o|substituted constant variable: a15543 
o|substituted constant variable: a15545 
o|substituted constant variable: a15547 
o|substituted constant variable: a15549 
o|substituted constant variable: a15551 
o|substituted constant variable: a15553 
o|substituted constant variable: a15555 
o|substituted constant variable: a15557 
o|substituted constant variable: a15559 
o|substituted constant variable: a15561 
o|substituted constant variable: a15563 
o|substituted constant variable: a15565 
o|substituted constant variable: a15567 
o|substituted constant variable: a15569 
o|substituted constant variable: a15574 
o|substituted constant variable: a15576 
o|substituted constant variable: a15578 
o|substituted constant variable: a15580 
o|substituted constant variable: a15582 
o|substituted constant variable: a15584 
o|substituted constant variable: a15586 
o|substituted constant variable: a15588 
o|inlining procedure: k12829 
o|inlining procedure: k12829 
o|inlining procedure: k12787 
o|contracted procedure: "(core.scm:1393) chicken.compiler.core#split-at" 
o|inlining procedure: k6442 
o|inlining procedure: k6442 
o|inlining procedure: k12950 
o|inlining procedure: k12950 
o|inlining procedure: k12988 
o|inlining procedure: k12988 
o|inlining procedure: k13043 
o|inlining procedure: k13043 
o|inlining procedure: k13094 
o|inlining procedure: k13094 
o|substituted constant variable: a13145 
o|substituted constant variable: a13146 
o|inlining procedure: k13138 
o|inlining procedure: k13138 
o|inlining procedure: "(core.scm:1399) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:1398) chicken.compiler.core#fourth" 
o|inlining procedure: "(core.scm:1397) chicken.compiler.core#third" 
o|inlining procedure: "(core.scm:1395) chicken.compiler.core#first" 
o|inlining procedure: k13171 
o|inlining procedure: "(core.scm:1480) chicken.compiler.core#second" 
o|inlining procedure: k13189 
o|inlining procedure: k13189 
o|inlining procedure: k13230 
o|inlining procedure: k13230 
o|inlining procedure: k13171 
o|inlining procedure: k13300 
o|inlining procedure: k13300 
o|substituted constant variable: a13323 
o|substituted constant variable: a13325 
o|substituted constant variable: a13327 
o|substituted constant variable: a13329 
o|substituted constant variable: a13331 
o|substituted constant variable: a13333 
o|substituted constant variable: a13335 
o|substituted constant variable: a13337 
o|substituted constant variable: a13339 
o|substituted constant variable: a13341 
o|substituted constant variable: a13343 
o|substituted constant variable: a13345 
o|substituted constant variable: a13347 
o|substituted constant variable: a13349 
o|substituted constant variable: a13351 
o|substituted constant variable: a13356 
o|substituted constant variable: a13358 
o|substituted constant variable: a13363 
o|substituted constant variable: a13365 
o|substituted constant variable: a13367 
o|substituted constant variable: a13369 
o|substituted constant variable: a13371 
o|substituted constant variable: a13373 
o|substituted constant variable: a13375 
o|substituted constant variable: a13377 
o|substituted constant variable: a13379 
o|substituted constant variable: a13381 
o|substituted constant variable: a13383 
o|substituted constant variable: a13385 
o|substituted constant variable: a13387 
o|substituted constant variable: a13389 
o|substituted constant variable: a13391 
o|substituted constant variable: a13393 
o|substituted constant variable: a13395 
o|substituted constant variable: a13397 
o|substituted constant variable: a13399 
o|substituted constant variable: a13401 
o|substituted constant variable: a13403 
o|substituted constant variable: a13405 
o|substituted constant variable: a13407 
o|substituted constant variable: a13409 
o|substituted constant variable: a13411 
o|substituted constant variable: a13413 
o|substituted constant variable: a13415 
o|substituted constant variable: a13417 
o|inlining procedure: k13421 
o|inlining procedure: k13421 
o|substituted constant variable: a13428 
o|substituted constant variable: a13430 
o|substituted constant variable: a13432 
o|substituted constant variable: a13434 
o|substituted constant variable: a13436 
o|substituted constant variable: a13438 
o|substituted constant variable: a13440 
o|substituted constant variable: a13442 
o|substituted constant variable: a13447 
o|substituted constant variable: a13449 
o|substituted constant variable: a13451 
o|inlining procedure: k13481 
o|substituted constant variable: a13492 
o|substituted constant variable: a13493 
o|inlining procedure: k13481 
o|inlining procedure: k13509 
o|inlining procedure: k13509 
o|inlining procedure: k13596 
o|inlining procedure: k13596 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#foreign-stub 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#foreign-stub? 
o|inlining procedure: k15850 
o|inlining procedure: k15850 
o|inlining procedure: k15917 
o|contracted procedure: "(core.scm:1863) g34563466" 
o|inlining procedure: k15917 
o|contracted procedure: "(core.scm:1857) chicken.compiler.core#make-foreign-stub" 
o|inlining procedure: k15998 
o|inlining procedure: k15998 
o|contracted procedure: "(core.scm:1851) type->symbol3357" 
o|inlining procedure: k15704 
o|inlining procedure: k15704 
o|inlining procedure: k15719 
o|inlining procedure: k15719 
o|substituted constant variable: a15761 
o|substituted constant variable: a15763 
o|substituted constant variable: a15765 
o|inlining procedure: k15766 
o|inlining procedure: k15766 
o|inlining procedure: k16050 
o|inlining procedure: k16050 
o|inlining procedure: "(core.scm:1883) chicken.compiler.core#second" 
o|inlining procedure: k16109 
o|inlining procedure: k16109 
o|inlining procedure: "(core.scm:1877) chicken.compiler.core#third" 
o|inlining procedure: k16162 
o|inlining procedure: k16162 
o|inlining procedure: k16196 
o|contracted procedure: "(core.scm:1891) g35183527" 
o|inlining procedure: k16196 
o|inlining procedure: "(core.scm:1889) chicken.compiler.core#third" 
o|inlining procedure: "(core.scm:1888) chicken.compiler.core#second" 
o|inlining procedure: k16441 
o|inlining procedure: k16441 
o|inlining procedure: k16477 
o|inlining procedure: k16477 
o|contracted procedure: "(core.scm:1938) g36733674" 
o|inlining procedure: k16596 
o|inlining procedure: k16608 
o|inlining procedure: k16608 
o|inlining procedure: k16631 
o|inlining procedure: k16631 
o|inlining procedure: k16596 
o|inlining procedure: "(core.scm:1957) chicken.compiler.core#first" 
o|contracted procedure: "(core.scm:1957) g36843685" 
o|inlining procedure: k16698 
o|inlining procedure: "(core.scm:1960) chicken.compiler.core#first" 
o|inlining procedure: k16698 
o|inlining procedure: "(core.scm:1970) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:1968) chicken.compiler.core#first" 
o|contracted procedure: "(core.scm:1967) g36933694" 
o|inlining procedure: k16799 
o|inlining procedure: k16799 
o|inlining procedure: k16826 
o|contracted procedure: "(core.scm:1980) walk-call-unit3633" 
o|contracted procedure: "(core.scm:2008) g37423743" 
o|inlining procedure: "(core.scm:1976) chicken.compiler.core#first" 
o|inlining procedure: k16826 
o|inlining procedure: k16886 
o|contracted procedure: "(core.scm:1986) chicken.compiler.core#last" 
o|inlining procedure: k7051 
o|inlining procedure: k7051 
o|inlining procedure: k16886 
o|substituted constant variable: a16903 
o|substituted constant variable: a16908 
o|substituted constant variable: a16910 
o|substituted constant variable: a16912 
o|substituted constant variable: a16914 
o|inlining procedure: k16918 
o|inlining procedure: k16918 
o|inlining procedure: k16930 
o|inlining procedure: k16930 
o|inlining procedure: k16942 
o|inlining procedure: k16942 
o|substituted constant variable: a16949 
o|substituted constant variable: a16951 
o|substituted constant variable: a16953 
o|substituted constant variable: a16955 
o|substituted constant variable: a16957 
o|substituted constant variable: a16959 
o|substituted constant variable: a16961 
o|substituted constant variable: a16963 
o|substituted constant variable: a16965 
o|substituted constant variable: a16970 
o|substituted constant variable: a16972 
o|substituted constant variable: a16974 
o|substituted constant variable: a16976 
o|inlining procedure: k16980 
o|inlining procedure: k16980 
o|inlining procedure: k16992 
o|inlining procedure: k16992 
o|substituted constant variable: a16999 
o|substituted constant variable: a17001 
o|substituted constant variable: a17003 
o|substituted constant variable: a17005 
o|substituted constant variable: a17007 
o|consed rest parameter at call site: "(core.scm:2001) chicken.compiler.core#cons*" 2 
o|contracted procedure: "(core.scm:1994) g37343735" 
o|inlining procedure: k17179 
o|inlining procedure: k17179 
o|inlining procedure: k17220 
o|inlining procedure: k17220 
o|substituted constant variable: a17279 
o|inlining procedure: k17280 
o|inlining procedure: k17280 
o|substituted constant variable: a17287 
o|inlining procedure: k17329 
o|inlining procedure: k17329 
o|inlining procedure: k17353 
o|inlining procedure: k17353 
o|inlining procedure: k17371 
o|inlining procedure: k17371 
o|inlining procedure: "(core.scm:2068) chicken.compiler.core#first" 
o|inlining procedure: k17384 
o|inlining procedure: k17384 
o|inlining procedure: "(core.scm:2098) chicken.compiler.core#first" 
o|inlining procedure: k17455 
o|inlining procedure: k17464 
o|inlining procedure: "(core.scm:2092) chicken.compiler.core#third" 
o|inlining procedure: k17464 
o|inlining procedure: k17455 
o|inlining procedure: "(core.scm:2085) chicken.compiler.core#first" 
o|inlining procedure: k17513 
o|inlining procedure: k17531 
o|inlining procedure: k17531 
o|inlining procedure: k17513 
o|inlining procedure: k17616 
o|inlining procedure: k17616 
o|inlining procedure: "(core.scm:2116) chicken.compiler.core#first" 
o|inlining procedure: k17636 
o|inlining procedure: k17717 
o|inlining procedure: k17717 
o|inlining procedure: "(core.scm:2147) chicken.compiler.core#second" 
o|inlining procedure: k17751 
o|inlining procedure: k17751 
o|inlining procedure: "(core.scm:2131) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2129) chicken.compiler.core#third" 
o|inlining procedure: k17636 
o|inlining procedure: k17824 
o|inlining procedure: k17824 
o|inlining procedure: k17852 
o|inlining procedure: k17852 
o|substituted constant variable: a17871 
o|substituted constant variable: a17873 
o|inlining procedure: "(core.scm:2155) chicken.compiler.core#first" 
o|inlining procedure: k17877 
o|inlining procedure: k17901 
o|inlining procedure: k17901 
o|inlining procedure: "(core.scm:2176) chicken.compiler.core#first" 
o|inlining procedure: k17877 
o|substituted constant variable: a17920 
o|substituted constant variable: a17922 
o|substituted constant variable: a17927 
o|substituted constant variable: a17929 
o|substituted constant variable: a17934 
o|substituted constant variable: a17936 
o|substituted constant variable: a17938 
o|substituted constant variable: a17943 
o|substituted constant variable: a17945 
o|substituted constant variable: a17947 
o|substituted constant variable: a17952 
o|substituted constant variable: a17954 
o|substituted constant variable: a17959 
o|substituted constant variable: a17961 
o|inlining procedure: k17965 
o|inlining procedure: k17965 
o|substituted constant variable: a17978 
o|substituted constant variable: a17980 
o|substituted constant variable: a17982 
o|substituted constant variable: a17984 
o|inlining procedure: k18002 
o|inlining procedure: k18002 
o|inlining procedure: k18063 
o|inlining procedure: k18063 
o|inlining procedure: k18078 
o|inlining procedure: k18078 
o|inlining procedure: k18132 
o|inlining procedure: k18132 
o|inlining procedure: k18166 
o|inlining procedure: k18166 
o|inlining procedure: k18181 
o|inlining procedure: k18181 
o|inlining procedure: k18199 
o|inlining procedure: k18217 
o|inlining procedure: k18217 
o|inlining procedure: k18199 
o|propagated global variable: tmp40294031 chicken.compiler.core#local-definitions 
o|propagated global variable: tmp40294031 chicken.compiler.core#local-definitions 
o|inlining procedure: k18254 
o|inlining procedure: k18254 
o|inlining procedure: k18267 
o|inlining procedure: k18267 
o|inlining procedure: "(core.scm:2207) chicken.compiler.core#first" 
o|inlining procedure: k18307 
o|inlining procedure: k18307 
o|inlining procedure: "(core.scm:2201) chicken.compiler.core#first" 
o|inlining procedure: k18334 
o|inlining procedure: k18334 
o|inlining procedure: "(core.scm:2197) chicken.compiler.core#first" 
o|inlining procedure: k18392 
o|inlining procedure: k18392 
o|inlining procedure: k18408 
o|inlining procedure: k18408 
o|inlining procedure: k18427 
o|inlining procedure: k18427 
o|inlining procedure: k18442 
o|inlining procedure: k18442 
o|removed side-effect free assignment to unused variable: assigned-locally4057 
o|inlining procedure: k18461 
o|inlining procedure: k18461 
o|inlining procedure: k18475 
o|inlining procedure: k18475 
o|inlining procedure: k18490 
o|inlining procedure: k18490 
o|substituted constant variable: a18507 
o|substituted constant variable: a18509 
o|substituted constant variable: a18511 
o|substituted constant variable: a18513 
o|substituted constant variable: a18515 
o|substituted constant variable: a18517 
o|substituted constant variable: a18519 
o|substituted constant variable: a18521 
o|substituted constant variable: a18523 
o|substituted constant variable: a18525 
o|substituted constant variable: a18527 
o|substituted constant variable: a18529 
o|inlining procedure: k18568 
o|inlining procedure: k18589 
o|inlining procedure: k18610 
o|inlining procedure: "(core.scm:2481) chicken.compiler.core#first" 
o|inlining procedure: k18610 
o|inlining procedure: k18632 
o|inlining procedure: "(core.scm:2480) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2480) chicken.compiler.core#first" 
o|inlining procedure: k18632 
o|inlining procedure: "(core.scm:2477) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:2476) chicken.compiler.core#first" 
o|substituted constant variable: a18661 
o|inlining procedure: k18589 
o|inlining procedure: k18669 
o|inlining procedure: k18669 
o|inlining procedure: "(core.scm:2470) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2469) chicken.compiler.core#third" 
o|inlining procedure: "(core.scm:2468) chicken.compiler.core#second" 
o|inlining procedure: k18568 
o|inlining procedure: k18702 
o|inlining procedure: k18729 
o|inlining procedure: k18729 
o|inlining procedure: k18741 
o|inlining procedure: k18741 
o|inlining procedure: "(core.scm:2453) chicken.compiler.core#first" 
o|inlining procedure: k18702 
o|inlining procedure: k18789 
o|inlining procedure: k18801 
o|inlining procedure: k18801 
o|inlining procedure: k18804 
o|inlining procedure: k18822 
o|inlining procedure: k18822 
o|inlining procedure: "(core.scm:2431) chicken.compiler.core#first" 
o|inlining procedure: k18804 
o|inlining procedure: k18789 
o|inlining procedure: k18847 
o|inlining procedure: k18875 
o|inlining procedure: "(core.scm:2418) chicken.compiler.core#first" 
o|inlining procedure: k18875 
o|inlining procedure: "(core.scm:2420) chicken.compiler.core#first" 
o|inlining procedure: k18910 
o|inlining procedure: k18910 
o|inlining procedure: k18943 
o|inlining procedure: k18943 
o|inlining procedure: "(core.scm:2405) chicken.compiler.core#third" 
o|inlining procedure: "(core.scm:2403) chicken.compiler.core#second" 
o|inlining procedure: k18847 
o|inlining procedure: k18979 
o|inlining procedure: k18979 
o|inlining procedure: "(core.scm:2387) chicken.compiler.core#first" 
o|inlining procedure: k19008 
o|inlining procedure: k19008 
o|inlining procedure: k19038 
o|inlining procedure: k19038 
o|inlining procedure: "(core.scm:2348) chicken.compiler.core#second" 
o|inlining procedure: k19074 
o|inlining procedure: k19101 
o|inlining procedure: k19101 
o|inlining procedure: "(core.scm:2365) chicken.compiler.core#second" 
o|inlining procedure: k19074 
o|inlining procedure: k19150 
o|inlining procedure: k19150 
o|substituted constant variable: a19194 
o|substituted constant variable: a19195 
o|inlining procedure: k19208 
o|inlining procedure: k19217 
o|inlining procedure: k19229 
o|inlining procedure: k19229 
o|inlining procedure: k19217 
o|inlining procedure: k19208 
o|inlining procedure: k19265 
o|inlining procedure: "(core.scm:2321) chicken.compiler.core#first" 
o|inlining procedure: k19265 
o|inlining procedure: k19260 
o|inlining procedure: k19295 
o|inlining procedure: k19295 
o|inlining procedure: k19260 
o|inlining procedure: k19315 
o|inlining procedure: k19315 
o|inlining procedure: k19330 
o|inlining procedure: k19330 
o|consed rest parameter at call site: "(core.scm:2508) chicken.compiler.core#lset-adjoin/eq?" 2 
o|consed rest parameter at call site: "(core.scm:2513) chicken.compiler.core#lset-adjoin/eq?" 2 
o|inlining procedure: k19394 
o|inlining procedure: "(core.scm:2524) chicken.compiler.core#first" 
o|inlining procedure: k19394 
o|inlining procedure: k19424 
o|inlining procedure: "(core.scm:2537) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:2536) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2535) chicken.compiler.core#first" 
o|inlining procedure: k19424 
o|inlining procedure: k19484 
o|inlining procedure: k19484 
o|inlining procedure: "(core.scm:2541) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2540) chicken.compiler.core#first" 
o|inlining procedure: k19497 
o|inlining procedure: k19539 
o|inlining procedure: k19539 
o|inlining procedure: k19575 
o|inlining procedure: k19585 
o|inlining procedure: k19618 
o|inlining procedure: k19618 
o|inlining procedure: k19647 
o|inlining procedure: k19656 
o|inlining procedure: k19656 
o|inlining procedure: k19647 
o|inlining procedure: "(core.scm:2570) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2569) chicken.compiler.core#third" 
o|inlining procedure: k19683 
o|inlining procedure: k19698 
o|inlining procedure: k19698 
o|inlining procedure: k19683 
o|inlining procedure: "(core.scm:2557) chicken.compiler.core#first" 
o|inlining procedure: k19585 
o|inlining procedure: k19575 
o|inlining procedure: "(core.scm:2549) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:2548) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2547) chicken.compiler.core#first" 
o|inlining procedure: k19497 
o|consed rest parameter at call site: "(core.scm:2599) chicken.compiler.core#lset-difference/eq?" 2 
o|contracted procedure: "(core.scm:2596) chicken.compiler.core#delete-duplicates" 
o|inlining procedure: k6846 
o|inlining procedure: k6846 
o|inlining procedure: "(core.scm:2596) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2594) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2592) chicken.compiler.core#third" 
o|inlining procedure: k19831 
o|inlining procedure: k19831 
o|substituted constant variable: a19866 
o|substituted constant variable: a19868 
o|substituted constant variable: a19870 
o|substituted constant variable: a19872 
o|substituted constant variable: a19874 
o|inlining procedure: k19878 
o|inlining procedure: k19878 
o|inlining procedure: k19890 
o|inlining procedure: k19890 
o|substituted constant variable: a19897 
o|substituted constant variable: a19899 
o|substituted constant variable: a19901 
o|substituted constant variable: a19903 
o|substituted constant variable: a19905 
o|substituted constant variable: a19910 
o|substituted constant variable: a19912 
o|inlining procedure: k19925 
o|inlining procedure: k19925 
o|inlining procedure: k19946 
o|inlining procedure: k19946 
o|inlining procedure: "(core.scm:2615) chicken.compiler.core#first" 
o|inlining procedure: k19959 
o|inlining procedure: k19990 
o|inlining procedure: k19990 
o|inlining procedure: "(core.scm:2623) chicken.compiler.core#first" 
o|inlining procedure: k19959 
o|inlining procedure: k20065 
o|inlining procedure: "(core.scm:2661) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:2657) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2651) chicken.compiler.core#first" 
o|inlining procedure: k20065 
o|inlining procedure: k20241 
o|inlining procedure: k20241 
o|inlining procedure: k20285 
o|inlining procedure: k20285 
o|inlining procedure: k20328 
o|inlining procedure: k20371 
o|inlining procedure: k20371 
o|inlining procedure: k20407 
o|contracted procedure: "(core.scm:2707) g46934702" 
o|inlining procedure: k20407 
o|inlining procedure: k20328 
o|inlining procedure: "(core.scm:2702) chicken.compiler.core#fourth" 
o|inlining procedure: k20467 
o|inlining procedure: k20467 
o|inlining procedure: k20483 
o|inlining procedure: k20483 
o|inlining procedure: k20495 
o|inlining procedure: k20495 
o|inlining procedure: "(core.scm:2691) chicken.compiler.core#second" 
o|inlining procedure: k20531 
o|inlining procedure: k20531 
o|inlining procedure: k20537 
o|inlining procedure: k20537 
o|inlining procedure: k20557 
o|inlining procedure: k20557 
o|inlining procedure: "(core.scm:2677) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:2674) chicken.compiler.core#first" 
o|inlining procedure: k20572 
o|inlining procedure: k20572 
o|inlining procedure: k20620 
o|inlining procedure: k20620 
o|inlining procedure: "(core.scm:2667) chicken.compiler.core#third" 
o|inlining procedure: k20657 
o|inlining procedure: k20686 
o|inlining procedure: k20686 
o|inlining procedure: k20753 
o|inlining procedure: k20753 
o|inlining procedure: k20796 
o|inlining procedure: k20796 
o|inlining procedure: "(core.scm:2734) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:2733) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2731) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2730) chicken.compiler.core#first" 
o|inlining procedure: k20657 
o|inlining procedure: k20848 
o|inlining procedure: k20848 
o|inlining procedure: k20873 
o|inlining procedure: k20873 
o|inlining procedure: k20876 
o|inlining procedure: k20876 
o|substituted constant variable: a20886 
o|substituted constant variable: a20888 
o|substituted constant variable: a20890 
o|substituted constant variable: a20895 
o|substituted constant variable: a20897 
o|substituted constant variable: a20899 
o|inlining procedure: k20903 
o|inlining procedure: k20903 
o|inlining procedure: k20915 
o|inlining procedure: k20915 
o|inlining procedure: k20927 
o|inlining procedure: k20927 
o|inlining procedure: k20939 
o|inlining procedure: k20939 
o|inlining procedure: k20951 
o|inlining procedure: k20951 
o|inlining procedure: k20963 
o|inlining procedure: k20963 
o|inlining procedure: k20975 
o|inlining procedure: k20975 
o|inlining procedure: k20987 
o|inlining procedure: k20987 
o|substituted constant variable: a21000 
o|substituted constant variable: a21002 
o|substituted constant variable: a21004 
o|substituted constant variable: a21006 
o|substituted constant variable: a21008 
o|substituted constant variable: a21010 
o|substituted constant variable: a21012 
o|substituted constant variable: a21014 
o|substituted constant variable: a21016 
o|substituted constant variable: a21018 
o|substituted constant variable: a21020 
o|substituted constant variable: a21022 
o|substituted constant variable: a21024 
o|substituted constant variable: a21026 
o|substituted constant variable: a21028 
o|substituted constant variable: a21030 
o|substituted constant variable: a21032 
o|substituted constant variable: a21034 
o|inlining procedure: k21038 
o|inlining procedure: k21038 
o|substituted constant variable: a21051 
o|substituted constant variable: a21053 
o|substituted constant variable: a21055 
o|substituted constant variable: a21057 
o|substituted constant variable: a21059 
o|inlining procedure: k21063 
o|inlining procedure: k21063 
o|inlining procedure: k21075 
o|inlining procedure: k21075 
o|substituted constant variable: a21088 
o|substituted constant variable: a21090 
o|substituted constant variable: a21092 
o|substituted constant variable: a21094 
o|substituted constant variable: a21096 
o|substituted constant variable: a21098 
o|inlining procedure: k21119 
o|inlining procedure: k21119 
o|inlining procedure: k21159 
o|inlining procedure: k21159 
o|inlining procedure: "(core.scm:2776) chicken.compiler.core#first" 
o|inlining procedure: k21205 
o|inlining procedure: k21205 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#lambda-literal 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#lambda-literal? 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#lambda-literal-arguments 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#lambda-literal-directly-called 
o|inlining procedure: k21387 
o|inlining procedure: k21387 
o|inlining procedure: k21450 
o|inlining procedure: k21450 
o|propagated global variable: tmp49554957 chicken.compiler.core#no-bound-checks 
o|inlining procedure: k21471 
o|propagated global variable: tmp49554957 chicken.compiler.core#no-bound-checks 
o|inlining procedure: k21471 
o|propagated global variable: tmp49584960 chicken.compiler.support#unsafe 
o|propagated global variable: tmp49584960 chicken.compiler.support#unsafe 
o|inlining procedure: k21480 
o|inlining procedure: k21480 
o|inlining procedure: k21498 
o|inlining procedure: k21498 
o|inlining procedure: "(core.scm:2873) chicken.compiler.core#first" 
o|inlining procedure: k21520 
o|inlining procedure: "(core.scm:2877) chicken.compiler.core#fourth" 
o|inlining procedure: "(core.scm:2876) chicken.compiler.core#second" 
o|inlining procedure: k21520 
o|inlining procedure: "(core.scm:2890) chicken.compiler.core#second" 
o|inlining procedure: k21595 
o|inlining procedure: k21595 
o|inlining procedure: "(core.scm:2898) chicken.compiler.core#second" 
o|inlining procedure: k21637 
o|inlining procedure: "(core.scm:2902) chicken.compiler.core#first" 
o|inlining procedure: k21637 
o|inlining procedure: "(core.scm:2906) chicken.compiler.core#first" 
o|inlining procedure: k21687 
o|inlining procedure: "(core.scm:2911) chicken.compiler.core#first" 
o|inlining procedure: k21687 
o|inlining procedure: k21728 
o|inlining procedure: k21728 
o|inlining procedure: "(core.scm:2918) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2914) chicken.compiler.core#first" 
o|inlining procedure: k21754 
o|inlining procedure: "(core.scm:2927) chicken.compiler.core#first" 
o|inlining procedure: k21754 
o|inlining procedure: "(core.scm:2997) chicken.compiler.core#first" 
o|consed rest parameter at call site: "(core.scm:2996) chicken.compiler.core#lset-adjoin/eq?" 2 
o|contracted procedure: "(core.scm:2971) chicken.compiler.core#make-lambda-literal" 
o|inlining procedure: k21877 
o|inlining procedure: k21877 
o|inlining procedure: "(core.scm:2973) chicken.compiler.core#second" 
o|inlining procedure: k21910 
o|inlining procedure: k21910 
o|inlining procedure: k21927 
o|inlining procedure: k21927 
o|inlining procedure: k21939 
o|inlining procedure: k21939 
o|inlining procedure: k21960 
o|inlining procedure: k21960 
o|inlining procedure: "(core.scm:2946) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:2944) chicken.compiler.core#third" 
o|inlining procedure: k21970 
o|inlining procedure: "(core.scm:3007) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:3001) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:3000) chicken.compiler.core#first" 
o|inlining procedure: k21970 
o|inlining procedure: "(core.scm:3018) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:3013) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:3012) chicken.compiler.core#first" 
o|inlining procedure: k22071 
o|inlining procedure: k22156 
o|inlining procedure: k22156 
o|inlining procedure: k22170 
o|inlining procedure: k22170 
o|inlining procedure: "(core.scm:3033) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:3032) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:3022) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:3021) chicken.compiler.core#first" 
o|inlining procedure: k22071 
o|inlining procedure: "(core.scm:3050) chicken.compiler.core#third" 
o|substituted constant variable: a22283 
o|consed rest parameter at call site: "(core.scm:3049) chicken.compiler.core#lset-adjoin/eq?" 2 
o|inlining procedure: "(core.scm:3048) chicken.compiler.core#second" 
o|inlining procedure: k22295 
o|inlining procedure: "(core.scm:3063) chicken.compiler.core#first" 
o|inlining procedure: k22295 
o|inlining procedure: k22325 
o|inlining procedure: k22325 
o|inlining procedure: k22340 
o|substituted constant variable: a22367 
o|substituted constant variable: a22368 
o|inlining procedure: k22340 
o|inlining procedure: k22410 
o|inlining procedure: k22410 
o|inlining procedure: "(core.scm:3067) chicken.compiler.core#first" 
o|inlining procedure: k22440 
o|inlining procedure: "(core.scm:3090) chicken.compiler.core#third" 
o|inlining procedure: "(core.scm:3087) chicken.compiler.core#second" 
o|inlining procedure: "(core.scm:3084) chicken.compiler.core#first" 
o|inlining procedure: k22440 
o|inlining procedure: k22541 
o|inlining procedure: k22541 
o|consed rest parameter at call site: "(core.scm:3111) chicken.compiler.core#cons*" 2 
o|inlining procedure: "(core.scm:3103) chicken.compiler.core#first" 
o|inlining procedure: "(core.scm:3096) chicken.compiler.core#first" 
o|inlining procedure: k22606 
o|inlining procedure: k22606 
o|substituted constant variable: a22632 
o|substituted constant variable: a22634 
o|substituted constant variable: a22639 
o|substituted constant variable: a22641 
o|substituted constant variable: a22643 
o|substituted constant variable: a22645 
o|substituted constant variable: a22647 
o|substituted constant variable: a22649 
o|substituted constant variable: a22651 
o|substituted constant variable: a22653 
o|substituted constant variable: a22658 
o|substituted constant variable: a22660 
o|substituted constant variable: a22662 
o|substituted constant variable: a22664 
o|substituted constant variable: a22666 
o|substituted constant variable: a22668 
o|substituted constant variable: a22670 
o|substituted constant variable: a22672 
o|substituted constant variable: a22674 
o|substituted constant variable: a22676 
o|substituted constant variable: a22678 
o|substituted constant variable: a22680 
o|inlining procedure: k22684 
o|inlining procedure: k22684 
o|substituted constant variable: a22691 
o|substituted constant variable: a22693 
o|substituted constant variable: a22695 
o|inlining procedure: k22716 
o|inlining procedure: k22716 
o|inlining procedure: k22750 
o|inlining procedure: k22750 
o|inlining procedure: k22777 
o|inlining procedure: k22777 
o|contracted procedure: "(core.scm:3136) chicken.compiler.core#posv" 
o|inlining procedure: k7528 
o|inlining procedure: k7528 
o|inlining procedure: k22810 
o|inlining procedure: k22810 
o|inlining procedure: k22835 
o|inlining procedure: k22835 
o|contracted procedure: "(core.scm:3147) chicken.compiler.core#list-index" 
o|inlining procedure: k7076 
o|inlining procedure: k7076 
o|inlining procedure: k22851 
o|inlining procedure: k22851 
o|inlining procedure: k22864 
o|inlining procedure: k22864 
o|inlining procedure: k22882 
o|inlining procedure: k22882 
o|inlining procedure: k22897 
o|inlining procedure: k22897 
o|simplifications: ((if . 1)) 
o|replaced variables: 5134 
o|removed binding forms: 989 
o|substituted constant variable: r674422969 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#first 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#second 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#third 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#fourth 
o|substituted constant variable: r689522976 
o|contracted procedure: "(mini-srfi-1.scm:175) chicken.compiler.core#any" 
o|substituted constant variable: r668622965 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#list-tabulate 
o|substituted constant variable: r749522991 
o|substituted constant variable: r777823001 
o|inlining procedure: k7864 
o|substituted constant variable: r799423016 
o|removed call to pure procedure with unused result: "(core.scm:574) chicken.base#void" 
o|substituted constant variable: r844623052 
o|substituted constant variable: r844623052 
o|substituted constant variable: r853623061 
o|substituted constant variable: r884523072 
o|substituted constant variable: r884523072 
o|substituted constant variable: r884523074 
o|substituted constant variable: r884523074 
o|substituted constant variable: r968023111 
o|substituted constant variable: r968023111 
o|substituted constant variable: r1027623127 
o|substituted constant variable: r1027623127 
o|substituted constant variable: r1029523131 
o|substituted constant variable: r1029523131 
o|substituted constant variable: r1082723149 
o|substituted constant variable: r1082723149 
o|substituted constant variable: r1082723151 
o|substituted constant variable: r1082723151 
o|substituted constant variable: r1072423153 
o|substituted constant variable: r1072423153 
o|substituted constant variable: r1084723156 
o|substituted constant variable: r1102423166 
o|substituted constant variable: r1103623168 
o|substituted constant variable: r1123123182 
o|inlining procedure: k11369 
o|substituted constant variable: r1138323189 
o|substituted constant variable: r1138323189 
o|substituted constant variable: r1160123217 
o|substituted constant variable: r1160123217 
o|substituted constant variable: r1165423222 
o|substituted constant variable: r1165423222 
o|substituted constant variable: r1173823226 
o|substituted constant variable: r1173823226 
o|substituted constant variable: r1213523279 
o|substituted constant variable: r1224623304 
o|substituted constant variable: r1224623304 
o|substituted constant variable: r1219723311 
o|substituted constant variable: r1227623314 
o|substituted constant variable: r1227623314 
o|substituted constant variable: r1230123326 
o|substituted constant variable: r1236723329 
o|substituted constant variable: r1236723329 
o|substituted constant variable: r1254523371 
o|substituted constant variable: r1257023374 
o|substituted constant variable: r1257023374 
o|substituted constant variable: r1262323382 
o|substituted constant variable: r1267223386 
o|substituted constant variable: r1267223386 
o|substituted constant variable: r1270523390 
o|substituted constant variable: r1270523390 
o|substituted constant variable: r1369023407 
o|substituted constant variable: r1369023407 
o|substituted constant variable: r1370623411 
o|substituted constant variable: r693923416 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|substituted constant variable: r1488223519 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|substituted constant variable: r1498123527 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|substituted constant variable: r1527023544 
o|inlining procedure: k15302 
o|substituted constant variable: r1530323548 
o|substituted constant variable: r1530323548 
o|folded constant expression: (scheme#not (quote #f)) 
o|substituted constant variable: r1542923557 
o|inlining procedure: k13764 
o|inlining procedure: k13764 
o|substituted constant variable: n240 
o|substituted constant variable: r1304423575 
o|substituted constant variable: r1313923581 
o|substituted constant variable: r1313923581 
o|substituted constant variable: r1330123616 
o|substituted constant variable: r1330123616 
o|inlining procedure: k13285 
o|contracted procedure: "(core.scm:1851) g34153424" 
o|substituted constant variable: r1570523634 
o|substituted constant variable: r1576723639 
o|inlining procedure: k15772 
o|substituted constant variable: r1644223669 
o|substituted constant variable: r1733023730 
o|substituted constant variable: r1746523755 
o|substituted constant variable: r1745623756 
o|substituted constant variable: r1771823776 
o|substituted constant variable: r1790223807 
o|substituted constant variable: r1826823835 
o|substituted constant variable: r1830823842 
o|substituted constant variable: r1833523849 
o|substituted constant variable: r1863323891 
o|substituted constant variable: r1867023904 
o|substituted constant variable: r1879023944 
o|substituted constant variable: r1891123958 
o|substituted constant variable: r1891123959 
o|substituted constant variable: r1923024003 
o|substituted constant variable: r1921824004 
o|substituted constant variable: r1920924005 
o|substituted constant variable: r1926124016 
o|substituted constant variable: r1931624018 
o|inlining procedure: k19585 
o|substituted constant variable: r1961924064 
o|substituted constant variable: r1965724068 
o|substituted constant variable: r1964824069 
o|inlining procedure: k19585 
o|substituted constant variable: r1968424083 
o|substituted constant variable: r1958624089 
o|substituted constant variable: r1958624089 
o|substituted constant variable: r1957624091 
o|substituted constant variable: r1957624091 
o|substituted constant variable: r2053224199 
o|substituted constant variable: r2053224199 
o|substituted constant variable: r2053224201 
o|substituted constant variable: r2053224201 
o|substituted constant variable: r2053824204 
o|substituted constant variable: r2055824206 
o|substituted constant variable: r2084924256 
o|substituted constant variable: r2084924256 
o|substituted constant variable: r2087424258 
o|substituted constant variable: r2087424258 
o|substituted constant variable: r2087424260 
o|substituted constant variable: r2087424260 
o|propagated global variable: r2147224305 chicken.compiler.core#no-bound-checks 
o|substituted constant variable: r2172924359 
o|substituted constant variable: r2172924359 
o|substituted constant variable: r2187824385 
o|substituted constant variable: r2187824386 
o|substituted constant variable: r2194024400 
o|substituted constant variable: r752924541 
o|substituted constant variable: r2283624546 
o|substituted constant variable: r707724547 
o|inlining procedure: k22864 
o|inlining procedure: k22864 
o|substituted constant variable: r2289824557 
o|inlining procedure: k22864 
o|replaced variables: 742 
o|removed binding forms: 3949 
o|removed conditional forms: 1 
o|inlining procedure: k7252 
o|inlining procedure: k7870 
o|inlining procedure: k7870 
o|inlining procedure: k7984 
o|inlining procedure: k7984 
o|inlining procedure: k7984 
o|contracted procedure: k8030 
o|inlining procedure: "(core.scm:711) chicken.compiler.core#alist-cons" 
o|inlining procedure: k10157 
o|inlining procedure: k10260 
o|inlining procedure: "(core.scm:930) chicken.compiler.core#alist-cons" 
o|inlining procedure: "(core.scm:1304) chicken.compiler.core#alist-cons" 
o|inlining procedure: "(core.scm:1299) chicken.compiler.core#fifth" 
o|inlining procedure: "(core.scm:1331) chicken.compiler.core#fifth" 
o|inlining procedure: "(core.scm:1317) chicken.compiler.core#alist-cons" 
o|inlining procedure: k13679 
o|inlining procedure: k14965 
o|inlining procedure: k14965 
o|substituted constant variable: r1530324812 
o|folded constant expression: (scheme#not (quote #f)) 
o|inlining procedure: k13085 
o|inlining procedure: k13085 
o|inlining procedure: "(core.scm:1504) chicken.compiler.core#alist-cons" 
o|inlining procedure: "(core.scm:1504) chicken.compiler.core#alist-cons" 
o|substituted constant variable: r157672363924846 
o|inlining procedure: k17889 
o|inlining procedure: "(core.scm:2259) chicken.compiler.core#alist-cons" 
o|inlining procedure: k18780 
o|inlining procedure: k18780 
o|inlining procedure: k18780 
o|inlining procedure: k18780 
o|inlining procedure: k18985 
o|inlining procedure: k19107 
o|inlining procedure: k19126 
o|inlining procedure: k19177 
o|inlining procedure: k19177 
o|inlining procedure: k19627 
o|inlining procedure: k20010 
o|inlining procedure: k20793 
o|inlining procedure: k21948 
o|inlining procedure: k21948 
o|inlining procedure: k22167 
o|replaced variables: 8 
o|removed binding forms: 828 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#fifth 
o|removed side-effect free assignment to unused variable: chicken.compiler.core#alist-cons 
o|substituted constant variable: r798524980 
o|substituted constant variable: r798524982 
o|substituted constant variable: r798524984 
o|substituted constant variable: r1015825021 
o|substituted constant variable: r1026125022 
o|inlining procedure: k12559 
o|substituted constant variable: z39325160 
o|contracted procedure: k18780 
o|substituted constant variable: r1878125210 
o|substituted constant variable: r1878125211 
o|substituted constant variable: r1912725218 
o|substituted constant variable: r1917825220 
o|substituted constant variable: r1958624897 
o|substituted constant variable: r1958624899 
o|substituted constant variable: r2079425245 
o|substituted constant variable: r2079425245 
o|substituted constant variable: r2194925250 
o|substituted constant variable: r2216825251 
o|substituted constant variable: r2216825251 
o|substituted constant variable: r2286524941 
o|substituted constant variable: r2286524943 
o|substituted constant variable: r2286524945 
o|replaced variables: 44 
o|removed binding forms: 28 
o|removed conditional forms: 10 
o|replaced variables: 1 
o|removed binding forms: 63 
o|removed binding forms: 1 
o|simplifications: ((if . 103) (##core#call . 1851) (let . 96)) 
o|  call simplifications:
o|    chicken.base#void
o|    scheme#boolean?
o|    scheme#char?
o|    scheme#eof-object?
o|    chicken.base#fixnum?	2
o|    chicken.fixnum#fxmax	2
o|    chicken.fixnum#fx*	2
o|    scheme#=	4
o|    scheme#set-cdr!
o|    scheme#-	7
o|    ##sys#make-structure	2
o|    ##sys#check-structure	22
o|    ##sys#block-ref	22
o|    scheme#member	3
o|    chicken.fixnum#fx<=
o|    chicken.fixnum#fx-	6
o|    scheme#call-with-current-continuation
o|    chicken.fixnum#fx>=	2
o|    scheme#number?	3
o|    scheme#<
o|    scheme#>	3
o|    scheme#cddddr	3
o|    scheme#vector	2
o|    scheme#string?	5
o|    scheme#equal?	2
o|    scheme#set-car!	3
o|    scheme#list-ref	2
o|    scheme#cddr	20
o|    scheme#assoc
o|    scheme#list	102
o|    ##sys#cons	37
o|    scheme#cdddr	11
o|    scheme#cadddr	12
o|    scheme#assq	17
o|    scheme#cdr	31
o|    scheme#caddr	40
o|    ##sys#list	114
o|    scheme#list?	10
o|    scheme#cadr	103
o|    ##sys#call-with-values	8
o|    ##sys#apply	4
o|    scheme#caar	2
o|    scheme#symbol?	17
o|    scheme#length	15
o|    scheme#+	23
o|    scheme#values	3
o|    chicken.fixnum#fx+	9
o|    scheme#eq?	310
o|    scheme#memq	22
o|    ##sys#setslot	40
o|    ##sys#check-list	74
o|    scheme#pair?	113
o|    ##sys#slot	202
o|    scheme#cons	160
o|    scheme#null?	41
o|    scheme#car	141
o|    scheme#not	64
o|contracted procedure: k6651 
o|contracted procedure: k6660 
o|contracted procedure: k6673 
o|contracted procedure: k6718 
o|contracted procedure: k6729 
o|contracted procedure: k6746 
o|contracted procedure: k6753 
o|contracted procedure: k6774 
o|contracted procedure: k6800 
o|contracted procedure: k6885 
o|contracted procedure: k6897 
o|contracted procedure: k6915 
o|contracted procedure: k6923 
o|contracted procedure: k6994 
o|contracted procedure: k7002 
o|contracted procedure: k7014 
o|contracted procedure: k7036 
o|contracted procedure: k7032 
o|contracted procedure: k7017 
o|contracted procedure: k7020 
o|contracted procedure: k7028 
o|contracted procedure: k7113 
o|contracted procedure: k7139 
o|contracted procedure: k7119 
o|contracted procedure: k7133 
o|contracted procedure: k7154 
o|contracted procedure: k7161 
o|contracted procedure: k7184 
o|contracted procedure: k7177 
o|contracted procedure: k7199 
o|contracted procedure: k7206 
o|contracted procedure: k7263 
o|contracted procedure: k7212 
o|contracted procedure: k7224 
o|contracted procedure: k7231 
o|contracted procedure: k7256 
o|contracted procedure: k7252 
o|contracted procedure: k6688 
o|contracted procedure: k6703 
o|contracted procedure: k7497 
o|contracted procedure: k7516 
o|contracted procedure: k7503 
o|contracted procedure: k7510 
o|contracted procedure: k7678 
o|contracted procedure: k7681 
o|contracted procedure: k7687 
o|contracted procedure: k7691 
o|contracted procedure: k7697 
o|contracted procedure: k7701 
o|contracted procedure: k7707 
o|contracted procedure: k7711 
o|contracted procedure: k7723 
o|contracted procedure: k7731 
o|contracted procedure: k7727 
o|contracted procedure: k7742 
o|contracted procedure: k7754 
o|contracted procedure: k7764 
o|contracted procedure: k7768 
o|contracted procedure: k7780 
o|contracted procedure: k7806 
o|contracted procedure: k7796 
o|contracted procedure: k7880 
o|contracted procedure: k7861 
o|contracted procedure: k7920 
o|contracted procedure: k7923 
o|contracted procedure: k7960 
o|contracted procedure: k7935 
o|contracted procedure: k7945 
o|contracted procedure: k7949 
o|contracted procedure: k7953 
o|contracted procedure: k7957 
o|contracted procedure: k7990 
o|contracted procedure: k7996 
o|contracted procedure: k8015 
o|contracted procedure: k8002 
o|contracted procedure: k7984 
o|contracted procedure: k8206 
o|contracted procedure: k8036 
o|contracted procedure: k8067 
o|contracted procedure: k8075 
o|contracted procedure: k8100 
o|contracted procedure: k8096 
o|contracted procedure: k8081 
o|contracted procedure: k8106 
o|contracted procedure: k8114 
o|contracted procedure: k8135 
o|contracted procedure: k8139 
o|contracted procedure: k8120 
o|contracted procedure: k8202 
o|contracted procedure: k8148 
o|contracted procedure: k8155 
o|contracted procedure: k8158 
o|contracted procedure: k8166 
o|contracted procedure: k8209 
o|contracted procedure: k8344 
o|contracted procedure: k13573 
o|contracted procedure: k8353 
o|contracted procedure: k13569 
o|contracted procedure: k8371 
o|contracted procedure: k8377 
o|contracted procedure: k13453 
o|contracted procedure: k8399 
o|contracted procedure: k8421 
o|contracted procedure: k8417 
o|contracted procedure: k8430 
o|contracted procedure: k8459 
o|contracted procedure: k8448 
o|contracted procedure: k8455 
o|contracted procedure: k8463 
o|contracted procedure: k8467 
o|contracted procedure: k8473 
o|contracted procedure: k8476 
o|contracted procedure: k8487 
o|contracted procedure: k8493 
o|contracted procedure: k8503 
o|contracted procedure: k8509 
o|contracted procedure: k8520 
o|contracted procedure: k8528 
o|contracted procedure: k8532 
o|contracted procedure: k8538 
o|contracted procedure: k8544 
o|contracted procedure: k8558 
o|contracted procedure: k8579 
o|contracted procedure: k8595 
o|contracted procedure: k8599 
o|contracted procedure: k8605 
o|contracted procedure: k8616 
o|contracted procedure: k8628 
o|contracted procedure: k8645 
o|contracted procedure: k8649 
o|contracted procedure: k8652 
o|contracted procedure: k8655 
o|contracted procedure: k8620 
o|contracted procedure: k8612 
o|contracted procedure: k8667 
o|contracted procedure: k8670 
o|contracted procedure: k8673 
o|contracted procedure: k8681 
o|contracted procedure: k8689 
o|contracted procedure: k8696 
o|contracted procedure: k8705 
o|contracted procedure: k8711 
o|contracted procedure: k687924994 
o|contracted procedure: k8724 
o|propagated global variable: z39324991 chicken.compiler.core#immutable-constants 
o|contracted procedure: k8736 
o|contracted procedure: k8745 
o|contracted procedure: k8748 
o|contracted procedure: k8761 
o|contracted procedure: k8768 
o|contracted procedure: k8786 
o|contracted procedure: k8801 
o|contracted procedure: k8805 
o|contracted procedure: k8811 
o|contracted procedure: k8818 
o|contracted procedure: k8824 
o|contracted procedure: k8827 
o|contracted procedure: k8860 
o|contracted procedure: k8830 
o|contracted procedure: k8847 
o|contracted procedure: k8850 
o|contracted procedure: k8872 
o|contracted procedure: k8875 
o|contracted procedure: k8881 
o|contracted procedure: k8884 
o|contracted procedure: k8896 
o|contracted procedure: k8906 
o|contracted procedure: k8919 
o|contracted procedure: k8924 
o|contracted procedure: k8927 
o|contracted procedure: k8969 
o|contracted procedure: k9024 
o|contracted procedure: k8988 
o|contracted procedure: k8991 
o|contracted procedure: k8994 
o|contracted procedure: k9002 
o|contracted procedure: k9006 
o|contracted procedure: k9014 
o|contracted procedure: k9018 
o|contracted procedure: k9040 
o|contracted procedure: k9043 
o|contracted procedure: k9046 
o|contracted procedure: k9054 
o|contracted procedure: k9062 
o|contracted procedure: k9071 
o|contracted procedure: k9074 
o|contracted procedure: k9091 
o|contracted procedure: k9103 
o|contracted procedure: k9087 
o|contracted procedure: k9083 
o|contracted procedure: k9114 
o|contracted procedure: k9142 
o|contracted procedure: k9138 
o|contracted procedure: k9134 
o|contracted procedure: k9151 
o|contracted procedure: k9173 
o|contracted procedure: k9123 
o|contracted procedure: k9127 
o|contracted procedure: k9169 
o|contracted procedure: k9154 
o|contracted procedure: k9157 
o|contracted procedure: k9165 
o|contracted procedure: k9185 
o|contracted procedure: k9207 
o|contracted procedure: k9100 
o|contracted procedure: k9203 
o|contracted procedure: k9188 
o|contracted procedure: k9191 
o|contracted procedure: k9199 
o|contracted procedure: k9216 
o|contracted procedure: k9219 
o|contracted procedure: k9225 
o|contracted procedure: k9228 
o|contracted procedure: k9234 
o|contracted procedure: k9245 
o|contracted procedure: k9257 
o|contracted procedure: k9272 
o|contracted procedure: k9285 
o|contracted procedure: k9281 
o|contracted procedure: k9288 
o|contracted procedure: k9268 
o|contracted procedure: k9264 
o|contracted procedure: k9241 
o|contracted procedure: k9299 
o|contracted procedure: k9319 
o|contracted procedure: k9315 
o|contracted procedure: k9311 
o|contracted procedure: k9364 
o|contracted procedure: k9328 
o|contracted procedure: k9354 
o|contracted procedure: k9358 
o|contracted procedure: k9350 
o|contracted procedure: k9331 
o|contracted procedure: k9334 
o|contracted procedure: k9342 
o|contracted procedure: k9346 
o|contracted procedure: k9412 
o|contracted procedure: k9376 
o|contracted procedure: k9379 
o|contracted procedure: k9382 
o|contracted procedure: k9390 
o|contracted procedure: k9394 
o|contracted procedure: k9402 
o|contracted procedure: k9406 
o|contracted procedure: k9424 
o|contracted procedure: k9446 
o|contracted procedure: k9254 
o|contracted procedure: k9442 
o|contracted procedure: k9427 
o|contracted procedure: k9430 
o|contracted procedure: k9438 
o|contracted procedure: k9458 
o|contracted procedure: k9461 
o|contracted procedure: k9464 
o|contracted procedure: k9472 
o|contracted procedure: k9480 
o|contracted procedure: k9489 
o|contracted procedure: k9492 
o|contracted procedure: k9495 
o|contracted procedure: k9509 
o|contracted procedure: k9533 
o|contracted procedure: k9547 
o|contracted procedure: k9550 
o|contracted procedure: k9553 
o|contracted procedure: k9561 
o|contracted procedure: k9569 
o|contracted procedure: k9578 
o|contracted procedure: k9581 
o|contracted procedure: k9595 
o|contracted procedure: k9598 
o|contracted procedure: k9607 
o|contracted procedure: k9619 
o|contracted procedure: k9628 
o|contracted procedure: k9647 
o|contracted procedure: k9653 
o|contracted procedure: k9662 
o|contracted procedure: k9679 
o|contracted procedure: k9742 
o|contracted procedure: k9738 
o|contracted procedure: k9770 
o|contracted procedure: k9773 
o|contracted procedure: k9776 
o|contracted procedure: k9784 
o|contracted procedure: k9792 
o|contracted procedure: k9822 
o|contracted procedure: k9854 
o|contracted procedure: k9865 
o|contracted procedure: k9879 
o|contracted procedure: k9909 
o|contracted procedure: k9912 
o|contracted procedure: k9928 
o|contracted procedure: k9950 
o|contracted procedure: k9888 
o|contracted procedure: k9946 
o|contracted procedure: k9931 
o|contracted procedure: k9934 
o|contracted procedure: k9942 
o|contracted procedure: k9906 
o|contracted procedure: k9959 
o|contracted procedure: k9962 
o|contracted procedure: k9988 
o|contracted procedure: k9991 
o|contracted procedure: k10003 
o|contracted procedure: k10012 
o|contracted procedure: k10015 
o|contracted procedure: k10052 
o|contracted procedure: k10071 
o|contracted procedure: k10081 
o|contracted procedure: k10085 
o|contracted procedure: k10098 
o|contracted procedure: k10120 
o|contracted procedure: k9971 
o|contracted procedure: k10116 
o|contracted procedure: k10101 
o|contracted procedure: k10104 
o|contracted procedure: k10112 
o|contracted procedure: k9985 
o|contracted procedure: k10129 
o|contracted procedure: k10164 
o|contracted procedure: k10168 
o|contracted procedure: k10157 
o|contracted procedure: k10183 
o|contracted procedure: k10190 
o|contracted procedure: k10215 
o|contracted procedure: k10206 
o|contracted procedure: k10232 
o|contracted procedure: k10228 
o|contracted procedure: k10221 
o|contracted procedure: k10238 
o|contracted procedure: k10241 
o|contracted procedure: k10244 
o|contracted procedure: k10267 
o|contracted procedure: k10271 
o|contracted procedure: k10290 
o|contracted procedure: k10282 
o|contracted procedure: k10286 
o|contracted procedure: k10275 
o|inlining procedure: k10260 
o|contracted procedure: k10294 
o|contracted procedure: k687925029 
o|contracted procedure: k10313 
o|contracted procedure: k10323 
o|contracted procedure: k10326 
o|contracted procedure: k10348 
o|contracted procedure: k10369 
o|contracted procedure: k10375 
o|contracted procedure: k10378 
o|contracted procedure: k10381 
o|contracted procedure: k10390 
o|contracted procedure: k10412 
o|contracted procedure: k10424 
o|contracted procedure: k10434 
o|contracted procedure: k10438 
o|contracted procedure: k10405 
o|contracted procedure: k10409 
o|contracted procedure: k10452 
o|contracted procedure: k10471 
o|contracted procedure: k10483 
o|contracted procedure: k10493 
o|contracted procedure: k10497 
o|contracted procedure: k10464 
o|contracted procedure: k10468 
o|contracted procedure: k10506 
o|contracted procedure: k10509 
o|contracted procedure: k10512 
o|contracted procedure: k10520 
o|contracted procedure: k10528 
o|contracted procedure: k10537 
o|contracted procedure: k10544 
o|contracted procedure: k10548 
o|contracted procedure: k10594 
o|contracted procedure: k10576 
o|contracted procedure: k10587 
o|contracted procedure: k10600 
o|contracted procedure: k10607 
o|contracted procedure: k10618 
o|contracted procedure: k10621 
o|contracted procedure: k10638 
o|contracted procedure: k10634 
o|contracted procedure: k10647 
o|contracted procedure: k10650 
o|contracted procedure: k10653 
o|contracted procedure: k10661 
o|contracted procedure: k10669 
o|contracted procedure: k10678 
o|contracted procedure: k10684 
o|contracted procedure: k10687 
o|contracted procedure: k10856 
o|contracted procedure: k10719 
o|contracted procedure: k10726 
o|contracted procedure: k10774 
o|contracted procedure: k10785 
o|contracted procedure: k10797 
o|contracted procedure: k10800 
o|contracted procedure: k10803 
o|contracted procedure: k10811 
o|contracted procedure: k10819 
o|contracted procedure: k10849 
o|contracted procedure: k10869 
o|contracted procedure: k8309 
o|contracted procedure: k8249 
o|contracted procedure: k8270 
o|contracted procedure: k8285 
o|contracted procedure: k8295 
o|contracted procedure: k8299 
o|contracted procedure: k10882 
o|contracted procedure: k10895 
o|contracted procedure: k10970 
o|contracted procedure: k10979 
o|contracted procedure: k11026 
o|contracted procedure: k11069 
o|contracted procedure: k11073 
o|contracted procedure: k11224 
o|contracted procedure: k11120 
o|contracted procedure: k11126 
o|contracted procedure: k11134 
o|contracted procedure: k11146 
o|contracted procedure: k11155 
o|contracted procedure: k11173 
o|contracted procedure: k11164 
o|contracted procedure: k11179 
o|contracted procedure: k11191 
o|contracted procedure: k11194 
o|contracted procedure: k11197 
o|contracted procedure: k11205 
o|contracted procedure: k11213 
o|contracted procedure: k11227 
o|contracted procedure: k11237 
o|contracted procedure: k11243 
o|contracted procedure: k11246 
o|contracted procedure: k11251 
o|contracted procedure: k11254 
o|contracted procedure: k11266 
o|contracted procedure: k11329 
o|contracted procedure: k11332 
o|contracted procedure: k11335 
o|contracted procedure: k11343 
o|contracted procedure: k11351 
o|contracted procedure: k11360 
o|contracted procedure: k11363 
o|contracted procedure: k11406 
o|contracted procedure: k11409 
o|contracted procedure: k11418 
o|contracted procedure: k11424 
o|contracted procedure: k11432 
o|contracted procedure: k11466 
o|contracted procedure: k11446 
o|contracted procedure: k11462 
o|contracted procedure: k11454 
o|contracted procedure: k11450 
o|contracted procedure: k11442 
o|contracted procedure: k11476 
o|contracted procedure: k11484 
o|contracted procedure: k11518 
o|contracted procedure: k11498 
o|contracted procedure: k11506 
o|contracted procedure: k11510 
o|contracted procedure: k11502 
o|contracted procedure: k11494 
o|contracted procedure: k11539 
o|contracted procedure: k11542 
o|contracted procedure: k11624 
o|contracted procedure: k11699 
o|contracted procedure: k11687 
o|contracted procedure: k11695 
o|contracted procedure: k11691 
o|contracted procedure: k11683 
o|contracted procedure: k11708 
o|contracted procedure: k11761 
o|contracted procedure: k11772 
o|contracted procedure: k11780 
o|contracted procedure: k11794 
o|contracted procedure: k11776 
o|contracted procedure: k11768 
o|contracted procedure: k11806 
o|contracted procedure: k11809 
o|contracted procedure: k11812 
o|contracted procedure: k11820 
o|contracted procedure: k11828 
o|contracted procedure: k11837 
o|contracted procedure: k11844 
o|contracted procedure: k11856 
o|contracted procedure: k11860 
o|contracted procedure: k11866 
o|contracted procedure: k11877 
o|contracted procedure: k11880 
o|contracted procedure: k11883 
o|contracted procedure: k11873 
o|contracted procedure: k11894 
o|contracted procedure: k11903 
o|contracted procedure: k11906 
o|contracted procedure: k11909 
o|contracted procedure: k11917 
o|contracted procedure: k11925 
o|contracted procedure: k11934 
o|contracted procedure: k11941 
o|contracted procedure: k11949 
o|contracted procedure: k11955 
o|contracted procedure: k11962 
o|contracted procedure: k11974 
o|contracted procedure: k11978 
o|contracted procedure: k11984 
o|contracted procedure: k11987 
o|contracted procedure: k11990 
o|contracted procedure: k12002 
o|contracted procedure: k12005 
o|contracted procedure: k12012 
o|contracted procedure: k12018 
o|contracted procedure: k12024 
o|contracted procedure: k12039 
o|contracted procedure: k12046 
o|contracted procedure: k12072 
o|contracted procedure: k12085 
o|contracted procedure: k12098 
o|contracted procedure: k12111 
o|contracted procedure: k12124 
o|contracted procedure: k16237 
o|contracted procedure: k16246 
o|contracted procedure: k16254 
o|contracted procedure: k16260 
o|contracted procedure: k16266 
o|contracted procedure: k16281 
o|contracted procedure: k16303 
o|contracted procedure: k16299 
o|contracted procedure: k16284 
o|contracted procedure: k16287 
o|contracted procedure: k16295 
o|contracted procedure: k16315 
o|contracted procedure: k16337 
o|contracted procedure: k16333 
o|contracted procedure: k16318 
o|contracted procedure: k16321 
o|contracted procedure: k16329 
o|contracted procedure: k16344 
o|contracted procedure: k16354 
o|contracted procedure: k16381 
o|contracted procedure: k16366 
o|contracted procedure: k16377 
o|contracted procedure: k16373 
o|contracted procedure: k12137 
o|contracted procedure: k12154 
o|contracted procedure: k12150 
o|contracted procedure: k12167 
o|contracted procedure: k12157 
o|contracted procedure: k12171 
o|contracted procedure: k12175 
o|contracted procedure: k12181 
o|contracted procedure: k12184 
o|contracted procedure: k12190 
o|contracted procedure: k12199 
o|contracted procedure: k12257 
o|contracted procedure: k12237 
o|contracted procedure: k12233 
o|contracted procedure: k12248 
o|contracted procedure: k12245 
o|contracted procedure: k12297 
o|contracted procedure: k12303 
o|contracted procedure: k12306 
o|contracted procedure: k12315 
o|contracted procedure: k12318 
o|contracted procedure: k12351 
o|contracted procedure: k12331 
o|contracted procedure: k12343 
o|contracted procedure: k12335 
o|contracted procedure: k687925068 
o|contracted procedure: k12339 
o|propagated global variable: z39325065 chicken.compiler.core#external-to-pointer 
o|contracted procedure: k683425073 
o|contracted procedure: k12359 
o|contracted procedure: k12390 
o|contracted procedure: k12393 
o|contracted procedure: k12537 
o|contracted procedure: k12530 
o|contracted procedure: k12405 
o|contracted procedure: k12527 
o|contracted procedure: k12412 
o|contracted procedure: k687925085 
o|contracted procedure: k12415 
o|contracted procedure: k12505 
o|contracted procedure: k12497 
o|contracted procedure: k12501 
o|contracted procedure: k12493 
o|contracted procedure: k12489 
o|contracted procedure: k12449 
o|contracted procedure: k12453 
o|contracted procedure: k12445 
o|contracted procedure: k12465 
o|contracted procedure: k683425078 
o|contracted procedure: k12482 
o|contracted procedure: k12541 
o|contracted procedure: k12547 
o|contracted procedure: k12550 
o|contracted procedure: k12553 
o|contracted procedure: k12597 
o|contracted procedure: k12600 
o|contracted procedure: k12606 
o|contracted procedure: k12697 
o|contracted procedure: k12693 
o|contracted procedure: k12619 
o|contracted procedure: k12632 
o|contracted procedure: k12664 
o|contracted procedure: k12660 
o|contracted procedure: k12762 
o|contracted procedure: k12772 
o|contracted procedure: k12765 
o|contracted procedure: k12790 
o|contracted procedure: k12801 
o|contracted procedure: k13699 
o|contracted procedure: k13670 
o|contracted procedure: k13676 
o|contracted procedure: k13692 
o|inlining procedure: k13679 
o|contracted procedure: k13689 
o|inlining procedure: k13679 
o|contracted procedure: k6929 
o|contracted procedure: k6941 
o|contracted procedure: k6964 
o|contracted procedure: k6972 
o|removed unused formal parameters: (return2708) 
o|contracted procedure: k13767 
o|contracted procedure: k13786 
o|contracted procedure: k13810 
o|contracted procedure: k13814 
o|contracted procedure: k13820 
o|contracted procedure: k13826 
o|contracted procedure: k13845 
o|contracted procedure: k13851 
o|contracted procedure: k13870 
o|contracted procedure: k13876 
o|contracted procedure: k13899 
o|contracted procedure: k13910 
o|contracted procedure: k13916 
o|contracted procedure: k13919 
o|contracted procedure: k13926 
o|contracted procedure: k13933 
o|contracted procedure: k13940 
o|contracted procedure: k13947 
o|contracted procedure: k13954 
o|contracted procedure: k13961 
o|contracted procedure: k13968 
o|contracted procedure: k13975 
o|contracted procedure: k13984 
o|contracted procedure: k13996 
o|contracted procedure: k14006 
o|contracted procedure: k14010 
o|contracted procedure: k14016 
o|contracted procedure: k14023 
o|contracted procedure: k14034 
o|contracted procedure: k14048 
o|contracted procedure: k14060 
o|contracted procedure: k14070 
o|contracted procedure: k14074 
o|contracted procedure: k14083 
o|contracted procedure: k14093 
o|contracted procedure: k14097 
o|contracted procedure: k14103 
o|contracted procedure: k14110 
o|contracted procedure: k14121 
o|contracted procedure: k14141 
o|contracted procedure: k14151 
o|contracted procedure: k14155 
o|contracted procedure: k14164 
o|contracted procedure: k14174 
o|contracted procedure: k14178 
o|contracted procedure: k14186 
o|contracted procedure: k14206 
o|contracted procedure: k14213 
o|contracted procedure: k14220 
o|contracted procedure: k14227 
o|contracted procedure: k14238 
o|contracted procedure: k14250 
o|contracted procedure: k14260 
o|contracted procedure: k14264 
o|contracted procedure: k14272 
o|contracted procedure: k14283 
o|contracted procedure: k14295 
o|contracted procedure: k14305 
o|contracted procedure: k14309 
o|contracted procedure: k14317 
o|contracted procedure: k14329 
o|contracted procedure: k14351 
o|contracted procedure: k14335 
o|contracted procedure: k14357 
o|contracted procedure: k14379 
o|contracted procedure: k14363 
o|contracted procedure: k14385 
o|contracted procedure: k14436 
o|contracted procedure: k14391 
o|contracted procedure: k14403 
o|contracted procedure: k14415 
o|contracted procedure: k14425 
o|contracted procedure: k14429 
o|contracted procedure: k14442 
o|contracted procedure: k14468 
o|contracted procedure: k14448 
o|contracted procedure: k14474 
o|contracted procedure: k14525 
o|contracted procedure: k14481 
o|contracted procedure: k14492 
o|contracted procedure: k14504 
o|contracted procedure: k14514 
o|contracted procedure: k14518 
o|contracted procedure: k14537 
o|contracted procedure: k14547 
o|contracted procedure: k14561 
o|contracted procedure: k14567 
o|contracted procedure: k14574 
o|contracted procedure: k14577 
o|contracted procedure: k14586 
o|contracted procedure: k14590 
o|contracted procedure: k14602 
o|contracted procedure: k14612 
o|contracted procedure: k14616 
o|contracted procedure: k14624 
o|contracted procedure: k14631 
o|contracted procedure: k14643 
o|contracted procedure: k14653 
o|contracted procedure: k14657 
o|contracted procedure: k14665 
o|contracted procedure: k14672 
o|contracted procedure: k14678 
o|contracted procedure: k14690 
o|contracted procedure: k14702 
o|contracted procedure: k14712 
o|contracted procedure: k14716 
o|contracted procedure: k14726 
o|contracted procedure: k14732 
o|contracted procedure: k14738 
o|contracted procedure: k14748 
o|contracted procedure: k14754 
o|contracted procedure: k14760 
o|contracted procedure: k14770 
o|contracted procedure: k14790 
o|contracted procedure: k14802 
o|contracted procedure: k14812 
o|contracted procedure: k14816 
o|contracted procedure: k14827 
o|contracted procedure: k14835 
o|contracted procedure: k14910 
o|contracted procedure: k14922 
o|contracted procedure: k14925 
o|contracted procedure: k14928 
o|contracted procedure: k14936 
o|contracted procedure: k14944 
o|contracted procedure: k14843 
o|contracted procedure: k14868 
o|contracted procedure: k14872 
o|contracted procedure: k14878 
o|contracted procedure: k14884 
o|contracted procedure: k14901 
o|contracted procedure: k14890 
o|contracted procedure: k14897 
o|contracted procedure: k14955 
o|contracted procedure: k14962 
o|contracted procedure: k14992 
o|contracted procedure: k14977 
o|contracted procedure: k14983 
o|contracted procedure: k15000 
o|contracted procedure: k15007 
o|contracted procedure: k15020 
o|contracted procedure: k15032 
o|contracted procedure: k15042 
o|contracted procedure: k15046 
o|contracted procedure: k15056 
o|contracted procedure: k15062 
o|contracted procedure: k15074 
o|contracted procedure: k15086 
o|contracted procedure: k15096 
o|contracted procedure: k15100 
o|contracted procedure: k15110 
o|contracted procedure: k15118 
o|contracted procedure: k15129 
o|contracted procedure: k15141 
o|contracted procedure: k15151 
o|contracted procedure: k15155 
o|contracted procedure: k15165 
o|contracted procedure: k15247 
o|contracted procedure: k15233 
o|contracted procedure: k15263 
o|contracted procedure: k15266 
o|contracted procedure: k15272 
o|contracted procedure: k15279 
o|contracted procedure: k15294 
o|contracted procedure: k15298 
o|contracted procedure: k15305 
o|contracted procedure: k15311 
o|contracted procedure: k15318 
o|contracted procedure: k15302 
o|contracted procedure: k15325 
o|contracted procedure: k15337 
o|contracted procedure: k15347 
o|contracted procedure: k15351 
o|contracted procedure: k15357 
o|contracted procedure: k15400 
o|contracted procedure: k15415 
o|contracted procedure: k15419 
o|contracted procedure: k15425 
o|contracted procedure: k15443 
o|contracted procedure: k15431 
o|contracted procedure: k15439 
o|contracted procedure: k15447 
o|contracted procedure: k15459 
o|contracted procedure: k15469 
o|contracted procedure: k15473 
o|contracted procedure: k15479 
o|contracted procedure: k15486 
o|contracted procedure: k15591 
o|removed unused parameter to known procedure: return2708 a13755 
o|contracted procedure: k12820 
o|contracted procedure: k12797 
o|contracted procedure: k12832 
o|contracted procedure: k12835 
o|contracted procedure: k12838 
o|contracted procedure: k12846 
o|contracted procedure: k12854 
o|contracted procedure: k12863 
o|contracted procedure: k12876 
o|contracted procedure: k6445 
o|contracted procedure: k6459 
o|contracted procedure: k6469 
o|contracted procedure: k6463 
o|contracted procedure: k12882 
o|contracted procedure: k13168 
o|contracted procedure: k12885 
o|contracted procedure: k13164 
o|contracted procedure: k12891 
o|contracted procedure: k13160 
o|contracted procedure: k12894 
o|contracted procedure: k12897 
o|contracted procedure: k12918 
o|contracted procedure: k12930 
o|contracted procedure: k12926 
o|contracted procedure: k12946 
o|contracted procedure: k12942 
o|contracted procedure: k12953 
o|contracted procedure: k12976 
o|contracted procedure: k12972 
o|contracted procedure: k12964 
o|contracted procedure: k12968 
o|contracted procedure: k12960 
o|contracted procedure: k12982 
o|contracted procedure: k12991 
o|contracted procedure: k13034 
o|contracted procedure: k13030 
o|contracted procedure: k13026 
o|contracted procedure: k13022 
o|contracted procedure: k13002 
o|contracted procedure: k13018 
o|contracted procedure: k13014 
o|contracted procedure: k13006 
o|contracted procedure: k12998 
o|contracted procedure: k13046 
o|contracted procedure: k13049 
o|contracted procedure: k13052 
o|contracted procedure: k13059 
o|contracted procedure: k13117 
o|contracted procedure: k13082 
o|contracted procedure: k13113 
o|contracted procedure: k13091 
o|contracted procedure: k13105 
o|contracted procedure: k13109 
o|contracted procedure: k13101 
o|contracted procedure: k13085 
o|contracted procedure: k13128 
o|contracted procedure: k13124 
o|contracted procedure: k13174 
o|contracted procedure: k13177 
o|contracted procedure: k13183 
o|contracted procedure: k13186 
o|contracted procedure: k13202 
o|contracted procedure: k13206 
o|contracted procedure: k13198 
o|contracted procedure: k13212 
o|contracted procedure: k13224 
o|contracted procedure: k13233 
o|contracted procedure: k13240 
o|contracted procedure: k13255 
o|contracted procedure: k13251 
o|contracted procedure: k13270 
o|contracted procedure: k13266 
o|contracted procedure: k13273 
o|contracted procedure: k13279 
o|contracted procedure: k13292 
o|contracted procedure: k13300 
o|contracted procedure: k687925156 
o|contracted procedure: k687925163 
o|contracted procedure: k13418 
o|contracted procedure: k13478 
o|contracted procedure: k13565 
o|contracted procedure: k13512 
o|contracted procedure: k13557 
o|contracted procedure: k13547 
o|contracted procedure: k13551 
o|contracted procedure: k13543 
o|contracted procedure: k13579 
o|contracted procedure: k13587 
o|contracted procedure: k13599 
o|contracted procedure: k13602 
o|contracted procedure: k13605 
o|contracted procedure: k13613 
o|contracted procedure: k13621 
o|contracted procedure: k13634 
o|contracted procedure: k13647 
o|contracted procedure: k13655 
o|contracted procedure: k15604 
o|contracted procedure: k15623 
o|contracted procedure: k15632 
o|contracted procedure: k15641 
o|contracted procedure: k15650 
o|contracted procedure: k15659 
o|contracted procedure: k15668 
o|contracted procedure: k15677 
o|contracted procedure: k15686 
o|contracted procedure: k15976 
o|contracted procedure: k15800 
o|contracted procedure: k15803 
o|contracted procedure: k15809 
o|contracted procedure: k15821 
o|contracted procedure: k15824 
o|contracted procedure: k15834 
o|contracted procedure: k15842 
o|contracted procedure: k15846 
o|contracted procedure: k15862 
o|contracted procedure: k15911 
o|contracted procedure: k15903 
o|contracted procedure: k15907 
o|contracted procedure: k15899 
o|contracted procedure: k15895 
o|contracted procedure: k15875 
o|contracted procedure: k15891 
o|contracted procedure: k15956 
o|contracted procedure: k15920 
o|contracted procedure: k15923 
o|contracted procedure: k15926 
o|contracted procedure: k15934 
o|contracted procedure: k15938 
o|contracted procedure: k15946 
o|contracted procedure: k15950 
o|contracted procedure: k15966 
o|contracted procedure: k15986 
o|contracted procedure: k15989 
o|contracted procedure: k16001 
o|contracted procedure: k16004 
o|contracted procedure: k16007 
o|contracted procedure: k16015 
o|contracted procedure: k16023 
o|contracted procedure: k16029 
o|contracted procedure: k16041 
o|contracted procedure: k16053 
o|contracted procedure: k16056 
o|contracted procedure: k16059 
o|contracted procedure: k16067 
o|contracted procedure: k16075 
o|contracted procedure: k15707 
o|contracted procedure: k15713 
o|contracted procedure: k15716 
o|contracted procedure: k15722 
o|contracted procedure: k15741 
o|contracted procedure: k15744 
o|contracted procedure: k15769 
o|contracted procedure: k15772 
o|contracted procedure: k16084 
o|contracted procedure: k16090 
o|contracted procedure: k16093 
o|contracted procedure: k16099 
o|contracted procedure: k16112 
o|contracted procedure: k16121 
o|contracted procedure: k16124 
o|contracted procedure: k16130 
o|contracted procedure: k16138 
o|contracted procedure: k16144 
o|contracted procedure: k16150 
o|contracted procedure: k16165 
o|contracted procedure: k16187 
o|contracted procedure: k16183 
o|contracted procedure: k16168 
o|contracted procedure: k16171 
o|contracted procedure: k16179 
o|contracted procedure: k16199 
o|contracted procedure: k16221 
o|contracted procedure: k16217 
o|contracted procedure: k16202 
o|contracted procedure: k16205 
o|contracted procedure: k16213 
o|contracted procedure: k16228 
o|contracted procedure: k16435 
o|contracted procedure: k16401 
o|contracted procedure: k16405 
o|contracted procedure: k16413 
o|contracted procedure: k16423 
o|contracted procedure: k16427 
o|contracted procedure: k16444 
o|contracted procedure: k16451 
o|contracted procedure: k16480 
o|contracted procedure: k16492 
o|contracted procedure: k16507 
o|contracted procedure: k16511 
o|contracted procedure: k16522 
o|contracted procedure: k16526 
o|contracted procedure: k16538 
o|contracted procedure: k16548 
o|contracted procedure: k16560 
o|contracted procedure: k16564 
o|contracted procedure: k16593 
o|contracted procedure: k16568 
o|contracted procedure: k16572 
o|contracted procedure: k16599 
o|contracted procedure: k16611 
o|contracted procedure: k16618 
o|contracted procedure: k16625 
o|contracted procedure: k16643 
o|contracted procedure: k16650 
o|contracted procedure: k16654 
o|contracted procedure: k16664 
o|contracted procedure: k16670 
o|contracted procedure: k16676 
o|contracted procedure: k16679 
o|contracted procedure: k16695 
o|contracted procedure: k16701 
o|contracted procedure: k16761 
o|contracted procedure: k16754 
o|contracted procedure: k16707 
o|contracted procedure: k16751 
o|contracted procedure: k16710 
o|contracted procedure: k16717 
o|contracted procedure: k16727 
o|contracted procedure: k16731 
o|contracted procedure: k16747 
o|contracted procedure: k16767 
o|contracted procedure: k16778 
o|contracted procedure: k16788 
o|contracted procedure: k16802 
o|contracted procedure: k16814 
o|contracted procedure: k16821 
o|contracted procedure: k16829 
o|contracted procedure: k16832 
o|contracted procedure: k16838 
o|contracted procedure: k16848 
o|contracted procedure: k17098 
o|contracted procedure: k17102 
o|contracted procedure: k17114 
o|contracted procedure: k17118 
o|contracted procedure: k17151 
o|contracted procedure: k17126 
o|contracted procedure: k17130 
o|contracted procedure: k16873 
o|contracted procedure: k16876 
o|contracted procedure: k16883 
o|contracted procedure: k16889 
o|contracted procedure: k7064 
o|contracted procedure: k7054 
o|contracted procedure: k16915 
o|contracted procedure: k16921 
o|contracted procedure: k16927 
o|contracted procedure: k16933 
o|contracted procedure: k16939 
o|contracted procedure: k16977 
o|contracted procedure: k16983 
o|contracted procedure: k16989 
o|contracted procedure: k17021 
o|contracted procedure: k17025 
o|contracted procedure: k17082 
o|contracted procedure: k17057 
o|contracted procedure: k17061 
o|contracted procedure: k17182 
o|contracted procedure: k17204 
o|contracted procedure: k17230 
o|contracted procedure: k17234 
o|contracted procedure: k17245 
o|contracted procedure: k17249 
o|contracted procedure: k17257 
o|contracted procedure: k17261 
o|contracted procedure: k17269 
o|contracted procedure: k19351 
o|contracted procedure: k17301 
o|contracted procedure: k17311 
o|contracted procedure: k17332 
o|contracted procedure: k17341 
o|contracted procedure: k17344 
o|contracted procedure: k17347 
o|contracted procedure: k17356 
o|contracted procedure: k17365 
o|contracted procedure: k17374 
o|contracted procedure: k17387 
o|contracted procedure: k17390 
o|contracted procedure: k17402 
o|contracted procedure: k17408 
o|contracted procedure: k17423 
o|contracted procedure: k17426 
o|contracted procedure: k17429 
o|contracted procedure: k17442 
o|contracted procedure: k17461 
o|contracted procedure: k17467 
o|contracted procedure: k17473 
o|contracted procedure: k17484 
o|contracted procedure: k17516 
o|contracted procedure: k17519 
o|contracted procedure: k17534 
o|contracted procedure: k17541 
o|contracted procedure: k17548 
o|contracted procedure: k17551 
o|contracted procedure: k17573 
o|contracted procedure: k17583 
o|contracted procedure: k17594 
o|contracted procedure: k17606 
o|contracted procedure: k17619 
o|contracted procedure: k17629 
o|contracted procedure: k17633 
o|contracted procedure: k17639 
o|contracted procedure: k17642 
o|contracted procedure: k17652 
o|contracted procedure: k17658 
o|contracted procedure: k17672 
o|contracted procedure: k17698 
o|contracted procedure: k17702 
o|contracted procedure: k17710 
o|contracted procedure: k17721 
o|contracted procedure: k17728 
o|contracted procedure: k17717 
o|contracted procedure: k17745 
o|contracted procedure: k17754 
o|contracted procedure: k17764 
o|contracted procedure: k17768 
o|contracted procedure: k17780 
o|contracted procedure: k17783 
o|contracted procedure: k17786 
o|contracted procedure: k17789 
o|contracted procedure: k17818 
o|contracted procedure: k17827 
o|contracted procedure: k17836 
o|contracted procedure: k17846 
o|contracted procedure: k17855 
o|contracted procedure: k17864 
o|contracted procedure: k17880 
o|contracted procedure: k17883 
o|contracted procedure: k17886 
o|contracted procedure: k17907 
o|contracted procedure: k17962 
o|contracted procedure: k17968 
o|contracted procedure: k17993 
o|contracted procedure: k18005 
o|contracted procedure: k18015 
o|contracted procedure: k18019 
o|contracted procedure: k18032 
o|contracted procedure: k18045 
o|contracted procedure: k18051 
o|contracted procedure: k18057 
o|contracted procedure: k18066 
o|contracted procedure: k18081 
o|contracted procedure: k18084 
o|contracted procedure: k18087 
o|contracted procedure: k18106 
o|contracted procedure: k18109 
o|contracted procedure: k18112 
o|contracted procedure: k18154 
o|contracted procedure: k18169 
o|contracted procedure: k18175 
o|contracted procedure: k18184 
o|contracted procedure: k18187 
o|contracted procedure: k18220 
o|contracted procedure: k18223 
o|contracted procedure: k18282 
o|contracted procedure: k18289 
o|contracted procedure: k18314 
o|contracted procedure: k18320 
o|contracted procedure: k18341 
o|contracted procedure: k18347 
o|contracted procedure: k18375 
o|contracted procedure: k687925207 
o|contracted procedure: k18371 
o|contracted procedure: k18400 
o|contracted procedure: k18405 
o|contracted procedure: k18411 
o|contracted procedure: k18418 
o|contracted procedure: k18424 
o|contracted procedure: k18430 
o|contracted procedure: k18437 
o|contracted procedure: k18445 
o|contracted procedure: k18451 
o|contracted procedure: k18457 
o|contracted procedure: k18464 
o|contracted procedure: k18471 
o|contracted procedure: k18478 
o|contracted procedure: k18485 
o|contracted procedure: k18493 
o|contracted procedure: k18501 
o|contracted procedure: k18530 
o|contracted procedure: k19324 
o|contracted procedure: k18537 
o|contracted procedure: k19321 
o|contracted procedure: k18541 
o|contracted procedure: k18689 
o|contracted procedure: k18580 
o|contracted procedure: k18583 
o|contracted procedure: k18586 
o|contracted procedure: k18663 
o|contracted procedure: k18601 
o|contracted procedure: k18604 
o|contracted procedure: k18607 
o|contracted procedure: k18616 
o|contracted procedure: k18629 
o|contracted procedure: k18635 
o|contracted procedure: k18642 
o|contracted procedure: k18646 
o|contracted procedure: k18666 
o|contracted procedure: k18672 
o|contracted procedure: k18699 
o|contracted procedure: k18705 
o|contracted procedure: k18708 
o|contracted procedure: k18723 
o|contracted procedure: k18735 
o|contracted procedure: k18738 
o|contracted procedure: k18759 
o|contracted procedure: k18786 
o|contracted procedure: k18792 
o|contracted procedure: k18807 
o|contracted procedure: k18810 
o|contracted procedure: k18813 
o|contracted procedure: k18963 
o|contracted procedure: k18850 
o|contracted procedure: k18859 
o|contracted procedure: k18866 
o|contracted procedure: k18885 
o|contracted procedure: k18898 
o|contracted procedure: k18920 
o|contracted procedure: k18934 
o|contracted procedure: k18946 
o|contracted procedure: k18956 
o|contracted procedure: k18960 
o|contracted procedure: k18976 
o|contracted procedure: k18985 
o|contracted procedure: k19026 
o|contracted procedure: k19017 
o|contracted procedure: k19032 
o|contracted procedure: k19067 
o|contracted procedure: k19035 
o|contracted procedure: k19083 
o|contracted procedure: k19123 
o|contracted procedure: k19104 
o|contracted procedure: k19126 
o|contracted procedure: k19214 
o|contracted procedure: k19220 
o|contracted procedure: k19226 
o|contracted procedure: k19232 
o|contracted procedure: k19254 
o|contracted procedure: k19268 
o|contracted procedure: k19275 
o|contracted procedure: k19286 
o|contracted procedure: k19298 
o|contracted procedure: k19308 
o|contracted procedure: k19312 
o|contracted procedure: k19333 
o|contracted procedure: k19343 
o|contracted procedure: k19347 
o|contracted procedure: k19397 
o|contracted procedure: k19400 
o|contracted procedure: k19403 
o|contracted procedure: k19409 
o|contracted procedure: k19418 
o|contracted procedure: k19427 
o|contracted procedure: k19436 
o|contracted procedure: k19451 
o|contracted procedure: k19455 
o|contracted procedure: k19459 
o|contracted procedure: k19469 
o|contracted procedure: k19462 
o|contracted procedure: k19475 
o|contracted procedure: k19478 
o|contracted procedure: k19487 
o|contracted procedure: k19494 
o|contracted procedure: k19500 
o|contracted procedure: k19503 
o|contracted procedure: k19506 
o|contracted procedure: k19739 
o|contracted procedure: k19732 
o|contracted procedure: k19509 
o|contracted procedure: k19512 
o|contracted procedure: k19522 
o|contracted procedure: k19530 
o|contracted procedure: k19542 
o|contracted procedure: k19545 
o|contracted procedure: k19548 
o|contracted procedure: k19556 
o|contracted procedure: k19564 
o|inlining procedure: k19571 
o|contracted procedure: k19578 
o|contracted procedure: k19588 
o|contracted procedure: k19603 
o|contracted procedure: k19606 
o|inlining procedure: k19585 
o|inlining procedure: k19585 
o|contracted procedure: k19644 
o|contracted procedure: k19666 
o|contracted procedure: k19670 
o|contracted procedure: k19653 
o|contracted procedure: k19680 
o|contracted procedure: k19713 
o|contracted procedure: k19686 
o|contracted procedure: k19692 
o|inlining procedure: k19571 
o|contracted procedure: k19745 
o|contracted procedure: k19748 
o|contracted procedure: k19755 
o|contracted procedure: k19761 
o|contracted procedure: k19791 
o|contracted procedure: k6849 
o|contracted procedure: k6852 
o|contracted procedure: k6862 
o|contracted procedure: k19799 
o|contracted procedure: k19814 
o|contracted procedure: k19822 
o|contracted procedure: k19834 
o|contracted procedure: k19837 
o|contracted procedure: k19840 
o|contracted procedure: k19848 
o|contracted procedure: k19856 
o|contracted procedure: k19875 
o|contracted procedure: k19881 
o|contracted procedure: k19887 
o|contracted procedure: k19928 
o|contracted procedure: k19937 
o|contracted procedure: k19940 
o|contracted procedure: k19956 
o|contracted procedure: k19962 
o|contracted procedure: k19980 
o|contracted procedure: k20004 
o|contracted procedure: k19993 
o|contracted procedure: k20007 
o|contracted procedure: k20024 
o|contracted procedure: k20032 
o|contracted procedure: k20028 
o|contracted procedure: k20020 
o|contracted procedure: k20035 
o|contracted procedure: k20042 
o|contracted procedure: k20048 
o|contracted procedure: k20068 
o|contracted procedure: k20071 
o|contracted procedure: k20087 
o|contracted procedure: k20091 
o|contracted procedure: k20103 
o|contracted procedure: k20107 
o|contracted procedure: k20119 
o|contracted procedure: k20123 
o|contracted procedure: k20131 
o|contracted procedure: k20144 
o|contracted procedure: k20147 
o|contracted procedure: k20150 
o|contracted procedure: k20162 
o|contracted procedure: k20165 
o|contracted procedure: k20168 
o|contracted procedure: k20174 
o|contracted procedure: k20177 
o|contracted procedure: k20186 
o|contracted procedure: k20192 
o|contracted procedure: k20198 
o|contracted procedure: k20527 
o|contracted procedure: k20211 
o|contracted procedure: k20223 
o|contracted procedure: k20235 
o|inlining procedure: k20215 
o|contracted procedure: k20248 
o|contracted procedure: k20271 
o|contracted procedure: k20264 
o|contracted procedure: k20279 
o|inlining procedure: k20215 
o|contracted procedure: k20288 
o|contracted procedure: k20291 
o|contracted procedure: k20294 
o|contracted procedure: k20302 
o|contracted procedure: k20310 
o|contracted procedure: k20443 
o|contracted procedure: k20447 
o|contracted procedure: k20451 
o|contracted procedure: k20317 
o|inlining procedure: k20321 
o|contracted procedure: k20331 
o|contracted procedure: k20342 
o|contracted procedure: k20362 
o|contracted procedure: k20374 
o|contracted procedure: k20401 
o|contracted procedure: k20381 
o|contracted procedure: k20389 
o|contracted procedure: k20385 
o|contracted procedure: k20410 
o|contracted procedure: k20413 
o|contracted procedure: k20416 
o|contracted procedure: k20424 
o|contracted procedure: k20432 
o|contracted procedure: k20351 
o|contracted procedure: k20359 
o|inlining procedure: k20321 
o|contracted procedure: k20439 
o|contracted procedure: k20459 
o|contracted procedure: k20464 
o|contracted procedure: k20473 
o|contracted procedure: k20480 
o|contracted procedure: k20483 
o|contracted procedure: k20498 
o|contracted procedure: k20501 
o|contracted procedure: k20504 
o|contracted procedure: k20512 
o|contracted procedure: k20520 
o|contracted procedure: k20554 
o|contracted procedure: k20550 
o|contracted procedure: k20560 
o|contracted procedure: k20611 
o|contracted procedure: k20575 
o|contracted procedure: k20601 
o|contracted procedure: k20605 
o|contracted procedure: k20597 
o|contracted procedure: k20578 
o|contracted procedure: k20581 
o|contracted procedure: k20589 
o|contracted procedure: k20593 
o|contracted procedure: k20623 
o|contracted procedure: k20626 
o|contracted procedure: k20629 
o|contracted procedure: k20637 
o|contracted procedure: k20645 
o|contracted procedure: k20660 
o|contracted procedure: k20663 
o|contracted procedure: k20666 
o|contracted procedure: k20696 
o|contracted procedure: k20700 
o|contracted procedure: k20712 
o|contracted procedure: k20716 
o|contracted procedure: k20729 
o|contracted procedure: k20733 
o|contracted procedure: k20737 
o|contracted procedure: k20763 
o|contracted procedure: k20767 
o|contracted procedure: k20782 
o|contracted procedure: k20786 
o|contracted procedure: k20809 
o|contracted procedure: k20802 
o|contracted procedure: k20793 
o|contracted procedure: k20812 
o|contracted procedure: k20819 
o|contracted procedure: k20829 
o|contracted procedure: k20836 
o|contracted procedure: k20848 
o|inlining procedure: k20840 
o|inlining procedure: k20840 
o|contracted procedure: k20869 
o|contracted procedure: k20865 
o|contracted procedure: k20879 
o|contracted procedure: k20900 
o|contracted procedure: k20906 
o|contracted procedure: k20912 
o|contracted procedure: k20918 
o|contracted procedure: k20924 
o|contracted procedure: k20930 
o|contracted procedure: k20936 
o|contracted procedure: k20942 
o|contracted procedure: k20948 
o|contracted procedure: k20954 
o|contracted procedure: k20960 
o|contracted procedure: k20966 
o|contracted procedure: k20972 
o|contracted procedure: k20978 
o|contracted procedure: k20984 
o|contracted procedure: k20990 
o|contracted procedure: k21035 
o|contracted procedure: k21041 
o|contracted procedure: k21060 
o|contracted procedure: k21066 
o|contracted procedure: k21072 
o|contracted procedure: k21078 
o|contracted procedure: k21102 
o|contracted procedure: k21110 
o|contracted procedure: k21122 
o|contracted procedure: k21125 
o|contracted procedure: k21128 
o|contracted procedure: k21136 
o|contracted procedure: k21144 
o|contracted procedure: k21153 
o|contracted procedure: k21180 
o|contracted procedure: k21168 
o|contracted procedure: k21172 
o|contracted procedure: k21212 
o|contracted procedure: k21234 
o|contracted procedure: k21243 
o|contracted procedure: k21261 
o|contracted procedure: k21270 
o|contracted procedure: k21279 
o|contracted procedure: k21288 
o|contracted procedure: k21297 
o|contracted procedure: k21306 
o|contracted procedure: k21324 
o|contracted procedure: k21333 
o|contracted procedure: k21342 
o|contracted procedure: k21351 
o|contracted procedure: k21360 
o|contracted procedure: k21369 
o|contracted procedure: k21404 
o|contracted procedure: k21400 
o|contracted procedure: k21396 
o|contracted procedure: k21420 
o|contracted procedure: k21446 
o|contracted procedure: k21501 
o|contracted procedure: k21510 
o|contracted procedure: k21517 
o|contracted procedure: k21523 
o|contracted procedure: k21526 
o|contracted procedure: k21529 
o|contracted procedure: k21536 
o|contracted procedure: k21546 
o|contracted procedure: k21549 
o|contracted procedure: k21553 
o|contracted procedure: k21557 
o|contracted procedure: k21571 
o|contracted procedure: k21577 
o|contracted procedure: k21592 
o|contracted procedure: k21581 
o|contracted procedure: k21598 
o|contracted procedure: k21602 
o|contracted procedure: k21615 
o|contracted procedure: k21619 
o|contracted procedure: k21634 
o|contracted procedure: k21640 
o|contracted procedure: k21644 
o|contracted procedure: k21663 
o|contracted procedure: k21669 
o|contracted procedure: k21684 
o|contracted procedure: k21690 
o|contracted procedure: k21694 
o|contracted procedure: k21701 
o|contracted procedure: k21709 
o|contracted procedure: k21715 
o|contracted procedure: k21718 
o|contracted procedure: k21736 
o|contracted procedure: k21743 
o|contracted procedure: k21757 
o|contracted procedure: k21764 
o|contracted procedure: k21771 
o|contracted procedure: k21775 
o|contracted procedure: k21781 
o|contracted procedure: k21784 
o|contracted procedure: k21787 
o|contracted procedure: k21799 
o|contracted procedure: k21805 
o|contracted procedure: k21839 
o|contracted procedure: k21835 
o|contracted procedure: k21847 
o|contracted procedure: k21853 
o|contracted procedure: k21860 
o|contracted procedure: k21843 
o|contracted procedure: k21874 
o|contracted procedure: k21880 
o|contracted procedure: k21889 
o|contracted procedure: k21895 
o|contracted procedure: k21902 
o|contracted procedure: k21913 
o|contracted procedure: k21920 
o|inlining procedure: k21910 
o|inlining procedure: k21910 
o|contracted procedure: k21930 
o|contracted procedure: k21954 
o|contracted procedure: k21957 
o|contracted procedure: k21948 
o|contracted procedure: k21973 
o|contracted procedure: k21976 
o|contracted procedure: k21979 
o|contracted procedure: k22026 
o|contracted procedure: k21982 
o|contracted procedure: k21991 
o|contracted procedure: k21995 
o|contracted procedure: k22007 
o|contracted procedure: k22015 
o|contracted procedure: k22039 
o|contracted procedure: k22042 
o|contracted procedure: k22045 
o|contracted procedure: k22049 
o|contracted procedure: k22056 
o|contracted procedure: k22068 
o|contracted procedure: k22074 
o|contracted procedure: k22077 
o|contracted procedure: k22080 
o|contracted procedure: k22111 
o|contracted procedure: k22107 
o|contracted procedure: k22095 
o|contracted procedure: k22099 
o|contracted procedure: k22120 
o|contracted procedure: k22136 
o|contracted procedure: k22140 
o|contracted procedure: k22144 
o|contracted procedure: k22152 
o|contracted procedure: k22183 
o|contracted procedure: k22176 
o|contracted procedure: k22167 
o|contracted procedure: k22186 
o|contracted procedure: k22193 
o|contracted procedure: k22207 
o|contracted procedure: k22292 
o|contracted procedure: k22210 
o|contracted procedure: k22288 
o|contracted procedure: k22213 
o|contracted procedure: k22236 
o|contracted procedure: k22239 
o|contracted procedure: k22243 
o|contracted procedure: k22247 
o|contracted procedure: k22261 
o|contracted procedure: k22280 
o|contracted procedure: k22269 
o|contracted procedure: k22276 
o|contracted procedure: k22298 
o|contracted procedure: k22311 
o|contracted procedure: k22319 
o|contracted procedure: k22322 
o|contracted procedure: k22337 
o|contracted procedure: k22343 
o|contracted procedure: k22403 
o|contracted procedure: k22423 
o|contracted procedure: k22430 
o|contracted procedure: k22443 
o|contracted procedure: k22446 
o|contracted procedure: k22459 
o|contracted procedure: k22463 
o|contracted procedure: k22470 
o|contracted procedure: k22478 
o|contracted procedure: k22482 
o|contracted procedure: k22490 
o|contracted procedure: k22494 
o|contracted procedure: k22498 
o|contracted procedure: k22502 
o|contracted procedure: k22506 
o|contracted procedure: k22512 
o|contracted procedure: k22522 
o|contracted procedure: k22530 
o|contracted procedure: k22534 
o|contracted procedure: k22549 
o|contracted procedure: k22560 
o|contracted procedure: k22564 
o|contracted procedure: k22583 
o|contracted procedure: k22591 
o|contracted procedure: k22595 
o|contracted procedure: k22599 
o|contracted procedure: k22603 
o|contracted procedure: k22609 
o|contracted procedure: k22612 
o|contracted procedure: k22616 
o|contracted procedure: k22681 
o|contracted procedure: k22699 
o|contracted procedure: k22707 
o|contracted procedure: k22719 
o|contracted procedure: k22722 
o|contracted procedure: k22725 
o|contracted procedure: k22733 
o|contracted procedure: k22741 
o|contracted procedure: k22762 
o|contracted procedure: k22766 
o|contracted procedure: k22786 
o|contracted procedure: k7531 
o|contracted procedure: k7538 
o|contracted procedure: k7546 
o|contracted procedure: k22799 
o|contracted procedure: k22819 
o|contracted procedure: k7079 
o|contracted procedure: k7092 
o|contracted procedure: k7098 
o|contracted procedure: k22910 
o|contracted procedure: k22854 
o|propagated global variable: r22911 ##sys#undefined-value 
o|contracted procedure: k22867 
o|inlining procedure: k22864 
o|contracted procedure: k22876 
o|inlining procedure: k22864 
o|contracted procedure: k22885 
o|contracted procedure: k22894 
o|contracted procedure: k22900 
o|contracted procedure: k22960 
o|contracted procedure: k22956 
o|simplifications: ((##core#call . 2) (if . 9) (let . 463)) 
o|  call simplifications:
o|    scheme#+	2
o|removed binding forms: 1650 
o|contracted procedure: k10260 
o|contracted procedure: k12469 
o|contracted procedure: k13800 
o|contracted procedure: k15215 
o|inlining procedure: k12950 
o|inlining procedure: k12950 
o|inlining procedure: k12950 
o|inlining procedure: k13296 
o|inlining procedure: k13296 
o|inlining procedure: k15850 
o|inlining procedure: k16087 
o|inlining procedure: "(core.scm:2071) grow3779" 
o|inlining procedure: "(core.scm:2078) grow3779" 
o|inlining procedure: k17435 
o|inlining procedure: "(core.scm:2082) grow3779" 
o|inlining procedure: "(core.scm:2165) grow3779" 
o|inlining procedure: "(core.scm:2062) grow3779" 
o|inlining procedure: "(core.scm:2482) quick-put!3786" 
o|inlining procedure: "(core.scm:2461) quick-put!3786" 
o|inlining procedure: "(core.scm:2438) quick-put!3786" 
o|inlining procedure: "(core.scm:2438) quick-put!3786" 
o|inlining procedure: "(core.scm:2390) quick-put!3786" 
o|inlining procedure: "(core.scm:2390) quick-put!3786" 
o|inlining procedure: "(core.scm:2354) quick-put!3786" 
o|inlining procedure: "(core.scm:2355) quick-put!3786" 
o|inlining procedure: "(core.scm:2369) quick-put!3786" 
o|inlining procedure: "(core.scm:2369) quick-put!3786" 
o|inlining procedure: "(core.scm:2364) quick-put!3786" 
o|inlining procedure: "(core.scm:2382) quick-put!3786" 
o|inlining procedure: "(core.scm:2381) quick-put!3786" 
o|inlining procedure: "(core.scm:2339) quick-put!3786" 
o|inlining procedure: k19575 
o|inlining procedure: k19575 
o|inlining procedure: k19575 
o|inlining procedure: k19575 
o|inlining procedure: k19575 
o|contracted procedure: k21673 
o|simplifications: ((let . 4)) 
o|replaced variables: 14 
o|removed binding forms: 12 
o|substituted constant variable: n378726648 
o|substituted constant variable: n378726652 
o|substituted constant variable: n378726658 
o|substituted constant variable: n378726668 
o|substituted constant variable: n378726672 
o|substituted constant variable: prop404526679 
o|substituted constant variable: prop404526686 
o|substituted constant variable: prop404526693 
o|substituted constant variable: val404626694 
o|substituted constant variable: prop404526700 
o|substituted constant variable: val404626701 
o|contracted procedure: "(core.scm:2438) quick-put!3786" 
o|substituted constant variable: prop404526709 
o|substituted constant variable: val404626710 
o|substituted constant variable: prop404526716 
o|substituted constant variable: val404626717 
o|substituted constant variable: prop404526723 
o|substituted constant variable: val404626724 
o|substituted constant variable: prop404526730 
o|substituted constant variable: val404626731 
o|substituted constant variable: prop404526737 
o|substituted constant variable: val404626738 
o|substituted constant variable: prop404526744 
o|substituted constant variable: val404626745 
o|substituted constant variable: prop404526751 
o|substituted constant variable: val404626752 
o|substituted constant variable: prop404526758 
o|substituted constant variable: prop404526765 
o|substituted constant variable: val404626766 
o|substituted constant variable: prop404526772 
o|substituted constant variable: val404626773 
o|replaced variables: 51 
o|removed binding forms: 7 
o|inlining procedure: k17393 
o|inlining procedure: k18619 
o|inlining procedure: k18717 
o|substituted constant variable: prop4045 
o|substituted constant variable: val4046 
o|replaced variables: 3 
o|removed binding forms: 68 
o|contracted procedure: k17326 
o|contracted procedure: k17359 
o|contracted procedure: k17405 
o|contracted procedure: k17821 
o|contracted procedure: k19168 
o|removed binding forms: 13 
o|removed binding forms: 4 
o|direct leaf routine/allocation: a7246 0 
o|direct leaf routine/allocation: loop633 0 
o|direct leaf routine/allocation: g13721382 18 
o|direct leaf routine/allocation: g16521665 0 
o|direct leaf routine/allocation: loop1867 0 
o|direct leaf routine/allocation: g434435 3 
o|direct leaf routine/allocation: loop474 0 
o|direct leaf routine/allocation: grow3779 29 
o|direct leaf routine/allocation: g40664078 0 
o|direct leaf routine/allocation: g46484657 0 
o|direct leaf routine/allocation: g52055206 0 
o|direct leaf routine/allocation: loop644 0 
o|direct leaf routine/allocation: new-literal4933 32 
o|direct leaf routine/allocation: g52215222 0 
o|contracted procedure: "(mini-srfi-1.scm:88) k6691" 
o|converted assignments to bindings: (loop633) 
o|contracted procedure: "(core.scm:790) k9398" 
o|contracted procedure: "(core.scm:888) k10074" 
o|converted assignments to bindings: (loop1867) 
o|contracted procedure: k16896 
o|converted assignments to bindings: (loop474) 
o|contracted procedure: "(core.scm:2114) k17576" 
o|contracted procedure: "(core.scm:2127) k17645" 
o|contracted procedure: "(core.scm:2288) k19336" 
o|contracted procedure: "(core.scm:2695) k20516" 
o|contracted procedure: k22774 
o|converted assignments to bindings: (loop644) 
o|simplifications: ((let . 4)) 
o|removed binding forms: 9 
o|direct leaf routine/allocation: loop338 0 
o|direct leaf routine/allocation: for-each-loop16511668 0 
o|direct leaf routine/allocation: for-each-loop40654089 0 
o|contracted procedure: k7240 
o|converted assignments to bindings: (loop338) 
o|contracted procedure: k10018 
o|converted assignments to bindings: (for-each-loop16511668) 
o|contracted procedure: k18533 
o|converted assignments to bindings: (for-each-loop40654089) 
o|simplifications: ((let . 3)) 
o|removed binding forms: 3 
o|customizable procedures: (a22832 loop480 g51755184 map-loop51695187 k21504 loop5148 k22328 k22349 immediate-literal4935 k22301 k22216 k22264 k22223 k22226 k22126 k22129 g50775078 k21864 k21731 walk4930 va26246 k21532 mapwalk4931 walk-var4928 k21436 k21439 blockvar-literal4934 walk-global4929 literal4932 g49464947 g48054806 g47764785 map-loop47704788 k19931 k19965 k20051 k20675 g47624763 map-loop45854602 map-loop45644609 k20201 map-loop46424666 map-loop46874705 loop4681 g47214730 map-loop47154733 maptransform4297 transform4296 ref-var4298 k19421 g44284437 map-loop44224440 loop384 k19597 test4292 k19615 k19621 register-direct-call!4294 register-customizable!4293 g43804389 map-loop43744392 chicken.compiler.core#concatenate gather4295 k19257 g41054112 for-each-loop41044115 k19183 k18550 g41664167 k19098 k18973 k18556 g41934200 for-each-loop41924210 k18913 k18878 k18562 k18714 k18571 k18592 k18613 k18072 k18129 k18157 k18202 g40124013 mark-rest-null?3783 mark-rest-cdr3782 g39563963 for-each-loop39553966 k17335 g38873895 for-each-loop38863899 k17684 k17687 g38563863 for-each-loop38553866 assign3784 loop3841 k17445 walk3780 walkeach3781 ref3785 loop3751 walk-arguments3635 chicken.compiler.core#cons* k16483 k16805 walk-call3632 walk-inline-call3634 cps-lambda3629 node-for-var?3630 loop3676 walk3631 map-loop35123530 map-loop35403557 loop3359 map-loop34093429 map-loop33833400 k15806 map-loop34503471 g26292638 map-loop26232641 k8739 g25802581 g25732574 loop2545 macro-alias807 loop241 g24862495 map-loop24802499 a13755 g32563263 for-each-loop32553287 k15365 g32123219 for-each-loop32113248 k15173 k15256 for-each-loop31843202 for-each-loop31593177 for-each-loop31283146 k14968 k14861 map-loop30823107 for-each-loop30573075 for-each-loop30273045 for-each-loop30093019 for-each-loop29913001 for-each-loop29522970 for-each-loop29202938 chicken.compiler.core#lset-difference/eq? for-each-loop28892907 for-each-loop28642882 for-each-loop28122840 for-each-loop28222855 for-each-loop27602778 for-each-loop27852803 for-each-loop27352753 chicken.compiler.core#lset-intersection/eq? globalize-all2675 check-decl2673 chicken.compiler.core#lset-union/eq? foldr419422 g424425 globalize2674 a12809 note-local2676 k12461 k12327 k12241 k16234 map-loop35743592 map-loop36023619 chicken.compiler.core#create-foreign-stub chicken.compiler.core#expand-foreign-lambda* chicken.compiler.core#expand-foreign-lambda fold2296 map-loop22572274 mapwalk816 g22302239 map-loop22242242 unquotify812 k11552 g21432144 g21342135 map-loop20332050 k10690 g18501859 map-loop18441874 k11140 loop1929 tmp15768 tmp25769 doloop19591960 for-each-loop983993 chicken.compiler.core#delete k10708 k10729 g20012010 map-loop19952013 map-loop17981817 g17191728 map-loop17131734 for-each-loop17641775 for-each-loop17461757 k10341 k10250 k10138 map-loop16191637 map-loop15801598 map-loop14881505 k9727 chicken.compiler.core#posq k9631 g14461455 map-loop14401458 map-loop13091326 map-loop13391357 map-loop13661390 map-loop14021426 map-loop12491267 map-loop12761297 chicken.compiler.core#unzip1 map-loop11611178 set-real-names!810 g12011211 map-loop11951216 canonicalize-body/ln809 k8833 chicken.compiler.core#lset-adjoin/eq? g11011110 map-loop10951113 g10521053 resolve-variable813 g951952 g941942 g931932 g927928 g923924 walk815 for-each-loop868882 handle-expansion-result808 lookup806 k7786 find-id805 g777784 for-each-loop776795 chicken.compiler.core#every foldl545549 foldl529533 chicken.compiler.core#filter foldl507511 loop491 map-loop447465 foldr401404 g406407 loop364 loop357 loop351 loop325) 
o|calls to known targets: 864 
o|identified direct recursive calls: f_6713 1 
o|identified direct recursive calls: f_6741 1 
o|identified direct recursive calls: f_6892 1 
o|identified direct recursive calls: f_7009 1 
o|identified direct recursive calls: f_7108 2 
o|identified direct recursive calls: f_6683 1 
o|identified direct recursive calls: f_7219 2 
o|identified direct recursive calls: f_7492 1 
o|identified direct recursive calls: f_9146 1 
o|identified direct recursive calls: f_9180 1 
o|identified direct recursive calls: f_9323 1 
o|identified direct recursive calls: f_9371 1 
o|identified direct recursive calls: f_9419 1 
o|identified direct recursive calls: f_10066 1 
o|identified direct recursive calls: f_11153 1 
o|identified direct recursive calls: f_16276 1 
o|identified direct recursive calls: f_16310 1 
o|identified direct recursive calls: f_6936 1 
o|identified direct recursive calls: f_6440 1 
o|identified direct recursive calls: f_15702 3 
o|identified direct recursive calls: f_16160 1 
o|identified direct recursive calls: f_16194 1 
o|identified direct recursive calls: f_7049 1 
o|identified direct recursive calls: f_19328 1 
o|identified direct recursive calls: f_20369 1 
o|identified direct recursive calls: f_20493 1 
o|identified direct recursive calls: f_20570 1 
o|identified direct recursive calls: f_7526 1 
o|fast box initializations: 137 
o|fast global references: 90 
o|fast global assignments: 52 
o|dropping unused closure argument: f_11153 
o|dropping unused closure argument: f_13668 
o|dropping unused closure argument: f_13728 
o|dropping unused closure argument: f_15693 
o|dropping unused closure argument: f_16082 
o|dropping unused closure argument: f_16119 
o|dropping unused closure argument: f_16439 
o|dropping unused closure argument: f_17308 
o|dropping unused closure argument: f_21151 
o|dropping unused closure argument: f_22849 
o|dropping unused closure argument: f_6643 
o|dropping unused closure argument: f_6707 
o|dropping unused closure argument: f_6735 
o|dropping unused closure argument: f_6763 
o|dropping unused closure argument: f_6883 
o|dropping unused closure argument: f_6992 
o|dropping unused closure argument: f_7049 
o|dropping unused closure argument: f_7102 
o|dropping unused closure argument: f_7143 
o|dropping unused closure argument: f_7188 
o|dropping unused closure argument: f_7267 
o|dropping unused closure argument: f_7486 
o|dropping unused closure argument: f_7857 
o|dropping unused closure argument: f_7913 
*/
/* end of file */
